Class: Aws::SageMaker::Types::AIBenchmarkEndpoint

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The SageMaker endpoint configuration for benchmarking.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#identifierString

The name or Amazon Resource Name (ARN) of the SageMaker endpoint to benchmark.



112
113
114
115
116
117
118
# File 'lib/aws-sdk-sagemaker/types.rb', line 112

class AIBenchmarkEndpoint < Struct.new(
  :identifier,
  :target_container_hostname,
  :inference_components)
  SENSITIVE = []
  include Aws::Structure
end

#inference_componentsArray<Types::AIBenchmarkInferenceComponent>

The list of inference components to benchmark on the endpoint.



112
113
114
115
116
117
118
# File 'lib/aws-sdk-sagemaker/types.rb', line 112

class AIBenchmarkEndpoint < Struct.new(
  :identifier,
  :target_container_hostname,
  :inference_components)
  SENSITIVE = []
  include Aws::Structure
end

#target_container_hostnameString

The hostname of the specific container to target within a multi-container endpoint.



112
113
114
115
116
117
118
# File 'lib/aws-sdk-sagemaker/types.rb', line 112

class AIBenchmarkEndpoint < Struct.new(
  :identifier,
  :target_container_hostname,
  :inference_components)
  SENSITIVE = []
  include Aws::Structure
end