Class: Aws::SageMaker::Types::AIBenchmarkJobSummary

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Summary information about an AI benchmark job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ai_benchmark_job_arnString

The Amazon Resource Name (ARN) of the benchmark job.

Returns:

  • (String)


81
82
83
84
85
86
87
88
89
90
# File 'lib/aws-sdk-sagemaker/types.rb', line 81

class AIBenchmarkJobSummary < Struct.new(
  :ai_benchmark_job_name,
  :ai_benchmark_job_arn,
  :ai_benchmark_job_status,
  :creation_time,
  :end_time,
  :ai_workload_config_name)
  SENSITIVE = []
  include Aws::Structure
end

#ai_benchmark_job_nameString

The name of the benchmark job.

Returns:

  • (String)


81
82
83
84
85
86
87
88
89
90
# File 'lib/aws-sdk-sagemaker/types.rb', line 81

class AIBenchmarkJobSummary < Struct.new(
  :ai_benchmark_job_name,
  :ai_benchmark_job_arn,
  :ai_benchmark_job_status,
  :creation_time,
  :end_time,
  :ai_workload_config_name)
  SENSITIVE = []
  include Aws::Structure
end

#ai_benchmark_job_statusString

The status of the benchmark job.

Returns:

  • (String)


81
82
83
84
85
86
87
88
89
90
# File 'lib/aws-sdk-sagemaker/types.rb', line 81

class AIBenchmarkJobSummary < Struct.new(
  :ai_benchmark_job_name,
  :ai_benchmark_job_arn,
  :ai_benchmark_job_status,
  :creation_time,
  :end_time,
  :ai_workload_config_name)
  SENSITIVE = []
  include Aws::Structure
end

#ai_workload_config_nameString

The name of the AI workload configuration used by the benchmark job.

Returns:

  • (String)


81
82
83
84
85
86
87
88
89
90
# File 'lib/aws-sdk-sagemaker/types.rb', line 81

class AIBenchmarkJobSummary < Struct.new(
  :ai_benchmark_job_name,
  :ai_benchmark_job_arn,
  :ai_benchmark_job_status,
  :creation_time,
  :end_time,
  :ai_workload_config_name)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

A timestamp that indicates when the benchmark job was created.

Returns:

  • (Time)


81
82
83
84
85
86
87
88
89
90
# File 'lib/aws-sdk-sagemaker/types.rb', line 81

class AIBenchmarkJobSummary < Struct.new(
  :ai_benchmark_job_name,
  :ai_benchmark_job_arn,
  :ai_benchmark_job_status,
  :creation_time,
  :end_time,
  :ai_workload_config_name)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

A timestamp that indicates when the benchmark job completed.

Returns:

  • (Time)


81
82
83
84
85
86
87
88
89
90
# File 'lib/aws-sdk-sagemaker/types.rb', line 81

class AIBenchmarkJobSummary < Struct.new(
  :ai_benchmark_job_name,
  :ai_benchmark_job_arn,
  :ai_benchmark_job_status,
  :creation_time,
  :end_time,
  :ai_workload_config_name)
  SENSITIVE = []
  include Aws::Structure
end