Class: Aws::SageMaker::Types::AIBenchmarkTarget
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::AIBenchmarkTarget
- Includes:
- Aws::Structure, Aws::Structure::Union
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Note:
AIBenchmarkTarget is a union - when making an API calls you must set exactly one of the members.
Note:
AIBenchmarkTarget is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of AIBenchmarkTarget corresponding to the set member.
The target for an AI benchmark job. This is a union type — specify one of the members.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#endpoint ⇒ Types::AIBenchmarkEndpoint
The SageMaker endpoint to benchmark.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#endpoint ⇒ Types::AIBenchmarkEndpoint
The SageMaker endpoint to benchmark.
164 165 166 167 168 169 170 171 172 173 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 164 class AIBenchmarkTarget < Struct.new( :endpoint, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Endpoint < AIBenchmarkTarget; end class Unknown < AIBenchmarkTarget; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
164 165 166 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 164 def unknown @unknown end |