Class: Aws::SageMaker::Types::AIDatasetConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure, Aws::Structure::Union
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Note:

AIDatasetConfig is a union - when making an API calls you must set exactly one of the members.

Note:

AIDatasetConfig is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of AIDatasetConfig corresponding to the set member.

The dataset configuration for an AI workload. This is a union type — specify one of the members.

Defined Under Namespace

Classes: InputDataConfig, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#input_data_configArray<Types::AIWorkloadInputDataConfig>

An array of input data channel configurations for the workload.



308
309
310
311
312
313
314
315
316
317
# File 'lib/aws-sdk-sagemaker/types.rb', line 308

class AIDatasetConfig < Struct.new(
  :input_data_config,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class InputDataConfig < AIDatasetConfig; end
  class Unknown < AIDatasetConfig; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



308
309
310
# File 'lib/aws-sdk-sagemaker/types.rb', line 308

def unknown
  @unknown
end