Class: Aws::SageMaker::Types::AIModelSource

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure, Aws::Structure::Union
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Note:

AIModelSource is a union - when making an API calls you must set exactly one of the members.

Note:

AIModelSource is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of AIModelSource corresponding to the set member.

The source of the model for an AI recommendation job. This is a union type.

Direct Known Subclasses

S3, Unknown

Defined Under Namespace

Classes: S3, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#s3Types::AIModelSourceS3

The Amazon S3 location of the model artifacts.



240
241
242
243
244
245
246
247
248
249
# File 'lib/aws-sdk-sagemaker/types.rb', line 240

class AIModelSource < Struct.new(
  :s3,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class S3 < AIModelSource; end
  class Unknown < AIModelSource; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



240
241
242
# File 'lib/aws-sdk-sagemaker/types.rb', line 240

def unknown
  @unknown
end