Class: Aws::SageMaker::Types::AIRecommendationComputeSpec
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::AIRecommendationComputeSpec
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The compute resource specification for an AI recommendation job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_reservation_config ⇒ Types::AICapacityReservationConfig
The capacity reservation configuration.
-
#instance_types ⇒ Array<String>
The list of instance types to consider for recommendations.
Instance Attribute Details
#capacity_reservation_config ⇒ Types::AICapacityReservationConfig
The capacity reservation configuration.
320 321 322 323 324 325 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 320 class AIRecommendationComputeSpec < Struct.new( :instance_types, :capacity_reservation_config) SENSITIVE = [] include Aws::Structure end |
#instance_types ⇒ Array<String>
The list of instance types to consider for recommendations. You can specify up to 3 instance types.
320 321 322 323 324 325 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 320 class AIRecommendationComputeSpec < Struct.new( :instance_types, :capacity_reservation_config) SENSITIVE = [] include Aws::Structure end |