Class: Aws::SageMaker::Types::AIRecommendationJobSummary

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Summary information about an AI recommendation job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ai_recommendation_job_arnString

The Amazon Resource Name (ARN) of the recommendation job.

Returns:

  • (String)


500
501
502
503
504
505
506
507
508
# File 'lib/aws-sdk-sagemaker/types.rb', line 500

class AIRecommendationJobSummary < Struct.new(
  :ai_recommendation_job_name,
  :ai_recommendation_job_arn,
  :ai_recommendation_job_status,
  :creation_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#ai_recommendation_job_nameString

The name of the recommendation job.

Returns:

  • (String)


500
501
502
503
504
505
506
507
508
# File 'lib/aws-sdk-sagemaker/types.rb', line 500

class AIRecommendationJobSummary < Struct.new(
  :ai_recommendation_job_name,
  :ai_recommendation_job_arn,
  :ai_recommendation_job_status,
  :creation_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#ai_recommendation_job_statusString

The status of the recommendation job.

Returns:

  • (String)


500
501
502
503
504
505
506
507
508
# File 'lib/aws-sdk-sagemaker/types.rb', line 500

class AIRecommendationJobSummary < Struct.new(
  :ai_recommendation_job_name,
  :ai_recommendation_job_arn,
  :ai_recommendation_job_status,
  :creation_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

A timestamp that indicates when the recommendation job was created.

Returns:

  • (Time)


500
501
502
503
504
505
506
507
508
# File 'lib/aws-sdk-sagemaker/types.rb', line 500

class AIRecommendationJobSummary < Struct.new(
  :ai_recommendation_job_name,
  :ai_recommendation_job_arn,
  :ai_recommendation_job_status,
  :creation_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

A timestamp that indicates when the recommendation job completed.

Returns:

  • (Time)


500
501
502
503
504
505
506
507
508
# File 'lib/aws-sdk-sagemaker/types.rb', line 500

class AIRecommendationJobSummary < Struct.new(
  :ai_recommendation_job_name,
  :ai_recommendation_job_arn,
  :ai_recommendation_job_status,
  :creation_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end