Class: Aws::SageMaker::Types::AIRecommendationModelDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Details about the model package in a recommendation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#inference_specification_nameString

The name of the inference specification within the model package.

Returns:

  • (String)


527
528
529
530
531
532
533
# File 'lib/aws-sdk-sagemaker/types.rb', line 527

class AIRecommendationModelDetails < Struct.new(
  :model_package_arn,
  :inference_specification_name,
  :instance_details)
  SENSITIVE = []
  include Aws::Structure
end

#instance_detailsArray<Types::AIRecommendationInstanceDetail>

The instance details for this recommendation, including instance type, count, and model copies per instance.



527
528
529
530
531
532
533
# File 'lib/aws-sdk-sagemaker/types.rb', line 527

class AIRecommendationModelDetails < Struct.new(
  :model_package_arn,
  :inference_specification_name,
  :instance_details)
  SENSITIVE = []
  include Aws::Structure
end

#model_package_arnString

The Amazon Resource Name (ARN) of the model package.

Returns:

  • (String)


527
528
529
530
531
532
533
# File 'lib/aws-sdk-sagemaker/types.rb', line 527

class AIRecommendationModelDetails < Struct.new(
  :model_package_arn,
  :inference_specification_name,
  :instance_details)
  SENSITIVE = []
  include Aws::Structure
end