Class: Aws::SageMaker::Types::AIRecommendationOptimizationDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::AIRecommendationOptimizationDetail
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Details about an optimization technique applied in a recommendation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#optimization_config ⇒ Hash<String,String>
A map of configuration parameters for the optimization technique.
-
#optimization_type ⇒ String
The type of optimization.
Instance Attribute Details
#optimization_config ⇒ Hash<String,String>
A map of configuration parameters for the optimization technique.
511 512 513 514 515 516 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 511 class AIRecommendationOptimizationDetail < Struct.new( :optimization_type, :optimization_config) SENSITIVE = [] include Aws::Structure end |
#optimization_type ⇒ String
The type of optimization. Valid values are ‘SpeculativeDecoding` and `KernelTuning`.
511 512 513 514 515 516 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 511 class AIRecommendationOptimizationDetail < Struct.new( :optimization_type, :optimization_config) SENSITIVE = [] include Aws::Structure end |