Class: Aws::SageMaker::Types::AIRecommendationOutputResult

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The output configuration for an AI recommendation job, including the S3 location for results and the model package group for deployment.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#mlflow_configTypes::AIMlflowConfig

The MLflow tracking configuration for the job.



601
602
603
604
605
606
607
# File 'lib/aws-sdk-sagemaker/types.rb', line 601

class AIRecommendationOutputResult < Struct.new(
  :s3_output_location,
  :model_package_group_identifier,
  :mlflow_config)
  SENSITIVE = []
  include Aws::Structure
end

#model_package_group_identifierString

The name or Amazon Resource Name (ARN) of the model package group where deployment-ready model packages are registered.

Returns:

  • (String)


601
602
603
604
605
606
607
# File 'lib/aws-sdk-sagemaker/types.rb', line 601

class AIRecommendationOutputResult < Struct.new(
  :s3_output_location,
  :model_package_group_identifier,
  :mlflow_config)
  SENSITIVE = []
  include Aws::Structure
end

#s3_output_locationString

The Amazon S3 URI where the recommendation job writes its output results.

Returns:

  • (String)


601
602
603
604
605
606
607
# File 'lib/aws-sdk-sagemaker/types.rb', line 601

class AIRecommendationOutputResult < Struct.new(
  :s3_output_location,
  :model_package_group_identifier,
  :mlflow_config)
  SENSITIVE = []
  include Aws::Structure
end