Class: Aws::SageMaker::Types::AIRecommendationPerformanceTarget
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::AIRecommendationPerformanceTarget
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The performance targets for an AI recommendation job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#constraints ⇒ Array<Types::AIRecommendationConstraint>
An array of performance constraints that define the optimization objectives.
Instance Attribute Details
#constraints ⇒ Array<Types::AIRecommendationConstraint>
An array of performance constraints that define the optimization objectives.
599 600 601 602 603 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 599 class AIRecommendationPerformanceTarget < Struct.new( :constraints) SENSITIVE = [] include Aws::Structure end |