Class: Aws::SageMaker::Types::AIWorkloadConfigSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::AIWorkloadConfigSummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Summary information about an AI workload configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ai_workload_config_arn ⇒ String
The Amazon Resource Name (ARN) of the AI workload configuration.
-
#ai_workload_config_name ⇒ String
The name of the AI workload configuration.
-
#creation_time ⇒ Time
A timestamp that indicates when the configuration was created.
Instance Attribute Details
#ai_workload_config_arn ⇒ String
The Amazon Resource Name (ARN) of the AI workload configuration.
621 622 623 624 625 626 627 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 621 class AIWorkloadConfigSummary < Struct.new( :ai_workload_config_name, :ai_workload_config_arn, :creation_time) SENSITIVE = [] include Aws::Structure end |
#ai_workload_config_name ⇒ String
The name of the AI workload configuration.
621 622 623 624 625 626 627 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 621 class AIWorkloadConfigSummary < Struct.new( :ai_workload_config_name, :ai_workload_config_arn, :creation_time) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
A timestamp that indicates when the configuration was created.
621 622 623 624 625 626 627 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 621 class AIWorkloadConfigSummary < Struct.new( :ai_workload_config_name, :ai_workload_config_arn, :creation_time) SENSITIVE = [] include Aws::Structure end |