Class: Aws::SageMaker::Types::AddClusterNodeSpecification

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Specifies an instance group and the number of nodes to add to it.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#availability_zonesArray<String>

The availability zones in which to add nodes. Use this to target node placement in specific availability zones within a flexible instance group.

Returns:

  • (Array<String>)


191
192
193
194
195
196
197
198
# File 'lib/aws-sdk-sagemaker/types.rb', line 191

class AddClusterNodeSpecification < Struct.new(
  :instance_group_name,
  :increment_target_count_by,
  :availability_zones,
  :instance_types)
  SENSITIVE = []
  include Aws::Structure
end

#increment_target_count_byInteger

The number of nodes to add to the specified instance group. The total number of nodes across all instance groups in a single request cannot exceed 50.

Returns:

  • (Integer)


191
192
193
194
195
196
197
198
# File 'lib/aws-sdk-sagemaker/types.rb', line 191

class AddClusterNodeSpecification < Struct.new(
  :instance_group_name,
  :increment_target_count_by,
  :availability_zones,
  :instance_types)
  SENSITIVE = []
  include Aws::Structure
end

#instance_group_nameString

The name of the instance group to which you want to add nodes.

Returns:

  • (String)


191
192
193
194
195
196
197
198
# File 'lib/aws-sdk-sagemaker/types.rb', line 191

class AddClusterNodeSpecification < Struct.new(
  :instance_group_name,
  :increment_target_count_by,
  :availability_zones,
  :instance_types)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typesArray<String>

The instance types to use when adding nodes. Use this to target specific instance types within a flexible instance group.

Returns:

  • (Array<String>)


191
192
193
194
195
196
197
198
# File 'lib/aws-sdk-sagemaker/types.rb', line 191

class AddClusterNodeSpecification < Struct.new(
  :instance_group_name,
  :increment_target_count_by,
  :availability_zones,
  :instance_types)
  SENSITIVE = []
  include Aws::Structure
end