Class: Aws::SageMaker::Types::AddTagsInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#resource_arnString

The Amazon Resource Name (ARN) of the resource that you want to tag.

Returns:

  • (String)


1063
1064
1065
1066
1067
1068
# File 'lib/aws-sdk-sagemaker/types.rb', line 1063

class AddTagsInput < Struct.new(
  :resource_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

An array of key-value pairs. You can use tags to categorize your Amazon Web Services resources in different ways, for example, by purpose, owner, or environment. For more information, see Tagging Amazon Web Services Resources.

Returns:



1063
1064
1065
1066
1067
1068
# File 'lib/aws-sdk-sagemaker/types.rb', line 1063

class AddTagsInput < Struct.new(
  :resource_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end