Class: Aws::SageMaker::Types::AdditionalS3DataSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::AdditionalS3DataSource
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
A data source used for training or inference that is in addition to the input dataset or model data.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compression_type ⇒ String
The type of compression used for an additional data source used in inference or training.
-
#etag ⇒ String
The ETag associated with S3 URI.
-
#s3_data_type ⇒ String
The data type of the additional data source that you specify for use in inference or training.
-
#s3_uri ⇒ String
The uniform resource identifier (URI) used to identify an additional data source used in inference or training.
Instance Attribute Details
#compression_type ⇒ String
The type of compression used for an additional data source used in
inference or training. Specify None if your additional data source
is not compressed.
1195 1196 1197 1198 1199 1200 1201 1202 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 1195 class AdditionalS3DataSource < Struct.new( :s3_data_type, :s3_uri, :compression_type, :etag) SENSITIVE = [] include Aws::Structure end |
#etag ⇒ String
The ETag associated with S3 URI.
1195 1196 1197 1198 1199 1200 1201 1202 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 1195 class AdditionalS3DataSource < Struct.new( :s3_data_type, :s3_uri, :compression_type, :etag) SENSITIVE = [] include Aws::Structure end |
#s3_data_type ⇒ String
The data type of the additional data source that you specify for use in inference or training.
1195 1196 1197 1198 1199 1200 1201 1202 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 1195 class AdditionalS3DataSource < Struct.new( :s3_data_type, :s3_uri, :compression_type, :etag) SENSITIVE = [] include Aws::Structure end |
#s3_uri ⇒ String
The uniform resource identifier (URI) used to identify an additional data source used in inference or training.
1195 1196 1197 1198 1199 1200 1201 1202 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 1195 class AdditionalS3DataSource < Struct.new( :s3_data_type, :s3_uri, :compression_type, :etag) SENSITIVE = [] include Aws::Structure end |