Class: Aws::SageMaker::Types::AsyncInferenceClientConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Configures the behavior of the client used by SageMaker to interact with the model container during asynchronous inference.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_concurrent_invocations_per_instanceInteger

The maximum number of concurrent requests sent by the SageMaker client to the model container. If no value is provided, SageMaker chooses an optimal value.



2624
2625
2626
2627
2628
# File 'lib/aws-sdk-sagemaker/types.rb', line 2624

class AsyncInferenceClientConfig < Struct.new(
  :max_concurrent_invocations_per_instance)
  SENSITIVE = []
  include Aws::Structure
end