Class: Aws::SageMaker::Types::AsyncInferenceNotificationConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Specifies the configuration for notifications of inference results for asynchronous inference.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#error_topicString

Amazon SNS topic to post a notification to when inference fails. If no topic is provided, no notification is sent on failure.

Returns:



1558
1559
1560
1561
1562
1563
# File 'lib/aws-sdk-sagemaker/types.rb', line 1558

class AsyncInferenceNotificationConfig < Struct.new(
  :success_topic,
  :error_topic)
  SENSITIVE = []
  include Aws::Structure
end

#success_topicString

Amazon SNS topic to post a notification to when inference completes successfully. If no topic is provided, no notification is sent on success.

Returns:



1558
1559
1560
1561
1562
1563
# File 'lib/aws-sdk-sagemaker/types.rb', line 1558

class AsyncInferenceNotificationConfig < Struct.new(
  :success_topic,
  :error_topic)
  SENSITIVE = []
  include Aws::Structure
end