Class: Aws::SageMaker::Types::AsyncInferenceOutputConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::AsyncInferenceOutputConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Specifies the configuration for asynchronous inference invocation outputs.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#kms_key_id ⇒ String
The Amazon Web Services Key Management Service (Amazon Web Services KMS) key that SageMaker uses to encrypt the asynchronous inference output in Amazon S3.
-
#notification_config ⇒ Types::AsyncInferenceNotificationConfig
Specifies the configuration for notifications of inference results for asynchronous inference.
-
#s3_failure_path ⇒ String
The Amazon S3 location to upload failure inference responses to.
-
#s3_output_path ⇒ String
The Amazon S3 location to upload inference responses to.
Instance Attribute Details
#kms_key_id ⇒ String
The Amazon Web Services Key Management Service (Amazon Web Services KMS) key that SageMaker uses to encrypt the asynchronous inference output in Amazon S3.
2712 2713 2714 2715 2716 2717 2718 2719 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 2712 class AsyncInferenceOutputConfig < Struct.new( :kms_key_id, :s3_output_path, :notification_config, :s3_failure_path) SENSITIVE = [] include Aws::Structure end |
#notification_config ⇒ Types::AsyncInferenceNotificationConfig
Specifies the configuration for notifications of inference results for asynchronous inference.
2712 2713 2714 2715 2716 2717 2718 2719 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 2712 class AsyncInferenceOutputConfig < Struct.new( :kms_key_id, :s3_output_path, :notification_config, :s3_failure_path) SENSITIVE = [] include Aws::Structure end |
#s3_failure_path ⇒ String
The Amazon S3 location to upload failure inference responses to.
2712 2713 2714 2715 2716 2717 2718 2719 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 2712 class AsyncInferenceOutputConfig < Struct.new( :kms_key_id, :s3_output_path, :notification_config, :s3_failure_path) SENSITIVE = [] include Aws::Structure end |
#s3_output_path ⇒ String
The Amazon S3 location to upload inference responses to.
2712 2713 2714 2715 2716 2717 2718 2719 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 2712 class AsyncInferenceOutputConfig < Struct.new( :kms_key_id, :s3_output_path, :notification_config, :s3_failure_path) SENSITIVE = [] include Aws::Structure end |