Class: Aws::SageMaker::Types::AttachClusterNodeNetworkInterfaceRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_nameString

The name or Amazon Resource Name (ARN) of the SageMaker HyperPod cluster that contains the target node.

Returns:



2790
2791
2792
2793
2794
2795
2796
# File 'lib/aws-sdk-sagemaker/types.rb', line 2790

class AttachClusterNodeNetworkInterfaceRequest < Struct.new(
  :cluster_name,
  :node_id,
  :network_interface_id)
  SENSITIVE = []
  include Aws::Structure
end

#network_interface_idString

The unique identifier of the elastic network interface (ENI) to attach.

Returns:



2790
2791
2792
2793
2794
2795
2796
# File 'lib/aws-sdk-sagemaker/types.rb', line 2790

class AttachClusterNodeNetworkInterfaceRequest < Struct.new(
  :cluster_name,
  :node_id,
  :network_interface_id)
  SENSITIVE = []
  include Aws::Structure
end

#node_idString

The unique identifier of the cluster node to which you want to attach the network interface. The node must belong to your specified HyperPod cluster and cannot be part of a Restricted Instance Group (RIG).

Returns:



2790
2791
2792
2793
2794
2795
2796
# File 'lib/aws-sdk-sagemaker/types.rb', line 2790

class AttachClusterNodeNetworkInterfaceRequest < Struct.new(
  :cluster_name,
  :node_id,
  :network_interface_id)
  SENSITIVE = []
  include Aws::Structure
end