Class: Aws::SageMaker::Types::AttachClusterNodeNetworkInterfaceResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attachment_idString

The unique identifier of the network interface attachment. Use this value to reference or detach the network interface later.

Returns:

  • (String)


2820
2821
2822
2823
2824
2825
2826
2827
# File 'lib/aws-sdk-sagemaker/types.rb', line 2820

class AttachClusterNodeNetworkInterfaceResponse < Struct.new(
  :cluster_arn,
  :node_id,
  :network_interface_id,
  :attachment_id)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_arnString

The Amazon Resource Name (ARN) of your SageMaker HyperPod cluster where the network interface attachment operation was performed.

Returns:

  • (String)


2820
2821
2822
2823
2824
2825
2826
2827
# File 'lib/aws-sdk-sagemaker/types.rb', line 2820

class AttachClusterNodeNetworkInterfaceResponse < Struct.new(
  :cluster_arn,
  :node_id,
  :network_interface_id,
  :attachment_id)
  SENSITIVE = []
  include Aws::Structure
end

#network_interface_idString

The unique identifier of the elastic network interface (ENI) that was attached.

Returns:

  • (String)


2820
2821
2822
2823
2824
2825
2826
2827
# File 'lib/aws-sdk-sagemaker/types.rb', line 2820

class AttachClusterNodeNetworkInterfaceResponse < Struct.new(
  :cluster_arn,
  :node_id,
  :network_interface_id,
  :attachment_id)
  SENSITIVE = []
  include Aws::Structure
end

#node_idString

The unique identifier of the cluster node where your network interface was attached.

Returns:

  • (String)


2820
2821
2822
2823
2824
2825
2826
2827
# File 'lib/aws-sdk-sagemaker/types.rb', line 2820

class AttachClusterNodeNetworkInterfaceResponse < Struct.new(
  :cluster_arn,
  :node_id,
  :network_interface_id,
  :attachment_id)
  SENSITIVE = []
  include Aws::Structure
end