Class: Aws::SageMaker::Types::AttachClusterNodeVolumeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::AttachClusterNodeVolumeRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster_arn ⇒ String
The Amazon Resource Name (ARN) of your SageMaker HyperPod cluster containing the target node.
-
#node_id ⇒ String
The unique identifier of the cluster node to which you want to attach the volume.
-
#volume_id ⇒ String
The unique identifier of your EBS volume to attach.
Instance Attribute Details
#cluster_arn ⇒ String
The Amazon Resource Name (ARN) of your SageMaker HyperPod cluster
containing the target node. Your cluster must use EKS as the
orchestration and be in the InService state.
2792 2793 2794 2795 2796 2797 2798 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 2792 class AttachClusterNodeVolumeRequest < Struct.new( :cluster_arn, :node_id, :volume_id) SENSITIVE = [] include Aws::Structure end |
#node_id ⇒ String
The unique identifier of the cluster node to which you want to attach the volume. The node must belong to your specified HyperPod cluster and cannot be part of a Restricted Instance Group (RIG).
2792 2793 2794 2795 2796 2797 2798 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 2792 class AttachClusterNodeVolumeRequest < Struct.new( :cluster_arn, :node_id, :volume_id) SENSITIVE = [] include Aws::Structure end |
#volume_id ⇒ String
The unique identifier of your EBS volume to attach. The volume must
be in the available state.
2792 2793 2794 2795 2796 2797 2798 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 2792 class AttachClusterNodeVolumeRequest < Struct.new( :cluster_arn, :node_id, :volume_id) SENSITIVE = [] include Aws::Structure end |