Class: Aws::SageMaker::Types::AutoMLAlgorithmConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The selection of algorithms trained on your dataset to generate the model candidates for an Autopilot job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_ml_algorithmsArray<String>

The selection of algorithms trained on your dataset to generate the model candidates for an Autopilot job.

  • For the tabular problem type TabularJobConfig:

    Selected algorithms must belong to the list corresponding to the training mode set in AutoMLJobConfig.Mode (ENSEMBLING or HYPERPARAMETER_TUNING). Choose a minimum of 1 algorithm.

  • In ENSEMBLING mode:

    • "catboost"

    • "extra-trees"

    • "fastai"

    • "lightgbm"

    • "linear-learner"

    • "nn-torch"

    • "randomforest"

    • "xgboost"

  • In HYPERPARAMETER_TUNING mode:

    • "linear-learner"

    • "mlp"

    • "xgboost"

  • For the time-series forecasting problem type TimeSeriesForecastingJobConfig:

  • Choose your algorithms from this list.

    • "cnn-qr"

    • "deepar"

    • "prophet"

    • "arima"

    • "npts"

    • "ets"

Returns:

  • (Array<String>)


2805
2806
2807
2808
2809
# File 'lib/aws-sdk-sagemaker/types.rb', line 2805

class AutoMLAlgorithmConfig < Struct.new(
  :auto_ml_algorithms)
  SENSITIVE = []
  include Aws::Structure
end