Class: Aws::SageMaker::Types::AutoMLCandidateGenerationConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Stores the config information for how a candidate is generated (optional).

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#feature_specification_s3_uriString

A URL to the Amazon S3 data source containing selected features from the input data source to run an Autopilot job. You can input FeatureAttributeNames (optional) in JSON format as shown below:

‘{ “FeatureAttributeNames”:[“col1”, “col2”, …] }`.

You can also specify the data type of the feature (optional) in the format shown below:

‘{ “FeatureDataTypes”:{“col1”:“numeric”, “col2”:“categorical” … } }`

<note markdown=“1”> These column keys may not include the target column.

</note>

In ensembling mode, Autopilot will only support the following data types: numeric, categorical, text and datetime. In HPO mode, Autopilot can support numeric, categorical, text, datetime and sequence.

If only FeatureDataTypes is provided, the column keys (col1, col2,..) should be a subset of the column names in the input data.

If both FeatureDataTypes and FeatureAttributeNames are provided, then the column keys should be a subset of the column names provided in FeatureAttributeNames.

The key name FeatureAttributeNames is fixed. The values listed in ‘[“col1”, “col2”, …]` is case sensitive and should be a list of strings containing unique values that are a subset of the column names in the input data. The list of columns provided must not include the target column.

Returns:

  • (String)


1751
1752
1753
1754
1755
# File 'lib/aws-sdk-sagemaker/types.rb', line 1751

class AutoMLCandidateGenerationConfig < Struct.new(
  :feature_specification_s3_uri)
  SENSITIVE = []
  include Aws::Structure
end