Class: Aws::SageMaker::Types::AutoMLChannel

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

A channel is a named input source that training algorithms can consume. The validation dataset size is limited to less than 2 GB. The training dataset size must be less than 100 GB. For more information, see .

<note markdown=“1”> A validation dataset must contain the same headers as the training dataset.

</note>

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#channel_typeString

The channel type (optional) is an enum string. The default value is training. Channels for training and validation must share the same ContentType and TargetAttributeName. For information on specifying training and validation channel types, see [ ‘How to specify training and validation datasets` ][1].

[1]: docs.aws.amazon.com/sagemaker/latest/dg/autopilot-datasets-problem-types.html#autopilot-data-sources-training-or-validation

Returns:

  • (String)


1826
1827
1828
1829
1830
1831
1832
1833
1834
# File 'lib/aws-sdk-sagemaker/types.rb', line 1826

class AutoMLChannel < Struct.new(
  :data_source,
  :compression_type,
  :target_attribute_name,
  :content_type,
  :channel_type)
  SENSITIVE = []
  include Aws::Structure
end

#compression_typeString

You can use Gzip or None. The default value is None.

Returns:

  • (String)


1826
1827
1828
1829
1830
1831
1832
1833
1834
# File 'lib/aws-sdk-sagemaker/types.rb', line 1826

class AutoMLChannel < Struct.new(
  :data_source,
  :compression_type,
  :target_attribute_name,
  :content_type,
  :channel_type)
  SENSITIVE = []
  include Aws::Structure
end

#content_typeString

The content type of the data from the input source. You can use ‘text/csv;header=present` or `x-application/vnd.amazon+parquet`. The default value is `text/csv;header=present`.

Returns:

  • (String)


1826
1827
1828
1829
1830
1831
1832
1833
1834
# File 'lib/aws-sdk-sagemaker/types.rb', line 1826

class AutoMLChannel < Struct.new(
  :data_source,
  :compression_type,
  :target_attribute_name,
  :content_type,
  :channel_type)
  SENSITIVE = []
  include Aws::Structure
end

#data_sourceTypes::AutoMLDataSource

The data source for an AutoML channel.



1826
1827
1828
1829
1830
1831
1832
1833
1834
# File 'lib/aws-sdk-sagemaker/types.rb', line 1826

class AutoMLChannel < Struct.new(
  :data_source,
  :compression_type,
  :target_attribute_name,
  :content_type,
  :channel_type)
  SENSITIVE = []
  include Aws::Structure
end

#target_attribute_nameString

The name of the target variable in supervised learning, usually represented by ‘y’.

Returns:

  • (String)


1826
1827
1828
1829
1830
1831
1832
1833
1834
# File 'lib/aws-sdk-sagemaker/types.rb', line 1826

class AutoMLChannel < Struct.new(
  :data_source,
  :compression_type,
  :target_attribute_name,
  :content_type,
  :channel_type)
  SENSITIVE = []
  include Aws::Structure
end