Class: Aws::SageMaker::Types::AutoMLProblemTypeConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::AutoMLProblemTypeConfig
- Includes:
- Aws::Structure, Aws::Structure::Union
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
AutoMLProblemTypeConfig is a union - when making an API calls you must set exactly one of the members.
AutoMLProblemTypeConfig is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of AutoMLProblemTypeConfig corresponding to the set member.
A collection of settings specific to the problem type used to configure an AutoML job V2. There must be one and only one config of the following type.
Defined Under Namespace
Classes: ImageClassificationJobConfig, TabularJobConfig, TextClassificationJobConfig, TextGenerationJobConfig, TimeSeriesForecastingJobConfig, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#image_classification_job_config ⇒ Types::ImageClassificationJobConfig
Settings used to configure an AutoML job V2 for the image classification problem type.
-
#tabular_job_config ⇒ Types::TabularJobConfig
Settings used to configure an AutoML job V2 for the tabular problem type (regression, classification).
-
#text_classification_job_config ⇒ Types::TextClassificationJobConfig
Settings used to configure an AutoML job V2 for the text classification problem type.
-
#text_generation_job_config ⇒ Types::TextGenerationJobConfig
Settings used to configure an AutoML job V2 for the text generation (LLMs fine-tuning) problem type.
-
#time_series_forecasting_job_config ⇒ Types::TimeSeriesForecastingJobConfig
Settings used to configure an AutoML job V2 for the time-series forecasting problem type.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#image_classification_job_config ⇒ Types::ImageClassificationJobConfig
Settings used to configure an AutoML job V2 for the image classification problem type.
3744 3745 3746 3747 3748 3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 3744 class AutoMLProblemTypeConfig < Struct.new( :image_classification_job_config, :text_classification_job_config, :time_series_forecasting_job_config, :tabular_job_config, :text_generation_job_config, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ImageClassificationJobConfig < AutoMLProblemTypeConfig; end class TextClassificationJobConfig < AutoMLProblemTypeConfig; end class TimeSeriesForecastingJobConfig < AutoMLProblemTypeConfig; end class TabularJobConfig < AutoMLProblemTypeConfig; end class TextGenerationJobConfig < AutoMLProblemTypeConfig; end class Unknown < AutoMLProblemTypeConfig; end end |
#tabular_job_config ⇒ Types::TabularJobConfig
Settings used to configure an AutoML job V2 for the tabular problem type (regression, classification).
3744 3745 3746 3747 3748 3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 3744 class AutoMLProblemTypeConfig < Struct.new( :image_classification_job_config, :text_classification_job_config, :time_series_forecasting_job_config, :tabular_job_config, :text_generation_job_config, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ImageClassificationJobConfig < AutoMLProblemTypeConfig; end class TextClassificationJobConfig < AutoMLProblemTypeConfig; end class TimeSeriesForecastingJobConfig < AutoMLProblemTypeConfig; end class TabularJobConfig < AutoMLProblemTypeConfig; end class TextGenerationJobConfig < AutoMLProblemTypeConfig; end class Unknown < AutoMLProblemTypeConfig; end end |
#text_classification_job_config ⇒ Types::TextClassificationJobConfig
Settings used to configure an AutoML job V2 for the text classification problem type.
3744 3745 3746 3747 3748 3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 3744 class AutoMLProblemTypeConfig < Struct.new( :image_classification_job_config, :text_classification_job_config, :time_series_forecasting_job_config, :tabular_job_config, :text_generation_job_config, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ImageClassificationJobConfig < AutoMLProblemTypeConfig; end class TextClassificationJobConfig < AutoMLProblemTypeConfig; end class TimeSeriesForecastingJobConfig < AutoMLProblemTypeConfig; end class TabularJobConfig < AutoMLProblemTypeConfig; end class TextGenerationJobConfig < AutoMLProblemTypeConfig; end class Unknown < AutoMLProblemTypeConfig; end end |
#text_generation_job_config ⇒ Types::TextGenerationJobConfig
Settings used to configure an AutoML job V2 for the text generation (LLMs fine-tuning) problem type.
3744 3745 3746 3747 3748 3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 3744 class AutoMLProblemTypeConfig < Struct.new( :image_classification_job_config, :text_classification_job_config, :time_series_forecasting_job_config, :tabular_job_config, :text_generation_job_config, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ImageClassificationJobConfig < AutoMLProblemTypeConfig; end class TextClassificationJobConfig < AutoMLProblemTypeConfig; end class TimeSeriesForecastingJobConfig < AutoMLProblemTypeConfig; end class TabularJobConfig < AutoMLProblemTypeConfig; end class TextGenerationJobConfig < AutoMLProblemTypeConfig; end class Unknown < AutoMLProblemTypeConfig; end end |
#time_series_forecasting_job_config ⇒ Types::TimeSeriesForecastingJobConfig
Settings used to configure an AutoML job V2 for the time-series forecasting problem type.
3744 3745 3746 3747 3748 3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 3744 class AutoMLProblemTypeConfig < Struct.new( :image_classification_job_config, :text_classification_job_config, :time_series_forecasting_job_config, :tabular_job_config, :text_generation_job_config, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ImageClassificationJobConfig < AutoMLProblemTypeConfig; end class TextClassificationJobConfig < AutoMLProblemTypeConfig; end class TimeSeriesForecastingJobConfig < AutoMLProblemTypeConfig; end class TabularJobConfig < AutoMLProblemTypeConfig; end class TextGenerationJobConfig < AutoMLProblemTypeConfig; end class Unknown < AutoMLProblemTypeConfig; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
3744 3745 3746 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 3744 def unknown @unknown end |