Class: Aws::SageMaker::Types::AutoParameter

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The name and an example value of the hyperparameter that you want to use in Autotune. If Automatic model tuning (AMT) determines that your hyperparameter is eligible for Autotune, an optimal hyperparameter range is selected for you.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

The name of the hyperparameter to optimize using Autotune.

Returns:

  • (String)


3920
3921
3922
3923
3924
3925
# File 'lib/aws-sdk-sagemaker/types.rb', line 3920

class AutoParameter < Struct.new(
  :name,
  :value_hint)
  SENSITIVE = []
  include Aws::Structure
end

#value_hintString

An example value of the hyperparameter to optimize using Autotune.

Returns:

  • (String)


3920
3921
3922
3923
3924
3925
# File 'lib/aws-sdk-sagemaker/types.rb', line 3920

class AutoParameter < Struct.new(
  :name,
  :value_hint)
  SENSITIVE = []
  include Aws::Structure
end