Class: Aws::SageMaker::Types::AvailableUpgrade
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::AvailableUpgrade
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Contains information about an available upgrade for a SageMaker Partner AI App, including the version number and release notes.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#release_notes ⇒ Array<String>
A list of release notes describing the changes and improvements included in the available upgrade version.
-
#version ⇒ String
The semantic version number of the available upgrade for the SageMaker Partner AI App.
Instance Attribute Details
#release_notes ⇒ Array<String>
A list of release notes describing the changes and improvements included in the available upgrade version.
3158 3159 3160 3161 3162 3163 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 3158 class AvailableUpgrade < Struct.new( :version, :release_notes) SENSITIVE = [] include Aws::Structure end |
#version ⇒ String
The semantic version number of the available upgrade for the SageMaker Partner AI App.
3158 3159 3160 3161 3162 3163 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 3158 class AvailableUpgrade < Struct.new( :version, :release_notes) SENSITIVE = [] include Aws::Structure end |