Class: Aws::SageMaker::Types::BatchAddClusterNodesResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#failedArray<Types::BatchAddClusterNodesError>

A list of errors that occurred during the node addition operation. Each entry includes the instance group name, error code, number of failed additions, and an error message.



4129
4130
4131
4132
4133
4134
# File 'lib/aws-sdk-sagemaker/types.rb', line 4129

class BatchAddClusterNodesResponse < Struct.new(
  :successful,
  :failed)
  SENSITIVE = []
  include Aws::Structure
end

#successfulArray<Types::NodeAdditionResult>

A list of NodeLogicalIDs that were successfully added to the cluster. The NodeLogicalID is unique per cluster and does not change between instance replacements. Each entry includes a NodeLogicalId that can be used to track the node's provisioning status (with DescribeClusterNode), the instance group name, and the current status of the node.

Returns:



4129
4130
4131
4132
4133
4134
# File 'lib/aws-sdk-sagemaker/types.rb', line 4129

class BatchAddClusterNodesResponse < Struct.new(
  :successful,
  :failed)
  SENSITIVE = []
  include Aws::Structure
end