Class: Aws::SageMaker::Types::BatchDataCaptureConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::BatchDataCaptureConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Configuration to control how SageMaker captures inference data for batch transform jobs.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destination_s3_uri ⇒ String
The Amazon S3 location being used to capture the data.
-
#generate_inference_id ⇒ Boolean
Flag that indicates whether to append inference id to the output.
-
#kms_key_id ⇒ String
The Amazon Resource Name (ARN) of a Amazon Web Services Key Management Service key that SageMaker uses to encrypt data on the storage volume attached to the ML compute instance that hosts the batch transform job.
Instance Attribute Details
#destination_s3_uri ⇒ String
The Amazon S3 location being used to capture the data.
2418 2419 2420 2421 2422 2423 2424 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 2418 class BatchDataCaptureConfig < Struct.new( :destination_s3_uri, :kms_key_id, :generate_inference_id) SENSITIVE = [] include Aws::Structure end |
#generate_inference_id ⇒ Boolean
Flag that indicates whether to append inference id to the output.
2418 2419 2420 2421 2422 2423 2424 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 2418 class BatchDataCaptureConfig < Struct.new( :destination_s3_uri, :kms_key_id, :generate_inference_id) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The Amazon Resource Name (ARN) of a Amazon Web Services Key Management Service key that SageMaker uses to encrypt data on the storage volume attached to the ML compute instance that hosts the batch transform job.
The KmsKeyId can be any of the following formats:
-
Key ID:
1234abcd-12ab-34cd-56ef-1234567890ab -
Key ARN:
arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab -
Alias name:
alias/ExampleAlias -
Alias name ARN:
arn:aws:kms:us-west-2:111122223333:alias/ExampleAlias
2418 2419 2420 2421 2422 2423 2424 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 2418 class BatchDataCaptureConfig < Struct.new( :destination_s3_uri, :kms_key_id, :generate_inference_id) SENSITIVE = [] include Aws::Structure end |