Class: Aws::SageMaker::Types::BatchDeleteClusterNodesError

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Represents an error encountered when deleting a node from a SageMaker HyperPod cluster.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#codeString

The error code associated with the error encountered when deleting a node.

The code provides information about the specific issue encountered, such as the node not being found, the node’s status being invalid for deletion, or the node ID being in use by another process.

Returns:

  • (String)


4103
4104
4105
4106
4107
4108
4109
# File 'lib/aws-sdk-sagemaker/types.rb', line 4103

class BatchDeleteClusterNodesError < Struct.new(
  :code,
  :message,
  :node_id)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

A message describing the error encountered when deleting a node.

Returns:

  • (String)


4103
4104
4105
4106
4107
4108
4109
# File 'lib/aws-sdk-sagemaker/types.rb', line 4103

class BatchDeleteClusterNodesError < Struct.new(
  :code,
  :message,
  :node_id)
  SENSITIVE = []
  include Aws::Structure
end

#node_idString

The ID of the node that encountered an error during the deletion process.

Returns:

  • (String)


4103
4104
4105
4106
4107
4108
4109
# File 'lib/aws-sdk-sagemaker/types.rb', line 4103

class BatchDeleteClusterNodesError < Struct.new(
  :code,
  :message,
  :node_id)
  SENSITIVE = []
  include Aws::Structure
end