Class: Aws::SageMaker::Types::BatchDeleteClusterNodesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::BatchDeleteClusterNodesRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster_name ⇒ String
The name of the SageMaker HyperPod cluster from which to delete the specified nodes.
-
#node_ids ⇒ Array<String>
A list of node IDs to be deleted from the specified cluster.
-
#node_logical_ids ⇒ Array<String>
A list of
NodeLogicalIdsidentifying the nodes to be deleted.
Instance Attribute Details
#cluster_name ⇒ String
The name of the SageMaker HyperPod cluster from which to delete the specified nodes.
4264 4265 4266 4267 4268 4269 4270 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 4264 class BatchDeleteClusterNodesRequest < Struct.new( :cluster_name, :node_ids, :node_logical_ids) SENSITIVE = [] include Aws::Structure end |
#node_ids ⇒ Array<String>
A list of node IDs to be deleted from the specified cluster.
- If you need to delete more than 99 instances, contact Support for assistance.
4264 4265 4266 4267 4268 4269 4270 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 4264 class BatchDeleteClusterNodesRequest < Struct.new( :cluster_name, :node_ids, :node_logical_ids) SENSITIVE = [] include Aws::Structure end |
#node_logical_ids ⇒ Array<String>
A list of NodeLogicalIds identifying the nodes to be deleted. You
can specify up to 50 NodeLogicalIds. You must specify either
NodeLogicalIds, InstanceIds, or both, with a combined maximum of
50 identifiers.
4264 4265 4266 4267 4268 4269 4270 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 4264 class BatchDeleteClusterNodesRequest < Struct.new( :cluster_name, :node_ids, :node_logical_ids) SENSITIVE = [] include Aws::Structure end |