Class: Aws::SageMaker::Types::BatchDescribeModelPackageSummary

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Provides summary information about the model package.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timeTime

The creation time of the mortgage package summary.

Returns:

  • (Time)


3542
3543
3544
3545
3546
3547
3548
3549
3550
3551
3552
3553
3554
# File 'lib/aws-sdk-sagemaker/types.rb', line 3542

class BatchDescribeModelPackageSummary < Struct.new(
  :model_package_group_name,
  :model_package_version,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :model_package_status,
  :model_approval_status,
  :model_package_registration_type)
  SENSITIVE = []
  include Aws::Structure
end

#inference_specificationTypes::InferenceSpecification

Defines how to perform inference generation after a training job is run.



3542
3543
3544
3545
3546
3547
3548
3549
3550
3551
3552
3553
3554
# File 'lib/aws-sdk-sagemaker/types.rb', line 3542

class BatchDescribeModelPackageSummary < Struct.new(
  :model_package_group_name,
  :model_package_version,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :model_package_status,
  :model_approval_status,
  :model_package_registration_type)
  SENSITIVE = []
  include Aws::Structure
end

#model_approval_statusString

The approval status of the model.

Returns:

  • (String)


3542
3543
3544
3545
3546
3547
3548
3549
3550
3551
3552
3553
3554
# File 'lib/aws-sdk-sagemaker/types.rb', line 3542

class BatchDescribeModelPackageSummary < Struct.new(
  :model_package_group_name,
  :model_package_version,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :model_package_status,
  :model_approval_status,
  :model_package_registration_type)
  SENSITIVE = []
  include Aws::Structure
end

#model_package_arnString

The Amazon Resource Name (ARN) of the model package.

Returns:

  • (String)


3542
3543
3544
3545
3546
3547
3548
3549
3550
3551
3552
3553
3554
# File 'lib/aws-sdk-sagemaker/types.rb', line 3542

class BatchDescribeModelPackageSummary < Struct.new(
  :model_package_group_name,
  :model_package_version,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :model_package_status,
  :model_approval_status,
  :model_package_registration_type)
  SENSITIVE = []
  include Aws::Structure
end

#model_package_descriptionString

The description of the model package.

Returns:

  • (String)


3542
3543
3544
3545
3546
3547
3548
3549
3550
3551
3552
3553
3554
# File 'lib/aws-sdk-sagemaker/types.rb', line 3542

class BatchDescribeModelPackageSummary < Struct.new(
  :model_package_group_name,
  :model_package_version,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :model_package_status,
  :model_approval_status,
  :model_package_registration_type)
  SENSITIVE = []
  include Aws::Structure
end

#model_package_group_nameString

The group name for the model package

Returns:

  • (String)


3542
3543
3544
3545
3546
3547
3548
3549
3550
3551
3552
3553
3554
# File 'lib/aws-sdk-sagemaker/types.rb', line 3542

class BatchDescribeModelPackageSummary < Struct.new(
  :model_package_group_name,
  :model_package_version,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :model_package_status,
  :model_approval_status,
  :model_package_registration_type)
  SENSITIVE = []
  include Aws::Structure
end

#model_package_registration_typeString

The package registration type of the model package summary.

Returns:

  • (String)


3542
3543
3544
3545
3546
3547
3548
3549
3550
3551
3552
3553
3554
# File 'lib/aws-sdk-sagemaker/types.rb', line 3542

class BatchDescribeModelPackageSummary < Struct.new(
  :model_package_group_name,
  :model_package_version,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :model_package_status,
  :model_approval_status,
  :model_package_registration_type)
  SENSITIVE = []
  include Aws::Structure
end

#model_package_statusString

The status of the mortgage package.

Returns:

  • (String)


3542
3543
3544
3545
3546
3547
3548
3549
3550
3551
3552
3553
3554
# File 'lib/aws-sdk-sagemaker/types.rb', line 3542

class BatchDescribeModelPackageSummary < Struct.new(
  :model_package_group_name,
  :model_package_version,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :model_package_status,
  :model_approval_status,
  :model_package_registration_type)
  SENSITIVE = []
  include Aws::Structure
end

#model_package_versionInteger

The version number of a versioned model.

Returns:

  • (Integer)


3542
3543
3544
3545
3546
3547
3548
3549
3550
3551
3552
3553
3554
# File 'lib/aws-sdk-sagemaker/types.rb', line 3542

class BatchDescribeModelPackageSummary < Struct.new(
  :model_package_group_name,
  :model_package_version,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :model_package_status,
  :model_approval_status,
  :model_package_registration_type)
  SENSITIVE = []
  include Aws::Structure
end