Class: Aws::SageMaker::Types::BatchRebootClusterNodesResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#failedArray<Types::BatchRebootClusterNodesError>

A list of errors encountered for EC2 instance IDs that could not be rebooted. Each error includes the instance ID, an error code, and a descriptive message.



4616
4617
4618
4619
4620
4621
4622
4623
# File 'lib/aws-sdk-sagemaker/types.rb', line 4616

class BatchRebootClusterNodesResponse < Struct.new(
  :successful,
  :failed,
  :failed_node_logical_ids,
  :successful_node_logical_ids)
  SENSITIVE = []
  include Aws::Structure
end

#failed_node_logical_idsArray<Types::BatchRebootClusterNodeLogicalIdsError>

A list of errors encountered for logical node IDs that could not be rebooted. Each error includes the logical node ID, an error code, and a descriptive message. This field is only present when NodeLogicalIds were provided in the request.



4616
4617
4618
4619
4620
4621
4622
4623
# File 'lib/aws-sdk-sagemaker/types.rb', line 4616

class BatchRebootClusterNodesResponse < Struct.new(
  :successful,
  :failed,
  :failed_node_logical_ids,
  :successful_node_logical_ids)
  SENSITIVE = []
  include Aws::Structure
end

#successfulArray<String>

A list of EC2 instance IDs for which the reboot operation was successfully initiated.



4616
4617
4618
4619
4620
4621
4622
4623
# File 'lib/aws-sdk-sagemaker/types.rb', line 4616

class BatchRebootClusterNodesResponse < Struct.new(
  :successful,
  :failed,
  :failed_node_logical_ids,
  :successful_node_logical_ids)
  SENSITIVE = []
  include Aws::Structure
end

#successful_node_logical_idsArray<String>

A list of logical node IDs for which the reboot operation was successfully initiated. This field is only present when NodeLogicalIds were provided in the request.



4616
4617
4618
4619
4620
4621
4622
4623
# File 'lib/aws-sdk-sagemaker/types.rb', line 4616

class BatchRebootClusterNodesResponse < Struct.new(
  :successful,
  :failed,
  :failed_node_logical_ids,
  :successful_node_logical_ids)
  SENSITIVE = []
  include Aws::Structure
end