Class: Aws::SageMaker::Types::BatchReplaceClusterNodesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::BatchReplaceClusterNodesResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#failed ⇒ Array<Types::BatchReplaceClusterNodesError>
A list of errors encountered for EC2 instance IDs that could not be replaced.
-
#failed_node_logical_ids ⇒ Array<Types::BatchReplaceClusterNodeLogicalIdsError>
A list of errors encountered for logical node IDs that could not be replaced.
-
#successful ⇒ Array<String>
A list of EC2 instance IDs for which the replacement operation was successfully initiated.
-
#successful_node_logical_ids ⇒ Array<String>
A list of logical node IDs for which the replacement operation was successfully initiated.
Instance Attribute Details
#failed ⇒ Array<Types::BatchReplaceClusterNodesError>
A list of errors encountered for EC2 instance IDs that could not be replaced. Each error includes the instance ID, an error code, and a descriptive message.
4737 4738 4739 4740 4741 4742 4743 4744 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 4737 class BatchReplaceClusterNodesResponse < Struct.new( :successful, :failed, :failed_node_logical_ids, :successful_node_logical_ids) SENSITIVE = [] include Aws::Structure end |
#failed_node_logical_ids ⇒ Array<Types::BatchReplaceClusterNodeLogicalIdsError>
A list of errors encountered for logical node IDs that could not be
replaced. Each error includes the logical node ID, an error code,
and a descriptive message. This field is only present when
NodeLogicalIds were provided in the request.
4737 4738 4739 4740 4741 4742 4743 4744 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 4737 class BatchReplaceClusterNodesResponse < Struct.new( :successful, :failed, :failed_node_logical_ids, :successful_node_logical_ids) SENSITIVE = [] include Aws::Structure end |
#successful ⇒ Array<String>
A list of EC2 instance IDs for which the replacement operation was successfully initiated.
4737 4738 4739 4740 4741 4742 4743 4744 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 4737 class BatchReplaceClusterNodesResponse < Struct.new( :successful, :failed, :failed_node_logical_ids, :successful_node_logical_ids) SENSITIVE = [] include Aws::Structure end |
#successful_node_logical_ids ⇒ Array<String>
A list of logical node IDs for which the replacement operation was
successfully initiated. This field is only present when
NodeLogicalIds were provided in the request.
4737 4738 4739 4740 4741 4742 4743 4744 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 4737 class BatchReplaceClusterNodesResponse < Struct.new( :successful, :failed, :failed_node_logical_ids, :successful_node_logical_ids) SENSITIVE = [] include Aws::Structure end |