Class: Aws::SageMaker::Types::BlueGreenUpdatePolicy
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::BlueGreenUpdatePolicy
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Update policy for a blue/green deployment. If this update policy is specified, SageMaker creates a new fleet during the deployment while maintaining the old fleet. SageMaker flips traffic to the new fleet according to the specified traffic routing configuration. Only one update policy should be used in the deployment configuration. If no update policy is specified, SageMaker uses a blue/green deployment strategy with all at once traffic shifting by default.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#maximum_execution_timeout_in_seconds ⇒ Integer
Maximum execution timeout for the deployment.
-
#termination_wait_in_seconds ⇒ Integer
Additional waiting time in seconds after the completion of an endpoint deployment before terminating the old endpoint fleet.
-
#traffic_routing_configuration ⇒ Types::TrafficRoutingConfig
Defines the traffic routing strategy to shift traffic from the old fleet to the new fleet during an endpoint deployment.
Instance Attribute Details
#maximum_execution_timeout_in_seconds ⇒ Integer
Maximum execution timeout for the deployment. Note that the timeout value should be larger than the total waiting time specified in ‘TerminationWaitInSeconds` and `WaitIntervalInSeconds`.
4840 4841 4842 4843 4844 4845 4846 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 4840 class BlueGreenUpdatePolicy < Struct.new( :traffic_routing_configuration, :termination_wait_in_seconds, :maximum_execution_timeout_in_seconds) SENSITIVE = [] include Aws::Structure end |
#termination_wait_in_seconds ⇒ Integer
Additional waiting time in seconds after the completion of an endpoint deployment before terminating the old endpoint fleet. Default is 0.
4840 4841 4842 4843 4844 4845 4846 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 4840 class BlueGreenUpdatePolicy < Struct.new( :traffic_routing_configuration, :termination_wait_in_seconds, :maximum_execution_timeout_in_seconds) SENSITIVE = [] include Aws::Structure end |
#traffic_routing_configuration ⇒ Types::TrafficRoutingConfig
Defines the traffic routing strategy to shift traffic from the old fleet to the new fleet during an endpoint deployment.
4840 4841 4842 4843 4844 4845 4846 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 4840 class BlueGreenUpdatePolicy < Struct.new( :traffic_routing_configuration, :termination_wait_in_seconds, :maximum_execution_timeout_in_seconds) SENSITIVE = [] include Aws::Structure end |