Class: Aws::SageMaker::Types::CapacitySizeConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The configuration of the size measurements of the AMI update. Using this configuration, you can specify whether SageMaker should update your instance group by an amount or percentage of instances.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#typeString

Specifies whether SageMaker should process the update by amount or percentage of instances.

Returns:

  • (String)


5304
5305
5306
5307
5308
5309
# File 'lib/aws-sdk-sagemaker/types.rb', line 5304

class CapacitySizeConfig < Struct.new(
  :type,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#valueInteger

Specifies the amount or percentage of instances SageMaker updates at a time.

Returns:

  • (Integer)


5304
5305
5306
5307
5308
5309
# File 'lib/aws-sdk-sagemaker/types.rb', line 5304

class CapacitySizeConfig < Struct.new(
  :type,
  :value)
  SENSITIVE = []
  include Aws::Structure
end