Class: Aws::SageMaker::Types::ChannelSpecification

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Defines a named input source, called a channel, to be used by an algorithm.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A brief description of the channel.

Returns:

  • (String)


5644
5645
5646
5647
5648
5649
5650
5651
5652
5653
# File 'lib/aws-sdk-sagemaker/types.rb', line 5644

class ChannelSpecification < Struct.new(
  :name,
  :description,
  :is_required,
  :supported_content_types,
  :supported_compression_types,
  :supported_input_modes)
  SENSITIVE = []
  include Aws::Structure
end

#is_requiredBoolean

Indicates whether the channel is required by the algorithm.

Returns:

  • (Boolean)


5644
5645
5646
5647
5648
5649
5650
5651
5652
5653
# File 'lib/aws-sdk-sagemaker/types.rb', line 5644

class ChannelSpecification < Struct.new(
  :name,
  :description,
  :is_required,
  :supported_content_types,
  :supported_compression_types,
  :supported_input_modes)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the channel.

Returns:

  • (String)


5644
5645
5646
5647
5648
5649
5650
5651
5652
5653
# File 'lib/aws-sdk-sagemaker/types.rb', line 5644

class ChannelSpecification < Struct.new(
  :name,
  :description,
  :is_required,
  :supported_content_types,
  :supported_compression_types,
  :supported_input_modes)
  SENSITIVE = []
  include Aws::Structure
end

#supported_compression_typesArray<String>

The allowed compression types, if data compression is used.

Returns:

  • (Array<String>)


5644
5645
5646
5647
5648
5649
5650
5651
5652
5653
# File 'lib/aws-sdk-sagemaker/types.rb', line 5644

class ChannelSpecification < Struct.new(
  :name,
  :description,
  :is_required,
  :supported_content_types,
  :supported_compression_types,
  :supported_input_modes)
  SENSITIVE = []
  include Aws::Structure
end

#supported_content_typesArray<String>

The supported MIME types for the data.

Returns:

  • (Array<String>)


5644
5645
5646
5647
5648
5649
5650
5651
5652
5653
# File 'lib/aws-sdk-sagemaker/types.rb', line 5644

class ChannelSpecification < Struct.new(
  :name,
  :description,
  :is_required,
  :supported_content_types,
  :supported_compression_types,
  :supported_input_modes)
  SENSITIVE = []
  include Aws::Structure
end

#supported_input_modesArray<String>

The allowed input mode, either FILE or PIPE.

In FILE mode, Amazon SageMaker copies the data from the input source onto the local Amazon Elastic Block Store (Amazon EBS) volumes before starting your training algorithm. This is the most commonly used input mode.

In PIPE mode, Amazon SageMaker streams input data from the source directly to your algorithm without using the EBS volume.

Returns:

  • (Array<String>)


5644
5645
5646
5647
5648
5649
5650
5651
5652
5653
# File 'lib/aws-sdk-sagemaker/types.rb', line 5644

class ChannelSpecification < Struct.new(
  :name,
  :description,
  :is_required,
  :supported_content_types,
  :supported_compression_types,
  :supported_input_modes)
  SENSITIVE = []
  include Aws::Structure
end