Class: Aws::SageMaker::Types::ClarifyCheckStepMetadata

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The container for the metadata for the ClarifyCheck step. For more information, see the topic on ClarifyCheck step in the Amazon SageMaker Developer Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#baseline_used_for_drift_check_constraintsString

The Amazon S3 URI of baseline constraints file to be used for the drift check.

Returns:

  • (String)


5785
5786
5787
5788
5789
5790
5791
5792
5793
5794
5795
5796
# File 'lib/aws-sdk-sagemaker/types.rb', line 5785

class  < Struct.new(
  :check_type,
  :baseline_used_for_drift_check_constraints,
  :calculated_baseline_constraints,
  :model_package_group_name,
  :violation_report,
  :check_job_arn,
  :skip_check,
  :register_new_baseline)
  SENSITIVE = []
  include Aws::Structure
end

#calculated_baseline_constraintsString

The Amazon S3 URI of the newly calculated baseline constraints file.

Returns:

  • (String)


5785
5786
5787
5788
5789
5790
5791
5792
5793
5794
5795
5796
# File 'lib/aws-sdk-sagemaker/types.rb', line 5785

class  < Struct.new(
  :check_type,
  :baseline_used_for_drift_check_constraints,
  :calculated_baseline_constraints,
  :model_package_group_name,
  :violation_report,
  :check_job_arn,
  :skip_check,
  :register_new_baseline)
  SENSITIVE = []
  include Aws::Structure
end

#check_job_arnString

The Amazon Resource Name (ARN) of the check processing job that was run by this step's execution.

Returns:

  • (String)


5785
5786
5787
5788
5789
5790
5791
5792
5793
5794
5795
5796
# File 'lib/aws-sdk-sagemaker/types.rb', line 5785

class  < Struct.new(
  :check_type,
  :baseline_used_for_drift_check_constraints,
  :calculated_baseline_constraints,
  :model_package_group_name,
  :violation_report,
  :check_job_arn,
  :skip_check,
  :register_new_baseline)
  SENSITIVE = []
  include Aws::Structure
end

#check_typeString

The type of the Clarify Check step

Returns:

  • (String)


5785
5786
5787
5788
5789
5790
5791
5792
5793
5794
5795
5796
# File 'lib/aws-sdk-sagemaker/types.rb', line 5785

class  < Struct.new(
  :check_type,
  :baseline_used_for_drift_check_constraints,
  :calculated_baseline_constraints,
  :model_package_group_name,
  :violation_report,
  :check_job_arn,
  :skip_check,
  :register_new_baseline)
  SENSITIVE = []
  include Aws::Structure
end

#model_package_group_nameString

The model package group name.

Returns:

  • (String)


5785
5786
5787
5788
5789
5790
5791
5792
5793
5794
5795
5796
# File 'lib/aws-sdk-sagemaker/types.rb', line 5785

class  < Struct.new(
  :check_type,
  :baseline_used_for_drift_check_constraints,
  :calculated_baseline_constraints,
  :model_package_group_name,
  :violation_report,
  :check_job_arn,
  :skip_check,
  :register_new_baseline)
  SENSITIVE = []
  include Aws::Structure
end

#register_new_baselineBoolean

This flag indicates if a newly calculated baseline can be accessed through step properties BaselineUsedForDriftCheckConstraints and BaselineUsedForDriftCheckStatistics. If it is set to False, the previous baseline of the configured check type must also be available. These can be accessed through the BaselineUsedForDriftCheckConstraints property.

Returns:

  • (Boolean)


5785
5786
5787
5788
5789
5790
5791
5792
5793
5794
5795
5796
# File 'lib/aws-sdk-sagemaker/types.rb', line 5785

class  < Struct.new(
  :check_type,
  :baseline_used_for_drift_check_constraints,
  :calculated_baseline_constraints,
  :model_package_group_name,
  :violation_report,
  :check_job_arn,
  :skip_check,
  :register_new_baseline)
  SENSITIVE = []
  include Aws::Structure
end

#skip_checkBoolean

This flag indicates if the drift check against the previous baseline will be skipped or not. If it is set to False, the previous baseline of the configured check type must be available.

Returns:

  • (Boolean)


5785
5786
5787
5788
5789
5790
5791
5792
5793
5794
5795
5796
# File 'lib/aws-sdk-sagemaker/types.rb', line 5785

class  < Struct.new(
  :check_type,
  :baseline_used_for_drift_check_constraints,
  :calculated_baseline_constraints,
  :model_package_group_name,
  :violation_report,
  :check_job_arn,
  :skip_check,
  :register_new_baseline)
  SENSITIVE = []
  include Aws::Structure
end

#violation_reportString

The Amazon S3 URI of the violation report if violations are detected.

Returns:

  • (String)


5785
5786
5787
5788
5789
5790
5791
5792
5793
5794
5795
5796
# File 'lib/aws-sdk-sagemaker/types.rb', line 5785

class  < Struct.new(
  :check_type,
  :baseline_used_for_drift_check_constraints,
  :calculated_baseline_constraints,
  :model_package_group_name,
  :violation_report,
  :check_job_arn,
  :skip_check,
  :register_new_baseline)
  SENSITIVE = []
  include Aws::Structure
end