Class: Aws::SageMaker::Types::ClarifyShapConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The configuration for SHAP analysis using SageMaker Clarify Explainer.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#number_of_samplesInteger

The number of samples to be used for analysis by the Kernal SHAP algorithm.

<note markdown=“1”> The number of samples determines the size of the synthetic dataset, which has an impact on latency of explainability requests. For more information, see the **Synthetic data** of [Configure and create an endpoint].

</note>

[1]: docs.aws.amazon.com/sagemaker/latest/dg/clarify-online-explainability-create-endpoint.html

Returns:



5157
5158
5159
5160
5161
5162
5163
5164
5165
# File 'lib/aws-sdk-sagemaker/types.rb', line 5157

class ClarifyShapConfig < Struct.new(
  :shap_baseline_config,
  :number_of_samples,
  :use_logit,
  :seed,
  :text_config)
  SENSITIVE = []
  include Aws::Structure
end

#seedInteger

The starting value used to initialize the random number generator in the explainer. Provide a value for this parameter to obtain a deterministic SHAP result.

Returns:



5157
5158
5159
5160
5161
5162
5163
5164
5165
# File 'lib/aws-sdk-sagemaker/types.rb', line 5157

class ClarifyShapConfig < Struct.new(
  :shap_baseline_config,
  :number_of_samples,
  :use_logit,
  :seed,
  :text_config)
  SENSITIVE = []
  include Aws::Structure
end

#shap_baseline_configTypes::ClarifyShapBaselineConfig

The configuration for the SHAP baseline of the Kernal SHAP algorithm.

Returns:



5157
5158
5159
5160
5161
5162
5163
5164
5165
# File 'lib/aws-sdk-sagemaker/types.rb', line 5157

class ClarifyShapConfig < Struct.new(
  :shap_baseline_config,
  :number_of_samples,
  :use_logit,
  :seed,
  :text_config)
  SENSITIVE = []
  include Aws::Structure
end

#text_configTypes::ClarifyTextConfig

A parameter that indicates if text features are treated as text and explanations are provided for individual units of text. Required for natural language processing (NLP) explainability only.

Returns:



5157
5158
5159
5160
5161
5162
5163
5164
5165
# File 'lib/aws-sdk-sagemaker/types.rb', line 5157

class ClarifyShapConfig < Struct.new(
  :shap_baseline_config,
  :number_of_samples,
  :use_logit,
  :seed,
  :text_config)
  SENSITIVE = []
  include Aws::Structure
end

#use_logitBoolean

A Boolean toggle to indicate if you want to use the logit function (true) or log-odds units (false) for model predictions. Defaults to false.

Returns:



5157
5158
5159
5160
5161
5162
5163
5164
5165
# File 'lib/aws-sdk-sagemaker/types.rb', line 5157

class ClarifyShapConfig < Struct.new(
  :shap_baseline_config,
  :number_of_samples,
  :use_logit,
  :seed,
  :text_config)
  SENSITIVE = []
  include Aws::Structure
end