Class: Aws::SageMaker::Types::ClusterInstanceStorageConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ClusterInstanceStorageConfig
- Includes:
- Aws::Structure, Aws::Structure::Union
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
ClusterInstanceStorageConfig is a union - when making an API calls you must set exactly one of the members.
ClusterInstanceStorageConfig is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ClusterInstanceStorageConfig corresponding to the set member.
Defines the configuration for attaching additional storage to the instances in the SageMaker HyperPod cluster instance group. To learn more, see [SageMaker HyperPod release notes: June 20, 2024].
Direct Known Subclasses
Defined Under Namespace
Classes: EbsVolumeConfig, FsxLustreConfig, FsxOpenZfsConfig, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ebs_volume_config ⇒ Types::ClusterEbsVolumeConfig
Defines the configuration for attaching additional Amazon Elastic Block Store (EBS) volumes to the instances in the SageMaker HyperPod cluster instance group.
-
#fsx_lustre_config ⇒ Types::ClusterFsxLustreConfig
Defines the configuration for attaching an Amazon FSx for Lustre file system to the instances in the SageMaker HyperPod cluster instance group.
-
#fsx_open_zfs_config ⇒ Types::ClusterFsxOpenZfsConfig
Defines the configuration for attaching an Amazon FSx for OpenZFS file system to the instances in the SageMaker HyperPod cluster instance group.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#ebs_volume_config ⇒ Types::ClusterEbsVolumeConfig
Defines the configuration for attaching additional Amazon Elastic Block Store (EBS) volumes to the instances in the SageMaker HyperPod cluster instance group. The additional EBS volume is attached to each instance within the SageMaker HyperPod cluster instance group and mounted to /opt/sagemaker.
5953 5954 5955 5956 5957 5958 5959 5960 5961 5962 5963 5964 5965 5966 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5953 class ClusterInstanceStorageConfig < Struct.new( :ebs_volume_config, :fsx_lustre_config, :fsx_open_zfs_config, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class EbsVolumeConfig < ClusterInstanceStorageConfig; end class FsxLustreConfig < ClusterInstanceStorageConfig; end class FsxOpenZfsConfig < ClusterInstanceStorageConfig; end class Unknown < ClusterInstanceStorageConfig; end end |
#fsx_lustre_config ⇒ Types::ClusterFsxLustreConfig
Defines the configuration for attaching an Amazon FSx for Lustre file system to the instances in the SageMaker HyperPod cluster instance group.
5953 5954 5955 5956 5957 5958 5959 5960 5961 5962 5963 5964 5965 5966 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5953 class ClusterInstanceStorageConfig < Struct.new( :ebs_volume_config, :fsx_lustre_config, :fsx_open_zfs_config, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class EbsVolumeConfig < ClusterInstanceStorageConfig; end class FsxLustreConfig < ClusterInstanceStorageConfig; end class FsxOpenZfsConfig < ClusterInstanceStorageConfig; end class Unknown < ClusterInstanceStorageConfig; end end |
#fsx_open_zfs_config ⇒ Types::ClusterFsxOpenZfsConfig
Defines the configuration for attaching an Amazon FSx for OpenZFS file system to the instances in the SageMaker HyperPod cluster instance group.
5953 5954 5955 5956 5957 5958 5959 5960 5961 5962 5963 5964 5965 5966 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5953 class ClusterInstanceStorageConfig < Struct.new( :ebs_volume_config, :fsx_lustre_config, :fsx_open_zfs_config, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class EbsVolumeConfig < ClusterInstanceStorageConfig; end class FsxLustreConfig < ClusterInstanceStorageConfig; end class FsxOpenZfsConfig < ClusterInstanceStorageConfig; end class Unknown < ClusterInstanceStorageConfig; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
5953 5954 5955 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5953 def unknown @unknown end |