Class: Aws::SageMaker::Types::ClusterInstanceTypeDetail

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Details about a specific instance type within a flexible instance group, including the count and configuration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#current_countInteger

The number of instances of this type currently running in the instance group.

Returns:

  • (Integer)


6084
6085
6086
6087
6088
6089
6090
# File 'lib/aws-sdk-sagemaker/types.rb', line 6084

class ClusterInstanceTypeDetail < Struct.new(
  :instance_type,
  :current_count,
  :threads_per_core)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typeString

The instance type.

Returns:

  • (String)


6084
6085
6086
6087
6088
6089
6090
# File 'lib/aws-sdk-sagemaker/types.rb', line 6084

class ClusterInstanceTypeDetail < Struct.new(
  :instance_type,
  :current_count,
  :threads_per_core)
  SENSITIVE = []
  include Aws::Structure
end

#threads_per_coreInteger

The number of threads per CPU core for this instance type.

Returns:

  • (Integer)


6084
6085
6086
6087
6088
6089
6090
# File 'lib/aws-sdk-sagemaker/types.rb', line 6084

class ClusterInstanceTypeDetail < Struct.new(
  :instance_type,
  :current_count,
  :threads_per_core)
  SENSITIVE = []
  include Aws::Structure
end