Class: Aws::SageMaker::Types::ClusterMetadata

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Metadata information about a HyperPod cluster showing information about the cluster level operations, such as creating, updating, and deleting.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#eks_role_access_entriesArray<String>

A list of Amazon EKS IAM role ARNs associated with the cluster. This is created by HyperPod on your behalf and only applies for EKS orchestrated clusters.



7301
7302
7303
7304
7305
7306
7307
# File 'lib/aws-sdk-sagemaker/types.rb', line 7301

class  < Struct.new(
  :failure_message,
  :eks_role_access_entries,
  :slr_access_entry)
  SENSITIVE = []
  include Aws::Structure
end

#failure_messageString

An error message describing why the cluster level operation (such as creating, updating, or deleting) failed.



7301
7302
7303
7304
7305
7306
7307
# File 'lib/aws-sdk-sagemaker/types.rb', line 7301

class  < Struct.new(
  :failure_message,
  :eks_role_access_entries,
  :slr_access_entry)
  SENSITIVE = []
  include Aws::Structure
end

#slr_access_entryString

The Service-Linked Role (SLR) associated with the cluster. This is created by HyperPod on your behalf and only applies for EKS orchestrated clusters.



7301
7302
7303
7304
7305
7306
7307
# File 'lib/aws-sdk-sagemaker/types.rb', line 7301

class  < Struct.new(
  :failure_message,
  :eks_role_access_entries,
  :slr_access_entry)
  SENSITIVE = []
  include Aws::Structure
end