Class: Aws::SageMaker::Types::ClusterNetworkInterface
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ClusterNetworkInterface
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The network interface configuration for a Amazon SageMaker HyperPod cluster instance group.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#interface_type ⇒ String
The type of network interface for the instance group.
Instance Attribute Details
#interface_type ⇒ String
The type of network interface for the instance group. Valid values:
-
‘efa` – An EFA with ENA interface, which provides both the EFA device for low-latency, high-throughput communication and the ENA device for IP networking.
-
‘efa-only` – An EFA-only interface, which provides only the EFA device capabilities without the ENA device for traditional IP networking.
For more information, see [Elastic Fabric Adapter].
6290 6291 6292 6293 6294 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6290 class ClusterNetworkInterface < Struct.new( :interface_type) SENSITIVE = [] include Aws::Structure end |