Class: Aws::SageMaker::Types::ClusterOrchestrator
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ClusterOrchestrator
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The type of orchestrator used for the SageMaker HyperPod cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#eks ⇒ Types::ClusterOrchestratorEksConfig
The Amazon EKS cluster used as the orchestrator for the SageMaker HyperPod cluster.
-
#slurm ⇒ Types::ClusterOrchestratorSlurmConfig
The Slurm orchestrator configuration for the SageMaker HyperPod cluster.
Instance Attribute Details
#eks ⇒ Types::ClusterOrchestratorEksConfig
The Amazon EKS cluster used as the orchestrator for the SageMaker HyperPod cluster.
7206 7207 7208 7209 7210 7211 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7206 class ClusterOrchestrator < Struct.new( :eks, :slurm) SENSITIVE = [] include Aws::Structure end |
#slurm ⇒ Types::ClusterOrchestratorSlurmConfig
The Slurm orchestrator configuration for the SageMaker HyperPod cluster.
7206 7207 7208 7209 7210 7211 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7206 class ClusterOrchestrator < Struct.new( :eks, :slurm) SENSITIVE = [] include Aws::Structure end |