Class: Aws::SageMaker::Types::ClusterPatchScheduleDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The schedule details for automatic patching, including the next scheduled patch date.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_patch_dateTime

The date and time of the next scheduled automatic patch.

Returns:

  • (Time)


7458
7459
7460
7461
7462
# File 'lib/aws-sdk-sagemaker/types.rb', line 7458

class ClusterPatchScheduleDetails < Struct.new(
  :next_patch_date)
  SENSITIVE = []
  include Aws::Structure
end