Class: Aws::SageMaker::Types::ClusterRestrictedInstanceGroupSpecification
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ClusterRestrictedInstanceGroupSpecification
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The specifications of a restricted instance group that you need to define.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#environment_config ⇒ Types::EnvironmentConfig
The configuration for the restricted instance groups (RIG) environment.
-
#execution_role ⇒ String
Specifies an IAM execution role to be assumed by the restricted instance group.
-
#instance_count ⇒ Integer
Specifies the number of instances to add to the restricted instance group of a SageMaker HyperPod cluster.
-
#instance_group_name ⇒ String
Specifies the name of the restricted instance group.
-
#instance_storage_configs ⇒ Array<Types::ClusterInstanceStorageConfig>
Specifies the additional storage configurations for the instances in the SageMaker HyperPod cluster restricted instance group.
-
#instance_type ⇒ String
Specifies the instance type of the restricted instance group.
-
#on_start_deep_health_checks ⇒ Array<String>
A flag indicating whether deep health checks should be performed when the cluster restricted instance group is created or updated.
-
#override_vpc_config ⇒ Types::VpcConfig
Specifies an Amazon Virtual Private Cloud (VPC) that your SageMaker jobs, hosted models, and compute resources have access to.
-
#scheduled_update_config ⇒ Types::ScheduledUpdateConfig
The configuration object of the schedule that SageMaker follows when updating the AMI.
-
#threads_per_core ⇒ Integer
The number you specified to ‘TreadsPerCore` in `CreateCluster` for enabling or disabling multithreading.
-
#training_plan_arn ⇒ String
The Amazon Resource Name (ARN) of the training plan to filter clusters by.
Instance Attribute Details
#environment_config ⇒ Types::EnvironmentConfig
The configuration for the restricted instance groups (RIG) environment.
7445 7446 7447 7448 7449 7450 7451 7452 7453 7454 7455 7456 7457 7458 7459 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7445 class ClusterRestrictedInstanceGroupSpecification < Struct.new( :instance_count, :instance_group_name, :instance_type, :execution_role, :threads_per_core, :instance_storage_configs, :on_start_deep_health_checks, :training_plan_arn, :override_vpc_config, :scheduled_update_config, :environment_config) SENSITIVE = [] include Aws::Structure end |
#execution_role ⇒ String
Specifies an IAM execution role to be assumed by the restricted instance group.
7445 7446 7447 7448 7449 7450 7451 7452 7453 7454 7455 7456 7457 7458 7459 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7445 class ClusterRestrictedInstanceGroupSpecification < Struct.new( :instance_count, :instance_group_name, :instance_type, :execution_role, :threads_per_core, :instance_storage_configs, :on_start_deep_health_checks, :training_plan_arn, :override_vpc_config, :scheduled_update_config, :environment_config) SENSITIVE = [] include Aws::Structure end |
#instance_count ⇒ Integer
Specifies the number of instances to add to the restricted instance group of a SageMaker HyperPod cluster.
7445 7446 7447 7448 7449 7450 7451 7452 7453 7454 7455 7456 7457 7458 7459 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7445 class ClusterRestrictedInstanceGroupSpecification < Struct.new( :instance_count, :instance_group_name, :instance_type, :execution_role, :threads_per_core, :instance_storage_configs, :on_start_deep_health_checks, :training_plan_arn, :override_vpc_config, :scheduled_update_config, :environment_config) SENSITIVE = [] include Aws::Structure end |
#instance_group_name ⇒ String
Specifies the name of the restricted instance group.
7445 7446 7447 7448 7449 7450 7451 7452 7453 7454 7455 7456 7457 7458 7459 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7445 class ClusterRestrictedInstanceGroupSpecification < Struct.new( :instance_count, :instance_group_name, :instance_type, :execution_role, :threads_per_core, :instance_storage_configs, :on_start_deep_health_checks, :training_plan_arn, :override_vpc_config, :scheduled_update_config, :environment_config) SENSITIVE = [] include Aws::Structure end |
#instance_storage_configs ⇒ Array<Types::ClusterInstanceStorageConfig>
Specifies the additional storage configurations for the instances in the SageMaker HyperPod cluster restricted instance group.
7445 7446 7447 7448 7449 7450 7451 7452 7453 7454 7455 7456 7457 7458 7459 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7445 class ClusterRestrictedInstanceGroupSpecification < Struct.new( :instance_count, :instance_group_name, :instance_type, :execution_role, :threads_per_core, :instance_storage_configs, :on_start_deep_health_checks, :training_plan_arn, :override_vpc_config, :scheduled_update_config, :environment_config) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
Specifies the instance type of the restricted instance group.
7445 7446 7447 7448 7449 7450 7451 7452 7453 7454 7455 7456 7457 7458 7459 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7445 class ClusterRestrictedInstanceGroupSpecification < Struct.new( :instance_count, :instance_group_name, :instance_type, :execution_role, :threads_per_core, :instance_storage_configs, :on_start_deep_health_checks, :training_plan_arn, :override_vpc_config, :scheduled_update_config, :environment_config) SENSITIVE = [] include Aws::Structure end |
#on_start_deep_health_checks ⇒ Array<String>
A flag indicating whether deep health checks should be performed when the cluster restricted instance group is created or updated.
7445 7446 7447 7448 7449 7450 7451 7452 7453 7454 7455 7456 7457 7458 7459 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7445 class ClusterRestrictedInstanceGroupSpecification < Struct.new( :instance_count, :instance_group_name, :instance_type, :execution_role, :threads_per_core, :instance_storage_configs, :on_start_deep_health_checks, :training_plan_arn, :override_vpc_config, :scheduled_update_config, :environment_config) SENSITIVE = [] include Aws::Structure end |
#override_vpc_config ⇒ Types::VpcConfig
Specifies an Amazon Virtual Private Cloud (VPC) that your SageMaker jobs, hosted models, and compute resources have access to. You can control access to and from your resources by configuring a VPC. For more information, see [Give SageMaker Access to Resources in your Amazon VPC].
[1]: docs.aws.amazon.com/sagemaker/latest/dg/infrastructure-give-access.html
7445 7446 7447 7448 7449 7450 7451 7452 7453 7454 7455 7456 7457 7458 7459 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7445 class ClusterRestrictedInstanceGroupSpecification < Struct.new( :instance_count, :instance_group_name, :instance_type, :execution_role, :threads_per_core, :instance_storage_configs, :on_start_deep_health_checks, :training_plan_arn, :override_vpc_config, :scheduled_update_config, :environment_config) SENSITIVE = [] include Aws::Structure end |
#scheduled_update_config ⇒ Types::ScheduledUpdateConfig
The configuration object of the schedule that SageMaker follows when updating the AMI.
7445 7446 7447 7448 7449 7450 7451 7452 7453 7454 7455 7456 7457 7458 7459 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7445 class ClusterRestrictedInstanceGroupSpecification < Struct.new( :instance_count, :instance_group_name, :instance_type, :execution_role, :threads_per_core, :instance_storage_configs, :on_start_deep_health_checks, :training_plan_arn, :override_vpc_config, :scheduled_update_config, :environment_config) SENSITIVE = [] include Aws::Structure end |
#threads_per_core ⇒ Integer
The number you specified to ‘TreadsPerCore` in `CreateCluster` for enabling or disabling multithreading. For instance types that support multithreading, you can specify 1 for disabling multithreading and 2 for enabling multithreading. For more information, see the reference table of [CPU cores and threads per CPU core per instance type] in the *Amazon Elastic Compute Cloud User Guide*.
[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/cpu-options-supported-instances-values.html
7445 7446 7447 7448 7449 7450 7451 7452 7453 7454 7455 7456 7457 7458 7459 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7445 class ClusterRestrictedInstanceGroupSpecification < Struct.new( :instance_count, :instance_group_name, :instance_type, :execution_role, :threads_per_core, :instance_storage_configs, :on_start_deep_health_checks, :training_plan_arn, :override_vpc_config, :scheduled_update_config, :environment_config) SENSITIVE = [] include Aws::Structure end |
#training_plan_arn ⇒ String
The Amazon Resource Name (ARN) of the training plan to filter clusters by. For more information about reserving GPU capacity for your SageMaker HyperPod clusters using Amazon SageMaker Training Plan, see ‘ CreateTrainingPlan `.
7445 7446 7447 7448 7449 7450 7451 7452 7453 7454 7455 7456 7457 7458 7459 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7445 class ClusterRestrictedInstanceGroupSpecification < Struct.new( :instance_count, :instance_group_name, :instance_type, :execution_role, :threads_per_core, :instance_storage_configs, :on_start_deep_health_checks, :training_plan_arn, :override_vpc_config, :scheduled_update_config, :environment_config) SENSITIVE = [] include Aws::Structure end |