Class: Aws::SageMaker::Types::ClusterRestrictedInstanceGroupsConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ClusterRestrictedInstanceGroupsConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The configuration for the restricted instance groups (RIG) in the SageMaker HyperPod cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#shared_environment_config ⇒ Types::ClusterSharedEnvironmentConfig
The shared environment configuration for the restricted instance groups (RIG).
Instance Attribute Details
#shared_environment_config ⇒ Types::ClusterSharedEnvironmentConfig
The shared environment configuration for the restricted instance groups (RIG).
7500 7501 7502 7503 7504 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7500 class ClusterRestrictedInstanceGroupsConfig < Struct.new( :shared_environment_config) SENSITIVE = [] include Aws::Structure end |