Class: Aws::SageMaker::Types::ClusterRestrictedInstanceGroupsConfigOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The output configuration for the restricted instance groups (RIG) in the SageMaker HyperPod cluster.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#shared_environment_configTypes::ClusterSharedEnvironmentConfigDetails

The shared environment configuration details for the restricted instance groups (RIG).



7516
7517
7518
7519
7520
# File 'lib/aws-sdk-sagemaker/types.rb', line 7516

class ClusterRestrictedInstanceGroupsConfigOutput < Struct.new(
  :shared_environment_config)
  SENSITIVE = []
  include Aws::Structure
end