Class: Aws::SageMaker::Types::ClusterSharedEnvironmentConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The shared environment configuration for the restricted instance groups (RIG).

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#f_sx_lustre_configTypes::FSxLustreConfig

Configuration settings for an Amazon FSx for Lustre file system in the shared environment.



7634
7635
7636
7637
7638
7639
# File 'lib/aws-sdk-sagemaker/types.rb', line 7634

class ClusterSharedEnvironmentConfig < Struct.new(
  :f_sx_lustre_deletion_policy,
  :f_sx_lustre_config)
  SENSITIVE = []
  include Aws::Structure
end

#f_sx_lustre_deletion_policyString

The deletion policy for the Amazon FSx for Lustre file system in the shared environment.

Returns:

  • (String)


7634
7635
7636
7637
7638
7639
# File 'lib/aws-sdk-sagemaker/types.rb', line 7634

class ClusterSharedEnvironmentConfig < Struct.new(
  :f_sx_lustre_deletion_policy,
  :f_sx_lustre_config)
  SENSITIVE = []
  include Aws::Structure
end