Class: Aws::SageMaker::Types::CodeEditorAppSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CodeEditorAppSettings
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The Code Editor application settings.
For more information about Code Editor, see [Get started with Code Editor in Amazon SageMaker].
[1]: docs.aws.amazon.com/sagemaker/latest/dg/code-editor.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#app_lifecycle_management ⇒ Types::AppLifecycleManagement
Settings that are used to configure and manage the lifecycle of CodeEditor applications.
-
#built_in_lifecycle_config_arn ⇒ String
The lifecycle configuration that runs before the default lifecycle configuration.
-
#custom_images ⇒ Array<Types::CustomImage>
A list of custom SageMaker images that are configured to run as a Code Editor app.
-
#default_resource_spec ⇒ Types::ResourceSpec
Specifies the ARN’s of a SageMaker AI image and SageMaker AI image version, and the instance type that the version runs on.
-
#lifecycle_config_arns ⇒ Array<String>
The Amazon Resource Name (ARN) of the Code Editor application lifecycle configuration.
Instance Attribute Details
#app_lifecycle_management ⇒ Types::AppLifecycleManagement
Settings that are used to configure and manage the lifecycle of CodeEditor applications.
6841 6842 6843 6844 6845 6846 6847 6848 6849 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6841 class CodeEditorAppSettings < Struct.new( :default_resource_spec, :custom_images, :lifecycle_config_arns, :app_lifecycle_management, :built_in_lifecycle_config_arn) SENSITIVE = [] include Aws::Structure end |
#built_in_lifecycle_config_arn ⇒ String
The lifecycle configuration that runs before the default lifecycle configuration. It can override changes made in the default lifecycle configuration.
6841 6842 6843 6844 6845 6846 6847 6848 6849 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6841 class CodeEditorAppSettings < Struct.new( :default_resource_spec, :custom_images, :lifecycle_config_arns, :app_lifecycle_management, :built_in_lifecycle_config_arn) SENSITIVE = [] include Aws::Structure end |
#custom_images ⇒ Array<Types::CustomImage>
A list of custom SageMaker images that are configured to run as a Code Editor app.
6841 6842 6843 6844 6845 6846 6847 6848 6849 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6841 class CodeEditorAppSettings < Struct.new( :default_resource_spec, :custom_images, :lifecycle_config_arns, :app_lifecycle_management, :built_in_lifecycle_config_arn) SENSITIVE = [] include Aws::Structure end |
#default_resource_spec ⇒ Types::ResourceSpec
Specifies the ARN’s of a SageMaker AI image and SageMaker AI image version, and the instance type that the version runs on.
<note markdown=“1”> When both SageMakerImageVersionArn and SageMakerImageArn are passed, SageMakerImageVersionArn is used. Any updates to SageMakerImageArn will not take effect if SageMakerImageVersionArn already exists in the ResourceSpec because SageMakerImageVersionArn always takes precedence. To clear the value set for SageMakerImageVersionArn, pass None as the value.
</note>
6841 6842 6843 6844 6845 6846 6847 6848 6849 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6841 class CodeEditorAppSettings < Struct.new( :default_resource_spec, :custom_images, :lifecycle_config_arns, :app_lifecycle_management, :built_in_lifecycle_config_arn) SENSITIVE = [] include Aws::Structure end |
#lifecycle_config_arns ⇒ Array<String>
The Amazon Resource Name (ARN) of the Code Editor application lifecycle configuration.
6841 6842 6843 6844 6845 6846 6847 6848 6849 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6841 class CodeEditorAppSettings < Struct.new( :default_resource_spec, :custom_images, :lifecycle_config_arns, :app_lifecycle_management, :built_in_lifecycle_config_arn) SENSITIVE = [] include Aws::Structure end |