Class: Aws::SageMaker::Types::CognitoConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Use this parameter to configure your Amazon Cognito workforce. A single Cognito workforce is created using and corresponds to a single Amazon Cognito user pool.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_idString

The client ID for your Amazon Cognito user pool.

Returns:

  • (String)


8249
8250
8251
8252
8253
8254
# File 'lib/aws-sdk-sagemaker/types.rb', line 8249

class CognitoConfig < Struct.new(
  :user_pool,
  :client_id)
  SENSITIVE = []
  include Aws::Structure
end

#user_poolString

A user pool is a user directory in Amazon Cognito. With a user pool, your users can sign in to your web or mobile app through Amazon Cognito. Your users can also sign in through social identity providers like Google, Facebook, Amazon, or Apple, and through SAML identity providers.

Returns:

  • (String)


8249
8250
8251
8252
8253
8254
# File 'lib/aws-sdk-sagemaker/types.rb', line 8249

class CognitoConfig < Struct.new(
  :user_pool,
  :client_id)
  SENSITIVE = []
  include Aws::Structure
end