Class: Aws::SageMaker::Types::CollectionConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CollectionConfig
- Includes:
- Aws::Structure, Aws::Structure::Union
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Note:
CollectionConfig is a union - when making an API calls you must set exactly one of the members.
Note:
CollectionConfig is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of CollectionConfig corresponding to the set member.
Configuration for your collection.
Defined Under Namespace
Classes: Unknown, VectorConfig
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#unknown ⇒ Object
Returns the value of attribute unknown.
-
#vector_config ⇒ Types::VectorConfig
Configuration for your vector collection type.
Instance Attribute Details
#unknown ⇒ Object
Returns the value of attribute unknown
8177 8178 8179 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 8177 def unknown @unknown end |
#vector_config ⇒ Types::VectorConfig
Configuration for your vector collection type.
Dimension: The number of elements in your vector.
^
8177 8178 8179 8180 8181 8182 8183 8184 8185 8186 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 8177 class CollectionConfig < Struct.new( :vector_config, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class VectorConfig < CollectionConfig; end class Unknown < CollectionConfig; end end |