Class: Aws::SageMaker::Types::ContextSummary

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Lists a summary of the properties of a context. A context provides a logical grouping of other entities.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#context_arnString

The Amazon Resource Name (ARN) of the context.

Returns:

  • (String)


8384
8385
8386
8387
8388
8389
8390
8391
8392
8393
# File 'lib/aws-sdk-sagemaker/types.rb', line 8384

class ContextSummary < Struct.new(
  :context_arn,
  :context_name,
  :source,
  :context_type,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#context_nameString

The name of the context.

Returns:

  • (String)


8384
8385
8386
8387
8388
8389
8390
8391
8392
8393
# File 'lib/aws-sdk-sagemaker/types.rb', line 8384

class ContextSummary < Struct.new(
  :context_arn,
  :context_name,
  :source,
  :context_type,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#context_typeString

The type of the context.

Returns:

  • (String)


8384
8385
8386
8387
8388
8389
8390
8391
8392
8393
# File 'lib/aws-sdk-sagemaker/types.rb', line 8384

class ContextSummary < Struct.new(
  :context_arn,
  :context_name,
  :source,
  :context_type,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

When the context was created.

Returns:

  • (Time)


8384
8385
8386
8387
8388
8389
8390
8391
8392
8393
# File 'lib/aws-sdk-sagemaker/types.rb', line 8384

class ContextSummary < Struct.new(
  :context_arn,
  :context_name,
  :source,
  :context_type,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

When the context was last modified.

Returns:

  • (Time)


8384
8385
8386
8387
8388
8389
8390
8391
8392
8393
# File 'lib/aws-sdk-sagemaker/types.rb', line 8384

class ContextSummary < Struct.new(
  :context_arn,
  :context_name,
  :source,
  :context_type,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#sourceTypes::ContextSource

The source of the context.



8384
8385
8386
8387
8388
8389
8390
8391
8392
8393
# File 'lib/aws-sdk-sagemaker/types.rb', line 8384

class ContextSummary < Struct.new(
  :context_arn,
  :context_name,
  :source,
  :context_type,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end