Class: Aws::SageMaker::Types::CreateAIRecommendationJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreateAIRecommendationJobRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#adapter_source ⇒ Types::AIAdapterSource
The LoRA adapter source for the recommendation job.
-
#ai_recommendation_job_name ⇒ String
The name of the AI recommendation job.
-
#ai_workload_config_identifier ⇒ String
The name or Amazon Resource Name (ARN) of the AI workload configuration to use for this recommendation job.
-
#compute_spec ⇒ Types::AIRecommendationComputeSpec
The compute resource specification for the recommendation job.
-
#inference_specification ⇒ Types::AIRecommendationInferenceSpecification
The inference framework configuration.
-
#model_source ⇒ Types::AIModelSource
The source of the model to optimize.
-
#optimize_model ⇒ Boolean
Whether to allow model optimization techniques such as quantization, speculative decoding, and kernel tuning.
-
#output_config ⇒ Types::AIRecommendationOutputConfig
The output configuration for the recommendation job, including the Amazon S3 location for results and an optional model package group where the optimized model is registered.
-
#performance_target ⇒ Types::AIRecommendationPerformanceTarget
The performance targets for the recommendation job.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that enables Amazon SageMaker AI to perform tasks on your behalf.
-
#tags ⇒ Array<Types::Tag>
The metadata that you apply to Amazon Web Services resources to help you categorize and organize them.
Instance Attribute Details
#adapter_source ⇒ Types::AIAdapterSource
The LoRA adapter source for the recommendation job. Specify either a list of model package ARNs or Amazon S3 URIs for your LoRA adapters. When this parameter is absent, the recommendation job runs without LoRA adapter support.
9118 9119 9120 9121 9122 9123 9124 9125 9126 9127 9128 9129 9130 9131 9132 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9118 class CreateAIRecommendationJobRequest < Struct.new( :ai_recommendation_job_name, :model_source, :output_config, :ai_workload_config_identifier, :performance_target, :role_arn, :inference_specification, :optimize_model, :compute_spec, :adapter_source, :tags) SENSITIVE = [] include Aws::Structure end |
#ai_recommendation_job_name ⇒ String
The name of the AI recommendation job. The name must be unique within your Amazon Web Services account in the current Amazon Web Services Region.
9118 9119 9120 9121 9122 9123 9124 9125 9126 9127 9128 9129 9130 9131 9132 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9118 class CreateAIRecommendationJobRequest < Struct.new( :ai_recommendation_job_name, :model_source, :output_config, :ai_workload_config_identifier, :performance_target, :role_arn, :inference_specification, :optimize_model, :compute_spec, :adapter_source, :tags) SENSITIVE = [] include Aws::Structure end |
#ai_workload_config_identifier ⇒ String
The name or Amazon Resource Name (ARN) of the AI workload configuration to use for this recommendation job.
9118 9119 9120 9121 9122 9123 9124 9125 9126 9127 9128 9129 9130 9131 9132 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9118 class CreateAIRecommendationJobRequest < Struct.new( :ai_recommendation_job_name, :model_source, :output_config, :ai_workload_config_identifier, :performance_target, :role_arn, :inference_specification, :optimize_model, :compute_spec, :adapter_source, :tags) SENSITIVE = [] include Aws::Structure end |
#compute_spec ⇒ Types::AIRecommendationComputeSpec
The compute resource specification for the recommendation job. You can specify up to 3 instance types to consider, and optionally provide capacity reservation configuration.
9118 9119 9120 9121 9122 9123 9124 9125 9126 9127 9128 9129 9130 9131 9132 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9118 class CreateAIRecommendationJobRequest < Struct.new( :ai_recommendation_job_name, :model_source, :output_config, :ai_workload_config_identifier, :performance_target, :role_arn, :inference_specification, :optimize_model, :compute_spec, :adapter_source, :tags) SENSITIVE = [] include Aws::Structure end |
#inference_specification ⇒ Types::AIRecommendationInferenceSpecification
The inference framework configuration. Specify the framework (such as LMI or vLLM) for the recommendation job.
9118 9119 9120 9121 9122 9123 9124 9125 9126 9127 9128 9129 9130 9131 9132 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9118 class CreateAIRecommendationJobRequest < Struct.new( :ai_recommendation_job_name, :model_source, :output_config, :ai_workload_config_identifier, :performance_target, :role_arn, :inference_specification, :optimize_model, :compute_spec, :adapter_source, :tags) SENSITIVE = [] include Aws::Structure end |
#model_source ⇒ Types::AIModelSource
The source of the model to optimize. Specify the Amazon S3 location of the model artifacts.
9118 9119 9120 9121 9122 9123 9124 9125 9126 9127 9128 9129 9130 9131 9132 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9118 class CreateAIRecommendationJobRequest < Struct.new( :ai_recommendation_job_name, :model_source, :output_config, :ai_workload_config_identifier, :performance_target, :role_arn, :inference_specification, :optimize_model, :compute_spec, :adapter_source, :tags) SENSITIVE = [] include Aws::Structure end |
#optimize_model ⇒ Boolean
Whether to allow model optimization techniques such as quantization,
speculative decoding, and kernel tuning. The default is true.
9118 9119 9120 9121 9122 9123 9124 9125 9126 9127 9128 9129 9130 9131 9132 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9118 class CreateAIRecommendationJobRequest < Struct.new( :ai_recommendation_job_name, :model_source, :output_config, :ai_workload_config_identifier, :performance_target, :role_arn, :inference_specification, :optimize_model, :compute_spec, :adapter_source, :tags) SENSITIVE = [] include Aws::Structure end |
#output_config ⇒ Types::AIRecommendationOutputConfig
The output configuration for the recommendation job, including the Amazon S3 location for results and an optional model package group where the optimized model is registered.
9118 9119 9120 9121 9122 9123 9124 9125 9126 9127 9128 9129 9130 9131 9132 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9118 class CreateAIRecommendationJobRequest < Struct.new( :ai_recommendation_job_name, :model_source, :output_config, :ai_workload_config_identifier, :performance_target, :role_arn, :inference_specification, :optimize_model, :compute_spec, :adapter_source, :tags) SENSITIVE = [] include Aws::Structure end |
#performance_target ⇒ Types::AIRecommendationPerformanceTarget
The performance targets for the recommendation job. Specify
constraints on metrics such as time to first token (ttft-ms),
throughput, or cost.
9118 9119 9120 9121 9122 9123 9124 9125 9126 9127 9128 9129 9130 9131 9132 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9118 class CreateAIRecommendationJobRequest < Struct.new( :ai_recommendation_job_name, :model_source, :output_config, :ai_workload_config_identifier, :performance_target, :role_arn, :inference_specification, :optimize_model, :compute_spec, :adapter_source, :tags) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that enables Amazon SageMaker AI to perform tasks on your behalf.
9118 9119 9120 9121 9122 9123 9124 9125 9126 9127 9128 9129 9130 9131 9132 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9118 class CreateAIRecommendationJobRequest < Struct.new( :ai_recommendation_job_name, :model_source, :output_config, :ai_workload_config_identifier, :performance_target, :role_arn, :inference_specification, :optimize_model, :compute_spec, :adapter_source, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The metadata that you apply to Amazon Web Services resources to help you categorize and organize them.
9118 9119 9120 9121 9122 9123 9124 9125 9126 9127 9128 9129 9130 9131 9132 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9118 class CreateAIRecommendationJobRequest < Struct.new( :ai_recommendation_job_name, :model_source, :output_config, :ai_workload_config_identifier, :performance_target, :role_arn, :inference_specification, :optimize_model, :compute_spec, :adapter_source, :tags) SENSITIVE = [] include Aws::Structure end |