Class: Aws::SageMaker::Types::CreateAppRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreateAppRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#app_name ⇒ String
The name of the app.
-
#app_type ⇒ String
The type of app.
-
#domain_id ⇒ String
The domain ID.
-
#recovery_mode ⇒ Boolean
Indicates whether the application is launched in recovery mode.
-
#resource_spec ⇒ Types::ResourceSpec
The instance type and the Amazon Resource Name (ARN) of the SageMaker AI image created on the instance.
-
#space_name ⇒ String
The name of the space.
-
#tags ⇒ Array<Types::Tag>
Each tag consists of a key and an optional value.
-
#user_profile_name ⇒ String
The user profile name.
Instance Attribute Details
#app_name ⇒ String
The name of the app.
7892 7893 7894 7895 7896 7897 7898 7899 7900 7901 7902 7903 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7892 class CreateAppRequest < Struct.new( :domain_id, :user_profile_name, :space_name, :app_type, :app_name, :tags, :resource_spec, :recovery_mode) SENSITIVE = [] include Aws::Structure end |
#app_type ⇒ String
The type of app.
7892 7893 7894 7895 7896 7897 7898 7899 7900 7901 7902 7903 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7892 class CreateAppRequest < Struct.new( :domain_id, :user_profile_name, :space_name, :app_type, :app_name, :tags, :resource_spec, :recovery_mode) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
The domain ID.
7892 7893 7894 7895 7896 7897 7898 7899 7900 7901 7902 7903 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7892 class CreateAppRequest < Struct.new( :domain_id, :user_profile_name, :space_name, :app_type, :app_name, :tags, :resource_spec, :recovery_mode) SENSITIVE = [] include Aws::Structure end |
#recovery_mode ⇒ Boolean
Indicates whether the application is launched in recovery mode.
7892 7893 7894 7895 7896 7897 7898 7899 7900 7901 7902 7903 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7892 class CreateAppRequest < Struct.new( :domain_id, :user_profile_name, :space_name, :app_type, :app_name, :tags, :resource_spec, :recovery_mode) SENSITIVE = [] include Aws::Structure end |
#resource_spec ⇒ Types::ResourceSpec
The instance type and the Amazon Resource Name (ARN) of the SageMaker AI image created on the instance.
<note markdown=“1”> The value of InstanceType passed as part of the ResourceSpec in the CreateApp call overrides the value passed as part of the ResourceSpec configured for the user profile or the domain. If InstanceType is not specified in any of those three ResourceSpec values for a KernelGateway app, the CreateApp call fails with a request validation error.
</note>
7892 7893 7894 7895 7896 7897 7898 7899 7900 7901 7902 7903 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7892 class CreateAppRequest < Struct.new( :domain_id, :user_profile_name, :space_name, :app_type, :app_name, :tags, :resource_spec, :recovery_mode) SENSITIVE = [] include Aws::Structure end |
#space_name ⇒ String
The name of the space. If this value is not set, then UserProfileName must be set.
7892 7893 7894 7895 7896 7897 7898 7899 7900 7901 7902 7903 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7892 class CreateAppRequest < Struct.new( :domain_id, :user_profile_name, :space_name, :app_type, :app_name, :tags, :resource_spec, :recovery_mode) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Each tag consists of a key and an optional value. Tag keys must be unique per resource.
7892 7893 7894 7895 7896 7897 7898 7899 7900 7901 7902 7903 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7892 class CreateAppRequest < Struct.new( :domain_id, :user_profile_name, :space_name, :app_type, :app_name, :tags, :resource_spec, :recovery_mode) SENSITIVE = [] include Aws::Structure end |
#user_profile_name ⇒ String
The user profile name. If this value is not set, then SpaceName must be set.
7892 7893 7894 7895 7896 7897 7898 7899 7900 7901 7902 7903 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7892 class CreateAppRequest < Struct.new( :domain_id, :user_profile_name, :space_name, :app_type, :app_name, :tags, :resource_spec, :recovery_mode) SENSITIVE = [] include Aws::Structure end |