Class: Aws::SageMaker::Types::CreateArtifactRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#artifact_nameString

The name of the artifact. Must be unique to your account in an Amazon Web Services Region.



4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
# File 'lib/aws-sdk-sagemaker/types.rb', line 4250

class CreateArtifactRequest < Struct.new(
  :artifact_name,
  :source,
  :artifact_type,
  :properties,
  :metadata_properties,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#artifact_typeString

The artifact type.



4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
# File 'lib/aws-sdk-sagemaker/types.rb', line 4250

class CreateArtifactRequest < Struct.new(
  :artifact_name,
  :source,
  :artifact_type,
  :properties,
  :metadata_properties,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#metadata_propertiesTypes::MetadataProperties

Metadata properties of the tracking entity, trial, or trial component.



4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
# File 'lib/aws-sdk-sagemaker/types.rb', line 4250

class CreateArtifactRequest < Struct.new(
  :artifact_name,
  :source,
  :artifact_type,
  :properties,
  :metadata_properties,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#propertiesHash<String,String>

A list of properties to add to the artifact.



4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
# File 'lib/aws-sdk-sagemaker/types.rb', line 4250

class CreateArtifactRequest < Struct.new(
  :artifact_name,
  :source,
  :artifact_type,
  :properties,
  :metadata_properties,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#sourceTypes::ArtifactSource

The ID, ID type, and URI of the source.



4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
# File 'lib/aws-sdk-sagemaker/types.rb', line 4250

class CreateArtifactRequest < Struct.new(
  :artifact_name,
  :source,
  :artifact_type,
  :properties,
  :metadata_properties,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

A list of tags to apply to the artifact.



4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
# File 'lib/aws-sdk-sagemaker/types.rb', line 4250

class CreateArtifactRequest < Struct.new(
  :artifact_name,
  :source,
  :artifact_type,
  :properties,
  :metadata_properties,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end