Class: Aws::SageMaker::Types::CreateAutoMLJobRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_ml_job_configTypes::AutoMLJobConfig

A collection of settings used to configure an AutoML job.



8046
8047
8048
8049
8050
8051
8052
8053
8054
8055
8056
8057
8058
8059
# File 'lib/aws-sdk-sagemaker/types.rb', line 8046

class CreateAutoMLJobRequest < Struct.new(
  :auto_ml_job_name,
  :input_data_config,
  :output_data_config,
  :problem_type,
  :auto_ml_job_objective,
  :auto_ml_job_config,
  :role_arn,
  :generate_candidate_definitions_only,
  :tags,
  :model_deploy_config)
  SENSITIVE = []
  include Aws::Structure
end

#auto_ml_job_nameString

Identifies an Autopilot job. The name must be unique to your account and is case insensitive.



8046
8047
8048
8049
8050
8051
8052
8053
8054
8055
8056
8057
8058
8059
# File 'lib/aws-sdk-sagemaker/types.rb', line 8046

class CreateAutoMLJobRequest < Struct.new(
  :auto_ml_job_name,
  :input_data_config,
  :output_data_config,
  :problem_type,
  :auto_ml_job_objective,
  :auto_ml_job_config,
  :role_arn,
  :generate_candidate_definitions_only,
  :tags,
  :model_deploy_config)
  SENSITIVE = []
  include Aws::Structure
end

#auto_ml_job_objectiveTypes::AutoMLJobObjective

Specifies a metric to minimize or maximize as the objective of a job. If not specified, the default objective metric depends on the problem type. See [AutoMLJobObjective] for the default values.

[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_AutoMLJobObjective.html



8046
8047
8048
8049
8050
8051
8052
8053
8054
8055
8056
8057
8058
8059
# File 'lib/aws-sdk-sagemaker/types.rb', line 8046

class CreateAutoMLJobRequest < Struct.new(
  :auto_ml_job_name,
  :input_data_config,
  :output_data_config,
  :problem_type,
  :auto_ml_job_objective,
  :auto_ml_job_config,
  :role_arn,
  :generate_candidate_definitions_only,
  :tags,
  :model_deploy_config)
  SENSITIVE = []
  include Aws::Structure
end

#generate_candidate_definitions_onlyBoolean

Generates possible candidates without training the models. A candidate is a combination of data preprocessors, algorithms, and algorithm parameter settings.



8046
8047
8048
8049
8050
8051
8052
8053
8054
8055
8056
8057
8058
8059
# File 'lib/aws-sdk-sagemaker/types.rb', line 8046

class CreateAutoMLJobRequest < Struct.new(
  :auto_ml_job_name,
  :input_data_config,
  :output_data_config,
  :problem_type,
  :auto_ml_job_objective,
  :auto_ml_job_config,
  :role_arn,
  :generate_candidate_definitions_only,
  :tags,
  :model_deploy_config)
  SENSITIVE = []
  include Aws::Structure
end

#input_data_configArray<Types::AutoMLChannel>

An array of channel objects that describes the input data and its location. Each channel is a named input source. Similar to InputDataConfig supported by [HyperParameterTrainingJobDefinition]. Format(s) supported: CSV, Parquet. A minimum of 500 rows is required for the training dataset. There is not a minimum number of rows required for the validation dataset.

[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_HyperParameterTrainingJobDefinition.html



8046
8047
8048
8049
8050
8051
8052
8053
8054
8055
8056
8057
8058
8059
# File 'lib/aws-sdk-sagemaker/types.rb', line 8046

class CreateAutoMLJobRequest < Struct.new(
  :auto_ml_job_name,
  :input_data_config,
  :output_data_config,
  :problem_type,
  :auto_ml_job_objective,
  :auto_ml_job_config,
  :role_arn,
  :generate_candidate_definitions_only,
  :tags,
  :model_deploy_config)
  SENSITIVE = []
  include Aws::Structure
end

#model_deploy_configTypes::ModelDeployConfig

Specifies how to generate the endpoint name for an automatic one-click Autopilot model deployment.



8046
8047
8048
8049
8050
8051
8052
8053
8054
8055
8056
8057
8058
8059
# File 'lib/aws-sdk-sagemaker/types.rb', line 8046

class CreateAutoMLJobRequest < Struct.new(
  :auto_ml_job_name,
  :input_data_config,
  :output_data_config,
  :problem_type,
  :auto_ml_job_objective,
  :auto_ml_job_config,
  :role_arn,
  :generate_candidate_definitions_only,
  :tags,
  :model_deploy_config)
  SENSITIVE = []
  include Aws::Structure
end

#output_data_configTypes::AutoMLOutputDataConfig

Provides information about encryption and the Amazon S3 output path needed to store artifacts from an AutoML job. Format(s) supported: CSV.



8046
8047
8048
8049
8050
8051
8052
8053
8054
8055
8056
8057
8058
8059
# File 'lib/aws-sdk-sagemaker/types.rb', line 8046

class CreateAutoMLJobRequest < Struct.new(
  :auto_ml_job_name,
  :input_data_config,
  :output_data_config,
  :problem_type,
  :auto_ml_job_objective,
  :auto_ml_job_config,
  :role_arn,
  :generate_candidate_definitions_only,
  :tags,
  :model_deploy_config)
  SENSITIVE = []
  include Aws::Structure
end

#problem_typeString

Defines the type of supervised learning problem available for the candidates. For more information, see [ SageMaker Autopilot problem types].

[1]: docs.aws.amazon.com/sagemaker/latest/dg/autopilot-datasets-problem-types.html#autopilot-problem-types



8046
8047
8048
8049
8050
8051
8052
8053
8054
8055
8056
8057
8058
8059
# File 'lib/aws-sdk-sagemaker/types.rb', line 8046

class CreateAutoMLJobRequest < Struct.new(
  :auto_ml_job_name,
  :input_data_config,
  :output_data_config,
  :problem_type,
  :auto_ml_job_objective,
  :auto_ml_job_config,
  :role_arn,
  :generate_candidate_definitions_only,
  :tags,
  :model_deploy_config)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The ARN of the role that is used to access the data.



8046
8047
8048
8049
8050
8051
8052
8053
8054
8055
8056
8057
8058
8059
# File 'lib/aws-sdk-sagemaker/types.rb', line 8046

class CreateAutoMLJobRequest < Struct.new(
  :auto_ml_job_name,
  :input_data_config,
  :output_data_config,
  :problem_type,
  :auto_ml_job_objective,
  :auto_ml_job_config,
  :role_arn,
  :generate_candidate_definitions_only,
  :tags,
  :model_deploy_config)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

An array of key-value pairs. You can use tags to categorize your Amazon Web Services resources in different ways, for example, by purpose, owner, or environment. For more information, see [Tagging Amazon Web ServicesResources]. Tag keys must be unique per resource.

[1]: docs.aws.amazon.com/general/latest/gr/aws_tagging.html



8046
8047
8048
8049
8050
8051
8052
8053
8054
8055
8056
8057
8058
8059
# File 'lib/aws-sdk-sagemaker/types.rb', line 8046

class CreateAutoMLJobRequest < Struct.new(
  :auto_ml_job_name,
  :input_data_config,
  :output_data_config,
  :problem_type,
  :auto_ml_job_objective,
  :auto_ml_job_config,
  :role_arn,
  :generate_candidate_definitions_only,
  :tags,
  :model_deploy_config)
  SENSITIVE = []
  include Aws::Structure
end