Class: Aws::SageMaker::Types::CreateEdgePackagingJobRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#compilation_job_nameString

The name of the SageMaker Neo compilation job that will be used to locate model artifacts for packaging.



10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
# File 'lib/aws-sdk-sagemaker/types.rb', line 10673

class CreateEdgePackagingJobRequest < Struct.new(
  :edge_packaging_job_name,
  :compilation_job_name,
  :model_name,
  :model_version,
  :role_arn,
  :output_config,
  :resource_key,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#edge_packaging_job_nameString

The name of the edge packaging job.



10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
# File 'lib/aws-sdk-sagemaker/types.rb', line 10673

class CreateEdgePackagingJobRequest < Struct.new(
  :edge_packaging_job_name,
  :compilation_job_name,
  :model_name,
  :model_version,
  :role_arn,
  :output_config,
  :resource_key,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#model_nameString

The name of the model.



10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
# File 'lib/aws-sdk-sagemaker/types.rb', line 10673

class CreateEdgePackagingJobRequest < Struct.new(
  :edge_packaging_job_name,
  :compilation_job_name,
  :model_name,
  :model_version,
  :role_arn,
  :output_config,
  :resource_key,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#model_versionString

The version of the model.



10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
# File 'lib/aws-sdk-sagemaker/types.rb', line 10673

class CreateEdgePackagingJobRequest < Struct.new(
  :edge_packaging_job_name,
  :compilation_job_name,
  :model_name,
  :model_version,
  :role_arn,
  :output_config,
  :resource_key,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#output_configTypes::EdgeOutputConfig

Provides information about the output location for the packaged model.



10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
# File 'lib/aws-sdk-sagemaker/types.rb', line 10673

class CreateEdgePackagingJobRequest < Struct.new(
  :edge_packaging_job_name,
  :compilation_job_name,
  :model_name,
  :model_version,
  :role_arn,
  :output_config,
  :resource_key,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#resource_keyString

The Amazon Web Services KMS key to use when encrypting the EBS volume the edge packaging job runs on.



10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
# File 'lib/aws-sdk-sagemaker/types.rb', line 10673

class CreateEdgePackagingJobRequest < Struct.new(
  :edge_packaging_job_name,
  :compilation_job_name,
  :model_name,
  :model_version,
  :role_arn,
  :output_config,
  :resource_key,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of an IAM role that enables Amazon SageMaker to download and upload the model, and to contact SageMaker Neo.



10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
# File 'lib/aws-sdk-sagemaker/types.rb', line 10673

class CreateEdgePackagingJobRequest < Struct.new(
  :edge_packaging_job_name,
  :compilation_job_name,
  :model_name,
  :model_version,
  :role_arn,
  :output_config,
  :resource_key,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Creates tags for the packaging job.



10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
# File 'lib/aws-sdk-sagemaker/types.rb', line 10673

class CreateEdgePackagingJobRequest < Struct.new(
  :edge_packaging_job_name,
  :compilation_job_name,
  :model_name,
  :model_version,
  :role_arn,
  :output_config,
  :resource_key,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end