Class: Aws::SageMaker::Types::CreateEndpointConfigInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreateEndpointConfigInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#async_inference_config ⇒ Types::AsyncInferenceConfig
Specifies configuration for how an endpoint performs asynchronous inference.
-
#data_capture_config ⇒ Types::DataCaptureConfig
Configuration to control how SageMaker captures inference data.
-
#endpoint_config_name ⇒ String
The name of the endpoint configuration.
-
#explainer_config ⇒ Types::ExplainerConfig
A member of
CreateEndpointConfigthat enables explainers. -
#kms_key_id ⇒ String
The Amazon Resource Name (ARN) of a Amazon Web Services Key Management Service key that SageMaker uses to encrypt data on the storage volume attached to the ML compute instance that hosts the endpoint.
-
#production_variants ⇒ Array<Types::ProductionVariant>
An array of
ProductionVariantobjects, one for each model that you want to host at this endpoint. -
#shadow_production_variants ⇒ Array<Types::ProductionVariant>
An array of
ProductionVariantobjects, one for each model that you want to host at this endpoint in shadow mode with production traffic replicated from the model specified onProductionVariants. -
#tags ⇒ Array<Types::Tag>
An array of key-value pairs.
Instance Attribute Details
#async_inference_config ⇒ Types::AsyncInferenceConfig
Specifies configuration for how an endpoint performs asynchronous inference. This is a required field in order for your Endpoint to be invoked using [InvokeEndpointAsync].
[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_runtime_InvokeEndpointAsync.html
5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5008 class CreateEndpointConfigInput < Struct.new( :endpoint_config_name, :production_variants, :data_capture_config, :tags, :kms_key_id, :async_inference_config, :explainer_config, :shadow_production_variants) SENSITIVE = [] include Aws::Structure end |
#data_capture_config ⇒ Types::DataCaptureConfig
Configuration to control how SageMaker captures inference data.
5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5008 class CreateEndpointConfigInput < Struct.new( :endpoint_config_name, :production_variants, :data_capture_config, :tags, :kms_key_id, :async_inference_config, :explainer_config, :shadow_production_variants) SENSITIVE = [] include Aws::Structure end |
#endpoint_config_name ⇒ String
The name of the endpoint configuration. You specify this name in a CreateEndpoint request.
5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5008 class CreateEndpointConfigInput < Struct.new( :endpoint_config_name, :production_variants, :data_capture_config, :tags, :kms_key_id, :async_inference_config, :explainer_config, :shadow_production_variants) SENSITIVE = [] include Aws::Structure end |
#explainer_config ⇒ Types::ExplainerConfig
A member of CreateEndpointConfig that enables explainers.
5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5008 class CreateEndpointConfigInput < Struct.new( :endpoint_config_name, :production_variants, :data_capture_config, :tags, :kms_key_id, :async_inference_config, :explainer_config, :shadow_production_variants) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The Amazon Resource Name (ARN) of a Amazon Web Services Key Management Service key that SageMaker uses to encrypt data on the storage volume attached to the ML compute instance that hosts the endpoint.
The KmsKeyId can be any of the following formats:
-
Key ID:
1234abcd-12ab-34cd-56ef-1234567890ab -
Key ARN:
arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab -
Alias name:
alias/ExampleAlias -
Alias name ARN:
arn:aws:kms:us-west-2:111122223333:alias/ExampleAlias
The KMS key policy must grant permission to the IAM role that you specify in your CreateEndpoint, UpdateEndpoint requests. For more information, refer to the Amazon Web Services Key Management Service section[ Using Key Policies in Amazon Web Services KMS ][1]
<note markdown=“1”> Certain Nitro-based instances include local storage, dependent on the instance type. Local storage volumes are encrypted using a hardware module on the instance. You can’t request a KmsKeyId when using an instance type with local storage. If any of the models that you specify in the ProductionVariants parameter use nitro-based instances with local storage, do not specify a value for the KmsKeyId parameter. If you specify a value for KmsKeyId when using any nitro-based instances with local storage, the call to CreateEndpointConfig fails.
For a list of instance types that support local instance storage,
see [Instance Store Volumes].
For more information about local instance storage encryption, see
[SSD Instance Store Volumes].
</note>
[1]: docs.aws.amazon.com/kms/latest/developerguide/key-policies.html [2]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/InstanceStorage.html#instance-store-volumes [3]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/ssd-instance-store.html
5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5008 class CreateEndpointConfigInput < Struct.new( :endpoint_config_name, :production_variants, :data_capture_config, :tags, :kms_key_id, :async_inference_config, :explainer_config, :shadow_production_variants) SENSITIVE = [] include Aws::Structure end |
#production_variants ⇒ Array<Types::ProductionVariant>
An array of ProductionVariant objects, one for each model that you want to host at this endpoint.
5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5008 class CreateEndpointConfigInput < Struct.new( :endpoint_config_name, :production_variants, :data_capture_config, :tags, :kms_key_id, :async_inference_config, :explainer_config, :shadow_production_variants) SENSITIVE = [] include Aws::Structure end |
#shadow_production_variants ⇒ Array<Types::ProductionVariant>
An array of ProductionVariant objects, one for each model that you want to host at this endpoint in shadow mode with production traffic replicated from the model specified on ProductionVariants. If you use this field, you can only specify one variant for ProductionVariants and one variant for ShadowProductionVariants.
5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5008 class CreateEndpointConfigInput < Struct.new( :endpoint_config_name, :production_variants, :data_capture_config, :tags, :kms_key_id, :async_inference_config, :explainer_config, :shadow_production_variants) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
An array of key-value pairs. You can use tags to categorize your Amazon Web Services resources in different ways, for example, by purpose, owner, or environment. For more information, see [Tagging Amazon Web Services Resources].
5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5008 class CreateEndpointConfigInput < Struct.new( :endpoint_config_name, :production_variants, :data_capture_config, :tags, :kms_key_id, :async_inference_config, :explainer_config, :shadow_production_variants) SENSITIVE = [] include Aws::Structure end |