Class: Aws::SageMaker::Types::CreateFeatureGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreateFeatureGroupRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A free-form description of a
FeatureGroup. -
#event_time_feature_name ⇒ String
The name of the feature that stores the
EventTimeof aRecordin aFeatureGroup. -
#feature_definitions ⇒ Array<Types::FeatureDefinition>
A list of
Featurenames and types. -
#feature_group_name ⇒ String
The name of the
FeatureGroup. -
#offline_store_config ⇒ Types::OfflineStoreConfig
Use this to configure an
OfflineFeatureStore. -
#online_store_config ⇒ Types::OnlineStoreConfig
You can turn the
OnlineStoreon or off by specifyingTruefor theEnableOnlineStoreflag inOnlineStoreConfig; the default value isFalse. -
#record_identifier_feature_name ⇒ String
The name of the
Featurewhose value uniquely identifies aRecorddefined in theFeatureStore. -
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM execution role used to persist data into the
OfflineStoreif anOfflineStoreConfigis provided. -
#tags ⇒ Array<Types::Tag>
Tags used to identify
Featuresin eachFeatureGroup.
Instance Attribute Details
#description ⇒ String
A free-form description of a FeatureGroup.
5244 5245 5246 5247 5248 5249 5250 5251 5252 5253 5254 5255 5256 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5244 class CreateFeatureGroupRequest < Struct.new( :feature_group_name, :record_identifier_feature_name, :event_time_feature_name, :feature_definitions, :online_store_config, :offline_store_config, :role_arn, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#event_time_feature_name ⇒ String
The name of the feature that stores the EventTime of a Record in a FeatureGroup.
An EventTime is a point in time when a new event occurs that corresponds to the creation or update of a Record in a FeatureGroup. All Records in the FeatureGroup must have a corresponding EventTime.
An EventTime can be a String or Fractional.
-
Fractional:EventTimefeature values must be a Unix timestamp in seconds. -
String:EventTimefeature values must be an ISO-8601 string in the format. The following formats are supported ‘yyyy-MM-dd’T’HH:mm:ssZ` and ‘yyyy-MM-dd’T’HH:mm:ss.SSSZ` whereyyyy,MM, andddrepresent the year, month, and day respectively andHH,mm,ss, and if applicable,SSSrepresent the hour, month, second and milliseconds respsectively. ‘’T’‘ andZare constants.
5244 5245 5246 5247 5248 5249 5250 5251 5252 5253 5254 5255 5256 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5244 class CreateFeatureGroupRequest < Struct.new( :feature_group_name, :record_identifier_feature_name, :event_time_feature_name, :feature_definitions, :online_store_config, :offline_store_config, :role_arn, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#feature_definitions ⇒ Array<Types::FeatureDefinition>
A list of Feature names and types. Name and Type is compulsory per Feature.
Valid feature ‘FeatureType`s are Integral, Fractional and String.
‘FeatureName`s cannot be any of the following: is_deleted, write_time, api_invocation_time
You can create up to 2,500 ‘FeatureDefinition`s per FeatureGroup.
5244 5245 5246 5247 5248 5249 5250 5251 5252 5253 5254 5255 5256 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5244 class CreateFeatureGroupRequest < Struct.new( :feature_group_name, :record_identifier_feature_name, :event_time_feature_name, :feature_definitions, :online_store_config, :offline_store_config, :role_arn, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#feature_group_name ⇒ String
The name of the FeatureGroup. The name must be unique within an Amazon Web Services Region in an Amazon Web Services account. The name:
-
Must start and end with an alphanumeric character.
-
Can only contain alphanumeric character and hyphens. Spaces are not allowed.
5244 5245 5246 5247 5248 5249 5250 5251 5252 5253 5254 5255 5256 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5244 class CreateFeatureGroupRequest < Struct.new( :feature_group_name, :record_identifier_feature_name, :event_time_feature_name, :feature_definitions, :online_store_config, :offline_store_config, :role_arn, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#offline_store_config ⇒ Types::OfflineStoreConfig
Use this to configure an OfflineFeatureStore. This parameter allows you to specify:
-
The Amazon Simple Storage Service (Amazon S3) location of an
OfflineStore. -
A configuration for an Amazon Web Services Glue or Amazon Web Services Hive data catalog.
-
An KMS encryption key to encrypt the Amazon S3 location used for
OfflineStore. If KMS encryption key is not specified, by default we encrypt all data at rest using Amazon Web Services KMS key. By defining your [bucket-level key] for SSE, you can reduce Amazon Web Services KMS requests costs by up to 99 percent. -
Format for the offline store table. Supported formats are Glue (Default) and [Apache Iceberg].
To learn more about this parameter, see OfflineStoreConfig.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/bucket-key.html [2]: iceberg.apache.org/
5244 5245 5246 5247 5248 5249 5250 5251 5252 5253 5254 5255 5256 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5244 class CreateFeatureGroupRequest < Struct.new( :feature_group_name, :record_identifier_feature_name, :event_time_feature_name, :feature_definitions, :online_store_config, :offline_store_config, :role_arn, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#online_store_config ⇒ Types::OnlineStoreConfig
You can turn the OnlineStore on or off by specifying True for the EnableOnlineStore flag in OnlineStoreConfig; the default value is False.
You can also include an Amazon Web Services KMS key ID (KMSKeyId) for at-rest encryption of the OnlineStore.
5244 5245 5246 5247 5248 5249 5250 5251 5252 5253 5254 5255 5256 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5244 class CreateFeatureGroupRequest < Struct.new( :feature_group_name, :record_identifier_feature_name, :event_time_feature_name, :feature_definitions, :online_store_config, :offline_store_config, :role_arn, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#record_identifier_feature_name ⇒ String
The name of the Feature whose value uniquely identifies a Record defined in the FeatureStore. Only the latest record per identifier value will be stored in the OnlineStore. RecordIdentifierFeatureName must be one of feature definitions’ names.
You use the RecordIdentifierFeatureName to access data in a FeatureStore.
This name:
-
Must start and end with an alphanumeric character.
-
Can only contains alphanumeric characters, hyphens, underscores. Spaces are not allowed.
5244 5245 5246 5247 5248 5249 5250 5251 5252 5253 5254 5255 5256 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5244 class CreateFeatureGroupRequest < Struct.new( :feature_group_name, :record_identifier_feature_name, :event_time_feature_name, :feature_definitions, :online_store_config, :offline_store_config, :role_arn, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM execution role used to persist data into the OfflineStore if an OfflineStoreConfig is provided.
5244 5245 5246 5247 5248 5249 5250 5251 5252 5253 5254 5255 5256 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5244 class CreateFeatureGroupRequest < Struct.new( :feature_group_name, :record_identifier_feature_name, :event_time_feature_name, :feature_definitions, :online_store_config, :offline_store_config, :role_arn, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Tags used to identify Features in each FeatureGroup.
5244 5245 5246 5247 5248 5249 5250 5251 5252 5253 5254 5255 5256 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5244 class CreateFeatureGroupRequest < Struct.new( :feature_group_name, :record_identifier_feature_name, :event_time_feature_name, :feature_definitions, :online_store_config, :offline_store_config, :role_arn, :description, :tags) SENSITIVE = [] include Aws::Structure end |