Class: Aws::SageMaker::Types::CreateHubContentPresignedUrlsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreateHubContentPresignedUrlsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_config ⇒ Types::PresignedUrlAccessConfig
Configuration settings for accessing the hub content, including end-user license agreement acceptance for gated models and expected S3 URL validation.
-
#hub_content_name ⇒ String
The name of the hub content for which to generate presigned URLs.
-
#hub_content_type ⇒ String
The type of hub content to access.
-
#hub_content_version ⇒ String
The version of the hub content.
-
#hub_name ⇒ String
The name or Amazon Resource Name (ARN) of the hub that contains the content.
-
#max_results ⇒ Integer
The maximum number of presigned URLs to return in the response.
-
#next_token ⇒ String
A token for pagination.
Instance Attribute Details
#access_config ⇒ Types::PresignedUrlAccessConfig
Configuration settings for accessing the hub content, including end-user license agreement acceptance for gated models and expected S3 URL validation.
9781 9782 9783 9784 9785 9786 9787 9788 9789 9790 9791 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9781 class CreateHubContentPresignedUrlsRequest < Struct.new( :hub_name, :hub_content_type, :hub_content_name, :hub_content_version, :access_config, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#hub_content_name ⇒ String
The name of the hub content for which to generate presigned URLs. This identifies the specific model or content within the hub.
9781 9782 9783 9784 9785 9786 9787 9788 9789 9790 9791 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9781 class CreateHubContentPresignedUrlsRequest < Struct.new( :hub_name, :hub_content_type, :hub_content_name, :hub_content_version, :access_config, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#hub_content_type ⇒ String
The type of hub content to access. Valid values include ‘Model`, `Notebook`, and `ModelReference`.
9781 9782 9783 9784 9785 9786 9787 9788 9789 9790 9791 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9781 class CreateHubContentPresignedUrlsRequest < Struct.new( :hub_name, :hub_content_type, :hub_content_name, :hub_content_version, :access_config, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#hub_content_version ⇒ String
The version of the hub content. If not specified, the latest version is used.
9781 9782 9783 9784 9785 9786 9787 9788 9789 9790 9791 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9781 class CreateHubContentPresignedUrlsRequest < Struct.new( :hub_name, :hub_content_type, :hub_content_name, :hub_content_version, :access_config, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#hub_name ⇒ String
The name or Amazon Resource Name (ARN) of the hub that contains the content. For public content, use ‘SageMakerPublicHub`.
9781 9782 9783 9784 9785 9786 9787 9788 9789 9790 9791 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9781 class CreateHubContentPresignedUrlsRequest < Struct.new( :hub_name, :hub_content_type, :hub_content_name, :hub_content_version, :access_config, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of presigned URLs to return in the response. Default value is 100. Large models may contain hundreds of files, requiring pagination to retrieve all URLs.
9781 9782 9783 9784 9785 9786 9787 9788 9789 9790 9791 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9781 class CreateHubContentPresignedUrlsRequest < Struct.new( :hub_name, :hub_content_type, :hub_content_name, :hub_content_version, :access_config, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token for pagination. Use this token to retrieve the next set of presigned URLs when the response is truncated.
9781 9782 9783 9784 9785 9786 9787 9788 9789 9790 9791 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9781 class CreateHubContentPresignedUrlsRequest < Struct.new( :hub_name, :hub_content_type, :hub_content_name, :hub_content_version, :access_config, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |