Class: Aws::SageMaker::Types::CreateHyperParameterTuningJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreateHyperParameterTuningJobRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#hyper_parameter_tuning_job_config ⇒ Types::HyperParameterTuningJobConfig
The HyperParameterTuningJobConfig object that describes the tuning job, including the search strategy, the objective metric used to evaluate training jobs, ranges of parameters to search, and resource limits for the tuning job.
-
#hyper_parameter_tuning_job_name ⇒ String
The name of the tuning job.
-
#tags ⇒ Array<Types::Tag>
An array of key-value pairs.
-
#training_job_definition ⇒ Types::HyperParameterTrainingJobDefinition
The HyperParameterTrainingJobDefinition object that describes the training jobs that this tuning job launches, including static hyperparameters, input data configuration, output data configuration, resource configuration, and stopping condition.
-
#training_job_definitions ⇒ Array<Types::HyperParameterTrainingJobDefinition>
A list of the HyperParameterTrainingJobDefinition objects launched for this tuning job.
-
#warm_start_config ⇒ Types::HyperParameterTuningJobWarmStartConfig
Specifies the configuration for starting the hyperparameter tuning job using one or more previous tuning jobs as a starting point.
Instance Attribute Details
#hyper_parameter_tuning_job_config ⇒ Types::HyperParameterTuningJobConfig
The HyperParameterTuningJobConfig object that describes the tuning job, including the search strategy, the objective metric used to evaluate training jobs, ranges of parameters to search, and resource limits for the tuning job. For more information, see [How Hyperparameter Tuning Works].
[1]: docs.aws.amazon.com/sagemaker/latest/dg/automatic-model-tuning-how-it-works.html
5492 5493 5494 5495 5496 5497 5498 5499 5500 5501 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5492 class CreateHyperParameterTuningJobRequest < Struct.new( :hyper_parameter_tuning_job_name, :hyper_parameter_tuning_job_config, :training_job_definition, :training_job_definitions, :warm_start_config, :tags) SENSITIVE = [] include Aws::Structure end |
#hyper_parameter_tuning_job_name ⇒ String
The name of the tuning job. This name is the prefix for the names of all training jobs that this tuning job launches. The name must be unique within the same Amazon Web Services account and Amazon Web Services Region. The name must have 1 to 32 characters. Valid characters are a-z, A-Z, 0-9, and : + = @ _ % - (hyphen). The name is not case sensitive.
5492 5493 5494 5495 5496 5497 5498 5499 5500 5501 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5492 class CreateHyperParameterTuningJobRequest < Struct.new( :hyper_parameter_tuning_job_name, :hyper_parameter_tuning_job_config, :training_job_definition, :training_job_definitions, :warm_start_config, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
An array of key-value pairs. You can use tags to categorize your Amazon Web Services resources in different ways, for example, by purpose, owner, or environment. For more information, see [Tagging Amazon Web Services Resources].
Tags that you specify for the tuning job are also added to all training jobs that the tuning job launches.
5492 5493 5494 5495 5496 5497 5498 5499 5500 5501 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5492 class CreateHyperParameterTuningJobRequest < Struct.new( :hyper_parameter_tuning_job_name, :hyper_parameter_tuning_job_config, :training_job_definition, :training_job_definitions, :warm_start_config, :tags) SENSITIVE = [] include Aws::Structure end |
#training_job_definition ⇒ Types::HyperParameterTrainingJobDefinition
The HyperParameterTrainingJobDefinition object that describes the training jobs that this tuning job launches, including static hyperparameters, input data configuration, output data configuration, resource configuration, and stopping condition.
5492 5493 5494 5495 5496 5497 5498 5499 5500 5501 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5492 class CreateHyperParameterTuningJobRequest < Struct.new( :hyper_parameter_tuning_job_name, :hyper_parameter_tuning_job_config, :training_job_definition, :training_job_definitions, :warm_start_config, :tags) SENSITIVE = [] include Aws::Structure end |
#training_job_definitions ⇒ Array<Types::HyperParameterTrainingJobDefinition>
A list of the HyperParameterTrainingJobDefinition objects launched for this tuning job.
5492 5493 5494 5495 5496 5497 5498 5499 5500 5501 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5492 class CreateHyperParameterTuningJobRequest < Struct.new( :hyper_parameter_tuning_job_name, :hyper_parameter_tuning_job_config, :training_job_definition, :training_job_definitions, :warm_start_config, :tags) SENSITIVE = [] include Aws::Structure end |
#warm_start_config ⇒ Types::HyperParameterTuningJobWarmStartConfig
Specifies the configuration for starting the hyperparameter tuning job using one or more previous tuning jobs as a starting point. The results of previous tuning jobs are used to inform which combinations of hyperparameters to search over in the new tuning job.
All training jobs launched by the new hyperparameter tuning job are evaluated by using the objective metric. If you specify IDENTICAL_DATA_AND_ALGORITHM as the WarmStartType value for the warm start configuration, the training job that performs the best in the new tuning job is compared to the best training jobs from the parent tuning jobs. From these, the training job that performs the best as measured by the objective metric is returned as the overall best training job.
<note markdown=“1”> All training jobs launched by parent hyperparameter tuning jobs and the new hyperparameter tuning jobs count against the limit of training jobs for the tuning job.
</note>
5492 5493 5494 5495 5496 5497 5498 5499 5500 5501 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5492 class CreateHyperParameterTuningJobRequest < Struct.new( :hyper_parameter_tuning_job_name, :hyper_parameter_tuning_job_config, :training_job_definition, :training_job_definitions, :warm_start_config, :tags) SENSITIVE = [] include Aws::Structure end |