Class: Aws::SageMaker::Types::CreateImageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreateImageRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the image.
-
#display_name ⇒ String
The display name of the image.
-
#image_name ⇒ String
The name of the image.
-
#role_arn ⇒ String
The ARN of an IAM role that enables Amazon SageMaker AI to perform tasks on your behalf.
-
#tags ⇒ Array<Types::Tag>
A list of tags to apply to the image.
Instance Attribute Details
#description ⇒ String
The description of the image.
11201 11202 11203 11204 11205 11206 11207 11208 11209 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 11201 class CreateImageRequest < Struct.new( :description, :display_name, :image_name, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The display name of the image. If not provided, ‘ImageName` is displayed.
11201 11202 11203 11204 11205 11206 11207 11208 11209 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 11201 class CreateImageRequest < Struct.new( :description, :display_name, :image_name, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#image_name ⇒ String
The name of the image. Must be unique to your account.
11201 11202 11203 11204 11205 11206 11207 11208 11209 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 11201 class CreateImageRequest < Struct.new( :description, :display_name, :image_name, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The ARN of an IAM role that enables Amazon SageMaker AI to perform tasks on your behalf.
11201 11202 11203 11204 11205 11206 11207 11208 11209 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 11201 class CreateImageRequest < Struct.new( :description, :display_name, :image_name, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of tags to apply to the image.
11201 11202 11203 11204 11205 11206 11207 11208 11209 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 11201 class CreateImageRequest < Struct.new( :description, :display_name, :image_name, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |