Class: Aws::SageMaker::Types::CreateInferenceComponentInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#endpoint_nameString

The name of an existing endpoint where you host the inference component.

Returns:

  • (String)


11165
11166
11167
11168
11169
11170
11171
11172
11173
11174
11175
# File 'lib/aws-sdk-sagemaker/types.rb', line 11165

class CreateInferenceComponentInput < Struct.new(
  :inference_component_name,
  :endpoint_name,
  :variant_name,
  :specification,
  :specifications,
  :runtime_config,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#inference_component_nameString

A unique name to assign to the inference component.

Returns:

  • (String)


11165
11166
11167
11168
11169
11170
11171
11172
11173
11174
11175
# File 'lib/aws-sdk-sagemaker/types.rb', line 11165

class CreateInferenceComponentInput < Struct.new(
  :inference_component_name,
  :endpoint_name,
  :variant_name,
  :specification,
  :specifications,
  :runtime_config,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#runtime_configTypes::InferenceComponentRuntimeConfig

Runtime settings for a model that is deployed with an inference component.



11165
11166
11167
11168
11169
11170
11171
11172
11173
11174
11175
# File 'lib/aws-sdk-sagemaker/types.rb', line 11165

class CreateInferenceComponentInput < Struct.new(
  :inference_component_name,
  :endpoint_name,
  :variant_name,
  :specification,
  :specifications,
  :runtime_config,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#specificationTypes::InferenceComponentSpecification

Details about the resources to deploy with this inference component, including the model, container, and compute resources.



11165
11166
11167
11168
11169
11170
11171
11172
11173
11174
11175
# File 'lib/aws-sdk-sagemaker/types.rb', line 11165

class CreateInferenceComponentInput < Struct.new(
  :inference_component_name,
  :endpoint_name,
  :variant_name,
  :specification,
  :specifications,
  :runtime_config,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#specificationsArray<Types::InferenceComponentSpecification>

A list of specification objects for the inference component, one per instance type. Use this parameter when you want to deploy a different model or resource configuration for the inference component on each instance type. You can use either this parameter or the singular ‘Specification` parameter, but not both.



11165
11166
11167
11168
11169
11170
11171
11172
11173
11174
11175
# File 'lib/aws-sdk-sagemaker/types.rb', line 11165

class CreateInferenceComponentInput < Struct.new(
  :inference_component_name,
  :endpoint_name,
  :variant_name,
  :specification,
  :specifications,
  :runtime_config,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

A list of key-value pairs associated with the model. For more information, see [Tagging Amazon Web Services resources] in the *Amazon Web Services General Reference*.

[1]: docs.aws.amazon.com/general/latest/gr/aws_tagging.html

Returns:



11165
11166
11167
11168
11169
11170
11171
11172
11173
11174
11175
# File 'lib/aws-sdk-sagemaker/types.rb', line 11165

class CreateInferenceComponentInput < Struct.new(
  :inference_component_name,
  :endpoint_name,
  :variant_name,
  :specification,
  :specifications,
  :runtime_config,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#variant_nameString

The name of an existing production variant where you host the inference component.

Returns:

  • (String)


11165
11166
11167
11168
11169
11170
11171
11172
11173
11174
11175
# File 'lib/aws-sdk-sagemaker/types.rb', line 11165

class CreateInferenceComponentInput < Struct.new(
  :inference_component_name,
  :endpoint_name,
  :variant_name,
  :specification,
  :specifications,
  :runtime_config,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end