Class: Aws::SageMaker::Types::CreateMlflowAppRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_default_statusString

Indicates whether this MLflow app is the default for the entire account.

Returns:

  • (String)


12264
12265
12266
12267
12268
12269
12270
12271
12272
12273
12274
12275
12276
# File 'lib/aws-sdk-sagemaker/types.rb', line 12264

class CreateMlflowAppRequest < Struct.new(
  :name,
  :artifact_store_uri,
  :role_arn,
  :kms_key_id,
  :model_registration_mode,
  :weekly_maintenance_window_start,
  :account_default_status,
  :default_domain_id_list,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#artifact_store_uriString

The S3 URI for a general purpose bucket to use as the MLflow App artifact store.

Returns:

  • (String)


12264
12265
12266
12267
12268
12269
12270
12271
12272
12273
12274
12275
12276
# File 'lib/aws-sdk-sagemaker/types.rb', line 12264

class CreateMlflowAppRequest < Struct.new(
  :name,
  :artifact_store_uri,
  :role_arn,
  :kms_key_id,
  :model_registration_mode,
  :weekly_maintenance_window_start,
  :account_default_status,
  :default_domain_id_list,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#default_domain_id_listArray<String>

List of SageMaker domain IDs for which this MLflow App is used as the default.

Returns:

  • (Array<String>)


12264
12265
12266
12267
12268
12269
12270
12271
12272
12273
12274
12275
12276
# File 'lib/aws-sdk-sagemaker/types.rb', line 12264

class CreateMlflowAppRequest < Struct.new(
  :name,
  :artifact_store_uri,
  :role_arn,
  :kms_key_id,
  :model_registration_mode,
  :weekly_maintenance_window_start,
  :account_default_status,
  :default_domain_id_list,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

The ID of the Amazon Web Services KMS key used to encrypt the data at rest associated with the MLflow App. If you don't specify a value, the MLflow App is not encrypted with a customer-managed key.

Returns:

  • (String)


12264
12265
12266
12267
12268
12269
12270
12271
12272
12273
12274
12275
12276
# File 'lib/aws-sdk-sagemaker/types.rb', line 12264

class CreateMlflowAppRequest < Struct.new(
  :name,
  :artifact_store_uri,
  :role_arn,
  :kms_key_id,
  :model_registration_mode,
  :weekly_maintenance_window_start,
  :account_default_status,
  :default_domain_id_list,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#model_registration_modeString

Whether to enable or disable automatic registration of new MLflow models to the SageMaker Model Registry. To enable automatic model registration, set this value to AutoModelRegistrationEnabled. To disable automatic model registration, set this value to AutoModelRegistrationDisabled. If not specified, AutomaticModelRegistration defaults to AutoModelRegistrationDisabled.

Returns:

  • (String)


12264
12265
12266
12267
12268
12269
12270
12271
12272
12273
12274
12275
12276
# File 'lib/aws-sdk-sagemaker/types.rb', line 12264

class CreateMlflowAppRequest < Struct.new(
  :name,
  :artifact_store_uri,
  :role_arn,
  :kms_key_id,
  :model_registration_mode,
  :weekly_maintenance_window_start,
  :account_default_status,
  :default_domain_id_list,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A string identifying the MLflow app name. This string is not part of the tracking server ARN.

Returns:

  • (String)


12264
12265
12266
12267
12268
12269
12270
12271
12272
12273
12274
12275
12276
# File 'lib/aws-sdk-sagemaker/types.rb', line 12264

class CreateMlflowAppRequest < Struct.new(
  :name,
  :artifact_store_uri,
  :role_arn,
  :kms_key_id,
  :model_registration_mode,
  :weekly_maintenance_window_start,
  :account_default_status,
  :default_domain_id_list,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) for an IAM role in your account that the MLflow App uses to access the artifact store in Amazon S3. The role should have the AmazonS3FullAccess permission.

Returns:

  • (String)


12264
12265
12266
12267
12268
12269
12270
12271
12272
12273
12274
12275
12276
# File 'lib/aws-sdk-sagemaker/types.rb', line 12264

class CreateMlflowAppRequest < Struct.new(
  :name,
  :artifact_store_uri,
  :role_arn,
  :kms_key_id,
  :model_registration_mode,
  :weekly_maintenance_window_start,
  :account_default_status,
  :default_domain_id_list,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Tags consisting of key-value pairs used to manage metadata for the MLflow App.

Returns:



12264
12265
12266
12267
12268
12269
12270
12271
12272
12273
12274
12275
12276
# File 'lib/aws-sdk-sagemaker/types.rb', line 12264

class CreateMlflowAppRequest < Struct.new(
  :name,
  :artifact_store_uri,
  :role_arn,
  :kms_key_id,
  :model_registration_mode,
  :weekly_maintenance_window_start,
  :account_default_status,
  :default_domain_id_list,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#weekly_maintenance_window_startString

The day and time of the week in Coordinated Universal Time (UTC) 24-hour standard time that weekly maintenance updates are scheduled. For example: TUE:03:30.

Returns:

  • (String)


12264
12265
12266
12267
12268
12269
12270
12271
12272
12273
12274
12275
12276
# File 'lib/aws-sdk-sagemaker/types.rb', line 12264

class CreateMlflowAppRequest < Struct.new(
  :name,
  :artifact_store_uri,
  :role_arn,
  :kms_key_id,
  :model_registration_mode,
  :weekly_maintenance_window_start,
  :account_default_status,
  :default_domain_id_list,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end