Class: Aws::SageMaker::Types::CreateModelPackageGroupInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreateModelPackageGroupInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#managed_configuration ⇒ Types::ManagedConfiguration
The managed configuration of the model package group.
-
#model_package_group_description ⇒ String
A description for the model group.
-
#model_package_group_name ⇒ String
The name of the model group.
-
#tags ⇒ Array<Types::Tag>
A list of key value pairs associated with the model group.
Instance Attribute Details
#managed_configuration ⇒ Types::ManagedConfiguration
The managed configuration of the model package group.
12769 12770 12771 12772 12773 12774 12775 12776 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12769 class CreateModelPackageGroupInput < Struct.new( :model_package_group_name, :model_package_group_description, :tags, :managed_configuration) SENSITIVE = [] include Aws::Structure end |
#model_package_group_description ⇒ String
A description for the model group.
12769 12770 12771 12772 12773 12774 12775 12776 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12769 class CreateModelPackageGroupInput < Struct.new( :model_package_group_name, :model_package_group_description, :tags, :managed_configuration) SENSITIVE = [] include Aws::Structure end |
#model_package_group_name ⇒ String
The name of the model group.
12769 12770 12771 12772 12773 12774 12775 12776 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12769 class CreateModelPackageGroupInput < Struct.new( :model_package_group_name, :model_package_group_description, :tags, :managed_configuration) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of key value pairs associated with the model group. For more information, see Tagging Amazon Web Services resources in the Amazon Web Services General Reference Guide.
12769 12770 12771 12772 12773 12774 12775 12776 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12769 class CreateModelPackageGroupInput < Struct.new( :model_package_group_name, :model_package_group_description, :tags, :managed_configuration) SENSITIVE = [] include Aws::Structure end |