Class: Aws::SageMaker::Types::CreateModelPackageInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreateModelPackageInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_inference_specifications ⇒ Array<Types::AdditionalInferenceSpecificationDefinition>
An array of additional Inference Specification objects.
-
#certify_for_marketplace ⇒ Boolean
Whether to certify the model package for listing on Amazon Web Services Marketplace.
-
#client_token ⇒ String
A unique token that guarantees that the call to this API is idempotent.
-
#customer_metadata_properties ⇒ Hash<String,String>
The metadata properties associated with the model package versions.
-
#domain ⇒ String
The machine learning domain of your model package and its components.
-
#drift_check_baselines ⇒ Types::DriftCheckBaselines
Represents the drift check baselines that can be used when the model monitor is set using the model package.
-
#inference_specification ⇒ Types::InferenceSpecification
Specifies details about inference jobs that can be run with models based on this model package, including the following:.
-
#metadata_properties ⇒ Types::MetadataProperties
Metadata properties of the tracking entity, trial, or trial component.
-
#model_approval_status ⇒ String
Whether the model is approved for deployment.
-
#model_metrics ⇒ Types::ModelMetrics
A structure that contains model metrics reports.
-
#model_package_description ⇒ String
A description of the model package.
-
#model_package_group_name ⇒ String
The name or Amazon Resource Name (ARN) of the model package group that this model version belongs to.
-
#model_package_name ⇒ String
The name of the model package.
-
#sample_payload_url ⇒ String
The Amazon Simple Storage Service (Amazon S3) path where the sample payload are stored.
-
#source_algorithm_specification ⇒ Types::SourceAlgorithmSpecification
Details about the algorithm that was used to create the model package.
-
#tags ⇒ Array<Types::Tag>
A list of key value pairs associated with the model.
-
#task ⇒ String
The machine learning task your model package accomplishes.
-
#validation_specification ⇒ Types::ModelPackageValidationSpecification
Specifies configurations for one or more transform jobs that SageMaker runs to test the model package.
Instance Attribute Details
#additional_inference_specifications ⇒ Array<Types::AdditionalInferenceSpecificationDefinition>
An array of additional Inference Specification objects. Each additional Inference Specification specifies artifacts based on this model package that can be used on inference endpoints. Generally used with SageMaker Neo to store the compiled artifacts.
6645 6646 6647 6648 6649 6650 6651 6652 6653 6654 6655 6656 6657 6658 6659 6660 6661 6662 6663 6664 6665 6666 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6645 class CreateModelPackageInput < Struct.new( :model_package_name, :model_package_group_name, :model_package_description, :inference_specification, :validation_specification, :source_algorithm_specification, :certify_for_marketplace, :tags, :model_approval_status, :metadata_properties, :model_metrics, :client_token, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#certify_for_marketplace ⇒ Boolean
Whether to certify the model package for listing on Amazon Web Services Marketplace.
This parameter is optional for unversioned models, and does not apply to versioned models.
6645 6646 6647 6648 6649 6650 6651 6652 6653 6654 6655 6656 6657 6658 6659 6660 6661 6662 6663 6664 6665 6666 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6645 class CreateModelPackageInput < Struct.new( :model_package_name, :model_package_group_name, :model_package_description, :inference_specification, :validation_specification, :source_algorithm_specification, :certify_for_marketplace, :tags, :model_approval_status, :metadata_properties, :model_metrics, :client_token, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique token that guarantees that the call to this API is idempotent.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
6645 6646 6647 6648 6649 6650 6651 6652 6653 6654 6655 6656 6657 6658 6659 6660 6661 6662 6663 6664 6665 6666 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6645 class CreateModelPackageInput < Struct.new( :model_package_name, :model_package_group_name, :model_package_description, :inference_specification, :validation_specification, :source_algorithm_specification, :certify_for_marketplace, :tags, :model_approval_status, :metadata_properties, :model_metrics, :client_token, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#customer_metadata_properties ⇒ Hash<String,String>
The metadata properties associated with the model package versions.
6645 6646 6647 6648 6649 6650 6651 6652 6653 6654 6655 6656 6657 6658 6659 6660 6661 6662 6663 6664 6665 6666 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6645 class CreateModelPackageInput < Struct.new( :model_package_name, :model_package_group_name, :model_package_description, :inference_specification, :validation_specification, :source_algorithm_specification, :certify_for_marketplace, :tags, :model_approval_status, :metadata_properties, :model_metrics, :client_token, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#domain ⇒ String
The machine learning domain of your model package and its components. Common machine learning domains include computer vision and natural language processing.
6645 6646 6647 6648 6649 6650 6651 6652 6653 6654 6655 6656 6657 6658 6659 6660 6661 6662 6663 6664 6665 6666 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6645 class CreateModelPackageInput < Struct.new( :model_package_name, :model_package_group_name, :model_package_description, :inference_specification, :validation_specification, :source_algorithm_specification, :certify_for_marketplace, :tags, :model_approval_status, :metadata_properties, :model_metrics, :client_token, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#drift_check_baselines ⇒ Types::DriftCheckBaselines
Represents the drift check baselines that can be used when the model monitor is set using the model package. For more information, see the topic on [Drift Detection against Previous Baselines in SageMaker Pipelines] in the *Amazon SageMaker Developer Guide*.
6645 6646 6647 6648 6649 6650 6651 6652 6653 6654 6655 6656 6657 6658 6659 6660 6661 6662 6663 6664 6665 6666 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6645 class CreateModelPackageInput < Struct.new( :model_package_name, :model_package_group_name, :model_package_description, :inference_specification, :validation_specification, :source_algorithm_specification, :certify_for_marketplace, :tags, :model_approval_status, :metadata_properties, :model_metrics, :client_token, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#inference_specification ⇒ Types::InferenceSpecification
Specifies details about inference jobs that can be run with models based on this model package, including the following:
-
The Amazon ECR paths of containers that contain the inference code and model artifacts.
-
The instance types that the model package supports for transform jobs and real-time endpoints used for inference.
-
The input and output content formats that the model package supports for inference.
6645 6646 6647 6648 6649 6650 6651 6652 6653 6654 6655 6656 6657 6658 6659 6660 6661 6662 6663 6664 6665 6666 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6645 class CreateModelPackageInput < Struct.new( :model_package_name, :model_package_group_name, :model_package_description, :inference_specification, :validation_specification, :source_algorithm_specification, :certify_for_marketplace, :tags, :model_approval_status, :metadata_properties, :model_metrics, :client_token, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#metadata_properties ⇒ Types::MetadataProperties
Metadata properties of the tracking entity, trial, or trial component.
6645 6646 6647 6648 6649 6650 6651 6652 6653 6654 6655 6656 6657 6658 6659 6660 6661 6662 6663 6664 6665 6666 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6645 class CreateModelPackageInput < Struct.new( :model_package_name, :model_package_group_name, :model_package_description, :inference_specification, :validation_specification, :source_algorithm_specification, :certify_for_marketplace, :tags, :model_approval_status, :metadata_properties, :model_metrics, :client_token, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#model_approval_status ⇒ String
Whether the model is approved for deployment.
This parameter is optional for versioned models, and does not apply to unversioned models.
For versioned models, the value of this parameter must be set to Approved to deploy the model.
6645 6646 6647 6648 6649 6650 6651 6652 6653 6654 6655 6656 6657 6658 6659 6660 6661 6662 6663 6664 6665 6666 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6645 class CreateModelPackageInput < Struct.new( :model_package_name, :model_package_group_name, :model_package_description, :inference_specification, :validation_specification, :source_algorithm_specification, :certify_for_marketplace, :tags, :model_approval_status, :metadata_properties, :model_metrics, :client_token, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#model_metrics ⇒ Types::ModelMetrics
A structure that contains model metrics reports.
6645 6646 6647 6648 6649 6650 6651 6652 6653 6654 6655 6656 6657 6658 6659 6660 6661 6662 6663 6664 6665 6666 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6645 class CreateModelPackageInput < Struct.new( :model_package_name, :model_package_group_name, :model_package_description, :inference_specification, :validation_specification, :source_algorithm_specification, :certify_for_marketplace, :tags, :model_approval_status, :metadata_properties, :model_metrics, :client_token, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#model_package_description ⇒ String
A description of the model package.
6645 6646 6647 6648 6649 6650 6651 6652 6653 6654 6655 6656 6657 6658 6659 6660 6661 6662 6663 6664 6665 6666 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6645 class CreateModelPackageInput < Struct.new( :model_package_name, :model_package_group_name, :model_package_description, :inference_specification, :validation_specification, :source_algorithm_specification, :certify_for_marketplace, :tags, :model_approval_status, :metadata_properties, :model_metrics, :client_token, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#model_package_group_name ⇒ String
The name or Amazon Resource Name (ARN) of the model package group that this model version belongs to.
This parameter is required for versioned models, and does not apply to unversioned models.
6645 6646 6647 6648 6649 6650 6651 6652 6653 6654 6655 6656 6657 6658 6659 6660 6661 6662 6663 6664 6665 6666 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6645 class CreateModelPackageInput < Struct.new( :model_package_name, :model_package_group_name, :model_package_description, :inference_specification, :validation_specification, :source_algorithm_specification, :certify_for_marketplace, :tags, :model_approval_status, :metadata_properties, :model_metrics, :client_token, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#model_package_name ⇒ String
The name of the model package. The name must have 1 to 63 characters. Valid characters are a-z, A-Z, 0-9, and - (hyphen).
This parameter is required for unversioned models. It is not applicable to versioned models.
6645 6646 6647 6648 6649 6650 6651 6652 6653 6654 6655 6656 6657 6658 6659 6660 6661 6662 6663 6664 6665 6666 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6645 class CreateModelPackageInput < Struct.new( :model_package_name, :model_package_group_name, :model_package_description, :inference_specification, :validation_specification, :source_algorithm_specification, :certify_for_marketplace, :tags, :model_approval_status, :metadata_properties, :model_metrics, :client_token, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#sample_payload_url ⇒ String
The Amazon Simple Storage Service (Amazon S3) path where the sample payload are stored. This path must point to a single gzip compressed tar archive (.tar.gz suffix).
6645 6646 6647 6648 6649 6650 6651 6652 6653 6654 6655 6656 6657 6658 6659 6660 6661 6662 6663 6664 6665 6666 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6645 class CreateModelPackageInput < Struct.new( :model_package_name, :model_package_group_name, :model_package_description, :inference_specification, :validation_specification, :source_algorithm_specification, :certify_for_marketplace, :tags, :model_approval_status, :metadata_properties, :model_metrics, :client_token, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#source_algorithm_specification ⇒ Types::SourceAlgorithmSpecification
Details about the algorithm that was used to create the model package.
6645 6646 6647 6648 6649 6650 6651 6652 6653 6654 6655 6656 6657 6658 6659 6660 6661 6662 6663 6664 6665 6666 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6645 class CreateModelPackageInput < Struct.new( :model_package_name, :model_package_group_name, :model_package_description, :inference_specification, :validation_specification, :source_algorithm_specification, :certify_for_marketplace, :tags, :model_approval_status, :metadata_properties, :model_metrics, :client_token, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of key value pairs associated with the model. For more information, see [Tagging Amazon Web Services resources] in the *Amazon Web Services General Reference Guide*.
6645 6646 6647 6648 6649 6650 6651 6652 6653 6654 6655 6656 6657 6658 6659 6660 6661 6662 6663 6664 6665 6666 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6645 class CreateModelPackageInput < Struct.new( :model_package_name, :model_package_group_name, :model_package_description, :inference_specification, :validation_specification, :source_algorithm_specification, :certify_for_marketplace, :tags, :model_approval_status, :metadata_properties, :model_metrics, :client_token, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#task ⇒ String
The machine learning task your model package accomplishes. Common machine learning tasks include object detection and image classification. The following tasks are supported by Inference Recommender: ‘“IMAGE_CLASSIFICATION”` | `“OBJECT_DETECTION”` | `“TEXT_GENERATION”` |`“IMAGE_SEGMENTATION”` | `“FILL_MASK”` | `“CLASSIFICATION”` | `“REGRESSION”` | `“OTHER”`.
Specify “OTHER” if none of the tasks listed fit your use case.
6645 6646 6647 6648 6649 6650 6651 6652 6653 6654 6655 6656 6657 6658 6659 6660 6661 6662 6663 6664 6665 6666 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6645 class CreateModelPackageInput < Struct.new( :model_package_name, :model_package_group_name, :model_package_description, :inference_specification, :validation_specification, :source_algorithm_specification, :certify_for_marketplace, :tags, :model_approval_status, :metadata_properties, :model_metrics, :client_token, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#validation_specification ⇒ Types::ModelPackageValidationSpecification
Specifies configurations for one or more transform jobs that SageMaker runs to test the model package.
6645 6646 6647 6648 6649 6650 6651 6652 6653 6654 6655 6656 6657 6658 6659 6660 6661 6662 6663 6664 6665 6666 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6645 class CreateModelPackageInput < Struct.new( :model_package_name, :model_package_group_name, :model_package_description, :inference_specification, :validation_specification, :source_algorithm_specification, :certify_for_marketplace, :tags, :model_approval_status, :metadata_properties, :model_metrics, :client_token, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |