Class: Aws::SageMaker::Types::CreateOptimizationJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreateOptimizationJobRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#deployment_instance_type ⇒ String
The type of instance that hosts the optimized model that you create with the optimization job.
-
#max_instance_count ⇒ Integer
The maximum number of instances to use for the optimization job.
-
#model_source ⇒ Types::OptimizationJobModelSource
The location of the source model to optimize with an optimization job.
-
#optimization_configs ⇒ Array<Types::OptimizationConfig>
Settings for each of the optimization techniques that the job applies.
-
#optimization_environment ⇒ Hash<String,String>
The environment variables to set in the model container.
-
#optimization_job_name ⇒ String
A custom name for the new optimization job.
-
#output_config ⇒ Types::OptimizationJobOutputConfig
Details for where to store the optimized model that you create with the optimization job.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that enables Amazon SageMaker AI to perform tasks on your behalf.
-
#stopping_condition ⇒ Types::StoppingCondition
Specifies a limit to how long a job can run.
-
#tags ⇒ Array<Types::Tag>
A list of key-value pairs associated with the optimization job.
-
#training_plan_arns ⇒ Array<String>
The Amazon Resource Name (ARN) of the training plan to use for this optimization job.
-
#vpc_config ⇒ Types::OptimizationVpcConfig
A VPC in Amazon VPC that your optimized model has access to.
Instance Attribute Details
#deployment_instance_type ⇒ String
The type of instance that hosts the optimized model that you create with the optimization job.
13501 13502 13503 13504 13505 13506 13507 13508 13509 13510 13511 13512 13513 13514 13515 13516 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13501 class CreateOptimizationJobRequest < Struct.new( :optimization_job_name, :role_arn, :model_source, :deployment_instance_type, :max_instance_count, :optimization_environment, :optimization_configs, :output_config, :stopping_condition, :tags, :vpc_config, :training_plan_arns) SENSITIVE = [] include Aws::Structure end |
#max_instance_count ⇒ Integer
The maximum number of instances to use for the optimization job.
13501 13502 13503 13504 13505 13506 13507 13508 13509 13510 13511 13512 13513 13514 13515 13516 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13501 class CreateOptimizationJobRequest < Struct.new( :optimization_job_name, :role_arn, :model_source, :deployment_instance_type, :max_instance_count, :optimization_environment, :optimization_configs, :output_config, :stopping_condition, :tags, :vpc_config, :training_plan_arns) SENSITIVE = [] include Aws::Structure end |
#model_source ⇒ Types::OptimizationJobModelSource
The location of the source model to optimize with an optimization job.
13501 13502 13503 13504 13505 13506 13507 13508 13509 13510 13511 13512 13513 13514 13515 13516 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13501 class CreateOptimizationJobRequest < Struct.new( :optimization_job_name, :role_arn, :model_source, :deployment_instance_type, :max_instance_count, :optimization_environment, :optimization_configs, :output_config, :stopping_condition, :tags, :vpc_config, :training_plan_arns) SENSITIVE = [] include Aws::Structure end |
#optimization_configs ⇒ Array<Types::OptimizationConfig>
Settings for each of the optimization techniques that the job applies.
13501 13502 13503 13504 13505 13506 13507 13508 13509 13510 13511 13512 13513 13514 13515 13516 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13501 class CreateOptimizationJobRequest < Struct.new( :optimization_job_name, :role_arn, :model_source, :deployment_instance_type, :max_instance_count, :optimization_environment, :optimization_configs, :output_config, :stopping_condition, :tags, :vpc_config, :training_plan_arns) SENSITIVE = [] include Aws::Structure end |
#optimization_environment ⇒ Hash<String,String>
The environment variables to set in the model container.
13501 13502 13503 13504 13505 13506 13507 13508 13509 13510 13511 13512 13513 13514 13515 13516 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13501 class CreateOptimizationJobRequest < Struct.new( :optimization_job_name, :role_arn, :model_source, :deployment_instance_type, :max_instance_count, :optimization_environment, :optimization_configs, :output_config, :stopping_condition, :tags, :vpc_config, :training_plan_arns) SENSITIVE = [] include Aws::Structure end |
#optimization_job_name ⇒ String
A custom name for the new optimization job.
13501 13502 13503 13504 13505 13506 13507 13508 13509 13510 13511 13512 13513 13514 13515 13516 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13501 class CreateOptimizationJobRequest < Struct.new( :optimization_job_name, :role_arn, :model_source, :deployment_instance_type, :max_instance_count, :optimization_environment, :optimization_configs, :output_config, :stopping_condition, :tags, :vpc_config, :training_plan_arns) SENSITIVE = [] include Aws::Structure end |
#output_config ⇒ Types::OptimizationJobOutputConfig
Details for where to store the optimized model that you create with the optimization job.
13501 13502 13503 13504 13505 13506 13507 13508 13509 13510 13511 13512 13513 13514 13515 13516 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13501 class CreateOptimizationJobRequest < Struct.new( :optimization_job_name, :role_arn, :model_source, :deployment_instance_type, :max_instance_count, :optimization_environment, :optimization_configs, :output_config, :stopping_condition, :tags, :vpc_config, :training_plan_arns) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that enables Amazon SageMaker AI to perform tasks on your behalf.
During model optimization, Amazon SageMaker AI needs your permission to:
-
Read input data from an S3 bucket
-
Write model artifacts to an S3 bucket
-
Write logs to Amazon CloudWatch Logs
-
Publish metrics to Amazon CloudWatch
You grant permissions for all of these tasks to an IAM role. To pass
this role to Amazon SageMaker AI, the caller of this API must have
the iam:PassRole permission. For more information, see Amazon
SageMaker AI Roles.
13501 13502 13503 13504 13505 13506 13507 13508 13509 13510 13511 13512 13513 13514 13515 13516 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13501 class CreateOptimizationJobRequest < Struct.new( :optimization_job_name, :role_arn, :model_source, :deployment_instance_type, :max_instance_count, :optimization_environment, :optimization_configs, :output_config, :stopping_condition, :tags, :vpc_config, :training_plan_arns) SENSITIVE = [] include Aws::Structure end |
#stopping_condition ⇒ Types::StoppingCondition
Specifies a limit to how long a job can run. When the job reaches the time limit, SageMaker ends the job. Use this API to cap costs.
To stop a training job, SageMaker sends the algorithm the SIGTERM
signal, which delays job termination for 120 seconds. Algorithms can
use this 120-second window to save the model artifacts, so the
results of training are not lost.
The training algorithms provided by SageMaker automatically save the
intermediate results of a model training job when possible. This
attempt to save artifacts is only a best effort case as model might
not be in a state from which it can be saved. For example, if
training has just started, the model might not be ready to save.
When saved, this intermediate data is a valid model artifact. You
can use it to create a model with CreateModel.
13501 13502 13503 13504 13505 13506 13507 13508 13509 13510 13511 13512 13513 13514 13515 13516 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13501 class CreateOptimizationJobRequest < Struct.new( :optimization_job_name, :role_arn, :model_source, :deployment_instance_type, :max_instance_count, :optimization_environment, :optimization_configs, :output_config, :stopping_condition, :tags, :vpc_config, :training_plan_arns) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of key-value pairs associated with the optimization job. For more information, see Tagging Amazon Web Services resources in the Amazon Web Services General Reference Guide.
13501 13502 13503 13504 13505 13506 13507 13508 13509 13510 13511 13512 13513 13514 13515 13516 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13501 class CreateOptimizationJobRequest < Struct.new( :optimization_job_name, :role_arn, :model_source, :deployment_instance_type, :max_instance_count, :optimization_environment, :optimization_configs, :output_config, :stopping_condition, :tags, :vpc_config, :training_plan_arns) SENSITIVE = [] include Aws::Structure end |
#training_plan_arns ⇒ Array<String>
The Amazon Resource Name (ARN) of the training plan to use for this optimization job.
When you use reserved capacity from a training plan, the optimization job runs on that reserved capacity instead of on-demand capacity. If you omit this field, the job uses on-demand capacity. Currently, you can specify at most one training plan.
For more information about how to reserve GPU capacity for your optimization jobs using Amazon SageMaker Training Plans, see Reserve capacity with training plans.
13501 13502 13503 13504 13505 13506 13507 13508 13509 13510 13511 13512 13513 13514 13515 13516 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13501 class CreateOptimizationJobRequest < Struct.new( :optimization_job_name, :role_arn, :model_source, :deployment_instance_type, :max_instance_count, :optimization_environment, :optimization_configs, :output_config, :stopping_condition, :tags, :vpc_config, :training_plan_arns) SENSITIVE = [] include Aws::Structure end |
#vpc_config ⇒ Types::OptimizationVpcConfig
A VPC in Amazon VPC that your optimized model has access to.
13501 13502 13503 13504 13505 13506 13507 13508 13509 13510 13511 13512 13513 13514 13515 13516 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13501 class CreateOptimizationJobRequest < Struct.new( :optimization_job_name, :role_arn, :model_source, :deployment_instance_type, :max_instance_count, :optimization_environment, :optimization_configs, :output_config, :stopping_condition, :tags, :vpc_config, :training_plan_arns) SENSITIVE = [] include Aws::Structure end |