Class: Aws::SageMaker::Types::CreatePartnerAppRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_configTypes::PartnerAppConfig

Configuration settings for the SageMaker Partner AI App.



13651
13652
13653
13654
13655
13656
13657
13658
13659
13660
13661
13662
13663
13664
13665
13666
13667
# File 'lib/aws-sdk-sagemaker/types.rb', line 13651

class CreatePartnerAppRequest < Struct.new(
  :name,
  :type,
  :execution_role_arn,
  :kms_key_id,
  :maintenance_config,
  :tier,
  :application_config,
  :idc_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :enable_auto_minor_version_upgrade,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#auth_typeString

The authorization type that users use to access the SageMaker Partner AI App. Valid values:

  • IAM: Users access the SageMaker Partner AI App with their Amazon Web Services IAM identity.

  • IDC: Users access the SageMaker Partner AI App with their Amazon Web Services IAM Identity Center identity. Specify the Identity Center instance to use in IdcConfig.

Returns:

  • (String)


13651
13652
13653
13654
13655
13656
13657
13658
13659
13660
13661
13662
13663
13664
13665
13666
13667
# File 'lib/aws-sdk-sagemaker/types.rb', line 13651

class CreatePartnerAppRequest < Struct.new(
  :name,
  :type,
  :execution_role_arn,
  :kms_key_id,
  :maintenance_config,
  :tier,
  :application_config,
  :idc_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :enable_auto_minor_version_upgrade,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique token that guarantees that the call to this API is idempotent.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


13651
13652
13653
13654
13655
13656
13657
13658
13659
13660
13661
13662
13663
13664
13665
13666
13667
# File 'lib/aws-sdk-sagemaker/types.rb', line 13651

class CreatePartnerAppRequest < Struct.new(
  :name,
  :type,
  :execution_role_arn,
  :kms_key_id,
  :maintenance_config,
  :tier,
  :application_config,
  :idc_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :enable_auto_minor_version_upgrade,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#enable_auto_minor_version_upgradeBoolean

When set to TRUE, the SageMaker Partner AI App is automatically upgraded to the latest minor version during the next scheduled maintenance window, if one is available. Default is FALSE.

Returns:

  • (Boolean)


13651
13652
13653
13654
13655
13656
13657
13658
13659
13660
13661
13662
13663
13664
13665
13666
13667
# File 'lib/aws-sdk-sagemaker/types.rb', line 13651

class CreatePartnerAppRequest < Struct.new(
  :name,
  :type,
  :execution_role_arn,
  :kms_key_id,
  :maintenance_config,
  :tier,
  :application_config,
  :idc_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :enable_auto_minor_version_upgrade,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#enable_iam_session_based_identityBoolean

When set to TRUE, the SageMaker Partner AI App sets the Amazon Web Services IAM session name or the authenticated IAM user as the identity of the SageMaker Partner AI App user.

Returns:

  • (Boolean)


13651
13652
13653
13654
13655
13656
13657
13658
13659
13660
13661
13662
13663
13664
13665
13666
13667
# File 'lib/aws-sdk-sagemaker/types.rb', line 13651

class CreatePartnerAppRequest < Struct.new(
  :name,
  :type,
  :execution_role_arn,
  :kms_key_id,
  :maintenance_config,
  :tier,
  :application_config,
  :idc_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :enable_auto_minor_version_upgrade,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#execution_role_arnString

The ARN of the IAM role that the partner application uses.

Returns:

  • (String)


13651
13652
13653
13654
13655
13656
13657
13658
13659
13660
13661
13662
13663
13664
13665
13666
13667
# File 'lib/aws-sdk-sagemaker/types.rb', line 13651

class CreatePartnerAppRequest < Struct.new(
  :name,
  :type,
  :execution_role_arn,
  :kms_key_id,
  :maintenance_config,
  :tier,
  :application_config,
  :idc_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :enable_auto_minor_version_upgrade,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#idc_configTypes::IdcConfigInput

Specifies the Amazon Web Services IAM Identity Center configuration for the SageMaker Partner AI App. Specify this parameter when AuthType is IDC. Apps that use IAM authorization don't use this parameter.



13651
13652
13653
13654
13655
13656
13657
13658
13659
13660
13661
13662
13663
13664
13665
13666
13667
# File 'lib/aws-sdk-sagemaker/types.rb', line 13651

class CreatePartnerAppRequest < Struct.new(
  :name,
  :type,
  :execution_role_arn,
  :kms_key_id,
  :maintenance_config,
  :tier,
  :application_config,
  :idc_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :enable_auto_minor_version_upgrade,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

SageMaker Partner AI Apps uses Amazon Web Services KMS to encrypt data at rest using an Amazon Web Services managed key by default. For more control, specify a customer managed key.

Returns:

  • (String)


13651
13652
13653
13654
13655
13656
13657
13658
13659
13660
13661
13662
13663
13664
13665
13666
13667
# File 'lib/aws-sdk-sagemaker/types.rb', line 13651

class CreatePartnerAppRequest < Struct.new(
  :name,
  :type,
  :execution_role_arn,
  :kms_key_id,
  :maintenance_config,
  :tier,
  :application_config,
  :idc_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :enable_auto_minor_version_upgrade,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#maintenance_configTypes::PartnerAppMaintenanceConfig

Maintenance configuration settings for the SageMaker Partner AI App.



13651
13652
13653
13654
13655
13656
13657
13658
13659
13660
13661
13662
13663
13664
13665
13666
13667
# File 'lib/aws-sdk-sagemaker/types.rb', line 13651

class CreatePartnerAppRequest < Struct.new(
  :name,
  :type,
  :execution_role_arn,
  :kms_key_id,
  :maintenance_config,
  :tier,
  :application_config,
  :idc_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :enable_auto_minor_version_upgrade,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name to give the SageMaker Partner AI App.

Returns:

  • (String)


13651
13652
13653
13654
13655
13656
13657
13658
13659
13660
13661
13662
13663
13664
13665
13666
13667
# File 'lib/aws-sdk-sagemaker/types.rb', line 13651

class CreatePartnerAppRequest < Struct.new(
  :name,
  :type,
  :execution_role_arn,
  :kms_key_id,
  :maintenance_config,
  :tier,
  :application_config,
  :idc_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :enable_auto_minor_version_upgrade,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Each tag consists of a key and an optional value. Tag keys must be unique per resource.

Returns:



13651
13652
13653
13654
13655
13656
13657
13658
13659
13660
13661
13662
13663
13664
13665
13666
13667
# File 'lib/aws-sdk-sagemaker/types.rb', line 13651

class CreatePartnerAppRequest < Struct.new(
  :name,
  :type,
  :execution_role_arn,
  :kms_key_id,
  :maintenance_config,
  :tier,
  :application_config,
  :idc_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :enable_auto_minor_version_upgrade,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tierString

Indicates the instance type and size of the cluster attached to the SageMaker Partner AI App.

Returns:

  • (String)


13651
13652
13653
13654
13655
13656
13657
13658
13659
13660
13661
13662
13663
13664
13665
13666
13667
# File 'lib/aws-sdk-sagemaker/types.rb', line 13651

class CreatePartnerAppRequest < Struct.new(
  :name,
  :type,
  :execution_role_arn,
  :kms_key_id,
  :maintenance_config,
  :tier,
  :application_config,
  :idc_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :enable_auto_minor_version_upgrade,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of SageMaker Partner AI App to create. Must be one of the following: lakera-guard, comet, deepchecks-llm-evaluation, or fiddler.

Returns:

  • (String)


13651
13652
13653
13654
13655
13656
13657
13658
13659
13660
13661
13662
13663
13664
13665
13666
13667
# File 'lib/aws-sdk-sagemaker/types.rb', line 13651

class CreatePartnerAppRequest < Struct.new(
  :name,
  :type,
  :execution_role_arn,
  :kms_key_id,
  :maintenance_config,
  :tier,
  :application_config,
  :idc_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :enable_auto_minor_version_upgrade,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end