Class: Aws::SageMaker::Types::CreateSpaceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreateSpaceRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_id ⇒ String
The ID of the associated domain.
-
#ownership_settings ⇒ Types::OwnershipSettings
A collection of ownership settings.
-
#space_display_name ⇒ String
The name of the space that appears in the SageMaker Studio UI.
-
#space_name ⇒ String
The name of the space.
-
#space_settings ⇒ Types::SpaceSettings
A collection of space settings.
-
#space_sharing_settings ⇒ Types::SpaceSharingSettings
A collection of space sharing settings.
-
#tags ⇒ Array<Types::Tag>
Tags to associated with the space.
Instance Attribute Details
#domain_id ⇒ String
The ID of the associated domain.
14204 14205 14206 14207 14208 14209 14210 14211 14212 14213 14214 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14204 class CreateSpaceRequest < Struct.new( :domain_id, :space_name, :tags, :space_settings, :ownership_settings, :space_sharing_settings, :space_display_name) SENSITIVE = [] include Aws::Structure end |
#ownership_settings ⇒ Types::OwnershipSettings
A collection of ownership settings.
14204 14205 14206 14207 14208 14209 14210 14211 14212 14213 14214 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14204 class CreateSpaceRequest < Struct.new( :domain_id, :space_name, :tags, :space_settings, :ownership_settings, :space_sharing_settings, :space_display_name) SENSITIVE = [] include Aws::Structure end |
#space_display_name ⇒ String
The name of the space that appears in the SageMaker Studio UI.
14204 14205 14206 14207 14208 14209 14210 14211 14212 14213 14214 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14204 class CreateSpaceRequest < Struct.new( :domain_id, :space_name, :tags, :space_settings, :ownership_settings, :space_sharing_settings, :space_display_name) SENSITIVE = [] include Aws::Structure end |
#space_name ⇒ String
The name of the space.
14204 14205 14206 14207 14208 14209 14210 14211 14212 14213 14214 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14204 class CreateSpaceRequest < Struct.new( :domain_id, :space_name, :tags, :space_settings, :ownership_settings, :space_sharing_settings, :space_display_name) SENSITIVE = [] include Aws::Structure end |
#space_settings ⇒ Types::SpaceSettings
A collection of space settings.
14204 14205 14206 14207 14208 14209 14210 14211 14212 14213 14214 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14204 class CreateSpaceRequest < Struct.new( :domain_id, :space_name, :tags, :space_settings, :ownership_settings, :space_sharing_settings, :space_display_name) SENSITIVE = [] include Aws::Structure end |
#space_sharing_settings ⇒ Types::SpaceSharingSettings
A collection of space sharing settings.
14204 14205 14206 14207 14208 14209 14210 14211 14212 14213 14214 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14204 class CreateSpaceRequest < Struct.new( :domain_id, :space_name, :tags, :space_settings, :ownership_settings, :space_sharing_settings, :space_display_name) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Tags to associated with the space. Each tag consists of a key and an
optional value. Tag keys must be unique for each resource. Tags are
searchable using the Search API.
14204 14205 14206 14207 14208 14209 14210 14211 14212 14213 14214 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14204 class CreateSpaceRequest < Struct.new( :domain_id, :space_name, :tags, :space_settings, :ownership_settings, :space_sharing_settings, :space_display_name) SENSITIVE = [] include Aws::Structure end |