Class: Aws::SageMaker::Types::CreateUserProfileRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreateUserProfileRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_id ⇒ String
The ID of the associated Domain.
-
#single_sign_on_user_identifier ⇒ String
A specifier for the type of value specified in SingleSignOnUserValue.
-
#single_sign_on_user_value ⇒ String
The username of the associated Amazon Web Services Single Sign-On User for this UserProfile.
-
#tags ⇒ Array<Types::Tag>
Each tag consists of a key and an optional value.
-
#user_profile_name ⇒ String
A name for the UserProfile.
-
#user_settings ⇒ Types::UserSettings
A collection of settings.
Instance Attribute Details
#domain_id ⇒ String
The ID of the associated Domain.
14930 14931 14932 14933 14934 14935 14936 14937 14938 14939 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14930 class CreateUserProfileRequest < Struct.new( :domain_id, :user_profile_name, :single_sign_on_user_identifier, :single_sign_on_user_value, :tags, :user_settings) SENSITIVE = [] include Aws::Structure end |
#single_sign_on_user_identifier ⇒ String
A specifier for the type of value specified in SingleSignOnUserValue. Currently, the only supported value is "UserName". If the Domain's AuthMode is IAM Identity Center, this field is required. If the Domain's AuthMode is not IAM Identity Center, this field cannot be specified.
14930 14931 14932 14933 14934 14935 14936 14937 14938 14939 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14930 class CreateUserProfileRequest < Struct.new( :domain_id, :user_profile_name, :single_sign_on_user_identifier, :single_sign_on_user_value, :tags, :user_settings) SENSITIVE = [] include Aws::Structure end |
#single_sign_on_user_value ⇒ String
The username of the associated Amazon Web Services Single Sign-On User for this UserProfile. If the Domain's AuthMode is IAM Identity Center, this field is required, and must match a valid username of a user in your directory. If the Domain's AuthMode is not IAM Identity Center, this field cannot be specified.
14930 14931 14932 14933 14934 14935 14936 14937 14938 14939 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14930 class CreateUserProfileRequest < Struct.new( :domain_id, :user_profile_name, :single_sign_on_user_identifier, :single_sign_on_user_value, :tags, :user_settings) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Each tag consists of a key and an optional value. Tag keys must be unique per resource.
Tags that you specify for the User Profile are also added to all Apps that the User Profile launches.
14930 14931 14932 14933 14934 14935 14936 14937 14938 14939 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14930 class CreateUserProfileRequest < Struct.new( :domain_id, :user_profile_name, :single_sign_on_user_identifier, :single_sign_on_user_value, :tags, :user_settings) SENSITIVE = [] include Aws::Structure end |
#user_profile_name ⇒ String
A name for the UserProfile. This value is not case sensitive.
14930 14931 14932 14933 14934 14935 14936 14937 14938 14939 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14930 class CreateUserProfileRequest < Struct.new( :domain_id, :user_profile_name, :single_sign_on_user_identifier, :single_sign_on_user_value, :tags, :user_settings) SENSITIVE = [] include Aws::Structure end |
#user_settings ⇒ Types::UserSettings
A collection of settings.
14930 14931 14932 14933 14934 14935 14936 14937 14938 14939 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14930 class CreateUserProfileRequest < Struct.new( :domain_id, :user_profile_name, :single_sign_on_user_identifier, :single_sign_on_user_value, :tags, :user_settings) SENSITIVE = [] include Aws::Structure end |