Class: Aws::SageMaker::Types::CustomFileSystem

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure, Aws::Structure::Union
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Note:

CustomFileSystem is a union - when making an API calls you must set exactly one of the members.

Note:

CustomFileSystem is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of CustomFileSystem corresponding to the set member.

A file system, created by you, that you assign to a user profile or space for an Amazon SageMaker AI Domain. Permitted users can access this file system in Amazon SageMaker AI Studio.

Direct Known Subclasses

EfsFileSystem, FSxLustreFileSystem, Unknown

Defined Under Namespace

Classes: EfsFileSystem, FSxLustreFileSystem, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#efs_file_systemTypes::EFSFileSystem

A custom file system in Amazon EFS.



10948
10949
10950
10951
10952
10953
10954
10955
10956
10957
10958
10959
# File 'lib/aws-sdk-sagemaker/types.rb', line 10948

class CustomFileSystem < Struct.new(
  :efs_file_system,
  :f_sx_lustre_file_system,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class EfsFileSystem < CustomFileSystem; end
  class FSxLustreFileSystem < CustomFileSystem; end
  class Unknown < CustomFileSystem; end
end

#f_sx_lustre_file_systemTypes::FSxLustreFileSystem

A custom file system in Amazon FSx for Lustre.



10948
10949
10950
10951
10952
10953
10954
10955
10956
10957
10958
10959
# File 'lib/aws-sdk-sagemaker/types.rb', line 10948

class CustomFileSystem < Struct.new(
  :efs_file_system,
  :f_sx_lustre_file_system,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class EfsFileSystem < CustomFileSystem; end
  class FSxLustreFileSystem < CustomFileSystem; end
  class Unknown < CustomFileSystem; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



10948
10949
10950
# File 'lib/aws-sdk-sagemaker/types.rb', line 10948

def unknown
  @unknown
end