Class: Aws::SageMaker::Types::DataCaptureConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Configuration to control how SageMaker AI captures inference data.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capture_content_type_headerTypes::CaptureContentTypeHeader

Configuration specifying how to treat different headers. If no headers are specified SageMaker AI will by default base64 encode when capturing the data.



13642
13643
13644
13645
13646
13647
13648
13649
13650
13651
# File 'lib/aws-sdk-sagemaker/types.rb', line 13642

class DataCaptureConfig < Struct.new(
  :enable_capture,
  :initial_sampling_percentage,
  :destination_s3_uri,
  :kms_key_id,
  :capture_options,
  :capture_content_type_header)
  SENSITIVE = []
  include Aws::Structure
end

#capture_optionsArray<Types::CaptureOption>

Specifies data Model Monitor will capture. You can configure whether to collect only input, only output, or both

Returns:



13642
13643
13644
13645
13646
13647
13648
13649
13650
13651
# File 'lib/aws-sdk-sagemaker/types.rb', line 13642

class DataCaptureConfig < Struct.new(
  :enable_capture,
  :initial_sampling_percentage,
  :destination_s3_uri,
  :kms_key_id,
  :capture_options,
  :capture_content_type_header)
  SENSITIVE = []
  include Aws::Structure
end

#destination_s3_uriString

The Amazon S3 location used to capture the data.

Returns:

  • (String)


13642
13643
13644
13645
13646
13647
13648
13649
13650
13651
# File 'lib/aws-sdk-sagemaker/types.rb', line 13642

class DataCaptureConfig < Struct.new(
  :enable_capture,
  :initial_sampling_percentage,
  :destination_s3_uri,
  :kms_key_id,
  :capture_options,
  :capture_content_type_header)
  SENSITIVE = []
  include Aws::Structure
end

#enable_captureBoolean

Whether data capture should be enabled or disabled (defaults to enabled).

Returns:

  • (Boolean)


13642
13643
13644
13645
13646
13647
13648
13649
13650
13651
# File 'lib/aws-sdk-sagemaker/types.rb', line 13642

class DataCaptureConfig < Struct.new(
  :enable_capture,
  :initial_sampling_percentage,
  :destination_s3_uri,
  :kms_key_id,
  :capture_options,
  :capture_content_type_header)
  SENSITIVE = []
  include Aws::Structure
end

#initial_sampling_percentageInteger

The percentage of requests SageMaker AI will capture. A lower value is recommended for Endpoints with high traffic.

Returns:

  • (Integer)


13642
13643
13644
13645
13646
13647
13648
13649
13650
13651
# File 'lib/aws-sdk-sagemaker/types.rb', line 13642

class DataCaptureConfig < Struct.new(
  :enable_capture,
  :initial_sampling_percentage,
  :destination_s3_uri,
  :kms_key_id,
  :capture_options,
  :capture_content_type_header)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

The Amazon Resource Name (ARN) of an Key Management Service key that SageMaker AI uses to encrypt the captured data at rest using Amazon S3 server-side encryption.

The KmsKeyId can be any of the following formats:

  • Key ID: 1234abcd-12ab-34cd-56ef-1234567890ab

  • Key ARN: arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab

  • Alias name: alias/ExampleAlias

  • Alias name ARN: arn:aws:kms:us-west-2:111122223333:alias/ExampleAlias

Returns:

  • (String)


13642
13643
13644
13645
13646
13647
13648
13649
13650
13651
# File 'lib/aws-sdk-sagemaker/types.rb', line 13642

class DataCaptureConfig < Struct.new(
  :enable_capture,
  :initial_sampling_percentage,
  :destination_s3_uri,
  :kms_key_id,
  :capture_options,
  :capture_content_type_header)
  SENSITIVE = []
  include Aws::Structure
end