Class: Aws::SageMaker::Types::DatasetDefinition
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DatasetDefinition
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Configuration for Dataset Definition inputs. The Dataset Definition input must specify exactly one of either ‘AthenaDatasetDefinition` or `RedshiftDatasetDefinition` types.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#athena_dataset_definition ⇒ Types::AthenaDatasetDefinition
Configuration for Athena Dataset Definition input.
-
#data_distribution_type ⇒ String
Whether the generated dataset is ‘FullyReplicated` or `ShardedByS3Key` (default).
-
#input_mode ⇒ String
Whether to use ‘File` or `Pipe` input mode.
-
#local_path ⇒ String
The local path where you want Amazon SageMaker to download the Dataset Definition inputs to run a processing job.
-
#redshift_dataset_definition ⇒ Types::RedshiftDatasetDefinition
Configuration for Redshift Dataset Definition input.
Instance Attribute Details
#athena_dataset_definition ⇒ Types::AthenaDatasetDefinition
Configuration for Athena Dataset Definition input.
15297 15298 15299 15300 15301 15302 15303 15304 15305 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 15297 class DatasetDefinition < Struct.new( :athena_dataset_definition, :redshift_dataset_definition, :local_path, :data_distribution_type, :input_mode) SENSITIVE = [] include Aws::Structure end |
#data_distribution_type ⇒ String
Whether the generated dataset is ‘FullyReplicated` or `ShardedByS3Key` (default).
15297 15298 15299 15300 15301 15302 15303 15304 15305 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 15297 class DatasetDefinition < Struct.new( :athena_dataset_definition, :redshift_dataset_definition, :local_path, :data_distribution_type, :input_mode) SENSITIVE = [] include Aws::Structure end |
#input_mode ⇒ String
Whether to use ‘File` or `Pipe` input mode. In `File` (default) mode, Amazon SageMaker copies the data from the input source onto the local Amazon Elastic Block Store (Amazon EBS) volumes before starting your training algorithm. This is the most commonly used input mode. In `Pipe` mode, Amazon SageMaker streams input data from the source directly to your algorithm without using the EBS volume.
15297 15298 15299 15300 15301 15302 15303 15304 15305 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 15297 class DatasetDefinition < Struct.new( :athena_dataset_definition, :redshift_dataset_definition, :local_path, :data_distribution_type, :input_mode) SENSITIVE = [] include Aws::Structure end |
#local_path ⇒ String
The local path where you want Amazon SageMaker to download the Dataset Definition inputs to run a processing job. ‘LocalPath` is an absolute path to the input data. This is a required parameter when `AppManaged` is `False` (default).
15297 15298 15299 15300 15301 15302 15303 15304 15305 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 15297 class DatasetDefinition < Struct.new( :athena_dataset_definition, :redshift_dataset_definition, :local_path, :data_distribution_type, :input_mode) SENSITIVE = [] include Aws::Structure end |
#redshift_dataset_definition ⇒ Types::RedshiftDatasetDefinition
Configuration for Redshift Dataset Definition input.
15297 15298 15299 15300 15301 15302 15303 15304 15305 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 15297 class DatasetDefinition < Struct.new( :athena_dataset_definition, :redshift_dataset_definition, :local_path, :data_distribution_type, :input_mode) SENSITIVE = [] include Aws::Structure end |