Class: Aws::SageMaker::Types::DebugHookConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Configuration information for the Amazon SageMaker Debugger hook parameters, metric and tensor collections, and storage paths. To learn more about how to configure the DebugHookConfig parameter, see Use the SageMaker and Debugger Configuration API Operations to Create, Update, and Debug Your Training Job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#collection_configurationsArray<Types::CollectionConfiguration>

Configuration information for Amazon SageMaker Debugger tensor collections. To learn more about how to configure the CollectionConfiguration parameter, see Use the SageMaker and Debugger Configuration API Operations to Create, Update, and Debug Your Training Job.

Returns:



15702
15703
15704
15705
15706
15707
15708
15709
# File 'lib/aws-sdk-sagemaker/types.rb', line 15702

class DebugHookConfig < Struct.new(
  :local_path,
  :s3_output_path,
  :hook_parameters,
  :collection_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#hook_parametersHash<String,String>

Configuration information for the Amazon SageMaker Debugger hook parameters.

Returns:

  • (Hash<String,String>)


15702
15703
15704
15705
15706
15707
15708
15709
# File 'lib/aws-sdk-sagemaker/types.rb', line 15702

class DebugHookConfig < Struct.new(
  :local_path,
  :s3_output_path,
  :hook_parameters,
  :collection_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#local_pathString

Path to local storage location for metrics and tensors. Defaults to /opt/ml/output/tensors/.

Returns:

  • (String)


15702
15703
15704
15705
15706
15707
15708
15709
# File 'lib/aws-sdk-sagemaker/types.rb', line 15702

class DebugHookConfig < Struct.new(
  :local_path,
  :s3_output_path,
  :hook_parameters,
  :collection_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#s3_output_pathString

Path to Amazon S3 storage location for metrics and tensors.

Returns:

  • (String)


15702
15703
15704
15705
15706
15707
15708
15709
# File 'lib/aws-sdk-sagemaker/types.rb', line 15702

class DebugHookConfig < Struct.new(
  :local_path,
  :s3_output_path,
  :hook_parameters,
  :collection_configurations)
  SENSITIVE = []
  include Aws::Structure
end