Class: Aws::SageMaker::Types::DebugRuleConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Configuration information for SageMaker Debugger rules for debugging. To learn more about how to configure the DebugRuleConfiguration parameter, see Use the SageMaker and Debugger Configuration API Operations to Create, Update, and Debug Your Training Job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_type ⇒ String

The instance type to deploy a custom rule for debugging a training job.

Returns:

  • (String)


15813
15814
15815
15816
15817
15818
15819
15820
15821
15822
15823
# File 'lib/aws-sdk-sagemaker/types.rb', line 15813

class DebugRuleConfiguration < Struct.new(
  :rule_configuration_name,
  :local_path,
  :s3_output_path,
  :rule_evaluator_image,
  :instance_type,
  :volume_size_in_gb,
  :rule_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#local_path ⇒ String

Path to local storage location for output of rules. Defaults to /opt/ml/processing/output/rule/.

Returns:

  • (String)


15813
15814
15815
15816
15817
15818
15819
15820
15821
15822
15823
# File 'lib/aws-sdk-sagemaker/types.rb', line 15813

class DebugRuleConfiguration < Struct.new(
  :rule_configuration_name,
  :local_path,
  :s3_output_path,
  :rule_evaluator_image,
  :instance_type,
  :volume_size_in_gb,
  :rule_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#rule_configuration_name ⇒ String

The name of the rule configuration. It must be unique relative to other rule configuration names.

Returns:

  • (String)


15813
15814
15815
15816
15817
15818
15819
15820
15821
15822
15823
# File 'lib/aws-sdk-sagemaker/types.rb', line 15813

class DebugRuleConfiguration < Struct.new(
  :rule_configuration_name,
  :local_path,
  :s3_output_path,
  :rule_evaluator_image,
  :instance_type,
  :volume_size_in_gb,
  :rule_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#rule_evaluator_image ⇒ String

The Amazon Elastic Container (ECR) Image for the managed rule evaluation.

Returns:

  • (String)


15813
15814
15815
15816
15817
15818
15819
15820
15821
15822
15823
# File 'lib/aws-sdk-sagemaker/types.rb', line 15813

class DebugRuleConfiguration < Struct.new(
  :rule_configuration_name,
  :local_path,
  :s3_output_path,
  :rule_evaluator_image,
  :instance_type,
  :volume_size_in_gb,
  :rule_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#rule_parameters ⇒ Hash<String,String>

Runtime configuration for rule container.

Returns:

  • (Hash<String,String>)


15813
15814
15815
15816
15817
15818
15819
15820
15821
15822
15823
# File 'lib/aws-sdk-sagemaker/types.rb', line 15813

class DebugRuleConfiguration < Struct.new(
  :rule_configuration_name,
  :local_path,
  :s3_output_path,
  :rule_evaluator_image,
  :instance_type,
  :volume_size_in_gb,
  :rule_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#s3_output_path ⇒ String

Path to Amazon S3 storage location for rules.

Returns:

  • (String)


15813
15814
15815
15816
15817
15818
15819
15820
15821
15822
15823
# File 'lib/aws-sdk-sagemaker/types.rb', line 15813

class DebugRuleConfiguration < Struct.new(
  :rule_configuration_name,
  :local_path,
  :s3_output_path,
  :rule_evaluator_image,
  :instance_type,
  :volume_size_in_gb,
  :rule_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#volume_size_in_gb ⇒ Integer

The size, in GB, of the ML storage volume attached to the processing instance.

Returns:

  • (Integer)


15813
15814
15815
15816
15817
15818
15819
15820
15821
15822
15823
# File 'lib/aws-sdk-sagemaker/types.rb', line 15813

class DebugRuleConfiguration < Struct.new(
  :rule_configuration_name,
  :local_path,
  :s3_output_path,
  :rule_evaluator_image,
  :instance_type,
  :volume_size_in_gb,
  :rule_parameters)
  SENSITIVE = []
  include Aws::Structure
end