Class: Aws::SageMaker::Types::DeleteFeatureGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DeleteFeatureGroupRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#feature_group_name ⇒ String
The name of the
FeatureGroupyou want to delete.
Instance Attribute Details
#feature_group_name ⇒ String
The name of the FeatureGroup you want to delete. The name must be unique within an Amazon Web Services Region in an Amazon Web Services account.
12034 12035 12036 12037 12038 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12034 class DeleteFeatureGroupRequest < Struct.new( :feature_group_name) SENSITIVE = [] include Aws::Structure end |