Class: Aws::SageMaker::Types::DeleteHubContentReferenceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DeleteHubContentReferenceRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#hub_content_name ⇒ String
The name of the hub content to delete.
-
#hub_content_type ⇒ String
The type of hub content reference to delete.
-
#hub_name ⇒ String
The name of the hub to delete the hub content reference from.
Instance Attribute Details
#hub_content_name ⇒ String
The name of the hub content to delete.
15787 15788 15789 15790 15791 15792 15793 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 15787 class DeleteHubContentReferenceRequest < Struct.new( :hub_name, :hub_content_type, :hub_content_name) SENSITIVE = [] include Aws::Structure end |
#hub_content_type ⇒ String
The type of hub content reference to delete. The only supported type of hub content reference to delete is ‘ModelReference`.
15787 15788 15789 15790 15791 15792 15793 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 15787 class DeleteHubContentReferenceRequest < Struct.new( :hub_name, :hub_content_type, :hub_content_name) SENSITIVE = [] include Aws::Structure end |
#hub_name ⇒ String
The name of the hub to delete the hub content reference from.
15787 15788 15789 15790 15791 15792 15793 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 15787 class DeleteHubContentReferenceRequest < Struct.new( :hub_name, :hub_content_type, :hub_content_name) SENSITIVE = [] include Aws::Structure end |