Class: Aws::SageMaker::Types::DeleteTagsInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#resource_arnString

The Amazon Resource Name (ARN) of the resource whose tags you want to delete.

Returns:

  • (String)


15092
15093
15094
15095
15096
15097
# File 'lib/aws-sdk-sagemaker/types.rb', line 15092

class DeleteTagsInput < Struct.new(
  :resource_arn,
  :tag_keys)
  SENSITIVE = []
  include Aws::Structure
end

#tag_keysArray<String>

An array or one or more tag keys to delete.

Returns:

  • (Array<String>)


15092
15093
15094
15095
15096
15097
# File 'lib/aws-sdk-sagemaker/types.rb', line 15092

class DeleteTagsInput < Struct.new(
  :resource_arn,
  :tag_keys)
  SENSITIVE = []
  include Aws::Structure
end