Class: Aws::SageMaker::Types::DeploymentConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DeploymentConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The deployment configuration for an endpoint, which contains the desired deployment strategy and rollback configurations.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_rollback_configuration ⇒ Types::AutoRollbackConfig
Automatic rollback configuration for handling endpoint deployment failures and recovery.
-
#blue_green_update_policy ⇒ Types::BlueGreenUpdatePolicy
Update policy for a blue/green deployment.
-
#rolling_update_policy ⇒ Types::RollingUpdatePolicy
Specifies a rolling deployment strategy for updating a SageMaker endpoint.
Instance Attribute Details
#auto_rollback_configuration ⇒ Types::AutoRollbackConfig
Automatic rollback configuration for handling endpoint deployment failures and recovery.
15286 15287 15288 15289 15290 15291 15292 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 15286 class DeploymentConfig < Struct.new( :blue_green_update_policy, :rolling_update_policy, :auto_rollback_configuration) SENSITIVE = [] include Aws::Structure end |
#blue_green_update_policy ⇒ Types::BlueGreenUpdatePolicy
Update policy for a blue/green deployment. If this update policy is specified, SageMaker creates a new fleet during the deployment while maintaining the old fleet. SageMaker flips traffic to the new fleet according to the specified traffic routing configuration. Only one update policy should be used in the deployment configuration. If no update policy is specified, SageMaker uses a blue/green deployment strategy with all at once traffic shifting by default.
15286 15287 15288 15289 15290 15291 15292 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 15286 class DeploymentConfig < Struct.new( :blue_green_update_policy, :rolling_update_policy, :auto_rollback_configuration) SENSITIVE = [] include Aws::Structure end |
#rolling_update_policy ⇒ Types::RollingUpdatePolicy
Specifies a rolling deployment strategy for updating a SageMaker endpoint.
15286 15287 15288 15289 15290 15291 15292 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 15286 class DeploymentConfig < Struct.new( :blue_green_update_policy, :rolling_update_policy, :auto_rollback_configuration) SENSITIVE = [] include Aws::Structure end |