Class: Aws::SageMaker::Types::DescribeAIRecommendationJobResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#adapter_sourceTypes::AIAdapterSource

The LoRA adapter source that was specified when the recommendation job was created. This field is absent when the job was created without LoRA adapters.



17390
17391
17392
17393
17394
17395
17396
17397
17398
17399
17400
17401
17402
17403
17404
17405
17406
17407
17408
17409
17410
17411
# File 'lib/aws-sdk-sagemaker/types.rb', line 17390

class DescribeAIRecommendationJobResponse < Struct.new(
  :ai_recommendation_job_name,
  :ai_recommendation_job_arn,
  :ai_recommendation_job_status,
  :failure_reason,
  :model_source,
  :output_config,
  :inference_specification,
  :ai_workload_config_identifier,
  :optimize_model,
  :performance_target,
  :recommendations,
  :role_arn,
  :compute_spec,
  :adapter_source,
  :creation_time,
  :start_time,
  :end_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#ai_recommendation_job_arnString

The Amazon Resource Name (ARN) of the AI recommendation job.

Returns:

  • (String)


17390
17391
17392
17393
17394
17395
17396
17397
17398
17399
17400
17401
17402
17403
17404
17405
17406
17407
17408
17409
17410
17411
# File 'lib/aws-sdk-sagemaker/types.rb', line 17390

class DescribeAIRecommendationJobResponse < Struct.new(
  :ai_recommendation_job_name,
  :ai_recommendation_job_arn,
  :ai_recommendation_job_status,
  :failure_reason,
  :model_source,
  :output_config,
  :inference_specification,
  :ai_workload_config_identifier,
  :optimize_model,
  :performance_target,
  :recommendations,
  :role_arn,
  :compute_spec,
  :adapter_source,
  :creation_time,
  :start_time,
  :end_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#ai_recommendation_job_nameString

The name of the AI recommendation job.

Returns:

  • (String)


17390
17391
17392
17393
17394
17395
17396
17397
17398
17399
17400
17401
17402
17403
17404
17405
17406
17407
17408
17409
17410
17411
# File 'lib/aws-sdk-sagemaker/types.rb', line 17390

class DescribeAIRecommendationJobResponse < Struct.new(
  :ai_recommendation_job_name,
  :ai_recommendation_job_arn,
  :ai_recommendation_job_status,
  :failure_reason,
  :model_source,
  :output_config,
  :inference_specification,
  :ai_workload_config_identifier,
  :optimize_model,
  :performance_target,
  :recommendations,
  :role_arn,
  :compute_spec,
  :adapter_source,
  :creation_time,
  :start_time,
  :end_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#ai_recommendation_job_statusString

The status of the AI recommendation job.

Returns:

  • (String)


17390
17391
17392
17393
17394
17395
17396
17397
17398
17399
17400
17401
17402
17403
17404
17405
17406
17407
17408
17409
17410
17411
# File 'lib/aws-sdk-sagemaker/types.rb', line 17390

class DescribeAIRecommendationJobResponse < Struct.new(
  :ai_recommendation_job_name,
  :ai_recommendation_job_arn,
  :ai_recommendation_job_status,
  :failure_reason,
  :model_source,
  :output_config,
  :inference_specification,
  :ai_workload_config_identifier,
  :optimize_model,
  :performance_target,
  :recommendations,
  :role_arn,
  :compute_spec,
  :adapter_source,
  :creation_time,
  :start_time,
  :end_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#ai_workload_config_identifierString

The name or Amazon Resource Name (ARN) of the AI workload configuration used for this recommendation job.

Returns:

  • (String)


17390
17391
17392
17393
17394
17395
17396
17397
17398
17399
17400
17401
17402
17403
17404
17405
17406
17407
17408
17409
17410
17411
# File 'lib/aws-sdk-sagemaker/types.rb', line 17390

class DescribeAIRecommendationJobResponse < Struct.new(
  :ai_recommendation_job_name,
  :ai_recommendation_job_arn,
  :ai_recommendation_job_status,
  :failure_reason,
  :model_source,
  :output_config,
  :inference_specification,
  :ai_workload_config_identifier,
  :optimize_model,
  :performance_target,
  :recommendations,
  :role_arn,
  :compute_spec,
  :adapter_source,
  :creation_time,
  :start_time,
  :end_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#compute_specTypes::AIRecommendationComputeSpec

The compute resource specification for the recommendation job.



17390
17391
17392
17393
17394
17395
17396
17397
17398
17399
17400
17401
17402
17403
17404
17405
17406
17407
17408
17409
17410
17411
# File 'lib/aws-sdk-sagemaker/types.rb', line 17390

class DescribeAIRecommendationJobResponse < Struct.new(
  :ai_recommendation_job_name,
  :ai_recommendation_job_arn,
  :ai_recommendation_job_status,
  :failure_reason,
  :model_source,
  :output_config,
  :inference_specification,
  :ai_workload_config_identifier,
  :optimize_model,
  :performance_target,
  :recommendations,
  :role_arn,
  :compute_spec,
  :adapter_source,
  :creation_time,
  :start_time,
  :end_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

A timestamp that indicates when the recommendation job was created.

Returns:

  • (Time)


17390
17391
17392
17393
17394
17395
17396
17397
17398
17399
17400
17401
17402
17403
17404
17405
17406
17407
17408
17409
17410
17411
# File 'lib/aws-sdk-sagemaker/types.rb', line 17390

class DescribeAIRecommendationJobResponse < Struct.new(
  :ai_recommendation_job_name,
  :ai_recommendation_job_arn,
  :ai_recommendation_job_status,
  :failure_reason,
  :model_source,
  :output_config,
  :inference_specification,
  :ai_workload_config_identifier,
  :optimize_model,
  :performance_target,
  :recommendations,
  :role_arn,
  :compute_spec,
  :adapter_source,
  :creation_time,
  :start_time,
  :end_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

A timestamp that indicates when the recommendation job completed.

Returns:

  • (Time)


17390
17391
17392
17393
17394
17395
17396
17397
17398
17399
17400
17401
17402
17403
17404
17405
17406
17407
17408
17409
17410
17411
# File 'lib/aws-sdk-sagemaker/types.rb', line 17390

class DescribeAIRecommendationJobResponse < Struct.new(
  :ai_recommendation_job_name,
  :ai_recommendation_job_arn,
  :ai_recommendation_job_status,
  :failure_reason,
  :model_source,
  :output_config,
  :inference_specification,
  :ai_workload_config_identifier,
  :optimize_model,
  :performance_target,
  :recommendations,
  :role_arn,
  :compute_spec,
  :adapter_source,
  :creation_time,
  :start_time,
  :end_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

If the recommendation job failed, the reason it failed.

Returns:

  • (String)


17390
17391
17392
17393
17394
17395
17396
17397
17398
17399
17400
17401
17402
17403
17404
17405
17406
17407
17408
17409
17410
17411
# File 'lib/aws-sdk-sagemaker/types.rb', line 17390

class DescribeAIRecommendationJobResponse < Struct.new(
  :ai_recommendation_job_name,
  :ai_recommendation_job_arn,
  :ai_recommendation_job_status,
  :failure_reason,
  :model_source,
  :output_config,
  :inference_specification,
  :ai_workload_config_identifier,
  :optimize_model,
  :performance_target,
  :recommendations,
  :role_arn,
  :compute_spec,
  :adapter_source,
  :creation_time,
  :start_time,
  :end_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#inference_specificationTypes::AIRecommendationInferenceSpecification

The inference framework configuration.



17390
17391
17392
17393
17394
17395
17396
17397
17398
17399
17400
17401
17402
17403
17404
17405
17406
17407
17408
17409
17410
17411
# File 'lib/aws-sdk-sagemaker/types.rb', line 17390

class DescribeAIRecommendationJobResponse < Struct.new(
  :ai_recommendation_job_name,
  :ai_recommendation_job_arn,
  :ai_recommendation_job_status,
  :failure_reason,
  :model_source,
  :output_config,
  :inference_specification,
  :ai_workload_config_identifier,
  :optimize_model,
  :performance_target,
  :recommendations,
  :role_arn,
  :compute_spec,
  :adapter_source,
  :creation_time,
  :start_time,
  :end_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#model_sourceTypes::AIModelSource

The source of the model that was analyzed.



17390
17391
17392
17393
17394
17395
17396
17397
17398
17399
17400
17401
17402
17403
17404
17405
17406
17407
17408
17409
17410
17411
# File 'lib/aws-sdk-sagemaker/types.rb', line 17390

class DescribeAIRecommendationJobResponse < Struct.new(
  :ai_recommendation_job_name,
  :ai_recommendation_job_arn,
  :ai_recommendation_job_status,
  :failure_reason,
  :model_source,
  :output_config,
  :inference_specification,
  :ai_workload_config_identifier,
  :optimize_model,
  :performance_target,
  :recommendations,
  :role_arn,
  :compute_spec,
  :adapter_source,
  :creation_time,
  :start_time,
  :end_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#optimize_modelBoolean

Whether model optimization techniques were allowed.

Returns:

  • (Boolean)


17390
17391
17392
17393
17394
17395
17396
17397
17398
17399
17400
17401
17402
17403
17404
17405
17406
17407
17408
17409
17410
17411
# File 'lib/aws-sdk-sagemaker/types.rb', line 17390

class DescribeAIRecommendationJobResponse < Struct.new(
  :ai_recommendation_job_name,
  :ai_recommendation_job_arn,
  :ai_recommendation_job_status,
  :failure_reason,
  :model_source,
  :output_config,
  :inference_specification,
  :ai_workload_config_identifier,
  :optimize_model,
  :performance_target,
  :recommendations,
  :role_arn,
  :compute_spec,
  :adapter_source,
  :creation_time,
  :start_time,
  :end_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#output_configTypes::AIRecommendationOutputResult

The output configuration for the recommendation job.



17390
17391
17392
17393
17394
17395
17396
17397
17398
17399
17400
17401
17402
17403
17404
17405
17406
17407
17408
17409
17410
17411
# File 'lib/aws-sdk-sagemaker/types.rb', line 17390

class DescribeAIRecommendationJobResponse < Struct.new(
  :ai_recommendation_job_name,
  :ai_recommendation_job_arn,
  :ai_recommendation_job_status,
  :failure_reason,
  :model_source,
  :output_config,
  :inference_specification,
  :ai_workload_config_identifier,
  :optimize_model,
  :performance_target,
  :recommendations,
  :role_arn,
  :compute_spec,
  :adapter_source,
  :creation_time,
  :start_time,
  :end_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#performance_targetTypes::AIRecommendationPerformanceTarget

The performance targets specified for the recommendation job.



17390
17391
17392
17393
17394
17395
17396
17397
17398
17399
17400
17401
17402
17403
17404
17405
17406
17407
17408
17409
17410
17411
# File 'lib/aws-sdk-sagemaker/types.rb', line 17390

class DescribeAIRecommendationJobResponse < Struct.new(
  :ai_recommendation_job_name,
  :ai_recommendation_job_arn,
  :ai_recommendation_job_status,
  :failure_reason,
  :model_source,
  :output_config,
  :inference_specification,
  :ai_workload_config_identifier,
  :optimize_model,
  :performance_target,
  :recommendations,
  :role_arn,
  :compute_spec,
  :adapter_source,
  :creation_time,
  :start_time,
  :end_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#recommendationsArray<Types::AIRecommendation>

The list of optimization recommendations generated by the job. Each recommendation includes optimization details, deployment configuration, expected performance metrics, and the associated benchmark job ARN.

Returns:



17390
17391
17392
17393
17394
17395
17396
17397
17398
17399
17400
17401
17402
17403
17404
17405
17406
17407
17408
17409
17410
17411
# File 'lib/aws-sdk-sagemaker/types.rb', line 17390

class DescribeAIRecommendationJobResponse < Struct.new(
  :ai_recommendation_job_name,
  :ai_recommendation_job_arn,
  :ai_recommendation_job_status,
  :failure_reason,
  :model_source,
  :output_config,
  :inference_specification,
  :ai_workload_config_identifier,
  :optimize_model,
  :performance_target,
  :recommendations,
  :role_arn,
  :compute_spec,
  :adapter_source,
  :creation_time,
  :start_time,
  :end_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of the IAM role used by the recommendation job.

Returns:

  • (String)


17390
17391
17392
17393
17394
17395
17396
17397
17398
17399
17400
17401
17402
17403
17404
17405
17406
17407
17408
17409
17410
17411
# File 'lib/aws-sdk-sagemaker/types.rb', line 17390

class DescribeAIRecommendationJobResponse < Struct.new(
  :ai_recommendation_job_name,
  :ai_recommendation_job_arn,
  :ai_recommendation_job_status,
  :failure_reason,
  :model_source,
  :output_config,
  :inference_specification,
  :ai_workload_config_identifier,
  :optimize_model,
  :performance_target,
  :recommendations,
  :role_arn,
  :compute_spec,
  :adapter_source,
  :creation_time,
  :start_time,
  :end_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

A timestamp that indicates when the recommendation job started running.

Returns:

  • (Time)


17390
17391
17392
17393
17394
17395
17396
17397
17398
17399
17400
17401
17402
17403
17404
17405
17406
17407
17408
17409
17410
17411
# File 'lib/aws-sdk-sagemaker/types.rb', line 17390

class DescribeAIRecommendationJobResponse < Struct.new(
  :ai_recommendation_job_name,
  :ai_recommendation_job_arn,
  :ai_recommendation_job_status,
  :failure_reason,
  :model_source,
  :output_config,
  :inference_specification,
  :ai_workload_config_identifier,
  :optimize_model,
  :performance_target,
  :recommendations,
  :role_arn,
  :compute_spec,
  :adapter_source,
  :creation_time,
  :start_time,
  :end_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The tags associated with the recommendation job.

Returns:



17390
17391
17392
17393
17394
17395
17396
17397
17398
17399
17400
17401
17402
17403
17404
17405
17406
17407
17408
17409
17410
17411
# File 'lib/aws-sdk-sagemaker/types.rb', line 17390

class DescribeAIRecommendationJobResponse < Struct.new(
  :ai_recommendation_job_name,
  :ai_recommendation_job_arn,
  :ai_recommendation_job_status,
  :failure_reason,
  :model_source,
  :output_config,
  :inference_specification,
  :ai_workload_config_identifier,
  :optimize_model,
  :performance_target,
  :recommendations,
  :role_arn,
  :compute_spec,
  :adapter_source,
  :creation_time,
  :start_time,
  :end_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end