Class: Aws::SageMaker::Types::DescribeClusterEventResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeClusterEventResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#event_details ⇒ Types::ClusterEventDetail
Detailed information about the requested cluster event, including event metadata for various resource types such as ‘Cluster`, `InstanceGroup`, `Instance`, and their associated attributes.
Instance Attribute Details
#event_details ⇒ Types::ClusterEventDetail
Detailed information about the requested cluster event, including event metadata for various resource types such as ‘Cluster`, `InstanceGroup`, `Instance`, and their associated attributes.
17565 17566 17567 17568 17569 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17565 class DescribeClusterEventResponse < Struct.new( :event_details) SENSITIVE = [] include Aws::Structure end |