Class: Aws::SageMaker::Types::DescribeClusterNodeRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_nameString

The string name or the Amazon Resource Name (ARN) of the SageMaker HyperPod cluster in which the node is.

Returns:

  • (String)


16317
16318
16319
16320
16321
16322
16323
# File 'lib/aws-sdk-sagemaker/types.rb', line 16317

class DescribeClusterNodeRequest < Struct.new(
  :cluster_name,
  :node_id,
  :node_logical_id)
  SENSITIVE = []
  include Aws::Structure
end

#node_idString

The ID of the SageMaker HyperPod cluster node.

Returns:

  • (String)


16317
16318
16319
16320
16321
16322
16323
# File 'lib/aws-sdk-sagemaker/types.rb', line 16317

class DescribeClusterNodeRequest < Struct.new(
  :cluster_name,
  :node_id,
  :node_logical_id)
  SENSITIVE = []
  include Aws::Structure
end

#node_logical_idString

The logical identifier of the node to describe. You can specify either NodeLogicalId or InstanceId, but not both. NodeLogicalId can be used to describe nodes that are still being provisioned and don't yet have an InstanceId assigned.

Returns:

  • (String)


16317
16318
16319
16320
16321
16322
16323
# File 'lib/aws-sdk-sagemaker/types.rb', line 16317

class DescribeClusterNodeRequest < Struct.new(
  :cluster_name,
  :node_id,
  :node_logical_id)
  SENSITIVE = []
  include Aws::Structure
end