Class: Aws::SageMaker::Types::DescribeCompilationJobResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#compilation_end_timeTime

The time when the model compilation job on a compilation job instance ended. For a successful or stopped job, this is when the job’s model artifacts have finished uploading. For a failed job, this is when Amazon SageMaker AI detected that the job failed.

Returns:

  • (Time)


18208
18209
18210
18211
18212
18213
18214
18215
18216
18217
18218
18219
18220
18221
18222
18223
18224
18225
18226
18227
18228
18229
# File 'lib/aws-sdk-sagemaker/types.rb', line 18208

class DescribeCompilationJobResponse < Struct.new(
  :compilation_job_name,
  :compilation_job_arn,
  :compilation_job_status,
  :compilation_start_time,
  :compilation_end_time,
  :stopping_condition,
  :inference_image,
  :model_package_version_arn,
  :creation_time,
  :last_modified_time,
  :failure_reason,
  :model_artifacts,
  :model_digests,
  :role_arn,
  :input_config,
  :output_config,
  :vpc_config,
  :derived_information)
  SENSITIVE = []
  include Aws::Structure
end

#compilation_job_arnString

The Amazon Resource Name (ARN) of the model compilation job.

Returns:

  • (String)


18208
18209
18210
18211
18212
18213
18214
18215
18216
18217
18218
18219
18220
18221
18222
18223
18224
18225
18226
18227
18228
18229
# File 'lib/aws-sdk-sagemaker/types.rb', line 18208

class DescribeCompilationJobResponse < Struct.new(
  :compilation_job_name,
  :compilation_job_arn,
  :compilation_job_status,
  :compilation_start_time,
  :compilation_end_time,
  :stopping_condition,
  :inference_image,
  :model_package_version_arn,
  :creation_time,
  :last_modified_time,
  :failure_reason,
  :model_artifacts,
  :model_digests,
  :role_arn,
  :input_config,
  :output_config,
  :vpc_config,
  :derived_information)
  SENSITIVE = []
  include Aws::Structure
end

#compilation_job_nameString

The name of the model compilation job.

Returns:

  • (String)


18208
18209
18210
18211
18212
18213
18214
18215
18216
18217
18218
18219
18220
18221
18222
18223
18224
18225
18226
18227
18228
18229
# File 'lib/aws-sdk-sagemaker/types.rb', line 18208

class DescribeCompilationJobResponse < Struct.new(
  :compilation_job_name,
  :compilation_job_arn,
  :compilation_job_status,
  :compilation_start_time,
  :compilation_end_time,
  :stopping_condition,
  :inference_image,
  :model_package_version_arn,
  :creation_time,
  :last_modified_time,
  :failure_reason,
  :model_artifacts,
  :model_digests,
  :role_arn,
  :input_config,
  :output_config,
  :vpc_config,
  :derived_information)
  SENSITIVE = []
  include Aws::Structure
end

#compilation_job_statusString

The status of the model compilation job.

Returns:

  • (String)


18208
18209
18210
18211
18212
18213
18214
18215
18216
18217
18218
18219
18220
18221
18222
18223
18224
18225
18226
18227
18228
18229
# File 'lib/aws-sdk-sagemaker/types.rb', line 18208

class DescribeCompilationJobResponse < Struct.new(
  :compilation_job_name,
  :compilation_job_arn,
  :compilation_job_status,
  :compilation_start_time,
  :compilation_end_time,
  :stopping_condition,
  :inference_image,
  :model_package_version_arn,
  :creation_time,
  :last_modified_time,
  :failure_reason,
  :model_artifacts,
  :model_digests,
  :role_arn,
  :input_config,
  :output_config,
  :vpc_config,
  :derived_information)
  SENSITIVE = []
  include Aws::Structure
end

#compilation_start_timeTime

The time when the model compilation job started the ‘CompilationJob` instances.

You are billed for the time between this timestamp and the timestamp in the ‘CompilationEndTime` field. In Amazon CloudWatch Logs, the start time might be later than this time. That’s because it takes time to download the compilation job, which depends on the size of the compilation job container.

Returns:

  • (Time)


18208
18209
18210
18211
18212
18213
18214
18215
18216
18217
18218
18219
18220
18221
18222
18223
18224
18225
18226
18227
18228
18229
# File 'lib/aws-sdk-sagemaker/types.rb', line 18208

class DescribeCompilationJobResponse < Struct.new(
  :compilation_job_name,
  :compilation_job_arn,
  :compilation_job_status,
  :compilation_start_time,
  :compilation_end_time,
  :stopping_condition,
  :inference_image,
  :model_package_version_arn,
  :creation_time,
  :last_modified_time,
  :failure_reason,
  :model_artifacts,
  :model_digests,
  :role_arn,
  :input_config,
  :output_config,
  :vpc_config,
  :derived_information)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

The time that the model compilation job was created.

Returns:

  • (Time)


18208
18209
18210
18211
18212
18213
18214
18215
18216
18217
18218
18219
18220
18221
18222
18223
18224
18225
18226
18227
18228
18229
# File 'lib/aws-sdk-sagemaker/types.rb', line 18208

class DescribeCompilationJobResponse < Struct.new(
  :compilation_job_name,
  :compilation_job_arn,
  :compilation_job_status,
  :compilation_start_time,
  :compilation_end_time,
  :stopping_condition,
  :inference_image,
  :model_package_version_arn,
  :creation_time,
  :last_modified_time,
  :failure_reason,
  :model_artifacts,
  :model_digests,
  :role_arn,
  :input_config,
  :output_config,
  :vpc_config,
  :derived_information)
  SENSITIVE = []
  include Aws::Structure
end

#derived_informationTypes::DerivedInformation

Information that SageMaker Neo automatically derived about the model.



18208
18209
18210
18211
18212
18213
18214
18215
18216
18217
18218
18219
18220
18221
18222
18223
18224
18225
18226
18227
18228
18229
# File 'lib/aws-sdk-sagemaker/types.rb', line 18208

class DescribeCompilationJobResponse < Struct.new(
  :compilation_job_name,
  :compilation_job_arn,
  :compilation_job_status,
  :compilation_start_time,
  :compilation_end_time,
  :stopping_condition,
  :inference_image,
  :model_package_version_arn,
  :creation_time,
  :last_modified_time,
  :failure_reason,
  :model_artifacts,
  :model_digests,
  :role_arn,
  :input_config,
  :output_config,
  :vpc_config,
  :derived_information)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

If a model compilation job failed, the reason it failed.

Returns:

  • (String)


18208
18209
18210
18211
18212
18213
18214
18215
18216
18217
18218
18219
18220
18221
18222
18223
18224
18225
18226
18227
18228
18229
# File 'lib/aws-sdk-sagemaker/types.rb', line 18208

class DescribeCompilationJobResponse < Struct.new(
  :compilation_job_name,
  :compilation_job_arn,
  :compilation_job_status,
  :compilation_start_time,
  :compilation_end_time,
  :stopping_condition,
  :inference_image,
  :model_package_version_arn,
  :creation_time,
  :last_modified_time,
  :failure_reason,
  :model_artifacts,
  :model_digests,
  :role_arn,
  :input_config,
  :output_config,
  :vpc_config,
  :derived_information)
  SENSITIVE = []
  include Aws::Structure
end

#inference_imageString

The inference image to use when compiling a model. Specify an image only if the target device is a cloud instance.

Returns:

  • (String)


18208
18209
18210
18211
18212
18213
18214
18215
18216
18217
18218
18219
18220
18221
18222
18223
18224
18225
18226
18227
18228
18229
# File 'lib/aws-sdk-sagemaker/types.rb', line 18208

class DescribeCompilationJobResponse < Struct.new(
  :compilation_job_name,
  :compilation_job_arn,
  :compilation_job_status,
  :compilation_start_time,
  :compilation_end_time,
  :stopping_condition,
  :inference_image,
  :model_package_version_arn,
  :creation_time,
  :last_modified_time,
  :failure_reason,
  :model_artifacts,
  :model_digests,
  :role_arn,
  :input_config,
  :output_config,
  :vpc_config,
  :derived_information)
  SENSITIVE = []
  include Aws::Structure
end

#input_configTypes::InputConfig

Information about the location in Amazon S3 of the input model artifacts, the name and shape of the expected data inputs, and the framework in which the model was trained.

Returns:



18208
18209
18210
18211
18212
18213
18214
18215
18216
18217
18218
18219
18220
18221
18222
18223
18224
18225
18226
18227
18228
18229
# File 'lib/aws-sdk-sagemaker/types.rb', line 18208

class DescribeCompilationJobResponse < Struct.new(
  :compilation_job_name,
  :compilation_job_arn,
  :compilation_job_status,
  :compilation_start_time,
  :compilation_end_time,
  :stopping_condition,
  :inference_image,
  :model_package_version_arn,
  :creation_time,
  :last_modified_time,
  :failure_reason,
  :model_artifacts,
  :model_digests,
  :role_arn,
  :input_config,
  :output_config,
  :vpc_config,
  :derived_information)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The time that the status of the model compilation job was last modified.

Returns:

  • (Time)


18208
18209
18210
18211
18212
18213
18214
18215
18216
18217
18218
18219
18220
18221
18222
18223
18224
18225
18226
18227
18228
18229
# File 'lib/aws-sdk-sagemaker/types.rb', line 18208

class DescribeCompilationJobResponse < Struct.new(
  :compilation_job_name,
  :compilation_job_arn,
  :compilation_job_status,
  :compilation_start_time,
  :compilation_end_time,
  :stopping_condition,
  :inference_image,
  :model_package_version_arn,
  :creation_time,
  :last_modified_time,
  :failure_reason,
  :model_artifacts,
  :model_digests,
  :role_arn,
  :input_config,
  :output_config,
  :vpc_config,
  :derived_information)
  SENSITIVE = []
  include Aws::Structure
end

#model_artifactsTypes::ModelArtifacts

Information about the location in Amazon S3 that has been configured for storing the model artifacts used in the compilation job.



18208
18209
18210
18211
18212
18213
18214
18215
18216
18217
18218
18219
18220
18221
18222
18223
18224
18225
18226
18227
18228
18229
# File 'lib/aws-sdk-sagemaker/types.rb', line 18208

class DescribeCompilationJobResponse < Struct.new(
  :compilation_job_name,
  :compilation_job_arn,
  :compilation_job_status,
  :compilation_start_time,
  :compilation_end_time,
  :stopping_condition,
  :inference_image,
  :model_package_version_arn,
  :creation_time,
  :last_modified_time,
  :failure_reason,
  :model_artifacts,
  :model_digests,
  :role_arn,
  :input_config,
  :output_config,
  :vpc_config,
  :derived_information)
  SENSITIVE = []
  include Aws::Structure
end

#model_digestsTypes::ModelDigests

Provides a BLAKE2 hash value that identifies the compiled model artifacts in Amazon S3.

Returns:



18208
18209
18210
18211
18212
18213
18214
18215
18216
18217
18218
18219
18220
18221
18222
18223
18224
18225
18226
18227
18228
18229
# File 'lib/aws-sdk-sagemaker/types.rb', line 18208

class DescribeCompilationJobResponse < Struct.new(
  :compilation_job_name,
  :compilation_job_arn,
  :compilation_job_status,
  :compilation_start_time,
  :compilation_end_time,
  :stopping_condition,
  :inference_image,
  :model_package_version_arn,
  :creation_time,
  :last_modified_time,
  :failure_reason,
  :model_artifacts,
  :model_digests,
  :role_arn,
  :input_config,
  :output_config,
  :vpc_config,
  :derived_information)
  SENSITIVE = []
  include Aws::Structure
end

#model_package_version_arnString

The Amazon Resource Name (ARN) of the versioned model package that was provided to SageMaker Neo when you initiated a compilation job.

Returns:

  • (String)


18208
18209
18210
18211
18212
18213
18214
18215
18216
18217
18218
18219
18220
18221
18222
18223
18224
18225
18226
18227
18228
18229
# File 'lib/aws-sdk-sagemaker/types.rb', line 18208

class DescribeCompilationJobResponse < Struct.new(
  :compilation_job_name,
  :compilation_job_arn,
  :compilation_job_status,
  :compilation_start_time,
  :compilation_end_time,
  :stopping_condition,
  :inference_image,
  :model_package_version_arn,
  :creation_time,
  :last_modified_time,
  :failure_reason,
  :model_artifacts,
  :model_digests,
  :role_arn,
  :input_config,
  :output_config,
  :vpc_config,
  :derived_information)
  SENSITIVE = []
  include Aws::Structure
end

#output_configTypes::OutputConfig

Information about the output location for the compiled model and the target device that the model runs on.

Returns:



18208
18209
18210
18211
18212
18213
18214
18215
18216
18217
18218
18219
18220
18221
18222
18223
18224
18225
18226
18227
18228
18229
# File 'lib/aws-sdk-sagemaker/types.rb', line 18208

class DescribeCompilationJobResponse < Struct.new(
  :compilation_job_name,
  :compilation_job_arn,
  :compilation_job_status,
  :compilation_start_time,
  :compilation_end_time,
  :stopping_condition,
  :inference_image,
  :model_package_version_arn,
  :creation_time,
  :last_modified_time,
  :failure_reason,
  :model_artifacts,
  :model_digests,
  :role_arn,
  :input_config,
  :output_config,
  :vpc_config,
  :derived_information)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker AI assumes to perform the model compilation job.

Returns:

  • (String)


18208
18209
18210
18211
18212
18213
18214
18215
18216
18217
18218
18219
18220
18221
18222
18223
18224
18225
18226
18227
18228
18229
# File 'lib/aws-sdk-sagemaker/types.rb', line 18208

class DescribeCompilationJobResponse < Struct.new(
  :compilation_job_name,
  :compilation_job_arn,
  :compilation_job_status,
  :compilation_start_time,
  :compilation_end_time,
  :stopping_condition,
  :inference_image,
  :model_package_version_arn,
  :creation_time,
  :last_modified_time,
  :failure_reason,
  :model_artifacts,
  :model_digests,
  :role_arn,
  :input_config,
  :output_config,
  :vpc_config,
  :derived_information)
  SENSITIVE = []
  include Aws::Structure
end

#stopping_conditionTypes::StoppingCondition

Specifies a limit to how long a model compilation job can run. When the job reaches the time limit, Amazon SageMaker AI ends the compilation job. Use this API to cap model training costs.



18208
18209
18210
18211
18212
18213
18214
18215
18216
18217
18218
18219
18220
18221
18222
18223
18224
18225
18226
18227
18228
18229
# File 'lib/aws-sdk-sagemaker/types.rb', line 18208

class DescribeCompilationJobResponse < Struct.new(
  :compilation_job_name,
  :compilation_job_arn,
  :compilation_job_status,
  :compilation_start_time,
  :compilation_end_time,
  :stopping_condition,
  :inference_image,
  :model_package_version_arn,
  :creation_time,
  :last_modified_time,
  :failure_reason,
  :model_artifacts,
  :model_digests,
  :role_arn,
  :input_config,
  :output_config,
  :vpc_config,
  :derived_information)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_configTypes::NeoVpcConfig

A [VpcConfig] object that specifies the VPC that you want your compilation job to connect to. Control access to your models by configuring the VPC. For more information, see [Protect Compilation Jobs by Using an Amazon Virtual Private Cloud].

[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_VpcConfig.html [2]: docs.aws.amazon.com/sagemaker/latest/dg/neo-vpc.html

Returns:



18208
18209
18210
18211
18212
18213
18214
18215
18216
18217
18218
18219
18220
18221
18222
18223
18224
18225
18226
18227
18228
18229
# File 'lib/aws-sdk-sagemaker/types.rb', line 18208

class DescribeCompilationJobResponse < Struct.new(
  :compilation_job_name,
  :compilation_job_arn,
  :compilation_job_status,
  :compilation_start_time,
  :compilation_end_time,
  :stopping_condition,
  :inference_image,
  :model_package_version_arn,
  :creation_time,
  :last_modified_time,
  :failure_reason,
  :model_artifacts,
  :model_digests,
  :role_arn,
  :input_config,
  :output_config,
  :vpc_config,
  :derived_information)
  SENSITIVE = []
  include Aws::Structure
end