Class: Aws::SageMaker::Types::DescribeContextResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#context_arnString

The Amazon Resource Name (ARN) of the context.

Returns:

  • (String)


18827
18828
18829
18830
18831
18832
18833
18834
18835
18836
18837
18838
18839
18840
18841
# File 'lib/aws-sdk-sagemaker/types.rb', line 18827

class DescribeContextResponse < Struct.new(
  :context_name,
  :context_arn,
  :source,
  :context_type,
  :description,
  :properties,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :lineage_group_arn)
  SENSITIVE = []
  include Aws::Structure
end

#context_nameString

The name of the context.

Returns:

  • (String)


18827
18828
18829
18830
18831
18832
18833
18834
18835
18836
18837
18838
18839
18840
18841
# File 'lib/aws-sdk-sagemaker/types.rb', line 18827

class DescribeContextResponse < Struct.new(
  :context_name,
  :context_arn,
  :source,
  :context_type,
  :description,
  :properties,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :lineage_group_arn)
  SENSITIVE = []
  include Aws::Structure
end

#context_typeString

The type of the context.

Returns:

  • (String)


18827
18828
18829
18830
18831
18832
18833
18834
18835
18836
18837
18838
18839
18840
18841
# File 'lib/aws-sdk-sagemaker/types.rb', line 18827

class DescribeContextResponse < Struct.new(
  :context_name,
  :context_arn,
  :source,
  :context_type,
  :description,
  :properties,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :lineage_group_arn)
  SENSITIVE = []
  include Aws::Structure
end

#created_byTypes::UserContext

Information about the user who created or modified a SageMaker resource.

Returns:



18827
18828
18829
18830
18831
18832
18833
18834
18835
18836
18837
18838
18839
18840
18841
# File 'lib/aws-sdk-sagemaker/types.rb', line 18827

class DescribeContextResponse < Struct.new(
  :context_name,
  :context_arn,
  :source,
  :context_type,
  :description,
  :properties,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :lineage_group_arn)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

When the context was created.

Returns:

  • (Time)


18827
18828
18829
18830
18831
18832
18833
18834
18835
18836
18837
18838
18839
18840
18841
# File 'lib/aws-sdk-sagemaker/types.rb', line 18827

class DescribeContextResponse < Struct.new(
  :context_name,
  :context_arn,
  :source,
  :context_type,
  :description,
  :properties,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :lineage_group_arn)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the context.

Returns:

  • (String)


18827
18828
18829
18830
18831
18832
18833
18834
18835
18836
18837
18838
18839
18840
18841
# File 'lib/aws-sdk-sagemaker/types.rb', line 18827

class DescribeContextResponse < Struct.new(
  :context_name,
  :context_arn,
  :source,
  :context_type,
  :description,
  :properties,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :lineage_group_arn)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_byTypes::UserContext

Information about the user who created or modified a SageMaker resource.

Returns:



18827
18828
18829
18830
18831
18832
18833
18834
18835
18836
18837
18838
18839
18840
18841
# File 'lib/aws-sdk-sagemaker/types.rb', line 18827

class DescribeContextResponse < Struct.new(
  :context_name,
  :context_arn,
  :source,
  :context_type,
  :description,
  :properties,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :lineage_group_arn)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

When the context was last modified.

Returns:

  • (Time)


18827
18828
18829
18830
18831
18832
18833
18834
18835
18836
18837
18838
18839
18840
18841
# File 'lib/aws-sdk-sagemaker/types.rb', line 18827

class DescribeContextResponse < Struct.new(
  :context_name,
  :context_arn,
  :source,
  :context_type,
  :description,
  :properties,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :lineage_group_arn)
  SENSITIVE = []
  include Aws::Structure
end

#lineage_group_arnString

The Amazon Resource Name (ARN) of the lineage group.

Returns:

  • (String)


18827
18828
18829
18830
18831
18832
18833
18834
18835
18836
18837
18838
18839
18840
18841
# File 'lib/aws-sdk-sagemaker/types.rb', line 18827

class DescribeContextResponse < Struct.new(
  :context_name,
  :context_arn,
  :source,
  :context_type,
  :description,
  :properties,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :lineage_group_arn)
  SENSITIVE = []
  include Aws::Structure
end

#propertiesHash<String,String>

A list of the context's properties.

Returns:

  • (Hash<String,String>)


18827
18828
18829
18830
18831
18832
18833
18834
18835
18836
18837
18838
18839
18840
18841
# File 'lib/aws-sdk-sagemaker/types.rb', line 18827

class DescribeContextResponse < Struct.new(
  :context_name,
  :context_arn,
  :source,
  :context_type,
  :description,
  :properties,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :lineage_group_arn)
  SENSITIVE = []
  include Aws::Structure
end

#sourceTypes::ContextSource

The source of the context.



18827
18828
18829
18830
18831
18832
18833
18834
18835
18836
18837
18838
18839
18840
18841
# File 'lib/aws-sdk-sagemaker/types.rb', line 18827

class DescribeContextResponse < Struct.new(
  :context_name,
  :context_arn,
  :source,
  :context_type,
  :description,
  :properties,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :lineage_group_arn)
  SENSITIVE = []
  include Aws::Structure
end