Class: Aws::SageMaker::Types::DescribeDeviceResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_versionString

Edge Manager agent version.



19113
19114
19115
19116
19117
19118
19119
19120
19121
19122
19123
19124
19125
19126
19127
# File 'lib/aws-sdk-sagemaker/types.rb', line 19113

class DescribeDeviceResponse < Struct.new(
  :device_arn,
  :device_name,
  :description,
  :device_fleet_name,
  :iot_thing_name,
  :registration_time,
  :latest_heartbeat,
  :models,
  :max_models,
  :next_token,
  :agent_version)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the device.



19113
19114
19115
19116
19117
19118
19119
19120
19121
19122
19123
19124
19125
19126
19127
# File 'lib/aws-sdk-sagemaker/types.rb', line 19113

class DescribeDeviceResponse < Struct.new(
  :device_arn,
  :device_name,
  :description,
  :device_fleet_name,
  :iot_thing_name,
  :registration_time,
  :latest_heartbeat,
  :models,
  :max_models,
  :next_token,
  :agent_version)
  SENSITIVE = []
  include Aws::Structure
end

#device_arnString

The Amazon Resource Name (ARN) of the device.



19113
19114
19115
19116
19117
19118
19119
19120
19121
19122
19123
19124
19125
19126
19127
# File 'lib/aws-sdk-sagemaker/types.rb', line 19113

class DescribeDeviceResponse < Struct.new(
  :device_arn,
  :device_name,
  :description,
  :device_fleet_name,
  :iot_thing_name,
  :registration_time,
  :latest_heartbeat,
  :models,
  :max_models,
  :next_token,
  :agent_version)
  SENSITIVE = []
  include Aws::Structure
end

#device_fleet_nameString

The name of the fleet the device belongs to.



19113
19114
19115
19116
19117
19118
19119
19120
19121
19122
19123
19124
19125
19126
19127
# File 'lib/aws-sdk-sagemaker/types.rb', line 19113

class DescribeDeviceResponse < Struct.new(
  :device_arn,
  :device_name,
  :description,
  :device_fleet_name,
  :iot_thing_name,
  :registration_time,
  :latest_heartbeat,
  :models,
  :max_models,
  :next_token,
  :agent_version)
  SENSITIVE = []
  include Aws::Structure
end

#device_nameString

The unique identifier of the device.



19113
19114
19115
19116
19117
19118
19119
19120
19121
19122
19123
19124
19125
19126
19127
# File 'lib/aws-sdk-sagemaker/types.rb', line 19113

class DescribeDeviceResponse < Struct.new(
  :device_arn,
  :device_name,
  :description,
  :device_fleet_name,
  :iot_thing_name,
  :registration_time,
  :latest_heartbeat,
  :models,
  :max_models,
  :next_token,
  :agent_version)
  SENSITIVE = []
  include Aws::Structure
end

#iot_thing_nameString

The Amazon Web Services Internet of Things (IoT) object thing name associated with the device.



19113
19114
19115
19116
19117
19118
19119
19120
19121
19122
19123
19124
19125
19126
19127
# File 'lib/aws-sdk-sagemaker/types.rb', line 19113

class DescribeDeviceResponse < Struct.new(
  :device_arn,
  :device_name,
  :description,
  :device_fleet_name,
  :iot_thing_name,
  :registration_time,
  :latest_heartbeat,
  :models,
  :max_models,
  :next_token,
  :agent_version)
  SENSITIVE = []
  include Aws::Structure
end

#latest_heartbeatTime

The last heartbeat received from the device.



19113
19114
19115
19116
19117
19118
19119
19120
19121
19122
19123
19124
19125
19126
19127
# File 'lib/aws-sdk-sagemaker/types.rb', line 19113

class DescribeDeviceResponse < Struct.new(
  :device_arn,
  :device_name,
  :description,
  :device_fleet_name,
  :iot_thing_name,
  :registration_time,
  :latest_heartbeat,
  :models,
  :max_models,
  :next_token,
  :agent_version)
  SENSITIVE = []
  include Aws::Structure
end

#max_modelsInteger

The maximum number of models.



19113
19114
19115
19116
19117
19118
19119
19120
19121
19122
19123
19124
19125
19126
19127
# File 'lib/aws-sdk-sagemaker/types.rb', line 19113

class DescribeDeviceResponse < Struct.new(
  :device_arn,
  :device_name,
  :description,
  :device_fleet_name,
  :iot_thing_name,
  :registration_time,
  :latest_heartbeat,
  :models,
  :max_models,
  :next_token,
  :agent_version)
  SENSITIVE = []
  include Aws::Structure
end

#modelsArray<Types::EdgeModel>

Models on the device.



19113
19114
19115
19116
19117
19118
19119
19120
19121
19122
19123
19124
19125
19126
19127
# File 'lib/aws-sdk-sagemaker/types.rb', line 19113

class DescribeDeviceResponse < Struct.new(
  :device_arn,
  :device_name,
  :description,
  :device_fleet_name,
  :iot_thing_name,
  :registration_time,
  :latest_heartbeat,
  :models,
  :max_models,
  :next_token,
  :agent_version)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The response from the last list when returning a list large enough to need tokening.



19113
19114
19115
19116
19117
19118
19119
19120
19121
19122
19123
19124
19125
19126
19127
# File 'lib/aws-sdk-sagemaker/types.rb', line 19113

class DescribeDeviceResponse < Struct.new(
  :device_arn,
  :device_name,
  :description,
  :device_fleet_name,
  :iot_thing_name,
  :registration_time,
  :latest_heartbeat,
  :models,
  :max_models,
  :next_token,
  :agent_version)
  SENSITIVE = []
  include Aws::Structure
end

#registration_timeTime

The timestamp of the last registration or de-reregistration.



19113
19114
19115
19116
19117
19118
19119
19120
19121
19122
19123
19124
19125
19126
19127
# File 'lib/aws-sdk-sagemaker/types.rb', line 19113

class DescribeDeviceResponse < Struct.new(
  :device_arn,
  :device_name,
  :description,
  :device_fleet_name,
  :iot_thing_name,
  :registration_time,
  :latest_heartbeat,
  :models,
  :max_models,
  :next_token,
  :agent_version)
  SENSITIVE = []
  include Aws::Structure
end