Class: Aws::SageMaker::Types::DescribeEdgeDeploymentPlanRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#edge_deployment_plan_nameString

The name of the deployment plan to describe.



19301
19302
19303
19304
19305
19306
19307
# File 'lib/aws-sdk-sagemaker/types.rb', line 19301

class DescribeEdgeDeploymentPlanRequest < Struct.new(
  :edge_deployment_plan_name,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to select (50 by default).



19301
19302
19303
19304
19305
19306
19307
# File 'lib/aws-sdk-sagemaker/types.rb', line 19301

class DescribeEdgeDeploymentPlanRequest < Struct.new(
  :edge_deployment_plan_name,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the edge deployment plan has enough stages to require tokening, then this is the response from the last list of stages returned.



19301
19302
19303
19304
19305
19306
19307
# File 'lib/aws-sdk-sagemaker/types.rb', line 19301

class DescribeEdgeDeploymentPlanRequest < Struct.new(
  :edge_deployment_plan_name,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end