Class: Aws::SageMaker::Types::DescribeEdgeDeploymentPlanResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timeTime

The time when the edge deployment plan was created.



19357
19358
19359
19360
19361
19362
19363
19364
19365
19366
19367
19368
19369
19370
19371
# File 'lib/aws-sdk-sagemaker/types.rb', line 19357

class DescribeEdgeDeploymentPlanResponse < Struct.new(
  :edge_deployment_plan_arn,
  :edge_deployment_plan_name,
  :model_configs,
  :device_fleet_name,
  :edge_deployment_success,
  :edge_deployment_pending,
  :edge_deployment_failed,
  :stages,
  :next_token,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#device_fleet_nameString

The device fleet used for this edge deployment plan.



19357
19358
19359
19360
19361
19362
19363
19364
19365
19366
19367
19368
19369
19370
19371
# File 'lib/aws-sdk-sagemaker/types.rb', line 19357

class DescribeEdgeDeploymentPlanResponse < Struct.new(
  :edge_deployment_plan_arn,
  :edge_deployment_plan_name,
  :model_configs,
  :device_fleet_name,
  :edge_deployment_success,
  :edge_deployment_pending,
  :edge_deployment_failed,
  :stages,
  :next_token,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#edge_deployment_failedInteger

The number of edge devices that failed the deployment.



19357
19358
19359
19360
19361
19362
19363
19364
19365
19366
19367
19368
19369
19370
19371
# File 'lib/aws-sdk-sagemaker/types.rb', line 19357

class DescribeEdgeDeploymentPlanResponse < Struct.new(
  :edge_deployment_plan_arn,
  :edge_deployment_plan_name,
  :model_configs,
  :device_fleet_name,
  :edge_deployment_success,
  :edge_deployment_pending,
  :edge_deployment_failed,
  :stages,
  :next_token,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#edge_deployment_pendingInteger

The number of edge devices yet to pick up deployment, or in progress.



19357
19358
19359
19360
19361
19362
19363
19364
19365
19366
19367
19368
19369
19370
19371
# File 'lib/aws-sdk-sagemaker/types.rb', line 19357

class DescribeEdgeDeploymentPlanResponse < Struct.new(
  :edge_deployment_plan_arn,
  :edge_deployment_plan_name,
  :model_configs,
  :device_fleet_name,
  :edge_deployment_success,
  :edge_deployment_pending,
  :edge_deployment_failed,
  :stages,
  :next_token,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#edge_deployment_plan_arnString

The ARN of edge deployment plan.



19357
19358
19359
19360
19361
19362
19363
19364
19365
19366
19367
19368
19369
19370
19371
# File 'lib/aws-sdk-sagemaker/types.rb', line 19357

class DescribeEdgeDeploymentPlanResponse < Struct.new(
  :edge_deployment_plan_arn,
  :edge_deployment_plan_name,
  :model_configs,
  :device_fleet_name,
  :edge_deployment_success,
  :edge_deployment_pending,
  :edge_deployment_failed,
  :stages,
  :next_token,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#edge_deployment_plan_nameString

The name of the edge deployment plan.



19357
19358
19359
19360
19361
19362
19363
19364
19365
19366
19367
19368
19369
19370
19371
# File 'lib/aws-sdk-sagemaker/types.rb', line 19357

class DescribeEdgeDeploymentPlanResponse < Struct.new(
  :edge_deployment_plan_arn,
  :edge_deployment_plan_name,
  :model_configs,
  :device_fleet_name,
  :edge_deployment_success,
  :edge_deployment_pending,
  :edge_deployment_failed,
  :stages,
  :next_token,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#edge_deployment_successInteger

The number of edge devices with the successful deployment.



19357
19358
19359
19360
19361
19362
19363
19364
19365
19366
19367
19368
19369
19370
19371
# File 'lib/aws-sdk-sagemaker/types.rb', line 19357

class DescribeEdgeDeploymentPlanResponse < Struct.new(
  :edge_deployment_plan_arn,
  :edge_deployment_plan_name,
  :model_configs,
  :device_fleet_name,
  :edge_deployment_success,
  :edge_deployment_pending,
  :edge_deployment_failed,
  :stages,
  :next_token,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The time when the edge deployment plan was last updated.



19357
19358
19359
19360
19361
19362
19363
19364
19365
19366
19367
19368
19369
19370
19371
# File 'lib/aws-sdk-sagemaker/types.rb', line 19357

class DescribeEdgeDeploymentPlanResponse < Struct.new(
  :edge_deployment_plan_arn,
  :edge_deployment_plan_name,
  :model_configs,
  :device_fleet_name,
  :edge_deployment_success,
  :edge_deployment_pending,
  :edge_deployment_failed,
  :stages,
  :next_token,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#model_configsArray<Types::EdgeDeploymentModelConfig>

List of models associated with the edge deployment plan.



19357
19358
19359
19360
19361
19362
19363
19364
19365
19366
19367
19368
19369
19370
19371
# File 'lib/aws-sdk-sagemaker/types.rb', line 19357

class DescribeEdgeDeploymentPlanResponse < Struct.new(
  :edge_deployment_plan_arn,
  :edge_deployment_plan_name,
  :model_configs,
  :device_fleet_name,
  :edge_deployment_success,
  :edge_deployment_pending,
  :edge_deployment_failed,
  :stages,
  :next_token,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

Token to use when calling the next set of stages in the edge deployment plan.



19357
19358
19359
19360
19361
19362
19363
19364
19365
19366
19367
19368
19369
19370
19371
# File 'lib/aws-sdk-sagemaker/types.rb', line 19357

class DescribeEdgeDeploymentPlanResponse < Struct.new(
  :edge_deployment_plan_arn,
  :edge_deployment_plan_name,
  :model_configs,
  :device_fleet_name,
  :edge_deployment_success,
  :edge_deployment_pending,
  :edge_deployment_failed,
  :stages,
  :next_token,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#stagesArray<Types::DeploymentStageStatusSummary>

List of stages in the edge deployment plan.



19357
19358
19359
19360
19361
19362
19363
19364
19365
19366
19367
19368
19369
19370
19371
# File 'lib/aws-sdk-sagemaker/types.rb', line 19357

class DescribeEdgeDeploymentPlanResponse < Struct.new(
  :edge_deployment_plan_arn,
  :edge_deployment_plan_name,
  :model_configs,
  :device_fleet_name,
  :edge_deployment_success,
  :edge_deployment_pending,
  :edge_deployment_failed,
  :stages,
  :next_token,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end