Class: Aws::SageMaker::Types::DescribeEdgePackagingJobResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#compilation_job_nameString

The name of the SageMaker Neo compilation job that is used to locate model artifacts that are being packaged.



19451
19452
19453
19454
19455
19456
19457
19458
19459
19460
19461
19462
19463
19464
19465
19466
19467
19468
19469
# File 'lib/aws-sdk-sagemaker/types.rb', line 19451

class DescribeEdgePackagingJobResponse < Struct.new(
  :edge_packaging_job_arn,
  :edge_packaging_job_name,
  :compilation_job_name,
  :model_name,
  :model_version,
  :role_arn,
  :output_config,
  :resource_key,
  :edge_packaging_job_status,
  :edge_packaging_job_status_message,
  :creation_time,
  :last_modified_time,
  :model_artifact,
  :model_signature,
  :preset_deployment_output)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

The timestamp of when the packaging job was created.



19451
19452
19453
19454
19455
19456
19457
19458
19459
19460
19461
19462
19463
19464
19465
19466
19467
19468
19469
# File 'lib/aws-sdk-sagemaker/types.rb', line 19451

class DescribeEdgePackagingJobResponse < Struct.new(
  :edge_packaging_job_arn,
  :edge_packaging_job_name,
  :compilation_job_name,
  :model_name,
  :model_version,
  :role_arn,
  :output_config,
  :resource_key,
  :edge_packaging_job_status,
  :edge_packaging_job_status_message,
  :creation_time,
  :last_modified_time,
  :model_artifact,
  :model_signature,
  :preset_deployment_output)
  SENSITIVE = []
  include Aws::Structure
end

#edge_packaging_job_arnString

The Amazon Resource Name (ARN) of the edge packaging job.



19451
19452
19453
19454
19455
19456
19457
19458
19459
19460
19461
19462
19463
19464
19465
19466
19467
19468
19469
# File 'lib/aws-sdk-sagemaker/types.rb', line 19451

class DescribeEdgePackagingJobResponse < Struct.new(
  :edge_packaging_job_arn,
  :edge_packaging_job_name,
  :compilation_job_name,
  :model_name,
  :model_version,
  :role_arn,
  :output_config,
  :resource_key,
  :edge_packaging_job_status,
  :edge_packaging_job_status_message,
  :creation_time,
  :last_modified_time,
  :model_artifact,
  :model_signature,
  :preset_deployment_output)
  SENSITIVE = []
  include Aws::Structure
end

#edge_packaging_job_nameString

The name of the edge packaging job.



19451
19452
19453
19454
19455
19456
19457
19458
19459
19460
19461
19462
19463
19464
19465
19466
19467
19468
19469
# File 'lib/aws-sdk-sagemaker/types.rb', line 19451

class DescribeEdgePackagingJobResponse < Struct.new(
  :edge_packaging_job_arn,
  :edge_packaging_job_name,
  :compilation_job_name,
  :model_name,
  :model_version,
  :role_arn,
  :output_config,
  :resource_key,
  :edge_packaging_job_status,
  :edge_packaging_job_status_message,
  :creation_time,
  :last_modified_time,
  :model_artifact,
  :model_signature,
  :preset_deployment_output)
  SENSITIVE = []
  include Aws::Structure
end

#edge_packaging_job_statusString

The current status of the packaging job.



19451
19452
19453
19454
19455
19456
19457
19458
19459
19460
19461
19462
19463
19464
19465
19466
19467
19468
19469
# File 'lib/aws-sdk-sagemaker/types.rb', line 19451

class DescribeEdgePackagingJobResponse < Struct.new(
  :edge_packaging_job_arn,
  :edge_packaging_job_name,
  :compilation_job_name,
  :model_name,
  :model_version,
  :role_arn,
  :output_config,
  :resource_key,
  :edge_packaging_job_status,
  :edge_packaging_job_status_message,
  :creation_time,
  :last_modified_time,
  :model_artifact,
  :model_signature,
  :preset_deployment_output)
  SENSITIVE = []
  include Aws::Structure
end

#edge_packaging_job_status_messageString

Returns a message describing the job status and error messages.



19451
19452
19453
19454
19455
19456
19457
19458
19459
19460
19461
19462
19463
19464
19465
19466
19467
19468
19469
# File 'lib/aws-sdk-sagemaker/types.rb', line 19451

class DescribeEdgePackagingJobResponse < Struct.new(
  :edge_packaging_job_arn,
  :edge_packaging_job_name,
  :compilation_job_name,
  :model_name,
  :model_version,
  :role_arn,
  :output_config,
  :resource_key,
  :edge_packaging_job_status,
  :edge_packaging_job_status_message,
  :creation_time,
  :last_modified_time,
  :model_artifact,
  :model_signature,
  :preset_deployment_output)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The timestamp of when the job was last updated.



19451
19452
19453
19454
19455
19456
19457
19458
19459
19460
19461
19462
19463
19464
19465
19466
19467
19468
19469
# File 'lib/aws-sdk-sagemaker/types.rb', line 19451

class DescribeEdgePackagingJobResponse < Struct.new(
  :edge_packaging_job_arn,
  :edge_packaging_job_name,
  :compilation_job_name,
  :model_name,
  :model_version,
  :role_arn,
  :output_config,
  :resource_key,
  :edge_packaging_job_status,
  :edge_packaging_job_status_message,
  :creation_time,
  :last_modified_time,
  :model_artifact,
  :model_signature,
  :preset_deployment_output)
  SENSITIVE = []
  include Aws::Structure
end

#model_artifactString

The Amazon Simple Storage (S3) URI where model artifacts ares stored.



19451
19452
19453
19454
19455
19456
19457
19458
19459
19460
19461
19462
19463
19464
19465
19466
19467
19468
19469
# File 'lib/aws-sdk-sagemaker/types.rb', line 19451

class DescribeEdgePackagingJobResponse < Struct.new(
  :edge_packaging_job_arn,
  :edge_packaging_job_name,
  :compilation_job_name,
  :model_name,
  :model_version,
  :role_arn,
  :output_config,
  :resource_key,
  :edge_packaging_job_status,
  :edge_packaging_job_status_message,
  :creation_time,
  :last_modified_time,
  :model_artifact,
  :model_signature,
  :preset_deployment_output)
  SENSITIVE = []
  include Aws::Structure
end

#model_nameString

The name of the model.



19451
19452
19453
19454
19455
19456
19457
19458
19459
19460
19461
19462
19463
19464
19465
19466
19467
19468
19469
# File 'lib/aws-sdk-sagemaker/types.rb', line 19451

class DescribeEdgePackagingJobResponse < Struct.new(
  :edge_packaging_job_arn,
  :edge_packaging_job_name,
  :compilation_job_name,
  :model_name,
  :model_version,
  :role_arn,
  :output_config,
  :resource_key,
  :edge_packaging_job_status,
  :edge_packaging_job_status_message,
  :creation_time,
  :last_modified_time,
  :model_artifact,
  :model_signature,
  :preset_deployment_output)
  SENSITIVE = []
  include Aws::Structure
end

#model_signatureString

The signature document of files in the model artifact.



19451
19452
19453
19454
19455
19456
19457
19458
19459
19460
19461
19462
19463
19464
19465
19466
19467
19468
19469
# File 'lib/aws-sdk-sagemaker/types.rb', line 19451

class DescribeEdgePackagingJobResponse < Struct.new(
  :edge_packaging_job_arn,
  :edge_packaging_job_name,
  :compilation_job_name,
  :model_name,
  :model_version,
  :role_arn,
  :output_config,
  :resource_key,
  :edge_packaging_job_status,
  :edge_packaging_job_status_message,
  :creation_time,
  :last_modified_time,
  :model_artifact,
  :model_signature,
  :preset_deployment_output)
  SENSITIVE = []
  include Aws::Structure
end

#model_versionString

The version of the model.



19451
19452
19453
19454
19455
19456
19457
19458
19459
19460
19461
19462
19463
19464
19465
19466
19467
19468
19469
# File 'lib/aws-sdk-sagemaker/types.rb', line 19451

class DescribeEdgePackagingJobResponse < Struct.new(
  :edge_packaging_job_arn,
  :edge_packaging_job_name,
  :compilation_job_name,
  :model_name,
  :model_version,
  :role_arn,
  :output_config,
  :resource_key,
  :edge_packaging_job_status,
  :edge_packaging_job_status_message,
  :creation_time,
  :last_modified_time,
  :model_artifact,
  :model_signature,
  :preset_deployment_output)
  SENSITIVE = []
  include Aws::Structure
end

#output_configTypes::EdgeOutputConfig

The output configuration for the edge packaging job.



19451
19452
19453
19454
19455
19456
19457
19458
19459
19460
19461
19462
19463
19464
19465
19466
19467
19468
19469
# File 'lib/aws-sdk-sagemaker/types.rb', line 19451

class DescribeEdgePackagingJobResponse < Struct.new(
  :edge_packaging_job_arn,
  :edge_packaging_job_name,
  :compilation_job_name,
  :model_name,
  :model_version,
  :role_arn,
  :output_config,
  :resource_key,
  :edge_packaging_job_status,
  :edge_packaging_job_status_message,
  :creation_time,
  :last_modified_time,
  :model_artifact,
  :model_signature,
  :preset_deployment_output)
  SENSITIVE = []
  include Aws::Structure
end

#preset_deployment_outputTypes::EdgePresetDeploymentOutput

The output of a SageMaker Edge Manager deployable resource.



19451
19452
19453
19454
19455
19456
19457
19458
19459
19460
19461
19462
19463
19464
19465
19466
19467
19468
19469
# File 'lib/aws-sdk-sagemaker/types.rb', line 19451

class DescribeEdgePackagingJobResponse < Struct.new(
  :edge_packaging_job_arn,
  :edge_packaging_job_name,
  :compilation_job_name,
  :model_name,
  :model_version,
  :role_arn,
  :output_config,
  :resource_key,
  :edge_packaging_job_status,
  :edge_packaging_job_status_message,
  :creation_time,
  :last_modified_time,
  :model_artifact,
  :model_signature,
  :preset_deployment_output)
  SENSITIVE = []
  include Aws::Structure
end

#resource_keyString

The Amazon Web Services KMS key to use when encrypting the EBS volume the job run on.



19451
19452
19453
19454
19455
19456
19457
19458
19459
19460
19461
19462
19463
19464
19465
19466
19467
19468
19469
# File 'lib/aws-sdk-sagemaker/types.rb', line 19451

class DescribeEdgePackagingJobResponse < Struct.new(
  :edge_packaging_job_arn,
  :edge_packaging_job_name,
  :compilation_job_name,
  :model_name,
  :model_version,
  :role_arn,
  :output_config,
  :resource_key,
  :edge_packaging_job_status,
  :edge_packaging_job_status_message,
  :creation_time,
  :last_modified_time,
  :model_artifact,
  :model_signature,
  :preset_deployment_output)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of an IAM role that enables Amazon SageMaker to download and upload the model, and to contact Neo.



19451
19452
19453
19454
19455
19456
19457
19458
19459
19460
19461
19462
19463
19464
19465
19466
19467
19468
19469
# File 'lib/aws-sdk-sagemaker/types.rb', line 19451

class DescribeEdgePackagingJobResponse < Struct.new(
  :edge_packaging_job_arn,
  :edge_packaging_job_name,
  :compilation_job_name,
  :model_name,
  :model_version,
  :role_arn,
  :output_config,
  :resource_key,
  :edge_packaging_job_status,
  :edge_packaging_job_status_message,
  :creation_time,
  :last_modified_time,
  :model_artifact,
  :model_signature,
  :preset_deployment_output)
  SENSITIVE = []
  include Aws::Structure
end