Class: Aws::SageMaker::Types::DescribeEndpointConfigOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#async_inference_configTypes::AsyncInferenceConfig

Returns the description of an endpoint configuration created using the [ CreateEndpointConfig ][1] API.

[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateEndpointConfig.html



17447
17448
17449
17450
17451
17452
17453
17454
17455
17456
17457
17458
17459
17460
17461
17462
17463
# File 'lib/aws-sdk-sagemaker/types.rb', line 17447

class DescribeEndpointConfigOutput < Struct.new(
  :endpoint_config_name,
  :endpoint_config_arn,
  :production_variants,
  :data_capture_config,
  :kms_key_id,
  :creation_time,
  :async_inference_config,
  :explainer_config,
  :shadow_production_variants,
  :execution_role_arn,
  :vpc_config,
  :enable_network_isolation,
  :metrics_config)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

A timestamp that shows when the endpoint configuration was created.

Returns:

  • (Time)


17447
17448
17449
17450
17451
17452
17453
17454
17455
17456
17457
17458
17459
17460
17461
17462
17463
# File 'lib/aws-sdk-sagemaker/types.rb', line 17447

class DescribeEndpointConfigOutput < Struct.new(
  :endpoint_config_name,
  :endpoint_config_arn,
  :production_variants,
  :data_capture_config,
  :kms_key_id,
  :creation_time,
  :async_inference_config,
  :explainer_config,
  :shadow_production_variants,
  :execution_role_arn,
  :vpc_config,
  :enable_network_isolation,
  :metrics_config)
  SENSITIVE = []
  include Aws::Structure
end

#data_capture_configTypes::DataCaptureConfig

Configuration to control how SageMaker AI captures inference data.



17447
17448
17449
17450
17451
17452
17453
17454
17455
17456
17457
17458
17459
17460
17461
17462
17463
# File 'lib/aws-sdk-sagemaker/types.rb', line 17447

class DescribeEndpointConfigOutput < Struct.new(
  :endpoint_config_name,
  :endpoint_config_arn,
  :production_variants,
  :data_capture_config,
  :kms_key_id,
  :creation_time,
  :async_inference_config,
  :explainer_config,
  :shadow_production_variants,
  :execution_role_arn,
  :vpc_config,
  :enable_network_isolation,
  :metrics_config)
  SENSITIVE = []
  include Aws::Structure
end

#enable_network_isolationBoolean

Indicates whether all model containers deployed to the endpoint are isolated. If they are, no inbound or outbound network calls can be made to or from the model containers.

Returns:

  • (Boolean)


17447
17448
17449
17450
17451
17452
17453
17454
17455
17456
17457
17458
17459
17460
17461
17462
17463
# File 'lib/aws-sdk-sagemaker/types.rb', line 17447

class DescribeEndpointConfigOutput < Struct.new(
  :endpoint_config_name,
  :endpoint_config_arn,
  :production_variants,
  :data_capture_config,
  :kms_key_id,
  :creation_time,
  :async_inference_config,
  :explainer_config,
  :shadow_production_variants,
  :execution_role_arn,
  :vpc_config,
  :enable_network_isolation,
  :metrics_config)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_config_arnString

The Amazon Resource Name (ARN) of the endpoint configuration.

Returns:

  • (String)


17447
17448
17449
17450
17451
17452
17453
17454
17455
17456
17457
17458
17459
17460
17461
17462
17463
# File 'lib/aws-sdk-sagemaker/types.rb', line 17447

class DescribeEndpointConfigOutput < Struct.new(
  :endpoint_config_name,
  :endpoint_config_arn,
  :production_variants,
  :data_capture_config,
  :kms_key_id,
  :creation_time,
  :async_inference_config,
  :explainer_config,
  :shadow_production_variants,
  :execution_role_arn,
  :vpc_config,
  :enable_network_isolation,
  :metrics_config)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_config_nameString

Name of the SageMaker endpoint configuration.

Returns:

  • (String)


17447
17448
17449
17450
17451
17452
17453
17454
17455
17456
17457
17458
17459
17460
17461
17462
17463
# File 'lib/aws-sdk-sagemaker/types.rb', line 17447

class DescribeEndpointConfigOutput < Struct.new(
  :endpoint_config_name,
  :endpoint_config_arn,
  :production_variants,
  :data_capture_config,
  :kms_key_id,
  :creation_time,
  :async_inference_config,
  :explainer_config,
  :shadow_production_variants,
  :execution_role_arn,
  :vpc_config,
  :enable_network_isolation,
  :metrics_config)
  SENSITIVE = []
  include Aws::Structure
end

#execution_role_arnString

The Amazon Resource Name (ARN) of the IAM role that you assigned to the endpoint configuration.

Returns:

  • (String)


17447
17448
17449
17450
17451
17452
17453
17454
17455
17456
17457
17458
17459
17460
17461
17462
17463
# File 'lib/aws-sdk-sagemaker/types.rb', line 17447

class DescribeEndpointConfigOutput < Struct.new(
  :endpoint_config_name,
  :endpoint_config_arn,
  :production_variants,
  :data_capture_config,
  :kms_key_id,
  :creation_time,
  :async_inference_config,
  :explainer_config,
  :shadow_production_variants,
  :execution_role_arn,
  :vpc_config,
  :enable_network_isolation,
  :metrics_config)
  SENSITIVE = []
  include Aws::Structure
end

#explainer_configTypes::ExplainerConfig

The configuration parameters for an explainer.



17447
17448
17449
17450
17451
17452
17453
17454
17455
17456
17457
17458
17459
17460
17461
17462
17463
# File 'lib/aws-sdk-sagemaker/types.rb', line 17447

class DescribeEndpointConfigOutput < Struct.new(
  :endpoint_config_name,
  :endpoint_config_arn,
  :production_variants,
  :data_capture_config,
  :kms_key_id,
  :creation_time,
  :async_inference_config,
  :explainer_config,
  :shadow_production_variants,
  :execution_role_arn,
  :vpc_config,
  :enable_network_isolation,
  :metrics_config)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

Amazon Web Services KMS key ID Amazon SageMaker uses to encrypt data when storing it on the ML storage volume attached to the instance.

Returns:

  • (String)


17447
17448
17449
17450
17451
17452
17453
17454
17455
17456
17457
17458
17459
17460
17461
17462
17463
# File 'lib/aws-sdk-sagemaker/types.rb', line 17447

class DescribeEndpointConfigOutput < Struct.new(
  :endpoint_config_name,
  :endpoint_config_arn,
  :production_variants,
  :data_capture_config,
  :kms_key_id,
  :creation_time,
  :async_inference_config,
  :explainer_config,
  :shadow_production_variants,
  :execution_role_arn,
  :vpc_config,
  :enable_network_isolation,
  :metrics_config)
  SENSITIVE = []
  include Aws::Structure
end

#metrics_configTypes::MetricsConfig

The configuration parameters for utilization metrics.



17447
17448
17449
17450
17451
17452
17453
17454
17455
17456
17457
17458
17459
17460
17461
17462
17463
# File 'lib/aws-sdk-sagemaker/types.rb', line 17447

class DescribeEndpointConfigOutput < Struct.new(
  :endpoint_config_name,
  :endpoint_config_arn,
  :production_variants,
  :data_capture_config,
  :kms_key_id,
  :creation_time,
  :async_inference_config,
  :explainer_config,
  :shadow_production_variants,
  :execution_role_arn,
  :vpc_config,
  :enable_network_isolation,
  :metrics_config)
  SENSITIVE = []
  include Aws::Structure
end

#production_variantsArray<Types::ProductionVariant>

An array of ProductionVariant objects, one for each model that you want to host at this endpoint.

Returns:



17447
17448
17449
17450
17451
17452
17453
17454
17455
17456
17457
17458
17459
17460
17461
17462
17463
# File 'lib/aws-sdk-sagemaker/types.rb', line 17447

class DescribeEndpointConfigOutput < Struct.new(
  :endpoint_config_name,
  :endpoint_config_arn,
  :production_variants,
  :data_capture_config,
  :kms_key_id,
  :creation_time,
  :async_inference_config,
  :explainer_config,
  :shadow_production_variants,
  :execution_role_arn,
  :vpc_config,
  :enable_network_isolation,
  :metrics_config)
  SENSITIVE = []
  include Aws::Structure
end

#shadow_production_variantsArray<Types::ProductionVariant>

An array of ProductionVariant objects, one for each model that you want to host at this endpoint in shadow mode with production traffic replicated from the model specified on ProductionVariants.

Returns:



17447
17448
17449
17450
17451
17452
17453
17454
17455
17456
17457
17458
17459
17460
17461
17462
17463
# File 'lib/aws-sdk-sagemaker/types.rb', line 17447

class DescribeEndpointConfigOutput < Struct.new(
  :endpoint_config_name,
  :endpoint_config_arn,
  :production_variants,
  :data_capture_config,
  :kms_key_id,
  :creation_time,
  :async_inference_config,
  :explainer_config,
  :shadow_production_variants,
  :execution_role_arn,
  :vpc_config,
  :enable_network_isolation,
  :metrics_config)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_configTypes::VpcConfig

Specifies an Amazon Virtual Private Cloud (VPC) that your SageMaker jobs, hosted models, and compute resources have access to. You can control access to and from your resources by configuring a VPC. For more information, see [Give SageMaker Access to Resources in your Amazon VPC].

[1]: docs.aws.amazon.com/sagemaker/latest/dg/infrastructure-give-access.html

Returns:



17447
17448
17449
17450
17451
17452
17453
17454
17455
17456
17457
17458
17459
17460
17461
17462
17463
# File 'lib/aws-sdk-sagemaker/types.rb', line 17447

class DescribeEndpointConfigOutput < Struct.new(
  :endpoint_config_name,
  :endpoint_config_arn,
  :production_variants,
  :data_capture_config,
  :kms_key_id,
  :creation_time,
  :async_inference_config,
  :explainer_config,
  :shadow_production_variants,
  :execution_role_arn,
  :vpc_config,
  :enable_network_isolation,
  :metrics_config)
  SENSITIVE = []
  include Aws::Structure
end