Class: Aws::SageMaker::Types::DescribeEndpointOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeEndpointOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#async_inference_config ⇒ Types::AsyncInferenceConfig
Returns the description of an endpoint configuration created using the [
CreateEndpointConfig][1] API. -
#creation_time ⇒ Time
A timestamp that shows when the endpoint was created.
-
#data_capture_config ⇒ Types::DataCaptureConfigSummary
The currently active data capture configuration used by your Endpoint.
-
#endpoint_arn ⇒ String
The Amazon Resource Name (ARN) of the endpoint.
-
#endpoint_config_name ⇒ String
The name of the endpoint configuration associated with this endpoint.
-
#endpoint_name ⇒ String
Name of the endpoint.
-
#endpoint_status ⇒ String
The status of the endpoint.
-
#explainer_config ⇒ Types::ExplainerConfig
The configuration parameters for an explainer.
-
#failure_reason ⇒ String
If the status of the endpoint is
Failed, the reason why it failed. -
#last_deployment_config ⇒ Types::DeploymentConfig
The most recent deployment configuration for the endpoint.
-
#last_modified_time ⇒ Time
A timestamp that shows when the endpoint was last modified.
-
#metrics_config ⇒ Types::MetricsConfig
The configuration parameters for utilization metrics.
-
#pending_deployment_summary ⇒ Types::PendingDeploymentSummary
Returns the summary of an in-progress deployment.
-
#production_variants ⇒ Array<Types::ProductionVariantSummary>
An array of [ProductionVariantSummary][1] objects, one for each model hosted behind this endpoint.
-
#shadow_production_variants ⇒ Array<Types::ProductionVariantSummary>
An array of [ProductionVariantSummary][1] objects, one for each model that you want to host at this endpoint in shadow mode with production traffic replicated from the model specified on
ProductionVariants.
Instance Attribute Details
#async_inference_config ⇒ Types::AsyncInferenceConfig
Returns the description of an endpoint configuration created using
the CreateEndpointConfig API.
19484 19485 19486 19487 19488 19489 19490 19491 19492 19493 19494 19495 19496 19497 19498 19499 19500 19501 19502 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19484 class DescribeEndpointOutput < Struct.new( :endpoint_name, :endpoint_arn, :endpoint_config_name, :production_variants, :data_capture_config, :endpoint_status, :failure_reason, :creation_time, :last_modified_time, :last_deployment_config, :async_inference_config, :pending_deployment_summary, :explainer_config, :shadow_production_variants, :metrics_config) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
A timestamp that shows when the endpoint was created.
19484 19485 19486 19487 19488 19489 19490 19491 19492 19493 19494 19495 19496 19497 19498 19499 19500 19501 19502 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19484 class DescribeEndpointOutput < Struct.new( :endpoint_name, :endpoint_arn, :endpoint_config_name, :production_variants, :data_capture_config, :endpoint_status, :failure_reason, :creation_time, :last_modified_time, :last_deployment_config, :async_inference_config, :pending_deployment_summary, :explainer_config, :shadow_production_variants, :metrics_config) SENSITIVE = [] include Aws::Structure end |
#data_capture_config ⇒ Types::DataCaptureConfigSummary
The currently active data capture configuration used by your Endpoint.
19484 19485 19486 19487 19488 19489 19490 19491 19492 19493 19494 19495 19496 19497 19498 19499 19500 19501 19502 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19484 class DescribeEndpointOutput < Struct.new( :endpoint_name, :endpoint_arn, :endpoint_config_name, :production_variants, :data_capture_config, :endpoint_status, :failure_reason, :creation_time, :last_modified_time, :last_deployment_config, :async_inference_config, :pending_deployment_summary, :explainer_config, :shadow_production_variants, :metrics_config) SENSITIVE = [] include Aws::Structure end |
#endpoint_arn ⇒ String
The Amazon Resource Name (ARN) of the endpoint.
19484 19485 19486 19487 19488 19489 19490 19491 19492 19493 19494 19495 19496 19497 19498 19499 19500 19501 19502 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19484 class DescribeEndpointOutput < Struct.new( :endpoint_name, :endpoint_arn, :endpoint_config_name, :production_variants, :data_capture_config, :endpoint_status, :failure_reason, :creation_time, :last_modified_time, :last_deployment_config, :async_inference_config, :pending_deployment_summary, :explainer_config, :shadow_production_variants, :metrics_config) SENSITIVE = [] include Aws::Structure end |
#endpoint_config_name ⇒ String
The name of the endpoint configuration associated with this endpoint.
19484 19485 19486 19487 19488 19489 19490 19491 19492 19493 19494 19495 19496 19497 19498 19499 19500 19501 19502 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19484 class DescribeEndpointOutput < Struct.new( :endpoint_name, :endpoint_arn, :endpoint_config_name, :production_variants, :data_capture_config, :endpoint_status, :failure_reason, :creation_time, :last_modified_time, :last_deployment_config, :async_inference_config, :pending_deployment_summary, :explainer_config, :shadow_production_variants, :metrics_config) SENSITIVE = [] include Aws::Structure end |
#endpoint_name ⇒ String
Name of the endpoint.
19484 19485 19486 19487 19488 19489 19490 19491 19492 19493 19494 19495 19496 19497 19498 19499 19500 19501 19502 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19484 class DescribeEndpointOutput < Struct.new( :endpoint_name, :endpoint_arn, :endpoint_config_name, :production_variants, :data_capture_config, :endpoint_status, :failure_reason, :creation_time, :last_modified_time, :last_deployment_config, :async_inference_config, :pending_deployment_summary, :explainer_config, :shadow_production_variants, :metrics_config) SENSITIVE = [] include Aws::Structure end |
#endpoint_status ⇒ String
The status of the endpoint.
-
OutOfService: Endpoint is not available to take incoming requests. -
Creating: CreateEndpoint is executing. -
Updating: UpdateEndpoint or UpdateEndpointWeightsAndCapacities is executing. -
SystemUpdating: Endpoint is undergoing maintenance and cannot be updated or deleted or re-scaled until it has completed. This maintenance operation does not change any customer-specified values such as VPC config, KMS encryption, model, instance type, or instance count. -
RollingBack: Endpoint fails to scale up or down or change its variant weight and is in the process of rolling back to its previous configuration. Once the rollback completes, endpoint returns to anInServicestatus. This transitional status only applies to an endpoint that has autoscaling enabled and is undergoing variant weight or capacity changes as part of an UpdateEndpointWeightsAndCapacities call or when the UpdateEndpointWeightsAndCapacities operation is called explicitly. -
InService: Endpoint is available to process incoming requests. -
Deleting: DeleteEndpoint is executing. -
Failed: Endpoint could not be created, updated, or re-scaled. Use theFailureReasonvalue returned by DescribeEndpoint for information about the failure. DeleteEndpoint is the only operation that can be performed on a failed endpoint. -
UpdateRollbackFailed: Both the rolling deployment and auto-rollback failed. Your endpoint is in service with a mix of the old and new endpoint configurations. For information about how to remedy this issue and restore the endpoint's status toInService, see Rolling Deployments.
19484 19485 19486 19487 19488 19489 19490 19491 19492 19493 19494 19495 19496 19497 19498 19499 19500 19501 19502 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19484 class DescribeEndpointOutput < Struct.new( :endpoint_name, :endpoint_arn, :endpoint_config_name, :production_variants, :data_capture_config, :endpoint_status, :failure_reason, :creation_time, :last_modified_time, :last_deployment_config, :async_inference_config, :pending_deployment_summary, :explainer_config, :shadow_production_variants, :metrics_config) SENSITIVE = [] include Aws::Structure end |
#explainer_config ⇒ Types::ExplainerConfig
The configuration parameters for an explainer.
19484 19485 19486 19487 19488 19489 19490 19491 19492 19493 19494 19495 19496 19497 19498 19499 19500 19501 19502 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19484 class DescribeEndpointOutput < Struct.new( :endpoint_name, :endpoint_arn, :endpoint_config_name, :production_variants, :data_capture_config, :endpoint_status, :failure_reason, :creation_time, :last_modified_time, :last_deployment_config, :async_inference_config, :pending_deployment_summary, :explainer_config, :shadow_production_variants, :metrics_config) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
If the status of the endpoint is Failed, the reason why it failed.
19484 19485 19486 19487 19488 19489 19490 19491 19492 19493 19494 19495 19496 19497 19498 19499 19500 19501 19502 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19484 class DescribeEndpointOutput < Struct.new( :endpoint_name, :endpoint_arn, :endpoint_config_name, :production_variants, :data_capture_config, :endpoint_status, :failure_reason, :creation_time, :last_modified_time, :last_deployment_config, :async_inference_config, :pending_deployment_summary, :explainer_config, :shadow_production_variants, :metrics_config) SENSITIVE = [] include Aws::Structure end |
#last_deployment_config ⇒ Types::DeploymentConfig
The most recent deployment configuration for the endpoint.
19484 19485 19486 19487 19488 19489 19490 19491 19492 19493 19494 19495 19496 19497 19498 19499 19500 19501 19502 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19484 class DescribeEndpointOutput < Struct.new( :endpoint_name, :endpoint_arn, :endpoint_config_name, :production_variants, :data_capture_config, :endpoint_status, :failure_reason, :creation_time, :last_modified_time, :last_deployment_config, :async_inference_config, :pending_deployment_summary, :explainer_config, :shadow_production_variants, :metrics_config) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
A timestamp that shows when the endpoint was last modified.
19484 19485 19486 19487 19488 19489 19490 19491 19492 19493 19494 19495 19496 19497 19498 19499 19500 19501 19502 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19484 class DescribeEndpointOutput < Struct.new( :endpoint_name, :endpoint_arn, :endpoint_config_name, :production_variants, :data_capture_config, :endpoint_status, :failure_reason, :creation_time, :last_modified_time, :last_deployment_config, :async_inference_config, :pending_deployment_summary, :explainer_config, :shadow_production_variants, :metrics_config) SENSITIVE = [] include Aws::Structure end |
#metrics_config ⇒ Types::MetricsConfig
The configuration parameters for utilization metrics.
19484 19485 19486 19487 19488 19489 19490 19491 19492 19493 19494 19495 19496 19497 19498 19499 19500 19501 19502 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19484 class DescribeEndpointOutput < Struct.new( :endpoint_name, :endpoint_arn, :endpoint_config_name, :production_variants, :data_capture_config, :endpoint_status, :failure_reason, :creation_time, :last_modified_time, :last_deployment_config, :async_inference_config, :pending_deployment_summary, :explainer_config, :shadow_production_variants, :metrics_config) SENSITIVE = [] include Aws::Structure end |
#pending_deployment_summary ⇒ Types::PendingDeploymentSummary
Returns the summary of an in-progress deployment. This field is only returned when the endpoint is creating or updating with a new endpoint configuration.
19484 19485 19486 19487 19488 19489 19490 19491 19492 19493 19494 19495 19496 19497 19498 19499 19500 19501 19502 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19484 class DescribeEndpointOutput < Struct.new( :endpoint_name, :endpoint_arn, :endpoint_config_name, :production_variants, :data_capture_config, :endpoint_status, :failure_reason, :creation_time, :last_modified_time, :last_deployment_config, :async_inference_config, :pending_deployment_summary, :explainer_config, :shadow_production_variants, :metrics_config) SENSITIVE = [] include Aws::Structure end |
#production_variants ⇒ Array<Types::ProductionVariantSummary>
An array of ProductionVariantSummary objects, one for each model hosted behind this endpoint.
19484 19485 19486 19487 19488 19489 19490 19491 19492 19493 19494 19495 19496 19497 19498 19499 19500 19501 19502 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19484 class DescribeEndpointOutput < Struct.new( :endpoint_name, :endpoint_arn, :endpoint_config_name, :production_variants, :data_capture_config, :endpoint_status, :failure_reason, :creation_time, :last_modified_time, :last_deployment_config, :async_inference_config, :pending_deployment_summary, :explainer_config, :shadow_production_variants, :metrics_config) SENSITIVE = [] include Aws::Structure end |
#shadow_production_variants ⇒ Array<Types::ProductionVariantSummary>
An array of ProductionVariantSummary objects, one for each
model that you want to host at this endpoint in shadow mode with
production traffic replicated from the model specified on
ProductionVariants.
19484 19485 19486 19487 19488 19489 19490 19491 19492 19493 19494 19495 19496 19497 19498 19499 19500 19501 19502 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19484 class DescribeEndpointOutput < Struct.new( :endpoint_name, :endpoint_arn, :endpoint_config_name, :production_variants, :data_capture_config, :endpoint_status, :failure_reason, :creation_time, :last_modified_time, :last_deployment_config, :async_inference_config, :pending_deployment_summary, :explainer_config, :shadow_production_variants, :metrics_config) SENSITIVE = [] include Aws::Structure end |