Class: Aws::SageMaker::Types::DescribeFeatureGroupResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timeTime

A timestamp indicating when SageMaker created the ‘FeatureGroup`.

Returns:

  • (Time)


19538
19539
19540
19541
19542
19543
19544
19545
19546
19547
19548
19549
19550
19551
19552
19553
19554
19555
19556
19557
19558
19559
# File 'lib/aws-sdk-sagemaker/types.rb', line 19538

class DescribeFeatureGroupResponse < Struct.new(
  :feature_group_arn,
  :feature_group_name,
  :record_identifier_feature_name,
  :event_time_feature_name,
  :feature_definitions,
  :creation_time,
  :last_modified_time,
  :online_store_config,
  :offline_store_config,
  :throughput_config,
  :role_arn,
  :feature_group_status,
  :offline_store_status,
  :last_update_status,
  :failure_reason,
  :description,
  :next_token,
  :online_store_total_size_bytes)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A free form description of the feature group.

Returns:

  • (String)


19538
19539
19540
19541
19542
19543
19544
19545
19546
19547
19548
19549
19550
19551
19552
19553
19554
19555
19556
19557
19558
19559
# File 'lib/aws-sdk-sagemaker/types.rb', line 19538

class DescribeFeatureGroupResponse < Struct.new(
  :feature_group_arn,
  :feature_group_name,
  :record_identifier_feature_name,
  :event_time_feature_name,
  :feature_definitions,
  :creation_time,
  :last_modified_time,
  :online_store_config,
  :offline_store_config,
  :throughput_config,
  :role_arn,
  :feature_group_status,
  :offline_store_status,
  :last_update_status,
  :failure_reason,
  :description,
  :next_token,
  :online_store_total_size_bytes)
  SENSITIVE = []
  include Aws::Structure
end

#event_time_feature_nameString

The name of the feature that stores the ‘EventTime` of a Record in a `FeatureGroup`.

An ‘EventTime` is a point in time when a new event occurs that corresponds to the creation or update of a `Record` in a `FeatureGroup`. All `Records` in the `FeatureGroup` have a corresponding `EventTime`.

Returns:

  • (String)


19538
19539
19540
19541
19542
19543
19544
19545
19546
19547
19548
19549
19550
19551
19552
19553
19554
19555
19556
19557
19558
19559
# File 'lib/aws-sdk-sagemaker/types.rb', line 19538

class DescribeFeatureGroupResponse < Struct.new(
  :feature_group_arn,
  :feature_group_name,
  :record_identifier_feature_name,
  :event_time_feature_name,
  :feature_definitions,
  :creation_time,
  :last_modified_time,
  :online_store_config,
  :offline_store_config,
  :throughput_config,
  :role_arn,
  :feature_group_status,
  :offline_store_status,
  :last_update_status,
  :failure_reason,
  :description,
  :next_token,
  :online_store_total_size_bytes)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

The reason that the ‘FeatureGroup` failed to be replicated in the `OfflineStore`. This is failure can occur because:

  • The ‘FeatureGroup` could not be created in the `OfflineStore`.

  • The ‘FeatureGroup` could not be deleted from the `OfflineStore`.

Returns:

  • (String)


19538
19539
19540
19541
19542
19543
19544
19545
19546
19547
19548
19549
19550
19551
19552
19553
19554
19555
19556
19557
19558
19559
# File 'lib/aws-sdk-sagemaker/types.rb', line 19538

class DescribeFeatureGroupResponse < Struct.new(
  :feature_group_arn,
  :feature_group_name,
  :record_identifier_feature_name,
  :event_time_feature_name,
  :feature_definitions,
  :creation_time,
  :last_modified_time,
  :online_store_config,
  :offline_store_config,
  :throughput_config,
  :role_arn,
  :feature_group_status,
  :offline_store_status,
  :last_update_status,
  :failure_reason,
  :description,
  :next_token,
  :online_store_total_size_bytes)
  SENSITIVE = []
  include Aws::Structure
end

#feature_definitionsArray<Types::FeatureDefinition>

A list of the ‘Features` in the `FeatureGroup`. Each feature is defined by a `FeatureName` and `FeatureType`.

Returns:



19538
19539
19540
19541
19542
19543
19544
19545
19546
19547
19548
19549
19550
19551
19552
19553
19554
19555
19556
19557
19558
19559
# File 'lib/aws-sdk-sagemaker/types.rb', line 19538

class DescribeFeatureGroupResponse < Struct.new(
  :feature_group_arn,
  :feature_group_name,
  :record_identifier_feature_name,
  :event_time_feature_name,
  :feature_definitions,
  :creation_time,
  :last_modified_time,
  :online_store_config,
  :offline_store_config,
  :throughput_config,
  :role_arn,
  :feature_group_status,
  :offline_store_status,
  :last_update_status,
  :failure_reason,
  :description,
  :next_token,
  :online_store_total_size_bytes)
  SENSITIVE = []
  include Aws::Structure
end

#feature_group_arnString

The Amazon Resource Name (ARN) of the ‘FeatureGroup`.

Returns:

  • (String)


19538
19539
19540
19541
19542
19543
19544
19545
19546
19547
19548
19549
19550
19551
19552
19553
19554
19555
19556
19557
19558
19559
# File 'lib/aws-sdk-sagemaker/types.rb', line 19538

class DescribeFeatureGroupResponse < Struct.new(
  :feature_group_arn,
  :feature_group_name,
  :record_identifier_feature_name,
  :event_time_feature_name,
  :feature_definitions,
  :creation_time,
  :last_modified_time,
  :online_store_config,
  :offline_store_config,
  :throughput_config,
  :role_arn,
  :feature_group_status,
  :offline_store_status,
  :last_update_status,
  :failure_reason,
  :description,
  :next_token,
  :online_store_total_size_bytes)
  SENSITIVE = []
  include Aws::Structure
end

#feature_group_nameString

he name of the ‘FeatureGroup`.

Returns:

  • (String)


19538
19539
19540
19541
19542
19543
19544
19545
19546
19547
19548
19549
19550
19551
19552
19553
19554
19555
19556
19557
19558
19559
# File 'lib/aws-sdk-sagemaker/types.rb', line 19538

class DescribeFeatureGroupResponse < Struct.new(
  :feature_group_arn,
  :feature_group_name,
  :record_identifier_feature_name,
  :event_time_feature_name,
  :feature_definitions,
  :creation_time,
  :last_modified_time,
  :online_store_config,
  :offline_store_config,
  :throughput_config,
  :role_arn,
  :feature_group_status,
  :offline_store_status,
  :last_update_status,
  :failure_reason,
  :description,
  :next_token,
  :online_store_total_size_bytes)
  SENSITIVE = []
  include Aws::Structure
end

#feature_group_statusString

The status of the feature group.

Returns:

  • (String)


19538
19539
19540
19541
19542
19543
19544
19545
19546
19547
19548
19549
19550
19551
19552
19553
19554
19555
19556
19557
19558
19559
# File 'lib/aws-sdk-sagemaker/types.rb', line 19538

class DescribeFeatureGroupResponse < Struct.new(
  :feature_group_arn,
  :feature_group_name,
  :record_identifier_feature_name,
  :event_time_feature_name,
  :feature_definitions,
  :creation_time,
  :last_modified_time,
  :online_store_config,
  :offline_store_config,
  :throughput_config,
  :role_arn,
  :feature_group_status,
  :offline_store_status,
  :last_update_status,
  :failure_reason,
  :description,
  :next_token,
  :online_store_total_size_bytes)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

A timestamp indicating when the feature group was last updated.

Returns:

  • (Time)


19538
19539
19540
19541
19542
19543
19544
19545
19546
19547
19548
19549
19550
19551
19552
19553
19554
19555
19556
19557
19558
19559
# File 'lib/aws-sdk-sagemaker/types.rb', line 19538

class DescribeFeatureGroupResponse < Struct.new(
  :feature_group_arn,
  :feature_group_name,
  :record_identifier_feature_name,
  :event_time_feature_name,
  :feature_definitions,
  :creation_time,
  :last_modified_time,
  :online_store_config,
  :offline_store_config,
  :throughput_config,
  :role_arn,
  :feature_group_status,
  :offline_store_status,
  :last_update_status,
  :failure_reason,
  :description,
  :next_token,
  :online_store_total_size_bytes)
  SENSITIVE = []
  include Aws::Structure
end

#last_update_statusTypes::LastUpdateStatus

A value indicating whether the update made to the feature group was successful.



19538
19539
19540
19541
19542
19543
19544
19545
19546
19547
19548
19549
19550
19551
19552
19553
19554
19555
19556
19557
19558
19559
# File 'lib/aws-sdk-sagemaker/types.rb', line 19538

class DescribeFeatureGroupResponse < Struct.new(
  :feature_group_arn,
  :feature_group_name,
  :record_identifier_feature_name,
  :event_time_feature_name,
  :feature_definitions,
  :creation_time,
  :last_modified_time,
  :online_store_config,
  :offline_store_config,
  :throughput_config,
  :role_arn,
  :feature_group_status,
  :offline_store_status,
  :last_update_status,
  :failure_reason,
  :description,
  :next_token,
  :online_store_total_size_bytes)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token to resume pagination of the list of ‘Features` (`FeatureDefinitions`).

Returns:

  • (String)


19538
19539
19540
19541
19542
19543
19544
19545
19546
19547
19548
19549
19550
19551
19552
19553
19554
19555
19556
19557
19558
19559
# File 'lib/aws-sdk-sagemaker/types.rb', line 19538

class DescribeFeatureGroupResponse < Struct.new(
  :feature_group_arn,
  :feature_group_name,
  :record_identifier_feature_name,
  :event_time_feature_name,
  :feature_definitions,
  :creation_time,
  :last_modified_time,
  :online_store_config,
  :offline_store_config,
  :throughput_config,
  :role_arn,
  :feature_group_status,
  :offline_store_status,
  :last_update_status,
  :failure_reason,
  :description,
  :next_token,
  :online_store_total_size_bytes)
  SENSITIVE = []
  include Aws::Structure
end

#offline_store_configTypes::OfflineStoreConfig

The configuration of the offline store. It includes the following configurations:

  • Amazon S3 location of the offline store.

  • Configuration of the Glue data catalog.

  • Table format of the offline store.

  • Option to disable the automatic creation of a Glue table for the offline store.

  • Encryption configuration.



19538
19539
19540
19541
19542
19543
19544
19545
19546
19547
19548
19549
19550
19551
19552
19553
19554
19555
19556
19557
19558
19559
# File 'lib/aws-sdk-sagemaker/types.rb', line 19538

class DescribeFeatureGroupResponse < Struct.new(
  :feature_group_arn,
  :feature_group_name,
  :record_identifier_feature_name,
  :event_time_feature_name,
  :feature_definitions,
  :creation_time,
  :last_modified_time,
  :online_store_config,
  :offline_store_config,
  :throughput_config,
  :role_arn,
  :feature_group_status,
  :offline_store_status,
  :last_update_status,
  :failure_reason,
  :description,
  :next_token,
  :online_store_total_size_bytes)
  SENSITIVE = []
  include Aws::Structure
end

#offline_store_statusTypes::OfflineStoreStatus

The status of the ‘OfflineStore`. Notifies you if replicating data into the `OfflineStore` has failed. Returns either: `Active` or `Blocked`



19538
19539
19540
19541
19542
19543
19544
19545
19546
19547
19548
19549
19550
19551
19552
19553
19554
19555
19556
19557
19558
19559
# File 'lib/aws-sdk-sagemaker/types.rb', line 19538

class DescribeFeatureGroupResponse < Struct.new(
  :feature_group_arn,
  :feature_group_name,
  :record_identifier_feature_name,
  :event_time_feature_name,
  :feature_definitions,
  :creation_time,
  :last_modified_time,
  :online_store_config,
  :offline_store_config,
  :throughput_config,
  :role_arn,
  :feature_group_status,
  :offline_store_status,
  :last_update_status,
  :failure_reason,
  :description,
  :next_token,
  :online_store_total_size_bytes)
  SENSITIVE = []
  include Aws::Structure
end

#online_store_configTypes::OnlineStoreConfig

The configuration for the ‘OnlineStore`.



19538
19539
19540
19541
19542
19543
19544
19545
19546
19547
19548
19549
19550
19551
19552
19553
19554
19555
19556
19557
19558
19559
# File 'lib/aws-sdk-sagemaker/types.rb', line 19538

class DescribeFeatureGroupResponse < Struct.new(
  :feature_group_arn,
  :feature_group_name,
  :record_identifier_feature_name,
  :event_time_feature_name,
  :feature_definitions,
  :creation_time,
  :last_modified_time,
  :online_store_config,
  :offline_store_config,
  :throughput_config,
  :role_arn,
  :feature_group_status,
  :offline_store_status,
  :last_update_status,
  :failure_reason,
  :description,
  :next_token,
  :online_store_total_size_bytes)
  SENSITIVE = []
  include Aws::Structure
end

#online_store_total_size_bytesInteger

The size of the ‘OnlineStore` in bytes.

Returns:

  • (Integer)


19538
19539
19540
19541
19542
19543
19544
19545
19546
19547
19548
19549
19550
19551
19552
19553
19554
19555
19556
19557
19558
19559
# File 'lib/aws-sdk-sagemaker/types.rb', line 19538

class DescribeFeatureGroupResponse < Struct.new(
  :feature_group_arn,
  :feature_group_name,
  :record_identifier_feature_name,
  :event_time_feature_name,
  :feature_definitions,
  :creation_time,
  :last_modified_time,
  :online_store_config,
  :offline_store_config,
  :throughput_config,
  :role_arn,
  :feature_group_status,
  :offline_store_status,
  :last_update_status,
  :failure_reason,
  :description,
  :next_token,
  :online_store_total_size_bytes)
  SENSITIVE = []
  include Aws::Structure
end

#record_identifier_feature_nameString

The name of the ‘Feature` used for `RecordIdentifier`, whose value uniquely identifies a record stored in the feature store.

Returns:

  • (String)


19538
19539
19540
19541
19542
19543
19544
19545
19546
19547
19548
19549
19550
19551
19552
19553
19554
19555
19556
19557
19558
19559
# File 'lib/aws-sdk-sagemaker/types.rb', line 19538

class DescribeFeatureGroupResponse < Struct.new(
  :feature_group_arn,
  :feature_group_name,
  :record_identifier_feature_name,
  :event_time_feature_name,
  :feature_definitions,
  :creation_time,
  :last_modified_time,
  :online_store_config,
  :offline_store_config,
  :throughput_config,
  :role_arn,
  :feature_group_status,
  :offline_store_status,
  :last_update_status,
  :failure_reason,
  :description,
  :next_token,
  :online_store_total_size_bytes)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of the IAM execution role used to persist data into the OfflineStore if an OfflineStoreConfig is provided.

Returns:

  • (String)


19538
19539
19540
19541
19542
19543
19544
19545
19546
19547
19548
19549
19550
19551
19552
19553
19554
19555
19556
19557
19558
19559
# File 'lib/aws-sdk-sagemaker/types.rb', line 19538

class DescribeFeatureGroupResponse < Struct.new(
  :feature_group_arn,
  :feature_group_name,
  :record_identifier_feature_name,
  :event_time_feature_name,
  :feature_definitions,
  :creation_time,
  :last_modified_time,
  :online_store_config,
  :offline_store_config,
  :throughput_config,
  :role_arn,
  :feature_group_status,
  :offline_store_status,
  :last_update_status,
  :failure_reason,
  :description,
  :next_token,
  :online_store_total_size_bytes)
  SENSITIVE = []
  include Aws::Structure
end

#throughput_configTypes::ThroughputConfigDescription

Active throughput configuration of the feature group. There are two modes: ‘ON_DEMAND` and `PROVISIONED`. With on-demand mode, you are charged for data reads and writes that your application performs on your feature group. You do not need to specify read and write throughput because Feature Store accommodates your workloads as they ramp up and down. You can switch a feature group to on-demand only once in a 24 hour period. With provisioned throughput mode, you specify the read and write capacity per second that you expect your application to require, and you are billed based on those limits. Exceeding provisioned throughput will result in your requests being throttled.

Note: ‘PROVISIONED` throughput mode is supported only for feature groups that are offline-only, or use the [ `Standard` ][1] tier online store.

[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_OnlineStoreConfig.html#sagemaker-Type-OnlineStoreConfig-StorageType



19538
19539
19540
19541
19542
19543
19544
19545
19546
19547
19548
19549
19550
19551
19552
19553
19554
19555
19556
19557
19558
19559
# File 'lib/aws-sdk-sagemaker/types.rb', line 19538

class DescribeFeatureGroupResponse < Struct.new(
  :feature_group_arn,
  :feature_group_name,
  :record_identifier_feature_name,
  :event_time_feature_name,
  :feature_definitions,
  :creation_time,
  :last_modified_time,
  :online_store_config,
  :offline_store_config,
  :throughput_config,
  :role_arn,
  :feature_group_status,
  :offline_store_status,
  :last_update_status,
  :failure_reason,
  :description,
  :next_token,
  :online_store_total_size_bytes)
  SENSITIVE = []
  include Aws::Structure
end