Class: Aws::SageMaker::Types::DescribeFeatureMetadataRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeFeatureMetadataRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#feature_group_name ⇒ String
The name of the feature group containing the feature.
-
#feature_name ⇒ String
The name of the feature.
Instance Attribute Details
#feature_group_name ⇒ String
The name of the feature group containing the feature.
11429 11430 11431 11432 11433 11434 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 11429 class DescribeFeatureMetadataRequest < Struct.new( :feature_group_name, :feature_name) SENSITIVE = [] include Aws::Structure end |
#feature_name ⇒ String
The name of the feature.
11429 11430 11431 11432 11433 11434 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 11429 class DescribeFeatureMetadataRequest < Struct.new( :feature_group_name, :feature_name) SENSITIVE = [] include Aws::Structure end |