Class: Aws::SageMaker::Types::DescribeHumanTaskUiRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeHumanTaskUiRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#human_task_ui_name ⇒ String
The name of the human task user interface (worker task template) you want information about.
Instance Attribute Details
#human_task_ui_name ⇒ String
The name of the human task user interface (worker task template) you want information about.
18395 18396 18397 18398 18399 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18395 class DescribeHumanTaskUiRequest < Struct.new( :human_task_ui_name) SENSITIVE = [] include Aws::Structure end |