Class: Aws::SageMaker::Types::DescribeImageVersionResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#base_imageString

The registry path of the container image on which this image version is based.



20706
20707
20708
20709
20710
20711
20712
20713
20714
20715
20716
20717
20718
20719
20720
20721
20722
20723
20724
20725
# File 'lib/aws-sdk-sagemaker/types.rb', line 20706

class DescribeImageVersionResponse < Struct.new(
  :base_image,
  :container_image,
  :creation_time,
  :failure_reason,
  :image_arn,
  :image_version_arn,
  :image_version_status,
  :last_modified_time,
  :version,
  :vendor_guidance,
  :job_type,
  :ml_framework,
  :programming_lang,
  :processor,
  :horovod,
  :release_notes)
  SENSITIVE = []
  include Aws::Structure
end

#container_imageString

The registry path of the container image that contains this image version.



20706
20707
20708
20709
20710
20711
20712
20713
20714
20715
20716
20717
20718
20719
20720
20721
20722
20723
20724
20725
# File 'lib/aws-sdk-sagemaker/types.rb', line 20706

class DescribeImageVersionResponse < Struct.new(
  :base_image,
  :container_image,
  :creation_time,
  :failure_reason,
  :image_arn,
  :image_version_arn,
  :image_version_status,
  :last_modified_time,
  :version,
  :vendor_guidance,
  :job_type,
  :ml_framework,
  :programming_lang,
  :processor,
  :horovod,
  :release_notes)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

When the version was created.



20706
20707
20708
20709
20710
20711
20712
20713
20714
20715
20716
20717
20718
20719
20720
20721
20722
20723
20724
20725
# File 'lib/aws-sdk-sagemaker/types.rb', line 20706

class DescribeImageVersionResponse < Struct.new(
  :base_image,
  :container_image,
  :creation_time,
  :failure_reason,
  :image_arn,
  :image_version_arn,
  :image_version_status,
  :last_modified_time,
  :version,
  :vendor_guidance,
  :job_type,
  :ml_framework,
  :programming_lang,
  :processor,
  :horovod,
  :release_notes)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

When a create or delete operation fails, the reason for the failure.



20706
20707
20708
20709
20710
20711
20712
20713
20714
20715
20716
20717
20718
20719
20720
20721
20722
20723
20724
20725
# File 'lib/aws-sdk-sagemaker/types.rb', line 20706

class DescribeImageVersionResponse < Struct.new(
  :base_image,
  :container_image,
  :creation_time,
  :failure_reason,
  :image_arn,
  :image_version_arn,
  :image_version_status,
  :last_modified_time,
  :version,
  :vendor_guidance,
  :job_type,
  :ml_framework,
  :programming_lang,
  :processor,
  :horovod,
  :release_notes)
  SENSITIVE = []
  include Aws::Structure
end

#horovodBoolean

Indicates Horovod compatibility.



20706
20707
20708
20709
20710
20711
20712
20713
20714
20715
20716
20717
20718
20719
20720
20721
20722
20723
20724
20725
# File 'lib/aws-sdk-sagemaker/types.rb', line 20706

class DescribeImageVersionResponse < Struct.new(
  :base_image,
  :container_image,
  :creation_time,
  :failure_reason,
  :image_arn,
  :image_version_arn,
  :image_version_status,
  :last_modified_time,
  :version,
  :vendor_guidance,
  :job_type,
  :ml_framework,
  :programming_lang,
  :processor,
  :horovod,
  :release_notes)
  SENSITIVE = []
  include Aws::Structure
end

#image_arnString

The ARN of the image the version is based on.



20706
20707
20708
20709
20710
20711
20712
20713
20714
20715
20716
20717
20718
20719
20720
20721
20722
20723
20724
20725
# File 'lib/aws-sdk-sagemaker/types.rb', line 20706

class DescribeImageVersionResponse < Struct.new(
  :base_image,
  :container_image,
  :creation_time,
  :failure_reason,
  :image_arn,
  :image_version_arn,
  :image_version_status,
  :last_modified_time,
  :version,
  :vendor_guidance,
  :job_type,
  :ml_framework,
  :programming_lang,
  :processor,
  :horovod,
  :release_notes)
  SENSITIVE = []
  include Aws::Structure
end

#image_version_arnString

The ARN of the version.



20706
20707
20708
20709
20710
20711
20712
20713
20714
20715
20716
20717
20718
20719
20720
20721
20722
20723
20724
20725
# File 'lib/aws-sdk-sagemaker/types.rb', line 20706

class DescribeImageVersionResponse < Struct.new(
  :base_image,
  :container_image,
  :creation_time,
  :failure_reason,
  :image_arn,
  :image_version_arn,
  :image_version_status,
  :last_modified_time,
  :version,
  :vendor_guidance,
  :job_type,
  :ml_framework,
  :programming_lang,
  :processor,
  :horovod,
  :release_notes)
  SENSITIVE = []
  include Aws::Structure
end

#image_version_statusString

The status of the version.



20706
20707
20708
20709
20710
20711
20712
20713
20714
20715
20716
20717
20718
20719
20720
20721
20722
20723
20724
20725
# File 'lib/aws-sdk-sagemaker/types.rb', line 20706

class DescribeImageVersionResponse < Struct.new(
  :base_image,
  :container_image,
  :creation_time,
  :failure_reason,
  :image_arn,
  :image_version_arn,
  :image_version_status,
  :last_modified_time,
  :version,
  :vendor_guidance,
  :job_type,
  :ml_framework,
  :programming_lang,
  :processor,
  :horovod,
  :release_notes)
  SENSITIVE = []
  include Aws::Structure
end

#job_typeString

Indicates SageMaker AI job type compatibility.

  • TRAINING: The image version is compatible with SageMaker AI training jobs.

  • INFERENCE: The image version is compatible with SageMaker AI inference jobs.

  • NOTEBOOK_KERNEL: The image version is compatible with SageMaker AI notebook kernels.



20706
20707
20708
20709
20710
20711
20712
20713
20714
20715
20716
20717
20718
20719
20720
20721
20722
20723
20724
20725
# File 'lib/aws-sdk-sagemaker/types.rb', line 20706

class DescribeImageVersionResponse < Struct.new(
  :base_image,
  :container_image,
  :creation_time,
  :failure_reason,
  :image_arn,
  :image_version_arn,
  :image_version_status,
  :last_modified_time,
  :version,
  :vendor_guidance,
  :job_type,
  :ml_framework,
  :programming_lang,
  :processor,
  :horovod,
  :release_notes)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

When the version was last modified.



20706
20707
20708
20709
20710
20711
20712
20713
20714
20715
20716
20717
20718
20719
20720
20721
20722
20723
20724
20725
# File 'lib/aws-sdk-sagemaker/types.rb', line 20706

class DescribeImageVersionResponse < Struct.new(
  :base_image,
  :container_image,
  :creation_time,
  :failure_reason,
  :image_arn,
  :image_version_arn,
  :image_version_status,
  :last_modified_time,
  :version,
  :vendor_guidance,
  :job_type,
  :ml_framework,
  :programming_lang,
  :processor,
  :horovod,
  :release_notes)
  SENSITIVE = []
  include Aws::Structure
end

#ml_frameworkString

The machine learning framework vended in the image version.



20706
20707
20708
20709
20710
20711
20712
20713
20714
20715
20716
20717
20718
20719
20720
20721
20722
20723
20724
20725
# File 'lib/aws-sdk-sagemaker/types.rb', line 20706

class DescribeImageVersionResponse < Struct.new(
  :base_image,
  :container_image,
  :creation_time,
  :failure_reason,
  :image_arn,
  :image_version_arn,
  :image_version_status,
  :last_modified_time,
  :version,
  :vendor_guidance,
  :job_type,
  :ml_framework,
  :programming_lang,
  :processor,
  :horovod,
  :release_notes)
  SENSITIVE = []
  include Aws::Structure
end

#processorString

Indicates CPU or GPU compatibility.

  • CPU: The image version is compatible with CPU.

  • GPU: The image version is compatible with GPU.



20706
20707
20708
20709
20710
20711
20712
20713
20714
20715
20716
20717
20718
20719
20720
20721
20722
20723
20724
20725
# File 'lib/aws-sdk-sagemaker/types.rb', line 20706

class DescribeImageVersionResponse < Struct.new(
  :base_image,
  :container_image,
  :creation_time,
  :failure_reason,
  :image_arn,
  :image_version_arn,
  :image_version_status,
  :last_modified_time,
  :version,
  :vendor_guidance,
  :job_type,
  :ml_framework,
  :programming_lang,
  :processor,
  :horovod,
  :release_notes)
  SENSITIVE = []
  include Aws::Structure
end

#programming_langString

The supported programming language and its version.



20706
20707
20708
20709
20710
20711
20712
20713
20714
20715
20716
20717
20718
20719
20720
20721
20722
20723
20724
20725
# File 'lib/aws-sdk-sagemaker/types.rb', line 20706

class DescribeImageVersionResponse < Struct.new(
  :base_image,
  :container_image,
  :creation_time,
  :failure_reason,
  :image_arn,
  :image_version_arn,
  :image_version_status,
  :last_modified_time,
  :version,
  :vendor_guidance,
  :job_type,
  :ml_framework,
  :programming_lang,
  :processor,
  :horovod,
  :release_notes)
  SENSITIVE = []
  include Aws::Structure
end

#release_notesString

The maintainer description of the image version.



20706
20707
20708
20709
20710
20711
20712
20713
20714
20715
20716
20717
20718
20719
20720
20721
20722
20723
20724
20725
# File 'lib/aws-sdk-sagemaker/types.rb', line 20706

class DescribeImageVersionResponse < Struct.new(
  :base_image,
  :container_image,
  :creation_time,
  :failure_reason,
  :image_arn,
  :image_version_arn,
  :image_version_status,
  :last_modified_time,
  :version,
  :vendor_guidance,
  :job_type,
  :ml_framework,
  :programming_lang,
  :processor,
  :horovod,
  :release_notes)
  SENSITIVE = []
  include Aws::Structure
end

#vendor_guidanceString

The stability of the image version specified by the maintainer.

  • NOT_PROVIDED: The maintainers did not provide a status for image version stability.

  • STABLE: The image version is stable.

  • TO_BE_ARCHIVED: The image version is set to be archived. Custom image versions that are set to be archived are automatically archived after three months.

  • ARCHIVED: The image version is archived. Archived image versions are not searchable and are no longer actively supported.



20706
20707
20708
20709
20710
20711
20712
20713
20714
20715
20716
20717
20718
20719
20720
20721
20722
20723
20724
20725
# File 'lib/aws-sdk-sagemaker/types.rb', line 20706

class DescribeImageVersionResponse < Struct.new(
  :base_image,
  :container_image,
  :creation_time,
  :failure_reason,
  :image_arn,
  :image_version_arn,
  :image_version_status,
  :last_modified_time,
  :version,
  :vendor_guidance,
  :job_type,
  :ml_framework,
  :programming_lang,
  :processor,
  :horovod,
  :release_notes)
  SENSITIVE = []
  include Aws::Structure
end

#versionInteger

The version number.



20706
20707
20708
20709
20710
20711
20712
20713
20714
20715
20716
20717
20718
20719
20720
20721
20722
20723
20724
20725
# File 'lib/aws-sdk-sagemaker/types.rb', line 20706

class DescribeImageVersionResponse < Struct.new(
  :base_image,
  :container_image,
  :creation_time,
  :failure_reason,
  :image_arn,
  :image_version_arn,
  :image_version_status,
  :last_modified_time,
  :version,
  :vendor_guidance,
  :job_type,
  :ml_framework,
  :programming_lang,
  :processor,
  :horovod,
  :release_notes)
  SENSITIVE = []
  include Aws::Structure
end