Class: Aws::SageMaker::Types::DescribeInferenceExperimentResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the inference experiment being described.

Returns:

  • (String)


18829
18830
18831
18832
18833
18834
18835
18836
18837
18838
18839
18840
18841
18842
18843
18844
18845
18846
18847
18848
# File 'lib/aws-sdk-sagemaker/types.rb', line 18829

class DescribeInferenceExperimentResponse < Struct.new(
  :arn,
  :name,
  :type,
  :schedule,
  :status,
  :status_reason,
  :description,
  :creation_time,
  :completion_time,
  :last_modified_time,
  :role_arn,
  :endpoint_metadata,
  :model_variants,
  :data_storage_config,
  :shadow_mode_config,
  :kms_key)
  SENSITIVE = []
  include Aws::Structure
end

#completion_timeTime

The timestamp at which the inference experiment was completed.

Returns:

  • (Time)


18829
18830
18831
18832
18833
18834
18835
18836
18837
18838
18839
18840
18841
18842
18843
18844
18845
18846
18847
18848
# File 'lib/aws-sdk-sagemaker/types.rb', line 18829

class DescribeInferenceExperimentResponse < Struct.new(
  :arn,
  :name,
  :type,
  :schedule,
  :status,
  :status_reason,
  :description,
  :creation_time,
  :completion_time,
  :last_modified_time,
  :role_arn,
  :endpoint_metadata,
  :model_variants,
  :data_storage_config,
  :shadow_mode_config,
  :kms_key)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

The timestamp at which you created the inference experiment.

Returns:

  • (Time)


18829
18830
18831
18832
18833
18834
18835
18836
18837
18838
18839
18840
18841
18842
18843
18844
18845
18846
18847
18848
# File 'lib/aws-sdk-sagemaker/types.rb', line 18829

class DescribeInferenceExperimentResponse < Struct.new(
  :arn,
  :name,
  :type,
  :schedule,
  :status,
  :status_reason,
  :description,
  :creation_time,
  :completion_time,
  :last_modified_time,
  :role_arn,
  :endpoint_metadata,
  :model_variants,
  :data_storage_config,
  :shadow_mode_config,
  :kms_key)
  SENSITIVE = []
  include Aws::Structure
end

#data_storage_configTypes::InferenceExperimentDataStorageConfig

The Amazon S3 location and configuration for storing inference request and response data.



18829
18830
18831
18832
18833
18834
18835
18836
18837
18838
18839
18840
18841
18842
18843
18844
18845
18846
18847
18848
# File 'lib/aws-sdk-sagemaker/types.rb', line 18829

class DescribeInferenceExperimentResponse < Struct.new(
  :arn,
  :name,
  :type,
  :schedule,
  :status,
  :status_reason,
  :description,
  :creation_time,
  :completion_time,
  :last_modified_time,
  :role_arn,
  :endpoint_metadata,
  :model_variants,
  :data_storage_config,
  :shadow_mode_config,
  :kms_key)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the inference experiment.

Returns:

  • (String)


18829
18830
18831
18832
18833
18834
18835
18836
18837
18838
18839
18840
18841
18842
18843
18844
18845
18846
18847
18848
# File 'lib/aws-sdk-sagemaker/types.rb', line 18829

class DescribeInferenceExperimentResponse < Struct.new(
  :arn,
  :name,
  :type,
  :schedule,
  :status,
  :status_reason,
  :description,
  :creation_time,
  :completion_time,
  :last_modified_time,
  :role_arn,
  :endpoint_metadata,
  :model_variants,
  :data_storage_config,
  :shadow_mode_config,
  :kms_key)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_metadataTypes::EndpointMetadata

The metadata of the endpoint on which the inference experiment ran.



18829
18830
18831
18832
18833
18834
18835
18836
18837
18838
18839
18840
18841
18842
18843
18844
18845
18846
18847
18848
# File 'lib/aws-sdk-sagemaker/types.rb', line 18829

class DescribeInferenceExperimentResponse < Struct.new(
  :arn,
  :name,
  :type,
  :schedule,
  :status,
  :status_reason,
  :description,
  :creation_time,
  :completion_time,
  :last_modified_time,
  :role_arn,
  :endpoint_metadata,
  :model_variants,
  :data_storage_config,
  :shadow_mode_config,
  :kms_key)
  SENSITIVE = []
  include Aws::Structure
end

#kms_keyString

The Amazon Web Services Key Management Service (Amazon Web Services KMS) key that Amazon SageMaker uses to encrypt data on the storage volume attached to the ML compute instance that hosts the endpoint. For more information, see [CreateInferenceExperiment].

[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateInferenceExperiment.html

Returns:

  • (String)


18829
18830
18831
18832
18833
18834
18835
18836
18837
18838
18839
18840
18841
18842
18843
18844
18845
18846
18847
18848
# File 'lib/aws-sdk-sagemaker/types.rb', line 18829

class DescribeInferenceExperimentResponse < Struct.new(
  :arn,
  :name,
  :type,
  :schedule,
  :status,
  :status_reason,
  :description,
  :creation_time,
  :completion_time,
  :last_modified_time,
  :role_arn,
  :endpoint_metadata,
  :model_variants,
  :data_storage_config,
  :shadow_mode_config,
  :kms_key)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The timestamp at which you last modified the inference experiment.

Returns:

  • (Time)


18829
18830
18831
18832
18833
18834
18835
18836
18837
18838
18839
18840
18841
18842
18843
18844
18845
18846
18847
18848
# File 'lib/aws-sdk-sagemaker/types.rb', line 18829

class DescribeInferenceExperimentResponse < Struct.new(
  :arn,
  :name,
  :type,
  :schedule,
  :status,
  :status_reason,
  :description,
  :creation_time,
  :completion_time,
  :last_modified_time,
  :role_arn,
  :endpoint_metadata,
  :model_variants,
  :data_storage_config,
  :shadow_mode_config,
  :kms_key)
  SENSITIVE = []
  include Aws::Structure
end

#model_variantsArray<Types::ModelVariantConfigSummary>

An array of ModelVariantConfigSummary objects. There is one for each variant in the inference experiment. Each ModelVariantConfigSummary object in the array describes the infrastructure configuration for deploying the corresponding variant.



18829
18830
18831
18832
18833
18834
18835
18836
18837
18838
18839
18840
18841
18842
18843
18844
18845
18846
18847
18848
# File 'lib/aws-sdk-sagemaker/types.rb', line 18829

class DescribeInferenceExperimentResponse < Struct.new(
  :arn,
  :name,
  :type,
  :schedule,
  :status,
  :status_reason,
  :description,
  :creation_time,
  :completion_time,
  :last_modified_time,
  :role_arn,
  :endpoint_metadata,
  :model_variants,
  :data_storage_config,
  :shadow_mode_config,
  :kms_key)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the inference experiment.

Returns:

  • (String)


18829
18830
18831
18832
18833
18834
18835
18836
18837
18838
18839
18840
18841
18842
18843
18844
18845
18846
18847
18848
# File 'lib/aws-sdk-sagemaker/types.rb', line 18829

class DescribeInferenceExperimentResponse < Struct.new(
  :arn,
  :name,
  :type,
  :schedule,
  :status,
  :status_reason,
  :description,
  :creation_time,
  :completion_time,
  :last_modified_time,
  :role_arn,
  :endpoint_metadata,
  :model_variants,
  :data_storage_config,
  :shadow_mode_config,
  :kms_key)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The ARN of the IAM role that Amazon SageMaker can assume to access model artifacts and container images, and manage Amazon SageMaker Inference endpoints for model deployment.

Returns:

  • (String)


18829
18830
18831
18832
18833
18834
18835
18836
18837
18838
18839
18840
18841
18842
18843
18844
18845
18846
18847
18848
# File 'lib/aws-sdk-sagemaker/types.rb', line 18829

class DescribeInferenceExperimentResponse < Struct.new(
  :arn,
  :name,
  :type,
  :schedule,
  :status,
  :status_reason,
  :description,
  :creation_time,
  :completion_time,
  :last_modified_time,
  :role_arn,
  :endpoint_metadata,
  :model_variants,
  :data_storage_config,
  :shadow_mode_config,
  :kms_key)
  SENSITIVE = []
  include Aws::Structure
end

#scheduleTypes::InferenceExperimentSchedule

The duration for which the inference experiment ran or will run.



18829
18830
18831
18832
18833
18834
18835
18836
18837
18838
18839
18840
18841
18842
18843
18844
18845
18846
18847
18848
# File 'lib/aws-sdk-sagemaker/types.rb', line 18829

class DescribeInferenceExperimentResponse < Struct.new(
  :arn,
  :name,
  :type,
  :schedule,
  :status,
  :status_reason,
  :description,
  :creation_time,
  :completion_time,
  :last_modified_time,
  :role_arn,
  :endpoint_metadata,
  :model_variants,
  :data_storage_config,
  :shadow_mode_config,
  :kms_key)
  SENSITIVE = []
  include Aws::Structure
end

#shadow_mode_configTypes::ShadowModeConfig

The configuration of ShadowMode inference experiment type, which shows the production variant that takes all the inference requests, and the shadow variant to which Amazon SageMaker replicates a percentage of the inference requests. For the shadow variant it also shows the percentage of requests that Amazon SageMaker replicates.



18829
18830
18831
18832
18833
18834
18835
18836
18837
18838
18839
18840
18841
18842
18843
18844
18845
18846
18847
18848
# File 'lib/aws-sdk-sagemaker/types.rb', line 18829

class DescribeInferenceExperimentResponse < Struct.new(
  :arn,
  :name,
  :type,
  :schedule,
  :status,
  :status_reason,
  :description,
  :creation_time,
  :completion_time,
  :last_modified_time,
  :role_arn,
  :endpoint_metadata,
  :model_variants,
  :data_storage_config,
  :shadow_mode_config,
  :kms_key)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the inference experiment. The following are the possible statuses for an inference experiment:

  • Creating - Amazon SageMaker is creating your experiment.

  • Created - Amazon SageMaker has finished the creation of your experiment and will begin the experiment at the scheduled time.

  • Updating - When you make changes to your experiment, your experiment shows as updating.

  • Starting - Amazon SageMaker is beginning your experiment.

  • Running - Your experiment is in progress.

  • Stopping - Amazon SageMaker is stopping your experiment.

  • Completed - Your experiment has completed.

  • Cancelled - When you conclude your experiment early using the

    StopInferenceExperiment][1

    API, or if any operation fails with

    an unexpected error, it shows as cancelled.

[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_StopInferenceExperiment.html

Returns:

  • (String)


18829
18830
18831
18832
18833
18834
18835
18836
18837
18838
18839
18840
18841
18842
18843
18844
18845
18846
18847
18848
# File 'lib/aws-sdk-sagemaker/types.rb', line 18829

class DescribeInferenceExperimentResponse < Struct.new(
  :arn,
  :name,
  :type,
  :schedule,
  :status,
  :status_reason,
  :description,
  :creation_time,
  :completion_time,
  :last_modified_time,
  :role_arn,
  :endpoint_metadata,
  :model_variants,
  :data_storage_config,
  :shadow_mode_config,
  :kms_key)
  SENSITIVE = []
  include Aws::Structure
end

#status_reasonString

The error message or client-specified Reason from the

StopInferenceExperiment][1

API, that explains the status of the

inference experiment.

[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_StopInferenceExperiment.html

Returns:

  • (String)


18829
18830
18831
18832
18833
18834
18835
18836
18837
18838
18839
18840
18841
18842
18843
18844
18845
18846
18847
18848
# File 'lib/aws-sdk-sagemaker/types.rb', line 18829

class DescribeInferenceExperimentResponse < Struct.new(
  :arn,
  :name,
  :type,
  :schedule,
  :status,
  :status_reason,
  :description,
  :creation_time,
  :completion_time,
  :last_modified_time,
  :role_arn,
  :endpoint_metadata,
  :model_variants,
  :data_storage_config,
  :shadow_mode_config,
  :kms_key)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of the inference experiment.

Returns:

  • (String)


18829
18830
18831
18832
18833
18834
18835
18836
18837
18838
18839
18840
18841
18842
18843
18844
18845
18846
18847
18848
# File 'lib/aws-sdk-sagemaker/types.rb', line 18829

class DescribeInferenceExperimentResponse < Struct.new(
  :arn,
  :name,
  :type,
  :schedule,
  :status,
  :status_reason,
  :description,
  :creation_time,
  :completion_time,
  :last_modified_time,
  :role_arn,
  :endpoint_metadata,
  :model_variants,
  :data_storage_config,
  :shadow_mode_config,
  :kms_key)
  SENSITIVE = []
  include Aws::Structure
end