Class: Aws::SageMaker::Types::DescribeJobSchemaVersionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeJobSchemaVersionResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_category ⇒ String
The category of the job schema.
-
#job_config_schema ⇒ String
The JSON schema document that defines the structure of the job configuration.
-
#job_config_schema_version ⇒ String
The version of the schema.
Instance Attribute Details
#job_category ⇒ String
The category of the job schema.
20756 20757 20758 20759 20760 20761 20762 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20756 class DescribeJobSchemaVersionResponse < Struct.new( :job_category, :job_config_schema_version, :job_config_schema) SENSITIVE = [] include Aws::Structure end |
#job_config_schema ⇒ String
The JSON schema document that defines the structure of the job configuration.
20756 20757 20758 20759 20760 20761 20762 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20756 class DescribeJobSchemaVersionResponse < Struct.new( :job_category, :job_config_schema_version, :job_config_schema) SENSITIVE = [] include Aws::Structure end |
#job_config_schema_version ⇒ String
The version of the schema.
20756 20757 20758 20759 20760 20761 20762 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20756 class DescribeJobSchemaVersionResponse < Struct.new( :job_category, :job_config_schema_version, :job_config_schema) SENSITIVE = [] include Aws::Structure end |