Class: Aws::SageMaker::Types::DescribeLabelingJobResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeLabelingJobResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Time
The date and time that the labeling job was created.
-
#failure_reason ⇒ String
If the job failed, the reason that it failed.
-
#human_task_config ⇒ Types::HumanTaskConfig
Configuration information required for human workers to complete a labeling task.
-
#input_config ⇒ Types::LabelingJobInputConfig
Input configuration information for the labeling job, such as the Amazon S3 location of the data objects and the location of the manifest file that describes the data objects.
-
#job_reference_code ⇒ String
A unique identifier for work done as part of a labeling job.
-
#label_attribute_name ⇒ String
The attribute used as the label in the output manifest file.
-
#label_category_config_s3_uri ⇒ String
The S3 location of the JSON file that defines the categories used to label data objects.
-
#label_counters ⇒ Types::LabelCounters
Provides a breakdown of the number of data objects labeled by humans, the number of objects labeled by machine, the number of objects than couldn’t be labeled, and the total number of objects labeled.
-
#labeling_job_algorithms_config ⇒ Types::LabelingJobAlgorithmsConfig
Configuration information for automated data labeling.
-
#labeling_job_arn ⇒ String
The Amazon Resource Name (ARN) of the labeling job.
-
#labeling_job_name ⇒ String
The name assigned to the labeling job when it was created.
-
#labeling_job_output ⇒ Types::LabelingJobOutput
The location of the output produced by the labeling job.
-
#labeling_job_status ⇒ String
The processing status of the labeling job.
-
#last_modified_time ⇒ Time
The date and time that the labeling job was last updated.
-
#output_config ⇒ Types::LabelingJobOutputConfig
The location of the job’s output data and the Amazon Web Services Key Management Service key ID for the key used to encrypt the output data, if any.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) that SageMaker assumes to perform tasks on your behalf during data labeling.
-
#stopping_conditions ⇒ Types::LabelingJobStoppingConditions
A set of conditions for stopping a labeling job.
-
#tags ⇒ Array<Types::Tag>
An array of key-value pairs.
Instance Attribute Details
#creation_time ⇒ Time
The date and time that the labeling job was created.
20500 20501 20502 20503 20504 20505 20506 20507 20508 20509 20510 20511 20512 20513 20514 20515 20516 20517 20518 20519 20520 20521 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20500 class DescribeLabelingJobResponse < Struct.new( :labeling_job_status, :label_counters, :failure_reason, :creation_time, :last_modified_time, :job_reference_code, :labeling_job_name, :labeling_job_arn, :label_attribute_name, :input_config, :output_config, :role_arn, :label_category_config_s3_uri, :stopping_conditions, :labeling_job_algorithms_config, :human_task_config, :tags, :labeling_job_output) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
If the job failed, the reason that it failed.
20500 20501 20502 20503 20504 20505 20506 20507 20508 20509 20510 20511 20512 20513 20514 20515 20516 20517 20518 20519 20520 20521 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20500 class DescribeLabelingJobResponse < Struct.new( :labeling_job_status, :label_counters, :failure_reason, :creation_time, :last_modified_time, :job_reference_code, :labeling_job_name, :labeling_job_arn, :label_attribute_name, :input_config, :output_config, :role_arn, :label_category_config_s3_uri, :stopping_conditions, :labeling_job_algorithms_config, :human_task_config, :tags, :labeling_job_output) SENSITIVE = [] include Aws::Structure end |
#human_task_config ⇒ Types::HumanTaskConfig
Configuration information required for human workers to complete a labeling task.
20500 20501 20502 20503 20504 20505 20506 20507 20508 20509 20510 20511 20512 20513 20514 20515 20516 20517 20518 20519 20520 20521 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20500 class DescribeLabelingJobResponse < Struct.new( :labeling_job_status, :label_counters, :failure_reason, :creation_time, :last_modified_time, :job_reference_code, :labeling_job_name, :labeling_job_arn, :label_attribute_name, :input_config, :output_config, :role_arn, :label_category_config_s3_uri, :stopping_conditions, :labeling_job_algorithms_config, :human_task_config, :tags, :labeling_job_output) SENSITIVE = [] include Aws::Structure end |
#input_config ⇒ Types::LabelingJobInputConfig
Input configuration information for the labeling job, such as the Amazon S3 location of the data objects and the location of the manifest file that describes the data objects.
20500 20501 20502 20503 20504 20505 20506 20507 20508 20509 20510 20511 20512 20513 20514 20515 20516 20517 20518 20519 20520 20521 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20500 class DescribeLabelingJobResponse < Struct.new( :labeling_job_status, :label_counters, :failure_reason, :creation_time, :last_modified_time, :job_reference_code, :labeling_job_name, :labeling_job_arn, :label_attribute_name, :input_config, :output_config, :role_arn, :label_category_config_s3_uri, :stopping_conditions, :labeling_job_algorithms_config, :human_task_config, :tags, :labeling_job_output) SENSITIVE = [] include Aws::Structure end |
#job_reference_code ⇒ String
A unique identifier for work done as part of a labeling job.
20500 20501 20502 20503 20504 20505 20506 20507 20508 20509 20510 20511 20512 20513 20514 20515 20516 20517 20518 20519 20520 20521 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20500 class DescribeLabelingJobResponse < Struct.new( :labeling_job_status, :label_counters, :failure_reason, :creation_time, :last_modified_time, :job_reference_code, :labeling_job_name, :labeling_job_arn, :label_attribute_name, :input_config, :output_config, :role_arn, :label_category_config_s3_uri, :stopping_conditions, :labeling_job_algorithms_config, :human_task_config, :tags, :labeling_job_output) SENSITIVE = [] include Aws::Structure end |
#label_attribute_name ⇒ String
The attribute used as the label in the output manifest file.
20500 20501 20502 20503 20504 20505 20506 20507 20508 20509 20510 20511 20512 20513 20514 20515 20516 20517 20518 20519 20520 20521 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20500 class DescribeLabelingJobResponse < Struct.new( :labeling_job_status, :label_counters, :failure_reason, :creation_time, :last_modified_time, :job_reference_code, :labeling_job_name, :labeling_job_arn, :label_attribute_name, :input_config, :output_config, :role_arn, :label_category_config_s3_uri, :stopping_conditions, :labeling_job_algorithms_config, :human_task_config, :tags, :labeling_job_output) SENSITIVE = [] include Aws::Structure end |
#label_category_config_s3_uri ⇒ String
The S3 location of the JSON file that defines the categories used to label data objects. Please note the following label-category limits:
-
Semantic segmentation labeling jobs using automated labeling: 20 labels
-
Box bounding labeling jobs (all): 10 labels
The file is a JSON structure in the following format:
‘{`
‘ “document-version”: “2018-11-28”`
‘ “labels”: [`
‘ {`
‘ “label”: “label 1”`
‘ },`
‘ {`
‘ “label”: “label 2”`
‘ },`
‘ …`
‘ {`
‘ “label”: “label n”`
‘ }`
‘ ]`
‘}`
20500 20501 20502 20503 20504 20505 20506 20507 20508 20509 20510 20511 20512 20513 20514 20515 20516 20517 20518 20519 20520 20521 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20500 class DescribeLabelingJobResponse < Struct.new( :labeling_job_status, :label_counters, :failure_reason, :creation_time, :last_modified_time, :job_reference_code, :labeling_job_name, :labeling_job_arn, :label_attribute_name, :input_config, :output_config, :role_arn, :label_category_config_s3_uri, :stopping_conditions, :labeling_job_algorithms_config, :human_task_config, :tags, :labeling_job_output) SENSITIVE = [] include Aws::Structure end |
#label_counters ⇒ Types::LabelCounters
Provides a breakdown of the number of data objects labeled by humans, the number of objects labeled by machine, the number of objects than couldn’t be labeled, and the total number of objects labeled.
20500 20501 20502 20503 20504 20505 20506 20507 20508 20509 20510 20511 20512 20513 20514 20515 20516 20517 20518 20519 20520 20521 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20500 class DescribeLabelingJobResponse < Struct.new( :labeling_job_status, :label_counters, :failure_reason, :creation_time, :last_modified_time, :job_reference_code, :labeling_job_name, :labeling_job_arn, :label_attribute_name, :input_config, :output_config, :role_arn, :label_category_config_s3_uri, :stopping_conditions, :labeling_job_algorithms_config, :human_task_config, :tags, :labeling_job_output) SENSITIVE = [] include Aws::Structure end |
#labeling_job_algorithms_config ⇒ Types::LabelingJobAlgorithmsConfig
Configuration information for automated data labeling.
20500 20501 20502 20503 20504 20505 20506 20507 20508 20509 20510 20511 20512 20513 20514 20515 20516 20517 20518 20519 20520 20521 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20500 class DescribeLabelingJobResponse < Struct.new( :labeling_job_status, :label_counters, :failure_reason, :creation_time, :last_modified_time, :job_reference_code, :labeling_job_name, :labeling_job_arn, :label_attribute_name, :input_config, :output_config, :role_arn, :label_category_config_s3_uri, :stopping_conditions, :labeling_job_algorithms_config, :human_task_config, :tags, :labeling_job_output) SENSITIVE = [] include Aws::Structure end |
#labeling_job_arn ⇒ String
The Amazon Resource Name (ARN) of the labeling job.
20500 20501 20502 20503 20504 20505 20506 20507 20508 20509 20510 20511 20512 20513 20514 20515 20516 20517 20518 20519 20520 20521 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20500 class DescribeLabelingJobResponse < Struct.new( :labeling_job_status, :label_counters, :failure_reason, :creation_time, :last_modified_time, :job_reference_code, :labeling_job_name, :labeling_job_arn, :label_attribute_name, :input_config, :output_config, :role_arn, :label_category_config_s3_uri, :stopping_conditions, :labeling_job_algorithms_config, :human_task_config, :tags, :labeling_job_output) SENSITIVE = [] include Aws::Structure end |
#labeling_job_name ⇒ String
The name assigned to the labeling job when it was created.
20500 20501 20502 20503 20504 20505 20506 20507 20508 20509 20510 20511 20512 20513 20514 20515 20516 20517 20518 20519 20520 20521 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20500 class DescribeLabelingJobResponse < Struct.new( :labeling_job_status, :label_counters, :failure_reason, :creation_time, :last_modified_time, :job_reference_code, :labeling_job_name, :labeling_job_arn, :label_attribute_name, :input_config, :output_config, :role_arn, :label_category_config_s3_uri, :stopping_conditions, :labeling_job_algorithms_config, :human_task_config, :tags, :labeling_job_output) SENSITIVE = [] include Aws::Structure end |
#labeling_job_output ⇒ Types::LabelingJobOutput
The location of the output produced by the labeling job.
20500 20501 20502 20503 20504 20505 20506 20507 20508 20509 20510 20511 20512 20513 20514 20515 20516 20517 20518 20519 20520 20521 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20500 class DescribeLabelingJobResponse < Struct.new( :labeling_job_status, :label_counters, :failure_reason, :creation_time, :last_modified_time, :job_reference_code, :labeling_job_name, :labeling_job_arn, :label_attribute_name, :input_config, :output_config, :role_arn, :label_category_config_s3_uri, :stopping_conditions, :labeling_job_algorithms_config, :human_task_config, :tags, :labeling_job_output) SENSITIVE = [] include Aws::Structure end |
#labeling_job_status ⇒ String
The processing status of the labeling job.
20500 20501 20502 20503 20504 20505 20506 20507 20508 20509 20510 20511 20512 20513 20514 20515 20516 20517 20518 20519 20520 20521 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20500 class DescribeLabelingJobResponse < Struct.new( :labeling_job_status, :label_counters, :failure_reason, :creation_time, :last_modified_time, :job_reference_code, :labeling_job_name, :labeling_job_arn, :label_attribute_name, :input_config, :output_config, :role_arn, :label_category_config_s3_uri, :stopping_conditions, :labeling_job_algorithms_config, :human_task_config, :tags, :labeling_job_output) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The date and time that the labeling job was last updated.
20500 20501 20502 20503 20504 20505 20506 20507 20508 20509 20510 20511 20512 20513 20514 20515 20516 20517 20518 20519 20520 20521 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20500 class DescribeLabelingJobResponse < Struct.new( :labeling_job_status, :label_counters, :failure_reason, :creation_time, :last_modified_time, :job_reference_code, :labeling_job_name, :labeling_job_arn, :label_attribute_name, :input_config, :output_config, :role_arn, :label_category_config_s3_uri, :stopping_conditions, :labeling_job_algorithms_config, :human_task_config, :tags, :labeling_job_output) SENSITIVE = [] include Aws::Structure end |
#output_config ⇒ Types::LabelingJobOutputConfig
The location of the job’s output data and the Amazon Web Services Key Management Service key ID for the key used to encrypt the output data, if any.
20500 20501 20502 20503 20504 20505 20506 20507 20508 20509 20510 20511 20512 20513 20514 20515 20516 20517 20518 20519 20520 20521 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20500 class DescribeLabelingJobResponse < Struct.new( :labeling_job_status, :label_counters, :failure_reason, :creation_time, :last_modified_time, :job_reference_code, :labeling_job_name, :labeling_job_arn, :label_attribute_name, :input_config, :output_config, :role_arn, :label_category_config_s3_uri, :stopping_conditions, :labeling_job_algorithms_config, :human_task_config, :tags, :labeling_job_output) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) that SageMaker assumes to perform tasks on your behalf during data labeling.
20500 20501 20502 20503 20504 20505 20506 20507 20508 20509 20510 20511 20512 20513 20514 20515 20516 20517 20518 20519 20520 20521 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20500 class DescribeLabelingJobResponse < Struct.new( :labeling_job_status, :label_counters, :failure_reason, :creation_time, :last_modified_time, :job_reference_code, :labeling_job_name, :labeling_job_arn, :label_attribute_name, :input_config, :output_config, :role_arn, :label_category_config_s3_uri, :stopping_conditions, :labeling_job_algorithms_config, :human_task_config, :tags, :labeling_job_output) SENSITIVE = [] include Aws::Structure end |
#stopping_conditions ⇒ Types::LabelingJobStoppingConditions
A set of conditions for stopping a labeling job. If any of the conditions are met, the job is automatically stopped.
20500 20501 20502 20503 20504 20505 20506 20507 20508 20509 20510 20511 20512 20513 20514 20515 20516 20517 20518 20519 20520 20521 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20500 class DescribeLabelingJobResponse < Struct.new( :labeling_job_status, :label_counters, :failure_reason, :creation_time, :last_modified_time, :job_reference_code, :labeling_job_name, :labeling_job_arn, :label_attribute_name, :input_config, :output_config, :role_arn, :label_category_config_s3_uri, :stopping_conditions, :labeling_job_algorithms_config, :human_task_config, :tags, :labeling_job_output) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
An array of key-value pairs. You can use tags to categorize your Amazon Web Services resources in different ways, for example, by purpose, owner, or environment. For more information, see [Tagging Amazon Web Services Resources].
20500 20501 20502 20503 20504 20505 20506 20507 20508 20509 20510 20511 20512 20513 20514 20515 20516 20517 20518 20519 20520 20521 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20500 class DescribeLabelingJobResponse < Struct.new( :labeling_job_status, :label_counters, :failure_reason, :creation_time, :last_modified_time, :job_reference_code, :labeling_job_name, :labeling_job_arn, :label_attribute_name, :input_config, :output_config, :role_arn, :label_category_config_s3_uri, :stopping_conditions, :labeling_job_algorithms_config, :human_task_config, :tags, :labeling_job_output) SENSITIVE = [] include Aws::Structure end |