Class: Aws::SageMaker::Types::DescribeMlflowAppResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_default_status ⇒ String

Indicates whether this MLflow app is the default for the entire account.

Returns:

  • (String)


21516
21517
21518
21519
21520
21521
21522
21523
21524
21525
21526
21527
21528
21529
21530
21531
21532
21533
21534
21535
# File 'lib/aws-sdk-sagemaker/types.rb', line 21516

class DescribeMlflowAppResponse < Struct.new(
  :arn,
  :name,
  :artifact_store_uri,
  :mlflow_version,
  :role_arn,
  :kms_key_id,
  :status,
  :model_registration_mode,
  :account_default_status,
  :default_domain_id_list,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :weekly_maintenance_window_start,
  :maintenance_status)
  SENSITIVE = []
  include Aws::Structure
end

#arn ⇒ String

The ARN of the MLflow App.

Returns:

  • (String)


21516
21517
21518
21519
21520
21521
21522
21523
21524
21525
21526
21527
21528
21529
21530
21531
21532
21533
21534
21535
# File 'lib/aws-sdk-sagemaker/types.rb', line 21516

class DescribeMlflowAppResponse < Struct.new(
  :arn,
  :name,
  :artifact_store_uri,
  :mlflow_version,
  :role_arn,
  :kms_key_id,
  :status,
  :model_registration_mode,
  :account_default_status,
  :default_domain_id_list,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :weekly_maintenance_window_start,
  :maintenance_status)
  SENSITIVE = []
  include Aws::Structure
end

#artifact_store_uri ⇒ String

The S3 URI of the general purpose bucket used as the MLflow App artifact store.

Returns:

  • (String)


21516
21517
21518
21519
21520
21521
21522
21523
21524
21525
21526
21527
21528
21529
21530
21531
21532
21533
21534
21535
# File 'lib/aws-sdk-sagemaker/types.rb', line 21516

class DescribeMlflowAppResponse < Struct.new(
  :arn,
  :name,
  :artifact_store_uri,
  :mlflow_version,
  :role_arn,
  :kms_key_id,
  :status,
  :model_registration_mode,
  :account_default_status,
  :default_domain_id_list,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :weekly_maintenance_window_start,
  :maintenance_status)
  SENSITIVE = []
  include Aws::Structure
end

#created_by ⇒ Types::UserContext

Information about the user who created or modified a SageMaker resource.

Returns:



21516
21517
21518
21519
21520
21521
21522
21523
21524
21525
21526
21527
21528
21529
21530
21531
21532
21533
21534
21535
# File 'lib/aws-sdk-sagemaker/types.rb', line 21516

class DescribeMlflowAppResponse < Struct.new(
  :arn,
  :name,
  :artifact_store_uri,
  :mlflow_version,
  :role_arn,
  :kms_key_id,
  :status,
  :model_registration_mode,
  :account_default_status,
  :default_domain_id_list,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :weekly_maintenance_window_start,
  :maintenance_status)
  SENSITIVE = []
  include Aws::Structure
end

#creation_time ⇒ Time

The timestamp when the MLflow App was created.

Returns:

  • (Time)


21516
21517
21518
21519
21520
21521
21522
21523
21524
21525
21526
21527
21528
21529
21530
21531
21532
21533
21534
21535
# File 'lib/aws-sdk-sagemaker/types.rb', line 21516

class DescribeMlflowAppResponse < Struct.new(
  :arn,
  :name,
  :artifact_store_uri,
  :mlflow_version,
  :role_arn,
  :kms_key_id,
  :status,
  :model_registration_mode,
  :account_default_status,
  :default_domain_id_list,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :weekly_maintenance_window_start,
  :maintenance_status)
  SENSITIVE = []
  include Aws::Structure
end

#default_domain_id_list ⇒ Array<String>

List of SageMaker Domain IDs for which this MLflow App is the default.

Returns:

  • (Array<String>)


21516
21517
21518
21519
21520
21521
21522
21523
21524
21525
21526
21527
21528
21529
21530
21531
21532
21533
21534
21535
# File 'lib/aws-sdk-sagemaker/types.rb', line 21516

class DescribeMlflowAppResponse < Struct.new(
  :arn,
  :name,
  :artifact_store_uri,
  :mlflow_version,
  :role_arn,
  :kms_key_id,
  :status,
  :model_registration_mode,
  :account_default_status,
  :default_domain_id_list,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :weekly_maintenance_window_start,
  :maintenance_status)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_id ⇒ String

The ID of the Amazon Web Services KMS key used to encrypt the data at rest associated with the MLflow App. This field is absent if the MLflow App is not encrypted with a customer-managed key.

Returns:

  • (String)


21516
21517
21518
21519
21520
21521
21522
21523
21524
21525
21526
21527
21528
21529
21530
21531
21532
21533
21534
21535
# File 'lib/aws-sdk-sagemaker/types.rb', line 21516

class DescribeMlflowAppResponse < Struct.new(
  :arn,
  :name,
  :artifact_store_uri,
  :mlflow_version,
  :role_arn,
  :kms_key_id,
  :status,
  :model_registration_mode,
  :account_default_status,
  :default_domain_id_list,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :weekly_maintenance_window_start,
  :maintenance_status)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_by ⇒ Types::UserContext

Information about the user who created or modified a SageMaker resource.

Returns:



21516
21517
21518
21519
21520
21521
21522
21523
21524
21525
21526
21527
21528
21529
21530
21531
21532
21533
21534
21535
# File 'lib/aws-sdk-sagemaker/types.rb', line 21516

class DescribeMlflowAppResponse < Struct.new(
  :arn,
  :name,
  :artifact_store_uri,
  :mlflow_version,
  :role_arn,
  :kms_key_id,
  :status,
  :model_registration_mode,
  :account_default_status,
  :default_domain_id_list,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :weekly_maintenance_window_start,
  :maintenance_status)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_time ⇒ Time

The timestamp when the MLflow App was last modified.

Returns:

  • (Time)


21516
21517
21518
21519
21520
21521
21522
21523
21524
21525
21526
21527
21528
21529
21530
21531
21532
21533
21534
21535
# File 'lib/aws-sdk-sagemaker/types.rb', line 21516

class DescribeMlflowAppResponse < Struct.new(
  :arn,
  :name,
  :artifact_store_uri,
  :mlflow_version,
  :role_arn,
  :kms_key_id,
  :status,
  :model_registration_mode,
  :account_default_status,
  :default_domain_id_list,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :weekly_maintenance_window_start,
  :maintenance_status)
  SENSITIVE = []
  include Aws::Structure
end

#maintenance_status ⇒ String

Current maintenance status of the MLflow App.

Returns:

  • (String)


21516
21517
21518
21519
21520
21521
21522
21523
21524
21525
21526
21527
21528
21529
21530
21531
21532
21533
21534
21535
# File 'lib/aws-sdk-sagemaker/types.rb', line 21516

class DescribeMlflowAppResponse < Struct.new(
  :arn,
  :name,
  :artifact_store_uri,
  :mlflow_version,
  :role_arn,
  :kms_key_id,
  :status,
  :model_registration_mode,
  :account_default_status,
  :default_domain_id_list,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :weekly_maintenance_window_start,
  :maintenance_status)
  SENSITIVE = []
  include Aws::Structure
end

#mlflow_version ⇒ String

The MLflow version used.

Returns:

  • (String)


21516
21517
21518
21519
21520
21521
21522
21523
21524
21525
21526
21527
21528
21529
21530
21531
21532
21533
21534
21535
# File 'lib/aws-sdk-sagemaker/types.rb', line 21516

class DescribeMlflowAppResponse < Struct.new(
  :arn,
  :name,
  :artifact_store_uri,
  :mlflow_version,
  :role_arn,
  :kms_key_id,
  :status,
  :model_registration_mode,
  :account_default_status,
  :default_domain_id_list,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :weekly_maintenance_window_start,
  :maintenance_status)
  SENSITIVE = []
  include Aws::Structure
end

#model_registration_mode ⇒ String

Whether automatic registration of new MLflow models to the SageMaker Model Registry is enabled.

Returns:

  • (String)


21516
21517
21518
21519
21520
21521
21522
21523
21524
21525
21526
21527
21528
21529
21530
21531
21532
21533
21534
21535
# File 'lib/aws-sdk-sagemaker/types.rb', line 21516

class DescribeMlflowAppResponse < Struct.new(
  :arn,
  :name,
  :artifact_store_uri,
  :mlflow_version,
  :role_arn,
  :kms_key_id,
  :status,
  :model_registration_mode,
  :account_default_status,
  :default_domain_id_list,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :weekly_maintenance_window_start,
  :maintenance_status)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the MLflow App.

Returns:

  • (String)


21516
21517
21518
21519
21520
21521
21522
21523
21524
21525
21526
21527
21528
21529
21530
21531
21532
21533
21534
21535
# File 'lib/aws-sdk-sagemaker/types.rb', line 21516

class DescribeMlflowAppResponse < Struct.new(
  :arn,
  :name,
  :artifact_store_uri,
  :mlflow_version,
  :role_arn,
  :kms_key_id,
  :status,
  :model_registration_mode,
  :account_default_status,
  :default_domain_id_list,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :weekly_maintenance_window_start,
  :maintenance_status)
  SENSITIVE = []
  include Aws::Structure
end

#role_arn ⇒ String

The Amazon Resource Name (ARN) for an IAM role in your account that the MLflow App uses to access the artifact store in Amazon S3.

Returns:

  • (String)


21516
21517
21518
21519
21520
21521
21522
21523
21524
21525
21526
21527
21528
21529
21530
21531
21532
21533
21534
21535
# File 'lib/aws-sdk-sagemaker/types.rb', line 21516

class DescribeMlflowAppResponse < Struct.new(
  :arn,
  :name,
  :artifact_store_uri,
  :mlflow_version,
  :role_arn,
  :kms_key_id,
  :status,
  :model_registration_mode,
  :account_default_status,
  :default_domain_id_list,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :weekly_maintenance_window_start,
  :maintenance_status)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The current creation status of the described MLflow App.

Returns:

  • (String)


21516
21517
21518
21519
21520
21521
21522
21523
21524
21525
21526
21527
21528
21529
21530
21531
21532
21533
21534
21535
# File 'lib/aws-sdk-sagemaker/types.rb', line 21516

class DescribeMlflowAppResponse < Struct.new(
  :arn,
  :name,
  :artifact_store_uri,
  :mlflow_version,
  :role_arn,
  :kms_key_id,
  :status,
  :model_registration_mode,
  :account_default_status,
  :default_domain_id_list,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :weekly_maintenance_window_start,
  :maintenance_status)
  SENSITIVE = []
  include Aws::Structure
end

#weekly_maintenance_window_start ⇒ String

The day and time of the week when weekly maintenance occurs.

Returns:

  • (String)


21516
21517
21518
21519
21520
21521
21522
21523
21524
21525
21526
21527
21528
21529
21530
21531
21532
21533
21534
21535
# File 'lib/aws-sdk-sagemaker/types.rb', line 21516

class DescribeMlflowAppResponse < Struct.new(
  :arn,
  :name,
  :artifact_store_uri,
  :mlflow_version,
  :role_arn,
  :kms_key_id,
  :status,
  :model_registration_mode,
  :account_default_status,
  :default_domain_id_list,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :weekly_maintenance_window_start,
  :maintenance_status)
  SENSITIVE = []
  include Aws::Structure
end