Class: Aws::SageMaker::Types::DescribeMlflowTrackingServerResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeMlflowTrackingServerResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#artifact_store_uri ⇒ String
The S3 URI of the general purpose bucket used as the MLflow Tracking Server artifact store.
-
#automatic_model_registration ⇒ Boolean
Whether automatic registration of new MLflow models to the SageMaker Model Registry is enabled.
-
#created_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
-
#creation_time ⇒ Time
The timestamp of when the described MLflow Tracking Server was created.
-
#is_active ⇒ String
Whether the described MLflow Tracking Server is currently active.
-
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
-
#last_modified_time ⇒ Time
The timestamp of when the described MLflow Tracking Server was last modified.
-
#mlflow_version ⇒ String
The MLflow version used for the described tracking server.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) for an IAM role in your account that the described MLflow Tracking Server uses to access the artifact store in Amazon S3.
-
#s3_bucket_owner_account_id ⇒ String
Expected Amazon Web Services account ID that owns the Amazon S3 bucket for artifact storage.
-
#s3_bucket_owner_verification ⇒ Boolean
Whether Amazon S3 Bucket Ownership checks are enabled whenever the tracking server interacts with Amazon Amazon S3.
-
#tracking_server_arn ⇒ String
The ARN of the described tracking server.
-
#tracking_server_maintenance_status ⇒ String
The current maintenance status of the described MLflow Tracking Server.
-
#tracking_server_name ⇒ String
The name of the described tracking server.
-
#tracking_server_size ⇒ String
The size of the described tracking server.
-
#tracking_server_status ⇒ String
The current creation status of the described MLflow Tracking Server.
-
#tracking_server_url ⇒ String
The URL to connect to the MLflow user interface for the described tracking server.
-
#weekly_maintenance_window_start ⇒ String
The day and time of the week when weekly maintenance occurs on the described tracking server.
Instance Attribute Details
#artifact_store_uri ⇒ String
The S3 URI of the general purpose bucket used as the MLflow Tracking Server artifact store.
19372 19373 19374 19375 19376 19377 19378 19379 19380 19381 19382 19383 19384 19385 19386 19387 19388 19389 19390 19391 19392 19393 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19372 class DescribeMlflowTrackingServerResponse < Struct.new( :tracking_server_arn, :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :tracking_server_status, :tracking_server_maintenance_status, :is_active, :tracking_server_url, :weekly_maintenance_window_start, :automatic_model_registration, :creation_time, :created_by, :last_modified_time, :last_modified_by, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#automatic_model_registration ⇒ Boolean
Whether automatic registration of new MLflow models to the SageMaker Model Registry is enabled.
19372 19373 19374 19375 19376 19377 19378 19379 19380 19381 19382 19383 19384 19385 19386 19387 19388 19389 19390 19391 19392 19393 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19372 class DescribeMlflowTrackingServerResponse < Struct.new( :tracking_server_arn, :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :tracking_server_status, :tracking_server_maintenance_status, :is_active, :tracking_server_url, :weekly_maintenance_window_start, :automatic_model_registration, :creation_time, :created_by, :last_modified_time, :last_modified_by, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
19372 19373 19374 19375 19376 19377 19378 19379 19380 19381 19382 19383 19384 19385 19386 19387 19388 19389 19390 19391 19392 19393 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19372 class DescribeMlflowTrackingServerResponse < Struct.new( :tracking_server_arn, :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :tracking_server_status, :tracking_server_maintenance_status, :is_active, :tracking_server_url, :weekly_maintenance_window_start, :automatic_model_registration, :creation_time, :created_by, :last_modified_time, :last_modified_by, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The timestamp of when the described MLflow Tracking Server was created.
19372 19373 19374 19375 19376 19377 19378 19379 19380 19381 19382 19383 19384 19385 19386 19387 19388 19389 19390 19391 19392 19393 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19372 class DescribeMlflowTrackingServerResponse < Struct.new( :tracking_server_arn, :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :tracking_server_status, :tracking_server_maintenance_status, :is_active, :tracking_server_url, :weekly_maintenance_window_start, :automatic_model_registration, :creation_time, :created_by, :last_modified_time, :last_modified_by, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#is_active ⇒ String
Whether the described MLflow Tracking Server is currently active.
19372 19373 19374 19375 19376 19377 19378 19379 19380 19381 19382 19383 19384 19385 19386 19387 19388 19389 19390 19391 19392 19393 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19372 class DescribeMlflowTrackingServerResponse < Struct.new( :tracking_server_arn, :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :tracking_server_status, :tracking_server_maintenance_status, :is_active, :tracking_server_url, :weekly_maintenance_window_start, :automatic_model_registration, :creation_time, :created_by, :last_modified_time, :last_modified_by, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
19372 19373 19374 19375 19376 19377 19378 19379 19380 19381 19382 19383 19384 19385 19386 19387 19388 19389 19390 19391 19392 19393 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19372 class DescribeMlflowTrackingServerResponse < Struct.new( :tracking_server_arn, :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :tracking_server_status, :tracking_server_maintenance_status, :is_active, :tracking_server_url, :weekly_maintenance_window_start, :automatic_model_registration, :creation_time, :created_by, :last_modified_time, :last_modified_by, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp of when the described MLflow Tracking Server was last modified.
19372 19373 19374 19375 19376 19377 19378 19379 19380 19381 19382 19383 19384 19385 19386 19387 19388 19389 19390 19391 19392 19393 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19372 class DescribeMlflowTrackingServerResponse < Struct.new( :tracking_server_arn, :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :tracking_server_status, :tracking_server_maintenance_status, :is_active, :tracking_server_url, :weekly_maintenance_window_start, :automatic_model_registration, :creation_time, :created_by, :last_modified_time, :last_modified_by, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#mlflow_version ⇒ String
The MLflow version used for the described tracking server.
19372 19373 19374 19375 19376 19377 19378 19379 19380 19381 19382 19383 19384 19385 19386 19387 19388 19389 19390 19391 19392 19393 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19372 class DescribeMlflowTrackingServerResponse < Struct.new( :tracking_server_arn, :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :tracking_server_status, :tracking_server_maintenance_status, :is_active, :tracking_server_url, :weekly_maintenance_window_start, :automatic_model_registration, :creation_time, :created_by, :last_modified_time, :last_modified_by, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) for an IAM role in your account that the described MLflow Tracking Server uses to access the artifact store in Amazon S3.
19372 19373 19374 19375 19376 19377 19378 19379 19380 19381 19382 19383 19384 19385 19386 19387 19388 19389 19390 19391 19392 19393 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19372 class DescribeMlflowTrackingServerResponse < Struct.new( :tracking_server_arn, :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :tracking_server_status, :tracking_server_maintenance_status, :is_active, :tracking_server_url, :weekly_maintenance_window_start, :automatic_model_registration, :creation_time, :created_by, :last_modified_time, :last_modified_by, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#s3_bucket_owner_account_id ⇒ String
Expected Amazon Web Services account ID that owns the Amazon S3 bucket for artifact storage.
19372 19373 19374 19375 19376 19377 19378 19379 19380 19381 19382 19383 19384 19385 19386 19387 19388 19389 19390 19391 19392 19393 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19372 class DescribeMlflowTrackingServerResponse < Struct.new( :tracking_server_arn, :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :tracking_server_status, :tracking_server_maintenance_status, :is_active, :tracking_server_url, :weekly_maintenance_window_start, :automatic_model_registration, :creation_time, :created_by, :last_modified_time, :last_modified_by, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#s3_bucket_owner_verification ⇒ Boolean
Whether Amazon S3 Bucket Ownership checks are enabled whenever the tracking server interacts with Amazon Amazon S3.
19372 19373 19374 19375 19376 19377 19378 19379 19380 19381 19382 19383 19384 19385 19386 19387 19388 19389 19390 19391 19392 19393 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19372 class DescribeMlflowTrackingServerResponse < Struct.new( :tracking_server_arn, :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :tracking_server_status, :tracking_server_maintenance_status, :is_active, :tracking_server_url, :weekly_maintenance_window_start, :automatic_model_registration, :creation_time, :created_by, :last_modified_time, :last_modified_by, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#tracking_server_arn ⇒ String
The ARN of the described tracking server.
19372 19373 19374 19375 19376 19377 19378 19379 19380 19381 19382 19383 19384 19385 19386 19387 19388 19389 19390 19391 19392 19393 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19372 class DescribeMlflowTrackingServerResponse < Struct.new( :tracking_server_arn, :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :tracking_server_status, :tracking_server_maintenance_status, :is_active, :tracking_server_url, :weekly_maintenance_window_start, :automatic_model_registration, :creation_time, :created_by, :last_modified_time, :last_modified_by, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#tracking_server_maintenance_status ⇒ String
The current maintenance status of the described MLflow Tracking Server.
19372 19373 19374 19375 19376 19377 19378 19379 19380 19381 19382 19383 19384 19385 19386 19387 19388 19389 19390 19391 19392 19393 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19372 class DescribeMlflowTrackingServerResponse < Struct.new( :tracking_server_arn, :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :tracking_server_status, :tracking_server_maintenance_status, :is_active, :tracking_server_url, :weekly_maintenance_window_start, :automatic_model_registration, :creation_time, :created_by, :last_modified_time, :last_modified_by, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#tracking_server_name ⇒ String
The name of the described tracking server.
19372 19373 19374 19375 19376 19377 19378 19379 19380 19381 19382 19383 19384 19385 19386 19387 19388 19389 19390 19391 19392 19393 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19372 class DescribeMlflowTrackingServerResponse < Struct.new( :tracking_server_arn, :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :tracking_server_status, :tracking_server_maintenance_status, :is_active, :tracking_server_url, :weekly_maintenance_window_start, :automatic_model_registration, :creation_time, :created_by, :last_modified_time, :last_modified_by, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#tracking_server_size ⇒ String
The size of the described tracking server.
19372 19373 19374 19375 19376 19377 19378 19379 19380 19381 19382 19383 19384 19385 19386 19387 19388 19389 19390 19391 19392 19393 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19372 class DescribeMlflowTrackingServerResponse < Struct.new( :tracking_server_arn, :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :tracking_server_status, :tracking_server_maintenance_status, :is_active, :tracking_server_url, :weekly_maintenance_window_start, :automatic_model_registration, :creation_time, :created_by, :last_modified_time, :last_modified_by, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#tracking_server_status ⇒ String
The current creation status of the described MLflow Tracking Server.
19372 19373 19374 19375 19376 19377 19378 19379 19380 19381 19382 19383 19384 19385 19386 19387 19388 19389 19390 19391 19392 19393 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19372 class DescribeMlflowTrackingServerResponse < Struct.new( :tracking_server_arn, :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :tracking_server_status, :tracking_server_maintenance_status, :is_active, :tracking_server_url, :weekly_maintenance_window_start, :automatic_model_registration, :creation_time, :created_by, :last_modified_time, :last_modified_by, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#tracking_server_url ⇒ String
The URL to connect to the MLflow user interface for the described tracking server.
19372 19373 19374 19375 19376 19377 19378 19379 19380 19381 19382 19383 19384 19385 19386 19387 19388 19389 19390 19391 19392 19393 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19372 class DescribeMlflowTrackingServerResponse < Struct.new( :tracking_server_arn, :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :tracking_server_status, :tracking_server_maintenance_status, :is_active, :tracking_server_url, :weekly_maintenance_window_start, :automatic_model_registration, :creation_time, :created_by, :last_modified_time, :last_modified_by, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#weekly_maintenance_window_start ⇒ String
The day and time of the week when weekly maintenance occurs on the described tracking server.
19372 19373 19374 19375 19376 19377 19378 19379 19380 19381 19382 19383 19384 19385 19386 19387 19388 19389 19390 19391 19392 19393 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19372 class DescribeMlflowTrackingServerResponse < Struct.new( :tracking_server_arn, :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :tracking_server_status, :tracking_server_maintenance_status, :is_active, :tracking_server_url, :weekly_maintenance_window_start, :automatic_model_registration, :creation_time, :created_by, :last_modified_time, :last_modified_by, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |