Class: Aws::SageMaker::Types::DescribeModelOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeModelOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#containers ⇒ Array<Types::ContainerDefinition>
The containers in the inference pipeline.
-
#creation_time ⇒ Time
A timestamp that shows when the model was created.
-
#deployment_recommendation ⇒ Types::DeploymentRecommendation
A set of recommended deployment configurations for the model.
-
#enable_network_isolation ⇒ Boolean
If
True, no inbound or outbound network calls can be made to or from the model container. -
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that you specified for the model.
-
#inference_execution_config ⇒ Types::InferenceExecutionConfig
Specifies details of how containers in a multi-container endpoint are called.
-
#model_arn ⇒ String
The Amazon Resource Name (ARN) of the model.
-
#model_name ⇒ String
Name of the SageMaker model.
-
#primary_container ⇒ Types::ContainerDefinition
The location of the primary inference code, associated artifacts, and custom environment map that the inference code uses when it is deployed in production.
-
#vpc_config ⇒ Types::VpcConfig
A [VpcConfig][1] object that specifies the VPC that this model has access to.
Instance Attribute Details
#containers ⇒ Array<Types::ContainerDefinition>
The containers in the inference pipeline.
22120 22121 22122 22123 22124 22125 22126 22127 22128 22129 22130 22131 22132 22133 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22120 class DescribeModelOutput < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :deployment_recommendation) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
A timestamp that shows when the model was created.
22120 22121 22122 22123 22124 22125 22126 22127 22128 22129 22130 22131 22132 22133 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22120 class DescribeModelOutput < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :deployment_recommendation) SENSITIVE = [] include Aws::Structure end |
#deployment_recommendation ⇒ Types::DeploymentRecommendation
A set of recommended deployment configurations for the model.
22120 22121 22122 22123 22124 22125 22126 22127 22128 22129 22130 22131 22132 22133 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22120 class DescribeModelOutput < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :deployment_recommendation) SENSITIVE = [] include Aws::Structure end |
#enable_network_isolation ⇒ Boolean
If True, no inbound or outbound network calls can be made to or
from the model container.
22120 22121 22122 22123 22124 22125 22126 22127 22128 22129 22130 22131 22132 22133 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22120 class DescribeModelOutput < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :deployment_recommendation) SENSITIVE = [] include Aws::Structure end |
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that you specified for the model.
22120 22121 22122 22123 22124 22125 22126 22127 22128 22129 22130 22131 22132 22133 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22120 class DescribeModelOutput < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :deployment_recommendation) SENSITIVE = [] include Aws::Structure end |
#inference_execution_config ⇒ Types::InferenceExecutionConfig
Specifies details of how containers in a multi-container endpoint are called.
22120 22121 22122 22123 22124 22125 22126 22127 22128 22129 22130 22131 22132 22133 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22120 class DescribeModelOutput < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :deployment_recommendation) SENSITIVE = [] include Aws::Structure end |
#model_arn ⇒ String
The Amazon Resource Name (ARN) of the model.
22120 22121 22122 22123 22124 22125 22126 22127 22128 22129 22130 22131 22132 22133 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22120 class DescribeModelOutput < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :deployment_recommendation) SENSITIVE = [] include Aws::Structure end |
#model_name ⇒ String
Name of the SageMaker model.
22120 22121 22122 22123 22124 22125 22126 22127 22128 22129 22130 22131 22132 22133 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22120 class DescribeModelOutput < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :deployment_recommendation) SENSITIVE = [] include Aws::Structure end |
#primary_container ⇒ Types::ContainerDefinition
The location of the primary inference code, associated artifacts, and custom environment map that the inference code uses when it is deployed in production.
22120 22121 22122 22123 22124 22125 22126 22127 22128 22129 22130 22131 22132 22133 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22120 class DescribeModelOutput < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :deployment_recommendation) SENSITIVE = [] include Aws::Structure end |
#vpc_config ⇒ Types::VpcConfig
A VpcConfig object that specifies the VPC that this model has access to. For more information, see Protect Endpoints by Using an Amazon Virtual Private Cloud
22120 22121 22122 22123 22124 22125 22126 22127 22128 22129 22130 22131 22132 22133 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22120 class DescribeModelOutput < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :deployment_recommendation) SENSITIVE = [] include Aws::Structure end |