Class: Aws::SageMaker::Types::DescribeModelPackageInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#included_dataString

Specifies the level of model package data to include in the response. Use this parameter to call ‘DescribeModelPackage` on a model package that has an associated model card without requiring `kms:Decrypt` permission on the customer-managed KMS key associated with the embedded model card.

  • ‘AllData`: Returns the full model package response, including the unredacted `ModelCard.ModelCardContent`. This option requires `kms:Decrypt` permission on the customer-managed key, if one is associated with the embedded model card. This is the default.

  • ‘MetadataOnly`: Returns the full model package response, but with the embedded `ModelCard.ModelCardContent` sanitized to include only a small set of unencrypted metadata fields. This option does not require `kms:Decrypt` permission. All other top-level response fields, including `InferenceSpecification`, `ModelMetrics`, `DriftCheckBaselines`, and `SecurityConfig`, are returned unchanged. For the list of fields preserved within `ModelCardContent`, see [ModelCard].

If you don’t specify a value, SageMaker returns ‘AllData`.

[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeModelPackage.html#sagemaker-DescribeModelPackage-response-ModelCard

Returns:

  • (String)


21733
21734
21735
21736
21737
21738
# File 'lib/aws-sdk-sagemaker/types.rb', line 21733

class DescribeModelPackageInput < Struct.new(
  :model_package_name,
  :included_data)
  SENSITIVE = []
  include Aws::Structure
end

#model_package_nameString

The name or Amazon Resource Name (ARN) of the model package to describe.

When you specify a name, the name must have 1 to 63 characters. Valid characters are a-z, A-Z, 0-9, and - (hyphen).

Returns:

  • (String)


21733
21734
21735
21736
21737
21738
# File 'lib/aws-sdk-sagemaker/types.rb', line 21733

class DescribeModelPackageInput < Struct.new(
  :model_package_name,
  :included_data)
  SENSITIVE = []
  include Aws::Structure
end