Class: Aws::SageMaker::Types::DescribeNotebookInstanceInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeNotebookInstanceInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#notebook_instance_name ⇒ String
The name of the notebook instance that you want information about.
Instance Attribute Details
#notebook_instance_name ⇒ String
The name of the notebook instance that you want information about.
22576 22577 22578 22579 22580 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22576 class DescribeNotebookInstanceInput < Struct.new( :notebook_instance_name) SENSITIVE = [] include Aws::Structure end |