Class: Aws::SageMaker::Types::DescribeNotebookInstanceOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeNotebookInstanceOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#accelerator_types ⇒ Array<String>
This parameter is no longer supported.
-
#additional_code_repositories ⇒ Array<String>
An array of up to three Git repositories associated with the notebook instance.
-
#creation_time ⇒ Time
A timestamp.
-
#default_code_repository ⇒ String
The Git repository associated with the notebook instance as its default code repository.
-
#direct_internet_access ⇒ String
Describes whether SageMaker AI provides internet access to the notebook instance.
-
#failure_reason ⇒ String
If status is ‘Failed`, the reason it failed.
-
#instance_metadata_service_configuration ⇒ Types::InstanceMetadataServiceConfiguration
Information on the IMDS configuration of the notebook instance.
-
#instance_type ⇒ String
The type of ML compute instance running on the notebook instance.
-
#ip_address_type ⇒ String
The IP address type configured for the notebook instance.
-
#kms_key_id ⇒ String
The Amazon Web Services KMS key ID SageMaker AI uses to encrypt data when storing it on the ML storage volume attached to the instance.
-
#last_modified_time ⇒ Time
A timestamp.
-
#network_interface_id ⇒ String
The network interface IDs that SageMaker AI created at the time of creating the instance.
-
#notebook_instance_arn ⇒ String
The Amazon Resource Name (ARN) of the notebook instance.
-
#notebook_instance_lifecycle_config_name ⇒ String
Returns the name of a notebook instance lifecycle configuration.
-
#notebook_instance_name ⇒ String
The name of the SageMaker AI notebook instance.
-
#notebook_instance_status ⇒ String
The status of the notebook instance.
-
#platform_identifier ⇒ String
The platform identifier of the notebook instance runtime environment.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role associated with the instance.
-
#root_access ⇒ String
Whether root access is enabled or disabled for users of the notebook instance.
-
#security_groups ⇒ Array<String>
The IDs of the VPC security groups.
-
#subnet_id ⇒ String
The ID of the VPC subnet.
-
#url ⇒ String
The URL that you use to connect to the Jupyter notebook that is running in your notebook instance.
-
#volume_size_in_gb ⇒ Integer
The size, in GB, of the ML storage volume attached to the notebook instance.
Instance Attribute Details
#accelerator_types ⇒ Array<String>
This parameter is no longer supported. Elastic Inference (EI) is no longer available.
This parameter was used to specify a list of the EI instance types associated with this notebook instance.
22354 22355 22356 22357 22358 22359 22360 22361 22362 22363 22364 22365 22366 22367 22368 22369 22370 22371 22372 22373 22374 22375 22376 22377 22378 22379 22380 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22354 class DescribeNotebookInstanceOutput < Struct.new( :notebook_instance_arn, :notebook_instance_name, :notebook_instance_status, :failure_reason, :url, :instance_type, :ip_address_type, :subnet_id, :security_groups, :role_arn, :kms_key_id, :network_interface_id, :last_modified_time, :creation_time, :notebook_instance_lifecycle_config_name, :direct_internet_access, :volume_size_in_gb, :accelerator_types, :default_code_repository, :additional_code_repositories, :root_access, :platform_identifier, :instance_metadata_service_configuration) SENSITIVE = [] include Aws::Structure end |
#additional_code_repositories ⇒ Array<String>
An array of up to three Git repositories associated with the notebook instance. These can be either the names of Git repositories stored as resources in your account, or the URL of Git repositories in [Amazon Web Services CodeCommit] or in any other Git repository. These repositories are cloned at the same level as the default repository of your notebook instance. For more information, see [Associating Git Repositories with SageMaker AI Notebook Instances].
[1]: docs.aws.amazon.com/codecommit/latest/userguide/welcome.html [2]: docs.aws.amazon.com/sagemaker/latest/dg/nbi-git-repo.html
22354 22355 22356 22357 22358 22359 22360 22361 22362 22363 22364 22365 22366 22367 22368 22369 22370 22371 22372 22373 22374 22375 22376 22377 22378 22379 22380 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22354 class DescribeNotebookInstanceOutput < Struct.new( :notebook_instance_arn, :notebook_instance_name, :notebook_instance_status, :failure_reason, :url, :instance_type, :ip_address_type, :subnet_id, :security_groups, :role_arn, :kms_key_id, :network_interface_id, :last_modified_time, :creation_time, :notebook_instance_lifecycle_config_name, :direct_internet_access, :volume_size_in_gb, :accelerator_types, :default_code_repository, :additional_code_repositories, :root_access, :platform_identifier, :instance_metadata_service_configuration) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
A timestamp. Use this parameter to return the time when the notebook instance was created
22354 22355 22356 22357 22358 22359 22360 22361 22362 22363 22364 22365 22366 22367 22368 22369 22370 22371 22372 22373 22374 22375 22376 22377 22378 22379 22380 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22354 class DescribeNotebookInstanceOutput < Struct.new( :notebook_instance_arn, :notebook_instance_name, :notebook_instance_status, :failure_reason, :url, :instance_type, :ip_address_type, :subnet_id, :security_groups, :role_arn, :kms_key_id, :network_interface_id, :last_modified_time, :creation_time, :notebook_instance_lifecycle_config_name, :direct_internet_access, :volume_size_in_gb, :accelerator_types, :default_code_repository, :additional_code_repositories, :root_access, :platform_identifier, :instance_metadata_service_configuration) SENSITIVE = [] include Aws::Structure end |
#default_code_repository ⇒ String
The Git repository associated with the notebook instance as its default code repository. This can be either the name of a Git repository stored as a resource in your account, or the URL of a Git repository in [Amazon Web Services CodeCommit] or in any other Git repository. When you open a notebook instance, it opens in the directory that contains this repository. For more information, see [Associating Git Repositories with SageMaker AI Notebook Instances].
[1]: docs.aws.amazon.com/codecommit/latest/userguide/welcome.html [2]: docs.aws.amazon.com/sagemaker/latest/dg/nbi-git-repo.html
22354 22355 22356 22357 22358 22359 22360 22361 22362 22363 22364 22365 22366 22367 22368 22369 22370 22371 22372 22373 22374 22375 22376 22377 22378 22379 22380 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22354 class DescribeNotebookInstanceOutput < Struct.new( :notebook_instance_arn, :notebook_instance_name, :notebook_instance_status, :failure_reason, :url, :instance_type, :ip_address_type, :subnet_id, :security_groups, :role_arn, :kms_key_id, :network_interface_id, :last_modified_time, :creation_time, :notebook_instance_lifecycle_config_name, :direct_internet_access, :volume_size_in_gb, :accelerator_types, :default_code_repository, :additional_code_repositories, :root_access, :platform_identifier, :instance_metadata_service_configuration) SENSITIVE = [] include Aws::Structure end |
#direct_internet_access ⇒ String
Describes whether SageMaker AI provides internet access to the notebook instance. If this value is set to Disabled, the notebook instance does not have internet access, and cannot connect to SageMaker AI training and endpoint services.
For more information, see [Notebook Instances Are Internet-Enabled by Default].
22354 22355 22356 22357 22358 22359 22360 22361 22362 22363 22364 22365 22366 22367 22368 22369 22370 22371 22372 22373 22374 22375 22376 22377 22378 22379 22380 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22354 class DescribeNotebookInstanceOutput < Struct.new( :notebook_instance_arn, :notebook_instance_name, :notebook_instance_status, :failure_reason, :url, :instance_type, :ip_address_type, :subnet_id, :security_groups, :role_arn, :kms_key_id, :network_interface_id, :last_modified_time, :creation_time, :notebook_instance_lifecycle_config_name, :direct_internet_access, :volume_size_in_gb, :accelerator_types, :default_code_repository, :additional_code_repositories, :root_access, :platform_identifier, :instance_metadata_service_configuration) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
If status is ‘Failed`, the reason it failed.
22354 22355 22356 22357 22358 22359 22360 22361 22362 22363 22364 22365 22366 22367 22368 22369 22370 22371 22372 22373 22374 22375 22376 22377 22378 22379 22380 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22354 class DescribeNotebookInstanceOutput < Struct.new( :notebook_instance_arn, :notebook_instance_name, :notebook_instance_status, :failure_reason, :url, :instance_type, :ip_address_type, :subnet_id, :security_groups, :role_arn, :kms_key_id, :network_interface_id, :last_modified_time, :creation_time, :notebook_instance_lifecycle_config_name, :direct_internet_access, :volume_size_in_gb, :accelerator_types, :default_code_repository, :additional_code_repositories, :root_access, :platform_identifier, :instance_metadata_service_configuration) SENSITIVE = [] include Aws::Structure end |
#instance_metadata_service_configuration ⇒ Types::InstanceMetadataServiceConfiguration
Information on the IMDS configuration of the notebook instance
22354 22355 22356 22357 22358 22359 22360 22361 22362 22363 22364 22365 22366 22367 22368 22369 22370 22371 22372 22373 22374 22375 22376 22377 22378 22379 22380 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22354 class DescribeNotebookInstanceOutput < Struct.new( :notebook_instance_arn, :notebook_instance_name, :notebook_instance_status, :failure_reason, :url, :instance_type, :ip_address_type, :subnet_id, :security_groups, :role_arn, :kms_key_id, :network_interface_id, :last_modified_time, :creation_time, :notebook_instance_lifecycle_config_name, :direct_internet_access, :volume_size_in_gb, :accelerator_types, :default_code_repository, :additional_code_repositories, :root_access, :platform_identifier, :instance_metadata_service_configuration) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The type of ML compute instance running on the notebook instance.
22354 22355 22356 22357 22358 22359 22360 22361 22362 22363 22364 22365 22366 22367 22368 22369 22370 22371 22372 22373 22374 22375 22376 22377 22378 22379 22380 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22354 class DescribeNotebookInstanceOutput < Struct.new( :notebook_instance_arn, :notebook_instance_name, :notebook_instance_status, :failure_reason, :url, :instance_type, :ip_address_type, :subnet_id, :security_groups, :role_arn, :kms_key_id, :network_interface_id, :last_modified_time, :creation_time, :notebook_instance_lifecycle_config_name, :direct_internet_access, :volume_size_in_gb, :accelerator_types, :default_code_repository, :additional_code_repositories, :root_access, :platform_identifier, :instance_metadata_service_configuration) SENSITIVE = [] include Aws::Structure end |
#ip_address_type ⇒ String
The IP address type configured for the notebook instance. Returns ‘ipv4` for IPv4-only connectivity or `dualstack` for both IPv4 and IPv6 connectivity.
22354 22355 22356 22357 22358 22359 22360 22361 22362 22363 22364 22365 22366 22367 22368 22369 22370 22371 22372 22373 22374 22375 22376 22377 22378 22379 22380 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22354 class DescribeNotebookInstanceOutput < Struct.new( :notebook_instance_arn, :notebook_instance_name, :notebook_instance_status, :failure_reason, :url, :instance_type, :ip_address_type, :subnet_id, :security_groups, :role_arn, :kms_key_id, :network_interface_id, :last_modified_time, :creation_time, :notebook_instance_lifecycle_config_name, :direct_internet_access, :volume_size_in_gb, :accelerator_types, :default_code_repository, :additional_code_repositories, :root_access, :platform_identifier, :instance_metadata_service_configuration) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The Amazon Web Services KMS key ID SageMaker AI uses to encrypt data when storing it on the ML storage volume attached to the instance.
22354 22355 22356 22357 22358 22359 22360 22361 22362 22363 22364 22365 22366 22367 22368 22369 22370 22371 22372 22373 22374 22375 22376 22377 22378 22379 22380 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22354 class DescribeNotebookInstanceOutput < Struct.new( :notebook_instance_arn, :notebook_instance_name, :notebook_instance_status, :failure_reason, :url, :instance_type, :ip_address_type, :subnet_id, :security_groups, :role_arn, :kms_key_id, :network_interface_id, :last_modified_time, :creation_time, :notebook_instance_lifecycle_config_name, :direct_internet_access, :volume_size_in_gb, :accelerator_types, :default_code_repository, :additional_code_repositories, :root_access, :platform_identifier, :instance_metadata_service_configuration) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
A timestamp. Use this parameter to retrieve the time when the notebook instance was last modified.
22354 22355 22356 22357 22358 22359 22360 22361 22362 22363 22364 22365 22366 22367 22368 22369 22370 22371 22372 22373 22374 22375 22376 22377 22378 22379 22380 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22354 class DescribeNotebookInstanceOutput < Struct.new( :notebook_instance_arn, :notebook_instance_name, :notebook_instance_status, :failure_reason, :url, :instance_type, :ip_address_type, :subnet_id, :security_groups, :role_arn, :kms_key_id, :network_interface_id, :last_modified_time, :creation_time, :notebook_instance_lifecycle_config_name, :direct_internet_access, :volume_size_in_gb, :accelerator_types, :default_code_repository, :additional_code_repositories, :root_access, :platform_identifier, :instance_metadata_service_configuration) SENSITIVE = [] include Aws::Structure end |
#network_interface_id ⇒ String
The network interface IDs that SageMaker AI created at the time of creating the instance.
22354 22355 22356 22357 22358 22359 22360 22361 22362 22363 22364 22365 22366 22367 22368 22369 22370 22371 22372 22373 22374 22375 22376 22377 22378 22379 22380 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22354 class DescribeNotebookInstanceOutput < Struct.new( :notebook_instance_arn, :notebook_instance_name, :notebook_instance_status, :failure_reason, :url, :instance_type, :ip_address_type, :subnet_id, :security_groups, :role_arn, :kms_key_id, :network_interface_id, :last_modified_time, :creation_time, :notebook_instance_lifecycle_config_name, :direct_internet_access, :volume_size_in_gb, :accelerator_types, :default_code_repository, :additional_code_repositories, :root_access, :platform_identifier, :instance_metadata_service_configuration) SENSITIVE = [] include Aws::Structure end |
#notebook_instance_arn ⇒ String
The Amazon Resource Name (ARN) of the notebook instance.
22354 22355 22356 22357 22358 22359 22360 22361 22362 22363 22364 22365 22366 22367 22368 22369 22370 22371 22372 22373 22374 22375 22376 22377 22378 22379 22380 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22354 class DescribeNotebookInstanceOutput < Struct.new( :notebook_instance_arn, :notebook_instance_name, :notebook_instance_status, :failure_reason, :url, :instance_type, :ip_address_type, :subnet_id, :security_groups, :role_arn, :kms_key_id, :network_interface_id, :last_modified_time, :creation_time, :notebook_instance_lifecycle_config_name, :direct_internet_access, :volume_size_in_gb, :accelerator_types, :default_code_repository, :additional_code_repositories, :root_access, :platform_identifier, :instance_metadata_service_configuration) SENSITIVE = [] include Aws::Structure end |
#notebook_instance_lifecycle_config_name ⇒ String
Returns the name of a notebook instance lifecycle configuration.
For information about notebook instance lifestyle configurations, see [Step 2.1: (Optional) Customize a Notebook Instance]
[1]: docs.aws.amazon.com/sagemaker/latest/dg/notebook-lifecycle-config.html
22354 22355 22356 22357 22358 22359 22360 22361 22362 22363 22364 22365 22366 22367 22368 22369 22370 22371 22372 22373 22374 22375 22376 22377 22378 22379 22380 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22354 class DescribeNotebookInstanceOutput < Struct.new( :notebook_instance_arn, :notebook_instance_name, :notebook_instance_status, :failure_reason, :url, :instance_type, :ip_address_type, :subnet_id, :security_groups, :role_arn, :kms_key_id, :network_interface_id, :last_modified_time, :creation_time, :notebook_instance_lifecycle_config_name, :direct_internet_access, :volume_size_in_gb, :accelerator_types, :default_code_repository, :additional_code_repositories, :root_access, :platform_identifier, :instance_metadata_service_configuration) SENSITIVE = [] include Aws::Structure end |
#notebook_instance_name ⇒ String
The name of the SageMaker AI notebook instance.
22354 22355 22356 22357 22358 22359 22360 22361 22362 22363 22364 22365 22366 22367 22368 22369 22370 22371 22372 22373 22374 22375 22376 22377 22378 22379 22380 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22354 class DescribeNotebookInstanceOutput < Struct.new( :notebook_instance_arn, :notebook_instance_name, :notebook_instance_status, :failure_reason, :url, :instance_type, :ip_address_type, :subnet_id, :security_groups, :role_arn, :kms_key_id, :network_interface_id, :last_modified_time, :creation_time, :notebook_instance_lifecycle_config_name, :direct_internet_access, :volume_size_in_gb, :accelerator_types, :default_code_repository, :additional_code_repositories, :root_access, :platform_identifier, :instance_metadata_service_configuration) SENSITIVE = [] include Aws::Structure end |
#notebook_instance_status ⇒ String
The status of the notebook instance.
22354 22355 22356 22357 22358 22359 22360 22361 22362 22363 22364 22365 22366 22367 22368 22369 22370 22371 22372 22373 22374 22375 22376 22377 22378 22379 22380 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22354 class DescribeNotebookInstanceOutput < Struct.new( :notebook_instance_arn, :notebook_instance_name, :notebook_instance_status, :failure_reason, :url, :instance_type, :ip_address_type, :subnet_id, :security_groups, :role_arn, :kms_key_id, :network_interface_id, :last_modified_time, :creation_time, :notebook_instance_lifecycle_config_name, :direct_internet_access, :volume_size_in_gb, :accelerator_types, :default_code_repository, :additional_code_repositories, :root_access, :platform_identifier, :instance_metadata_service_configuration) SENSITIVE = [] include Aws::Structure end |
#platform_identifier ⇒ String
The platform identifier of the notebook instance runtime environment.
22354 22355 22356 22357 22358 22359 22360 22361 22362 22363 22364 22365 22366 22367 22368 22369 22370 22371 22372 22373 22374 22375 22376 22377 22378 22379 22380 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22354 class DescribeNotebookInstanceOutput < Struct.new( :notebook_instance_arn, :notebook_instance_name, :notebook_instance_status, :failure_reason, :url, :instance_type, :ip_address_type, :subnet_id, :security_groups, :role_arn, :kms_key_id, :network_interface_id, :last_modified_time, :creation_time, :notebook_instance_lifecycle_config_name, :direct_internet_access, :volume_size_in_gb, :accelerator_types, :default_code_repository, :additional_code_repositories, :root_access, :platform_identifier, :instance_metadata_service_configuration) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role associated with the instance.
22354 22355 22356 22357 22358 22359 22360 22361 22362 22363 22364 22365 22366 22367 22368 22369 22370 22371 22372 22373 22374 22375 22376 22377 22378 22379 22380 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22354 class DescribeNotebookInstanceOutput < Struct.new( :notebook_instance_arn, :notebook_instance_name, :notebook_instance_status, :failure_reason, :url, :instance_type, :ip_address_type, :subnet_id, :security_groups, :role_arn, :kms_key_id, :network_interface_id, :last_modified_time, :creation_time, :notebook_instance_lifecycle_config_name, :direct_internet_access, :volume_size_in_gb, :accelerator_types, :default_code_repository, :additional_code_repositories, :root_access, :platform_identifier, :instance_metadata_service_configuration) SENSITIVE = [] include Aws::Structure end |
#root_access ⇒ String
Whether root access is enabled or disabled for users of the notebook instance.
<note markdown=“1”> Lifecycle configurations need root access to be able to set up a notebook instance. Because of this, lifecycle configurations associated with a notebook instance always run with root access even if you disable root access for users.
</note>
22354 22355 22356 22357 22358 22359 22360 22361 22362 22363 22364 22365 22366 22367 22368 22369 22370 22371 22372 22373 22374 22375 22376 22377 22378 22379 22380 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22354 class DescribeNotebookInstanceOutput < Struct.new( :notebook_instance_arn, :notebook_instance_name, :notebook_instance_status, :failure_reason, :url, :instance_type, :ip_address_type, :subnet_id, :security_groups, :role_arn, :kms_key_id, :network_interface_id, :last_modified_time, :creation_time, :notebook_instance_lifecycle_config_name, :direct_internet_access, :volume_size_in_gb, :accelerator_types, :default_code_repository, :additional_code_repositories, :root_access, :platform_identifier, :instance_metadata_service_configuration) SENSITIVE = [] include Aws::Structure end |
#security_groups ⇒ Array<String>
The IDs of the VPC security groups.
22354 22355 22356 22357 22358 22359 22360 22361 22362 22363 22364 22365 22366 22367 22368 22369 22370 22371 22372 22373 22374 22375 22376 22377 22378 22379 22380 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22354 class DescribeNotebookInstanceOutput < Struct.new( :notebook_instance_arn, :notebook_instance_name, :notebook_instance_status, :failure_reason, :url, :instance_type, :ip_address_type, :subnet_id, :security_groups, :role_arn, :kms_key_id, :network_interface_id, :last_modified_time, :creation_time, :notebook_instance_lifecycle_config_name, :direct_internet_access, :volume_size_in_gb, :accelerator_types, :default_code_repository, :additional_code_repositories, :root_access, :platform_identifier, :instance_metadata_service_configuration) SENSITIVE = [] include Aws::Structure end |
#subnet_id ⇒ String
The ID of the VPC subnet.
22354 22355 22356 22357 22358 22359 22360 22361 22362 22363 22364 22365 22366 22367 22368 22369 22370 22371 22372 22373 22374 22375 22376 22377 22378 22379 22380 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22354 class DescribeNotebookInstanceOutput < Struct.new( :notebook_instance_arn, :notebook_instance_name, :notebook_instance_status, :failure_reason, :url, :instance_type, :ip_address_type, :subnet_id, :security_groups, :role_arn, :kms_key_id, :network_interface_id, :last_modified_time, :creation_time, :notebook_instance_lifecycle_config_name, :direct_internet_access, :volume_size_in_gb, :accelerator_types, :default_code_repository, :additional_code_repositories, :root_access, :platform_identifier, :instance_metadata_service_configuration) SENSITIVE = [] include Aws::Structure end |
#url ⇒ String
The URL that you use to connect to the Jupyter notebook that is running in your notebook instance.
22354 22355 22356 22357 22358 22359 22360 22361 22362 22363 22364 22365 22366 22367 22368 22369 22370 22371 22372 22373 22374 22375 22376 22377 22378 22379 22380 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22354 class DescribeNotebookInstanceOutput < Struct.new( :notebook_instance_arn, :notebook_instance_name, :notebook_instance_status, :failure_reason, :url, :instance_type, :ip_address_type, :subnet_id, :security_groups, :role_arn, :kms_key_id, :network_interface_id, :last_modified_time, :creation_time, :notebook_instance_lifecycle_config_name, :direct_internet_access, :volume_size_in_gb, :accelerator_types, :default_code_repository, :additional_code_repositories, :root_access, :platform_identifier, :instance_metadata_service_configuration) SENSITIVE = [] include Aws::Structure end |
#volume_size_in_gb ⇒ Integer
The size, in GB, of the ML storage volume attached to the notebook instance.
22354 22355 22356 22357 22358 22359 22360 22361 22362 22363 22364 22365 22366 22367 22368 22369 22370 22371 22372 22373 22374 22375 22376 22377 22378 22379 22380 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22354 class DescribeNotebookInstanceOutput < Struct.new( :notebook_instance_arn, :notebook_instance_name, :notebook_instance_status, :failure_reason, :url, :instance_type, :ip_address_type, :subnet_id, :security_groups, :role_arn, :kms_key_id, :network_interface_id, :last_modified_time, :creation_time, :notebook_instance_lifecycle_config_name, :direct_internet_access, :volume_size_in_gb, :accelerator_types, :default_code_repository, :additional_code_repositories, :root_access, :platform_identifier, :instance_metadata_service_configuration) SENSITIVE = [] include Aws::Structure end |