Class: Aws::SageMaker::Types::DescribePartnerAppResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_configTypes::PartnerAppConfig

Configuration settings for the SageMaker Partner AI App.



17857
17858
17859
17860
17861
17862
17863
17864
17865
17866
17867
17868
17869
17870
17871
17872
17873
17874
# File 'lib/aws-sdk-sagemaker/types.rb', line 17857

class DescribePartnerAppResponse < Struct.new(
  :arn,
  :name,
  :type,
  :status,
  :creation_time,
  :execution_role_arn,
  :base_url,
  :maintenance_config,
  :tier,
  :version,
  :application_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The ARN of the SageMaker Partner AI App that was described.

Returns:

  • (String)


17857
17858
17859
17860
17861
17862
17863
17864
17865
17866
17867
17868
17869
17870
17871
17872
17873
17874
# File 'lib/aws-sdk-sagemaker/types.rb', line 17857

class DescribePartnerAppResponse < Struct.new(
  :arn,
  :name,
  :type,
  :status,
  :creation_time,
  :execution_role_arn,
  :base_url,
  :maintenance_config,
  :tier,
  :version,
  :application_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#auth_typeString

The authorization type that users use to access the SageMaker Partner AI App.

Returns:

  • (String)


17857
17858
17859
17860
17861
17862
17863
17864
17865
17866
17867
17868
17869
17870
17871
17872
17873
17874
# File 'lib/aws-sdk-sagemaker/types.rb', line 17857

class DescribePartnerAppResponse < Struct.new(
  :arn,
  :name,
  :type,
  :status,
  :creation_time,
  :execution_role_arn,
  :base_url,
  :maintenance_config,
  :tier,
  :version,
  :application_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#base_urlString

The URL of the SageMaker Partner AI App that the Application SDK uses to support in-app calls for the user.

Returns:

  • (String)


17857
17858
17859
17860
17861
17862
17863
17864
17865
17866
17867
17868
17869
17870
17871
17872
17873
17874
# File 'lib/aws-sdk-sagemaker/types.rb', line 17857

class DescribePartnerAppResponse < Struct.new(
  :arn,
  :name,
  :type,
  :status,
  :creation_time,
  :execution_role_arn,
  :base_url,
  :maintenance_config,
  :tier,
  :version,
  :application_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

The time that the SageMaker Partner AI App was created.

Returns:

  • (Time)


17857
17858
17859
17860
17861
17862
17863
17864
17865
17866
17867
17868
17869
17870
17871
17872
17873
17874
# File 'lib/aws-sdk-sagemaker/types.rb', line 17857

class DescribePartnerAppResponse < Struct.new(
  :arn,
  :name,
  :type,
  :status,
  :creation_time,
  :execution_role_arn,
  :base_url,
  :maintenance_config,
  :tier,
  :version,
  :application_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#enable_iam_session_based_identityBoolean

When set to TRUE, the SageMaker Partner AI App sets the Amazon Web Services IAM session name or the authenticated IAM user as the identity of the SageMaker Partner AI App user.

Returns:

  • (Boolean)


17857
17858
17859
17860
17861
17862
17863
17864
17865
17866
17867
17868
17869
17870
17871
17872
17873
17874
# File 'lib/aws-sdk-sagemaker/types.rb', line 17857

class DescribePartnerAppResponse < Struct.new(
  :arn,
  :name,
  :type,
  :status,
  :creation_time,
  :execution_role_arn,
  :base_url,
  :maintenance_config,
  :tier,
  :version,
  :application_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#errorTypes::ErrorInfo

This is an error field object that contains the error code and the reason for an operation failure.

Returns:



17857
17858
17859
17860
17861
17862
17863
17864
17865
17866
17867
17868
17869
17870
17871
17872
17873
17874
# File 'lib/aws-sdk-sagemaker/types.rb', line 17857

class DescribePartnerAppResponse < Struct.new(
  :arn,
  :name,
  :type,
  :status,
  :creation_time,
  :execution_role_arn,
  :base_url,
  :maintenance_config,
  :tier,
  :version,
  :application_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#execution_role_arnString

The ARN of the IAM role associated with the SageMaker Partner AI App.

Returns:

  • (String)


17857
17858
17859
17860
17861
17862
17863
17864
17865
17866
17867
17868
17869
17870
17871
17872
17873
17874
# File 'lib/aws-sdk-sagemaker/types.rb', line 17857

class DescribePartnerAppResponse < Struct.new(
  :arn,
  :name,
  :type,
  :status,
  :creation_time,
  :execution_role_arn,
  :base_url,
  :maintenance_config,
  :tier,
  :version,
  :application_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#maintenance_configTypes::PartnerAppMaintenanceConfig

Maintenance configuration settings for the SageMaker Partner AI App.



17857
17858
17859
17860
17861
17862
17863
17864
17865
17866
17867
17868
17869
17870
17871
17872
17873
17874
# File 'lib/aws-sdk-sagemaker/types.rb', line 17857

class DescribePartnerAppResponse < Struct.new(
  :arn,
  :name,
  :type,
  :status,
  :creation_time,
  :execution_role_arn,
  :base_url,
  :maintenance_config,
  :tier,
  :version,
  :application_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the SageMaker Partner AI App.

Returns:

  • (String)


17857
17858
17859
17860
17861
17862
17863
17864
17865
17866
17867
17868
17869
17870
17871
17872
17873
17874
# File 'lib/aws-sdk-sagemaker/types.rb', line 17857

class DescribePartnerAppResponse < Struct.new(
  :arn,
  :name,
  :type,
  :status,
  :creation_time,
  :execution_role_arn,
  :base_url,
  :maintenance_config,
  :tier,
  :version,
  :application_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the SageMaker Partner AI App.

Returns:

  • (String)


17857
17858
17859
17860
17861
17862
17863
17864
17865
17866
17867
17868
17869
17870
17871
17872
17873
17874
# File 'lib/aws-sdk-sagemaker/types.rb', line 17857

class DescribePartnerAppResponse < Struct.new(
  :arn,
  :name,
  :type,
  :status,
  :creation_time,
  :execution_role_arn,
  :base_url,
  :maintenance_config,
  :tier,
  :version,
  :application_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#tierString

The instance type and size of the cluster attached to the SageMaker Partner AI App.

Returns:

  • (String)


17857
17858
17859
17860
17861
17862
17863
17864
17865
17866
17867
17868
17869
17870
17871
17872
17873
17874
# File 'lib/aws-sdk-sagemaker/types.rb', line 17857

class DescribePartnerAppResponse < Struct.new(
  :arn,
  :name,
  :type,
  :status,
  :creation_time,
  :execution_role_arn,
  :base_url,
  :maintenance_config,
  :tier,
  :version,
  :application_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of SageMaker Partner AI App. Must be one of the following: lakera-guard, comet, deepchecks-llm-evaluation, or fiddler.

Returns:

  • (String)


17857
17858
17859
17860
17861
17862
17863
17864
17865
17866
17867
17868
17869
17870
17871
17872
17873
17874
# File 'lib/aws-sdk-sagemaker/types.rb', line 17857

class DescribePartnerAppResponse < Struct.new(
  :arn,
  :name,
  :type,
  :status,
  :creation_time,
  :execution_role_arn,
  :base_url,
  :maintenance_config,
  :tier,
  :version,
  :application_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#versionString

The version of the SageMaker Partner AI App.

Returns:

  • (String)


17857
17858
17859
17860
17861
17862
17863
17864
17865
17866
17867
17868
17869
17870
17871
17872
17873
17874
# File 'lib/aws-sdk-sagemaker/types.rb', line 17857

class DescribePartnerAppResponse < Struct.new(
  :arn,
  :name,
  :type,
  :status,
  :creation_time,
  :execution_role_arn,
  :base_url,
  :maintenance_config,
  :tier,
  :version,
  :application_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :error)
  SENSITIVE = []
  include Aws::Structure
end