Class: Aws::SageMaker::Types::DescribePipelineExecutionResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_by ⇒ Types::UserContext

Information about the user who created or modified a SageMaker resource.

Returns:



23296
23297
23298
23299
23300
23301
23302
23303
23304
23305
23306
23307
23308
23309
23310
23311
23312
23313
23314
# File 'lib/aws-sdk-sagemaker/types.rb', line 23296

class DescribePipelineExecutionResponse < Struct.new(
  :pipeline_arn,
  :pipeline_execution_arn,
  :pipeline_execution_display_name,
  :pipeline_execution_status,
  :pipeline_execution_description,
  :pipeline_experiment_config,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :created_by,
  :last_modified_by,
  :parallelism_configuration,
  :selective_execution_config,
  :pipeline_version_id,
  :m_lflow_config)
  SENSITIVE = []
  include Aws::Structure
end

#creation_time ⇒ Time

The time when the pipeline execution was created.

Returns:

  • (Time)


23296
23297
23298
23299
23300
23301
23302
23303
23304
23305
23306
23307
23308
23309
23310
23311
23312
23313
23314
# File 'lib/aws-sdk-sagemaker/types.rb', line 23296

class DescribePipelineExecutionResponse < Struct.new(
  :pipeline_arn,
  :pipeline_execution_arn,
  :pipeline_execution_display_name,
  :pipeline_execution_status,
  :pipeline_execution_description,
  :pipeline_experiment_config,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :created_by,
  :last_modified_by,
  :parallelism_configuration,
  :selective_execution_config,
  :pipeline_version_id,
  :m_lflow_config)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reason ⇒ String

If the execution failed, a message describing why.

Returns:

  • (String)


23296
23297
23298
23299
23300
23301
23302
23303
23304
23305
23306
23307
23308
23309
23310
23311
23312
23313
23314
# File 'lib/aws-sdk-sagemaker/types.rb', line 23296

class DescribePipelineExecutionResponse < Struct.new(
  :pipeline_arn,
  :pipeline_execution_arn,
  :pipeline_execution_display_name,
  :pipeline_execution_status,
  :pipeline_execution_description,
  :pipeline_experiment_config,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :created_by,
  :last_modified_by,
  :parallelism_configuration,
  :selective_execution_config,
  :pipeline_version_id,
  :m_lflow_config)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_by ⇒ Types::UserContext

Information about the user who created or modified a SageMaker resource.

Returns:



23296
23297
23298
23299
23300
23301
23302
23303
23304
23305
23306
23307
23308
23309
23310
23311
23312
23313
23314
# File 'lib/aws-sdk-sagemaker/types.rb', line 23296

class DescribePipelineExecutionResponse < Struct.new(
  :pipeline_arn,
  :pipeline_execution_arn,
  :pipeline_execution_display_name,
  :pipeline_execution_status,
  :pipeline_execution_description,
  :pipeline_experiment_config,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :created_by,
  :last_modified_by,
  :parallelism_configuration,
  :selective_execution_config,
  :pipeline_version_id,
  :m_lflow_config)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_time ⇒ Time

The time when the pipeline execution was modified last.

Returns:

  • (Time)


23296
23297
23298
23299
23300
23301
23302
23303
23304
23305
23306
23307
23308
23309
23310
23311
23312
23313
23314
# File 'lib/aws-sdk-sagemaker/types.rb', line 23296

class DescribePipelineExecutionResponse < Struct.new(
  :pipeline_arn,
  :pipeline_execution_arn,
  :pipeline_execution_display_name,
  :pipeline_execution_status,
  :pipeline_execution_description,
  :pipeline_experiment_config,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :created_by,
  :last_modified_by,
  :parallelism_configuration,
  :selective_execution_config,
  :pipeline_version_id,
  :m_lflow_config)
  SENSITIVE = []
  include Aws::Structure
end

#m_lflow_config ⇒ Types::MLflowConfiguration

The MLflow configuration of the pipeline execution.



23296
23297
23298
23299
23300
23301
23302
23303
23304
23305
23306
23307
23308
23309
23310
23311
23312
23313
23314
# File 'lib/aws-sdk-sagemaker/types.rb', line 23296

class DescribePipelineExecutionResponse < Struct.new(
  :pipeline_arn,
  :pipeline_execution_arn,
  :pipeline_execution_display_name,
  :pipeline_execution_status,
  :pipeline_execution_description,
  :pipeline_experiment_config,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :created_by,
  :last_modified_by,
  :parallelism_configuration,
  :selective_execution_config,
  :pipeline_version_id,
  :m_lflow_config)
  SENSITIVE = []
  include Aws::Structure
end

#parallelism_configuration ⇒ Types::ParallelismConfiguration

The parallelism configuration applied to the pipeline.



23296
23297
23298
23299
23300
23301
23302
23303
23304
23305
23306
23307
23308
23309
23310
23311
23312
23313
23314
# File 'lib/aws-sdk-sagemaker/types.rb', line 23296

class DescribePipelineExecutionResponse < Struct.new(
  :pipeline_arn,
  :pipeline_execution_arn,
  :pipeline_execution_display_name,
  :pipeline_execution_status,
  :pipeline_execution_description,
  :pipeline_experiment_config,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :created_by,
  :last_modified_by,
  :parallelism_configuration,
  :selective_execution_config,
  :pipeline_version_id,
  :m_lflow_config)
  SENSITIVE = []
  include Aws::Structure
end

#pipeline_arn ⇒ String

The Amazon Resource Name (ARN) of the pipeline.

Returns:

  • (String)


23296
23297
23298
23299
23300
23301
23302
23303
23304
23305
23306
23307
23308
23309
23310
23311
23312
23313
23314
# File 'lib/aws-sdk-sagemaker/types.rb', line 23296

class DescribePipelineExecutionResponse < Struct.new(
  :pipeline_arn,
  :pipeline_execution_arn,
  :pipeline_execution_display_name,
  :pipeline_execution_status,
  :pipeline_execution_description,
  :pipeline_experiment_config,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :created_by,
  :last_modified_by,
  :parallelism_configuration,
  :selective_execution_config,
  :pipeline_version_id,
  :m_lflow_config)
  SENSITIVE = []
  include Aws::Structure
end

#pipeline_execution_arn ⇒ String

The Amazon Resource Name (ARN) of the pipeline execution.

Returns:

  • (String)


23296
23297
23298
23299
23300
23301
23302
23303
23304
23305
23306
23307
23308
23309
23310
23311
23312
23313
23314
# File 'lib/aws-sdk-sagemaker/types.rb', line 23296

class DescribePipelineExecutionResponse < Struct.new(
  :pipeline_arn,
  :pipeline_execution_arn,
  :pipeline_execution_display_name,
  :pipeline_execution_status,
  :pipeline_execution_description,
  :pipeline_experiment_config,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :created_by,
  :last_modified_by,
  :parallelism_configuration,
  :selective_execution_config,
  :pipeline_version_id,
  :m_lflow_config)
  SENSITIVE = []
  include Aws::Structure
end

#pipeline_execution_description ⇒ String

The description of the pipeline execution.

Returns:

  • (String)


23296
23297
23298
23299
23300
23301
23302
23303
23304
23305
23306
23307
23308
23309
23310
23311
23312
23313
23314
# File 'lib/aws-sdk-sagemaker/types.rb', line 23296

class DescribePipelineExecutionResponse < Struct.new(
  :pipeline_arn,
  :pipeline_execution_arn,
  :pipeline_execution_display_name,
  :pipeline_execution_status,
  :pipeline_execution_description,
  :pipeline_experiment_config,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :created_by,
  :last_modified_by,
  :parallelism_configuration,
  :selective_execution_config,
  :pipeline_version_id,
  :m_lflow_config)
  SENSITIVE = []
  include Aws::Structure
end

#pipeline_execution_display_name ⇒ String

The display name of the pipeline execution.

Returns:

  • (String)


23296
23297
23298
23299
23300
23301
23302
23303
23304
23305
23306
23307
23308
23309
23310
23311
23312
23313
23314
# File 'lib/aws-sdk-sagemaker/types.rb', line 23296

class DescribePipelineExecutionResponse < Struct.new(
  :pipeline_arn,
  :pipeline_execution_arn,
  :pipeline_execution_display_name,
  :pipeline_execution_status,
  :pipeline_execution_description,
  :pipeline_experiment_config,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :created_by,
  :last_modified_by,
  :parallelism_configuration,
  :selective_execution_config,
  :pipeline_version_id,
  :m_lflow_config)
  SENSITIVE = []
  include Aws::Structure
end

#pipeline_execution_status ⇒ String

The status of the pipeline execution.

Returns:

  • (String)


23296
23297
23298
23299
23300
23301
23302
23303
23304
23305
23306
23307
23308
23309
23310
23311
23312
23313
23314
# File 'lib/aws-sdk-sagemaker/types.rb', line 23296

class DescribePipelineExecutionResponse < Struct.new(
  :pipeline_arn,
  :pipeline_execution_arn,
  :pipeline_execution_display_name,
  :pipeline_execution_status,
  :pipeline_execution_description,
  :pipeline_experiment_config,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :created_by,
  :last_modified_by,
  :parallelism_configuration,
  :selective_execution_config,
  :pipeline_version_id,
  :m_lflow_config)
  SENSITIVE = []
  include Aws::Structure
end

#pipeline_experiment_config ⇒ Types::PipelineExperimentConfig

Specifies the names of the experiment and trial created by a pipeline.



23296
23297
23298
23299
23300
23301
23302
23303
23304
23305
23306
23307
23308
23309
23310
23311
23312
23313
23314
# File 'lib/aws-sdk-sagemaker/types.rb', line 23296

class DescribePipelineExecutionResponse < Struct.new(
  :pipeline_arn,
  :pipeline_execution_arn,
  :pipeline_execution_display_name,
  :pipeline_execution_status,
  :pipeline_execution_description,
  :pipeline_experiment_config,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :created_by,
  :last_modified_by,
  :parallelism_configuration,
  :selective_execution_config,
  :pipeline_version_id,
  :m_lflow_config)
  SENSITIVE = []
  include Aws::Structure
end

#pipeline_version_id ⇒ Integer

The ID of the pipeline version.

Returns:

  • (Integer)


23296
23297
23298
23299
23300
23301
23302
23303
23304
23305
23306
23307
23308
23309
23310
23311
23312
23313
23314
# File 'lib/aws-sdk-sagemaker/types.rb', line 23296

class DescribePipelineExecutionResponse < Struct.new(
  :pipeline_arn,
  :pipeline_execution_arn,
  :pipeline_execution_display_name,
  :pipeline_execution_status,
  :pipeline_execution_description,
  :pipeline_experiment_config,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :created_by,
  :last_modified_by,
  :parallelism_configuration,
  :selective_execution_config,
  :pipeline_version_id,
  :m_lflow_config)
  SENSITIVE = []
  include Aws::Structure
end

#selective_execution_config ⇒ Types::SelectiveExecutionConfig

The selective execution configuration applied to the pipeline run.



23296
23297
23298
23299
23300
23301
23302
23303
23304
23305
23306
23307
23308
23309
23310
23311
23312
23313
23314
# File 'lib/aws-sdk-sagemaker/types.rb', line 23296

class DescribePipelineExecutionResponse < Struct.new(
  :pipeline_arn,
  :pipeline_execution_arn,
  :pipeline_execution_display_name,
  :pipeline_execution_status,
  :pipeline_execution_description,
  :pipeline_experiment_config,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :created_by,
  :last_modified_by,
  :parallelism_configuration,
  :selective_execution_config,
  :pipeline_version_id,
  :m_lflow_config)
  SENSITIVE = []
  include Aws::Structure
end