Class: Aws::SageMaker::Types::DescribeProjectOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeProjectOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_by ⇒ Types::UserContext
Information about the user who created or modified an experiment, trial, trial component, lineage group, project, or model card.
-
#creation_time ⇒ Time
The time when the project was created.
-
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified an experiment, trial, trial component, lineage group, project, or model card.
-
#last_modified_time ⇒ Time
The timestamp when project was last modified.
-
#project_arn ⇒ String
The Amazon Resource Name (ARN) of the project.
-
#project_description ⇒ String
The description of the project.
-
#project_id ⇒ String
The ID of the project.
-
#project_name ⇒ String
The name of the project.
-
#project_status ⇒ String
The status of the project.
-
#service_catalog_provisioned_product_details ⇒ Types::ServiceCatalogProvisionedProductDetails
Information about a provisioned service catalog product.
-
#service_catalog_provisioning_details ⇒ Types::ServiceCatalogProvisioningDetails
Information used to provision a service catalog product.
Instance Attribute Details
#created_by ⇒ Types::UserContext
Information about the user who created or modified an experiment, trial, trial component, lineage group, project, or model card.
18264 18265 18266 18267 18268 18269 18270 18271 18272 18273 18274 18275 18276 18277 18278 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18264 class DescribeProjectOutput < Struct.new( :project_arn, :project_name, :project_id, :project_description, :service_catalog_provisioning_details, :service_catalog_provisioned_product_details, :project_status, :created_by, :creation_time, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The time when the project was created.
18264 18265 18266 18267 18268 18269 18270 18271 18272 18273 18274 18275 18276 18277 18278 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18264 class DescribeProjectOutput < Struct.new( :project_arn, :project_name, :project_id, :project_description, :service_catalog_provisioning_details, :service_catalog_provisioned_product_details, :project_status, :created_by, :creation_time, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified an experiment, trial, trial component, lineage group, project, or model card.
18264 18265 18266 18267 18268 18269 18270 18271 18272 18273 18274 18275 18276 18277 18278 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18264 class DescribeProjectOutput < Struct.new( :project_arn, :project_name, :project_id, :project_description, :service_catalog_provisioning_details, :service_catalog_provisioned_product_details, :project_status, :created_by, :creation_time, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp when project was last modified.
18264 18265 18266 18267 18268 18269 18270 18271 18272 18273 18274 18275 18276 18277 18278 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18264 class DescribeProjectOutput < Struct.new( :project_arn, :project_name, :project_id, :project_description, :service_catalog_provisioning_details, :service_catalog_provisioned_product_details, :project_status, :created_by, :creation_time, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#project_arn ⇒ String
The Amazon Resource Name (ARN) of the project.
18264 18265 18266 18267 18268 18269 18270 18271 18272 18273 18274 18275 18276 18277 18278 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18264 class DescribeProjectOutput < Struct.new( :project_arn, :project_name, :project_id, :project_description, :service_catalog_provisioning_details, :service_catalog_provisioned_product_details, :project_status, :created_by, :creation_time, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#project_description ⇒ String
The description of the project.
18264 18265 18266 18267 18268 18269 18270 18271 18272 18273 18274 18275 18276 18277 18278 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18264 class DescribeProjectOutput < Struct.new( :project_arn, :project_name, :project_id, :project_description, :service_catalog_provisioning_details, :service_catalog_provisioned_product_details, :project_status, :created_by, :creation_time, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#project_id ⇒ String
The ID of the project.
18264 18265 18266 18267 18268 18269 18270 18271 18272 18273 18274 18275 18276 18277 18278 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18264 class DescribeProjectOutput < Struct.new( :project_arn, :project_name, :project_id, :project_description, :service_catalog_provisioning_details, :service_catalog_provisioned_product_details, :project_status, :created_by, :creation_time, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#project_name ⇒ String
The name of the project.
18264 18265 18266 18267 18268 18269 18270 18271 18272 18273 18274 18275 18276 18277 18278 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18264 class DescribeProjectOutput < Struct.new( :project_arn, :project_name, :project_id, :project_description, :service_catalog_provisioning_details, :service_catalog_provisioned_product_details, :project_status, :created_by, :creation_time, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#project_status ⇒ String
The status of the project.
18264 18265 18266 18267 18268 18269 18270 18271 18272 18273 18274 18275 18276 18277 18278 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18264 class DescribeProjectOutput < Struct.new( :project_arn, :project_name, :project_id, :project_description, :service_catalog_provisioning_details, :service_catalog_provisioned_product_details, :project_status, :created_by, :creation_time, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#service_catalog_provisioned_product_details ⇒ Types::ServiceCatalogProvisionedProductDetails
Information about a provisioned service catalog product.
18264 18265 18266 18267 18268 18269 18270 18271 18272 18273 18274 18275 18276 18277 18278 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18264 class DescribeProjectOutput < Struct.new( :project_arn, :project_name, :project_id, :project_description, :service_catalog_provisioning_details, :service_catalog_provisioned_product_details, :project_status, :created_by, :creation_time, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#service_catalog_provisioning_details ⇒ Types::ServiceCatalogProvisioningDetails
Information used to provision a service catalog product. For information, see [What is Amazon Web Services Service Catalog].
[1]: docs.aws.amazon.com/servicecatalog/latest/adminguide/introduction.html
18264 18265 18266 18267 18268 18269 18270 18271 18272 18273 18274 18275 18276 18277 18278 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18264 class DescribeProjectOutput < Struct.new( :project_arn, :project_name, :project_id, :project_description, :service_catalog_provisioning_details, :service_catalog_provisioned_product_details, :project_status, :created_by, :creation_time, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |