Class: Aws::SageMaker::Types::DescribeTransformJobResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_ml_job_arnString

The Amazon Resource Name (ARN) of the AutoML transform job.

Returns:



22284
22285
22286
22287
22288
22289
22290
22291
22292
22293
22294
22295
22296
22297
22298
22299
22300
22301
22302
22303
22304
22305
22306
22307
22308
# File 'lib/aws-sdk-sagemaker/types.rb', line 22284

class DescribeTransformJobResponse < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :transform_job_status,
  :failure_reason,
  :model_name,
  :max_concurrent_transforms,
  :model_client_config,
  :max_payload_in_mb,
  :batch_strategy,
  :environment,
  :transform_input,
  :transform_output,
  :data_capture_config,
  :transform_resources,
  :creation_time,
  :transform_start_time,
  :transform_end_time,
  :labeling_job_arn,
  :auto_ml_job_arn,
  :data_processing,
  :experiment_config)
  SENSITIVE = []
  include Aws::Structure
end

#batch_strategyString

Specifies the number of records to include in a mini-batch for an HTTP inference request. A record ** is a single unit of input data that inference can be made on. For example, a single line in a CSV file is a record.

To enable the batch strategy, you must set SplitType to Line, RecordIO, or TFRecord.

Returns:



22284
22285
22286
22287
22288
22289
22290
22291
22292
22293
22294
22295
22296
22297
22298
22299
22300
22301
22302
22303
22304
22305
22306
22307
22308
# File 'lib/aws-sdk-sagemaker/types.rb', line 22284

class DescribeTransformJobResponse < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :transform_job_status,
  :failure_reason,
  :model_name,
  :max_concurrent_transforms,
  :model_client_config,
  :max_payload_in_mb,
  :batch_strategy,
  :environment,
  :transform_input,
  :transform_output,
  :data_capture_config,
  :transform_resources,
  :creation_time,
  :transform_start_time,
  :transform_end_time,
  :labeling_job_arn,
  :auto_ml_job_arn,
  :data_processing,
  :experiment_config)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

A timestamp that shows when the transform Job was created.

Returns:



22284
22285
22286
22287
22288
22289
22290
22291
22292
22293
22294
22295
22296
22297
22298
22299
22300
22301
22302
22303
22304
22305
22306
22307
22308
# File 'lib/aws-sdk-sagemaker/types.rb', line 22284

class DescribeTransformJobResponse < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :transform_job_status,
  :failure_reason,
  :model_name,
  :max_concurrent_transforms,
  :model_client_config,
  :max_payload_in_mb,
  :batch_strategy,
  :environment,
  :transform_input,
  :transform_output,
  :data_capture_config,
  :transform_resources,
  :creation_time,
  :transform_start_time,
  :transform_end_time,
  :labeling_job_arn,
  :auto_ml_job_arn,
  :data_processing,
  :experiment_config)
  SENSITIVE = []
  include Aws::Structure
end

#data_capture_configTypes::BatchDataCaptureConfig

Configuration to control how SageMaker captures inference data.

Returns:



22284
22285
22286
22287
22288
22289
22290
22291
22292
22293
22294
22295
22296
22297
22298
22299
22300
22301
22302
22303
22304
22305
22306
22307
22308
# File 'lib/aws-sdk-sagemaker/types.rb', line 22284

class DescribeTransformJobResponse < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :transform_job_status,
  :failure_reason,
  :model_name,
  :max_concurrent_transforms,
  :model_client_config,
  :max_payload_in_mb,
  :batch_strategy,
  :environment,
  :transform_input,
  :transform_output,
  :data_capture_config,
  :transform_resources,
  :creation_time,
  :transform_start_time,
  :transform_end_time,
  :labeling_job_arn,
  :auto_ml_job_arn,
  :data_processing,
  :experiment_config)
  SENSITIVE = []
  include Aws::Structure
end

#data_processingTypes::DataProcessing

The data structure used to specify the data to be used for inference in a batch transform job and to associate the data that is relevant to the prediction results in the output. The input filter provided allows you to exclude input data that is not needed for inference in a batch transform job. The output filter provided allows you to include input data relevant to interpreting the predictions in the output from the job. For more information, see [Associate Prediction Results with their Corresponding Input Records].

[1]: docs.aws.amazon.com/sagemaker/latest/dg/batch-transform-data-processing.html

Returns:



22284
22285
22286
22287
22288
22289
22290
22291
22292
22293
22294
22295
22296
22297
22298
22299
22300
22301
22302
22303
22304
22305
22306
22307
22308
# File 'lib/aws-sdk-sagemaker/types.rb', line 22284

class DescribeTransformJobResponse < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :transform_job_status,
  :failure_reason,
  :model_name,
  :max_concurrent_transforms,
  :model_client_config,
  :max_payload_in_mb,
  :batch_strategy,
  :environment,
  :transform_input,
  :transform_output,
  :data_capture_config,
  :transform_resources,
  :creation_time,
  :transform_start_time,
  :transform_end_time,
  :labeling_job_arn,
  :auto_ml_job_arn,
  :data_processing,
  :experiment_config)
  SENSITIVE = []
  include Aws::Structure
end

#environmentHash<String,String>

The environment variables to set in the Docker container. We support up to 16 key and values entries in the map.

Returns:



22284
22285
22286
22287
22288
22289
22290
22291
22292
22293
22294
22295
22296
22297
22298
22299
22300
22301
22302
22303
22304
22305
22306
22307
22308
# File 'lib/aws-sdk-sagemaker/types.rb', line 22284

class DescribeTransformJobResponse < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :transform_job_status,
  :failure_reason,
  :model_name,
  :max_concurrent_transforms,
  :model_client_config,
  :max_payload_in_mb,
  :batch_strategy,
  :environment,
  :transform_input,
  :transform_output,
  :data_capture_config,
  :transform_resources,
  :creation_time,
  :transform_start_time,
  :transform_end_time,
  :labeling_job_arn,
  :auto_ml_job_arn,
  :data_processing,
  :experiment_config)
  SENSITIVE = []
  include Aws::Structure
end

#experiment_configTypes::ExperimentConfig

Associates a SageMaker job as a trial component with an experiment and trial. Specified when you call the following APIs:

  • CreateProcessingJob][1
  • CreateTrainingJob][2
  • CreateTransformJob][3

[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateProcessingJob.html [2]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateTrainingJob.html [3]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateTransformJob.html

Returns:



22284
22285
22286
22287
22288
22289
22290
22291
22292
22293
22294
22295
22296
22297
22298
22299
22300
22301
22302
22303
22304
22305
22306
22307
22308
# File 'lib/aws-sdk-sagemaker/types.rb', line 22284

class DescribeTransformJobResponse < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :transform_job_status,
  :failure_reason,
  :model_name,
  :max_concurrent_transforms,
  :model_client_config,
  :max_payload_in_mb,
  :batch_strategy,
  :environment,
  :transform_input,
  :transform_output,
  :data_capture_config,
  :transform_resources,
  :creation_time,
  :transform_start_time,
  :transform_end_time,
  :labeling_job_arn,
  :auto_ml_job_arn,
  :data_processing,
  :experiment_config)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

If the transform job failed, FailureReason describes why it failed. A transform job creates a log file, which includes error messages, and stores it as an Amazon S3 object. For more information, see [Log Amazon SageMaker Events with Amazon CloudWatch].

[1]: docs.aws.amazon.com/sagemaker/latest/dg/logging-cloudwatch.html

Returns:



22284
22285
22286
22287
22288
22289
22290
22291
22292
22293
22294
22295
22296
22297
22298
22299
22300
22301
22302
22303
22304
22305
22306
22307
22308
# File 'lib/aws-sdk-sagemaker/types.rb', line 22284

class DescribeTransformJobResponse < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :transform_job_status,
  :failure_reason,
  :model_name,
  :max_concurrent_transforms,
  :model_client_config,
  :max_payload_in_mb,
  :batch_strategy,
  :environment,
  :transform_input,
  :transform_output,
  :data_capture_config,
  :transform_resources,
  :creation_time,
  :transform_start_time,
  :transform_end_time,
  :labeling_job_arn,
  :auto_ml_job_arn,
  :data_processing,
  :experiment_config)
  SENSITIVE = []
  include Aws::Structure
end

#labeling_job_arnString

The Amazon Resource Name (ARN) of the Amazon SageMaker Ground Truth labeling job that created the transform or training job.

Returns:



22284
22285
22286
22287
22288
22289
22290
22291
22292
22293
22294
22295
22296
22297
22298
22299
22300
22301
22302
22303
22304
22305
22306
22307
22308
# File 'lib/aws-sdk-sagemaker/types.rb', line 22284

class DescribeTransformJobResponse < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :transform_job_status,
  :failure_reason,
  :model_name,
  :max_concurrent_transforms,
  :model_client_config,
  :max_payload_in_mb,
  :batch_strategy,
  :environment,
  :transform_input,
  :transform_output,
  :data_capture_config,
  :transform_resources,
  :creation_time,
  :transform_start_time,
  :transform_end_time,
  :labeling_job_arn,
  :auto_ml_job_arn,
  :data_processing,
  :experiment_config)
  SENSITIVE = []
  include Aws::Structure
end

#max_concurrent_transformsInteger

The maximum number of parallel requests on each instance node that can be launched in a transform job. The default value is 1.

Returns:



22284
22285
22286
22287
22288
22289
22290
22291
22292
22293
22294
22295
22296
22297
22298
22299
22300
22301
22302
22303
22304
22305
22306
22307
22308
# File 'lib/aws-sdk-sagemaker/types.rb', line 22284

class DescribeTransformJobResponse < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :transform_job_status,
  :failure_reason,
  :model_name,
  :max_concurrent_transforms,
  :model_client_config,
  :max_payload_in_mb,
  :batch_strategy,
  :environment,
  :transform_input,
  :transform_output,
  :data_capture_config,
  :transform_resources,
  :creation_time,
  :transform_start_time,
  :transform_end_time,
  :labeling_job_arn,
  :auto_ml_job_arn,
  :data_processing,
  :experiment_config)
  SENSITIVE = []
  include Aws::Structure
end

#max_payload_in_mbInteger

The maximum payload size, in MB, used in the transform job.

Returns:



22284
22285
22286
22287
22288
22289
22290
22291
22292
22293
22294
22295
22296
22297
22298
22299
22300
22301
22302
22303
22304
22305
22306
22307
22308
# File 'lib/aws-sdk-sagemaker/types.rb', line 22284

class DescribeTransformJobResponse < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :transform_job_status,
  :failure_reason,
  :model_name,
  :max_concurrent_transforms,
  :model_client_config,
  :max_payload_in_mb,
  :batch_strategy,
  :environment,
  :transform_input,
  :transform_output,
  :data_capture_config,
  :transform_resources,
  :creation_time,
  :transform_start_time,
  :transform_end_time,
  :labeling_job_arn,
  :auto_ml_job_arn,
  :data_processing,
  :experiment_config)
  SENSITIVE = []
  include Aws::Structure
end

#model_client_configTypes::ModelClientConfig

The timeout and maximum number of retries for processing a transform job invocation.

Returns:



22284
22285
22286
22287
22288
22289
22290
22291
22292
22293
22294
22295
22296
22297
22298
22299
22300
22301
22302
22303
22304
22305
22306
22307
22308
# File 'lib/aws-sdk-sagemaker/types.rb', line 22284

class DescribeTransformJobResponse < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :transform_job_status,
  :failure_reason,
  :model_name,
  :max_concurrent_transforms,
  :model_client_config,
  :max_payload_in_mb,
  :batch_strategy,
  :environment,
  :transform_input,
  :transform_output,
  :data_capture_config,
  :transform_resources,
  :creation_time,
  :transform_start_time,
  :transform_end_time,
  :labeling_job_arn,
  :auto_ml_job_arn,
  :data_processing,
  :experiment_config)
  SENSITIVE = []
  include Aws::Structure
end

#model_nameString

The name of the model used in the transform job.

Returns:



22284
22285
22286
22287
22288
22289
22290
22291
22292
22293
22294
22295
22296
22297
22298
22299
22300
22301
22302
22303
22304
22305
22306
22307
22308
# File 'lib/aws-sdk-sagemaker/types.rb', line 22284

class DescribeTransformJobResponse < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :transform_job_status,
  :failure_reason,
  :model_name,
  :max_concurrent_transforms,
  :model_client_config,
  :max_payload_in_mb,
  :batch_strategy,
  :environment,
  :transform_input,
  :transform_output,
  :data_capture_config,
  :transform_resources,
  :creation_time,
  :transform_start_time,
  :transform_end_time,
  :labeling_job_arn,
  :auto_ml_job_arn,
  :data_processing,
  :experiment_config)
  SENSITIVE = []
  include Aws::Structure
end

#transform_end_timeTime

Indicates when the transform job has been completed, or has stopped or failed. You are billed for the time interval between this time and the value of TransformStartTime.

Returns:



22284
22285
22286
22287
22288
22289
22290
22291
22292
22293
22294
22295
22296
22297
22298
22299
22300
22301
22302
22303
22304
22305
22306
22307
22308
# File 'lib/aws-sdk-sagemaker/types.rb', line 22284

class DescribeTransformJobResponse < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :transform_job_status,
  :failure_reason,
  :model_name,
  :max_concurrent_transforms,
  :model_client_config,
  :max_payload_in_mb,
  :batch_strategy,
  :environment,
  :transform_input,
  :transform_output,
  :data_capture_config,
  :transform_resources,
  :creation_time,
  :transform_start_time,
  :transform_end_time,
  :labeling_job_arn,
  :auto_ml_job_arn,
  :data_processing,
  :experiment_config)
  SENSITIVE = []
  include Aws::Structure
end

#transform_inputTypes::TransformInput

Describes the dataset to be transformed and the Amazon S3 location where it is stored.

Returns:



22284
22285
22286
22287
22288
22289
22290
22291
22292
22293
22294
22295
22296
22297
22298
22299
22300
22301
22302
22303
22304
22305
22306
22307
22308
# File 'lib/aws-sdk-sagemaker/types.rb', line 22284

class DescribeTransformJobResponse < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :transform_job_status,
  :failure_reason,
  :model_name,
  :max_concurrent_transforms,
  :model_client_config,
  :max_payload_in_mb,
  :batch_strategy,
  :environment,
  :transform_input,
  :transform_output,
  :data_capture_config,
  :transform_resources,
  :creation_time,
  :transform_start_time,
  :transform_end_time,
  :labeling_job_arn,
  :auto_ml_job_arn,
  :data_processing,
  :experiment_config)
  SENSITIVE = []
  include Aws::Structure
end

#transform_job_arnString

The Amazon Resource Name (ARN) of the transform job.

Returns:



22284
22285
22286
22287
22288
22289
22290
22291
22292
22293
22294
22295
22296
22297
22298
22299
22300
22301
22302
22303
22304
22305
22306
22307
22308
# File 'lib/aws-sdk-sagemaker/types.rb', line 22284

class DescribeTransformJobResponse < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :transform_job_status,
  :failure_reason,
  :model_name,
  :max_concurrent_transforms,
  :model_client_config,
  :max_payload_in_mb,
  :batch_strategy,
  :environment,
  :transform_input,
  :transform_output,
  :data_capture_config,
  :transform_resources,
  :creation_time,
  :transform_start_time,
  :transform_end_time,
  :labeling_job_arn,
  :auto_ml_job_arn,
  :data_processing,
  :experiment_config)
  SENSITIVE = []
  include Aws::Structure
end

#transform_job_nameString

The name of the transform job.

Returns:



22284
22285
22286
22287
22288
22289
22290
22291
22292
22293
22294
22295
22296
22297
22298
22299
22300
22301
22302
22303
22304
22305
22306
22307
22308
# File 'lib/aws-sdk-sagemaker/types.rb', line 22284

class DescribeTransformJobResponse < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :transform_job_status,
  :failure_reason,
  :model_name,
  :max_concurrent_transforms,
  :model_client_config,
  :max_payload_in_mb,
  :batch_strategy,
  :environment,
  :transform_input,
  :transform_output,
  :data_capture_config,
  :transform_resources,
  :creation_time,
  :transform_start_time,
  :transform_end_time,
  :labeling_job_arn,
  :auto_ml_job_arn,
  :data_processing,
  :experiment_config)
  SENSITIVE = []
  include Aws::Structure
end

#transform_job_statusString

The status of the transform job. If the transform job failed, the reason is returned in the FailureReason field.

Returns:



22284
22285
22286
22287
22288
22289
22290
22291
22292
22293
22294
22295
22296
22297
22298
22299
22300
22301
22302
22303
22304
22305
22306
22307
22308
# File 'lib/aws-sdk-sagemaker/types.rb', line 22284

class DescribeTransformJobResponse < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :transform_job_status,
  :failure_reason,
  :model_name,
  :max_concurrent_transforms,
  :model_client_config,
  :max_payload_in_mb,
  :batch_strategy,
  :environment,
  :transform_input,
  :transform_output,
  :data_capture_config,
  :transform_resources,
  :creation_time,
  :transform_start_time,
  :transform_end_time,
  :labeling_job_arn,
  :auto_ml_job_arn,
  :data_processing,
  :experiment_config)
  SENSITIVE = []
  include Aws::Structure
end

#transform_outputTypes::TransformOutput

Identifies the Amazon S3 location where you want Amazon SageMaker to save the results from the transform job.

Returns:



22284
22285
22286
22287
22288
22289
22290
22291
22292
22293
22294
22295
22296
22297
22298
22299
22300
22301
22302
22303
22304
22305
22306
22307
22308
# File 'lib/aws-sdk-sagemaker/types.rb', line 22284

class DescribeTransformJobResponse < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :transform_job_status,
  :failure_reason,
  :model_name,
  :max_concurrent_transforms,
  :model_client_config,
  :max_payload_in_mb,
  :batch_strategy,
  :environment,
  :transform_input,
  :transform_output,
  :data_capture_config,
  :transform_resources,
  :creation_time,
  :transform_start_time,
  :transform_end_time,
  :labeling_job_arn,
  :auto_ml_job_arn,
  :data_processing,
  :experiment_config)
  SENSITIVE = []
  include Aws::Structure
end

#transform_resourcesTypes::TransformResources

Describes the resources, including ML instance types and ML instance count, to use for the transform job.

Returns:



22284
22285
22286
22287
22288
22289
22290
22291
22292
22293
22294
22295
22296
22297
22298
22299
22300
22301
22302
22303
22304
22305
22306
22307
22308
# File 'lib/aws-sdk-sagemaker/types.rb', line 22284

class DescribeTransformJobResponse < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :transform_job_status,
  :failure_reason,
  :model_name,
  :max_concurrent_transforms,
  :model_client_config,
  :max_payload_in_mb,
  :batch_strategy,
  :environment,
  :transform_input,
  :transform_output,
  :data_capture_config,
  :transform_resources,
  :creation_time,
  :transform_start_time,
  :transform_end_time,
  :labeling_job_arn,
  :auto_ml_job_arn,
  :data_processing,
  :experiment_config)
  SENSITIVE = []
  include Aws::Structure
end

#transform_start_timeTime

Indicates when the transform job starts on ML instances. You are billed for the time interval between this time and the value of TransformEndTime.

Returns:



22284
22285
22286
22287
22288
22289
22290
22291
22292
22293
22294
22295
22296
22297
22298
22299
22300
22301
22302
22303
22304
22305
22306
22307
22308
# File 'lib/aws-sdk-sagemaker/types.rb', line 22284

class DescribeTransformJobResponse < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :transform_job_status,
  :failure_reason,
  :model_name,
  :max_concurrent_transforms,
  :model_client_config,
  :max_payload_in_mb,
  :batch_strategy,
  :environment,
  :transform_input,
  :transform_output,
  :data_capture_config,
  :transform_resources,
  :creation_time,
  :transform_start_time,
  :transform_end_time,
  :labeling_job_arn,
  :auto_ml_job_arn,
  :data_processing,
  :experiment_config)
  SENSITIVE = []
  include Aws::Structure
end