Class: Aws::SageMaker::Types::DescribeWorkforceResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#workforceTypes::Workforce

A single private workforce, which is automatically created when you create your first private work team. You can create one private work force in each Amazon Web Services Region. By default, any workforce-related API operation used in a specific region will apply to the workforce created in that region. To learn how to create a private workforce, see Create a Private Workforce.



25007
25008
25009
25010
25011
# File 'lib/aws-sdk-sagemaker/types.rb', line 25007

class DescribeWorkforceResponse < Struct.new(
  :workforce)
  SENSITIVE = []
  include Aws::Structure
end