Class: Aws::SageMaker::Types::DesiredWeightAndCapacity

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Specifies weight and capacity values for a production variant.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#desired_instance_countInteger

The variant's capacity.



25058
25059
25060
25061
25062
25063
25064
25065
# File 'lib/aws-sdk-sagemaker/types.rb', line 25058

class DesiredWeightAndCapacity < Struct.new(
  :variant_name,
  :desired_weight,
  :desired_instance_count,
  :serverless_update_config)
  SENSITIVE = []
  include Aws::Structure
end

#desired_weightFloat

The variant's weight.



25058
25059
25060
25061
25062
25063
25064
25065
# File 'lib/aws-sdk-sagemaker/types.rb', line 25058

class DesiredWeightAndCapacity < Struct.new(
  :variant_name,
  :desired_weight,
  :desired_instance_count,
  :serverless_update_config)
  SENSITIVE = []
  include Aws::Structure
end

#serverless_update_configTypes::ProductionVariantServerlessUpdateConfig

Specifies the serverless update concurrency configuration for an endpoint variant.



25058
25059
25060
25061
25062
25063
25064
25065
# File 'lib/aws-sdk-sagemaker/types.rb', line 25058

class DesiredWeightAndCapacity < Struct.new(
  :variant_name,
  :desired_weight,
  :desired_instance_count,
  :serverless_update_config)
  SENSITIVE = []
  include Aws::Structure
end

#variant_nameString

The name of the variant to update.



25058
25059
25060
25061
25062
25063
25064
25065
# File 'lib/aws-sdk-sagemaker/types.rb', line 25058

class DesiredWeightAndCapacity < Struct.new(
  :variant_name,
  :desired_weight,
  :desired_instance_count,
  :serverless_update_config)
  SENSITIVE = []
  include Aws::Structure
end