Class: Aws::SageMaker::Types::DetachClusterNodeVolumeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DetachClusterNodeVolumeRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster_arn ⇒ String
The Amazon Resource Name (ARN) of your SageMaker HyperPod cluster containing the target node.
-
#node_id ⇒ String
The unique identifier of the cluster node from which you want to detach the volume.
-
#volume_id ⇒ String
The unique identifier of your EBS volume that you want to detach.
Instance Attribute Details
#cluster_arn ⇒ String
The Amazon Resource Name (ARN) of your SageMaker HyperPod cluster
containing the target node. Your cluster must use EKS as the
orchestration and be in the InService state.
25027 25028 25029 25030 25031 25032 25033 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 25027 class DetachClusterNodeVolumeRequest < Struct.new( :cluster_arn, :node_id, :volume_id) SENSITIVE = [] include Aws::Structure end |
#node_id ⇒ String
The unique identifier of the cluster node from which you want to detach the volume.
25027 25028 25029 25030 25031 25032 25033 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 25027 class DetachClusterNodeVolumeRequest < Struct.new( :cluster_arn, :node_id, :volume_id) SENSITIVE = [] include Aws::Structure end |
#volume_id ⇒ String
The unique identifier of your EBS volume that you want to detach. Your volume must be currently attached to the specified node.
25027 25028 25029 25030 25031 25032 25033 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 25027 class DetachClusterNodeVolumeRequest < Struct.new( :cluster_arn, :node_id, :volume_id) SENSITIVE = [] include Aws::Structure end |