Class: Aws::SageMaker::Types::DetachClusterNodeVolumeResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attach_time ⇒ Time

The original timestamp when your volume was initially attached to the node.

Returns:

  • (Time)


25123
25124
25125
25126
25127
25128
25129
25130
25131
25132
# File 'lib/aws-sdk-sagemaker/types.rb', line 25123

class DetachClusterNodeVolumeResponse < Struct.new(
  :cluster_arn,
  :node_id,
  :volume_id,
  :attach_time,
  :status,
  :device_name)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_arn ⇒ String

The Amazon Resource Name (ARN) of your SageMaker HyperPod cluster where the volume detachment operation was performed.

Returns:

  • (String)


25123
25124
25125
25126
25127
25128
25129
25130
25131
25132
# File 'lib/aws-sdk-sagemaker/types.rb', line 25123

class DetachClusterNodeVolumeResponse < Struct.new(
  :cluster_arn,
  :node_id,
  :volume_id,
  :attach_time,
  :status,
  :device_name)
  SENSITIVE = []
  include Aws::Structure
end

#device_name ⇒ String

The device name assigned to your attached volume on the target instance.

Returns:

  • (String)


25123
25124
25125
25126
25127
25128
25129
25130
25131
25132
# File 'lib/aws-sdk-sagemaker/types.rb', line 25123

class DetachClusterNodeVolumeResponse < Struct.new(
  :cluster_arn,
  :node_id,
  :volume_id,
  :attach_time,
  :status,
  :device_name)
  SENSITIVE = []
  include Aws::Structure
end

#node_id ⇒ String

The unique identifier of the cluster node from which your volume was detached.

Returns:

  • (String)


25123
25124
25125
25126
25127
25128
25129
25130
25131
25132
# File 'lib/aws-sdk-sagemaker/types.rb', line 25123

class DetachClusterNodeVolumeResponse < Struct.new(
  :cluster_arn,
  :node_id,
  :volume_id,
  :attach_time,
  :status,
  :device_name)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The current status of your volume detachment operation.

Returns:

  • (String)


25123
25124
25125
25126
25127
25128
25129
25130
25131
25132
# File 'lib/aws-sdk-sagemaker/types.rb', line 25123

class DetachClusterNodeVolumeResponse < Struct.new(
  :cluster_arn,
  :node_id,
  :volume_id,
  :attach_time,
  :status,
  :device_name)
  SENSITIVE = []
  include Aws::Structure
end

#volume_id ⇒ String

The unique identifier of your EBS volume that was detached.

Returns:

  • (String)


25123
25124
25125
25126
25127
25128
25129
25130
25131
25132
# File 'lib/aws-sdk-sagemaker/types.rb', line 25123

class DetachClusterNodeVolumeResponse < Struct.new(
  :cluster_arn,
  :node_id,
  :volume_id,
  :attach_time,
  :status,
  :device_name)
  SENSITIVE = []
  include Aws::Structure
end