Class: Aws::SageMaker::Types::DomainSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DomainSettings
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
A collection of settings that apply to the ‘SageMaker Domain`. These settings are specified through the `CreateDomain` API call.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#amazon_q_settings ⇒ Types::AmazonQSettings
A collection of settings that configure the Amazon Q experience within the domain.
-
#docker_settings ⇒ Types::DockerSettings
A collection of settings that configure the domain’s Docker interaction.
-
#execution_role_identity_config ⇒ String
The configuration for attaching a SageMaker AI user profile name to the execution role as a [sts:SourceIdentity key].
-
#ip_address_type ⇒ String
The IP address type for the domain.
-
#r_studio_server_pro_domain_settings ⇒ Types::RStudioServerProDomainSettings
A collection of settings that configure the ‘RStudioServerPro` Domain-level app.
-
#security_group_ids ⇒ Array<String>
The security groups for the Amazon Virtual Private Cloud that the ‘Domain` uses for communication between Domain-level apps and user apps.
-
#trusted_identity_propagation_settings ⇒ Types::TrustedIdentityPropagationSettings
The Trusted Identity Propagation (TIP) settings for the SageMaker domain.
-
#unified_studio_settings ⇒ Types::UnifiedStudioSettings
The settings that apply to an SageMaker AI domain when you use it in Amazon SageMaker Unified Studio.
Instance Attribute Details
#amazon_q_settings ⇒ Types::AmazonQSettings
A collection of settings that configure the Amazon Q experience within the domain. The ‘AuthMode` that you use to create the domain must be `SSO`.
24711 24712 24713 24714 24715 24716 24717 24718 24719 24720 24721 24722 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 24711 class DomainSettings < Struct.new( :security_group_ids, :r_studio_server_pro_domain_settings, :execution_role_identity_config, :trusted_identity_propagation_settings, :docker_settings, :amazon_q_settings, :unified_studio_settings, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#docker_settings ⇒ Types::DockerSettings
A collection of settings that configure the domain’s Docker interaction.
24711 24712 24713 24714 24715 24716 24717 24718 24719 24720 24721 24722 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 24711 class DomainSettings < Struct.new( :security_group_ids, :r_studio_server_pro_domain_settings, :execution_role_identity_config, :trusted_identity_propagation_settings, :docker_settings, :amazon_q_settings, :unified_studio_settings, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#execution_role_identity_config ⇒ String
The configuration for attaching a SageMaker AI user profile name to the execution role as a [sts:SourceIdentity key].
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_control-access_monitor.html
24711 24712 24713 24714 24715 24716 24717 24718 24719 24720 24721 24722 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 24711 class DomainSettings < Struct.new( :security_group_ids, :r_studio_server_pro_domain_settings, :execution_role_identity_config, :trusted_identity_propagation_settings, :docker_settings, :amazon_q_settings, :unified_studio_settings, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#ip_address_type ⇒ String
The IP address type for the domain. Specify ‘ipv4` for IPv4-only connectivity or `dualstack` for both IPv4 and IPv6 connectivity. When you specify `dualstack`, the subnet must support IPv6 CIDR blocks. If not specified, defaults to `ipv4`.
24711 24712 24713 24714 24715 24716 24717 24718 24719 24720 24721 24722 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 24711 class DomainSettings < Struct.new( :security_group_ids, :r_studio_server_pro_domain_settings, :execution_role_identity_config, :trusted_identity_propagation_settings, :docker_settings, :amazon_q_settings, :unified_studio_settings, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#r_studio_server_pro_domain_settings ⇒ Types::RStudioServerProDomainSettings
A collection of settings that configure the ‘RStudioServerPro` Domain-level app.
24711 24712 24713 24714 24715 24716 24717 24718 24719 24720 24721 24722 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 24711 class DomainSettings < Struct.new( :security_group_ids, :r_studio_server_pro_domain_settings, :execution_role_identity_config, :trusted_identity_propagation_settings, :docker_settings, :amazon_q_settings, :unified_studio_settings, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#security_group_ids ⇒ Array<String>
The security groups for the Amazon Virtual Private Cloud that the ‘Domain` uses for communication between Domain-level apps and user apps.
24711 24712 24713 24714 24715 24716 24717 24718 24719 24720 24721 24722 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 24711 class DomainSettings < Struct.new( :security_group_ids, :r_studio_server_pro_domain_settings, :execution_role_identity_config, :trusted_identity_propagation_settings, :docker_settings, :amazon_q_settings, :unified_studio_settings, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#trusted_identity_propagation_settings ⇒ Types::TrustedIdentityPropagationSettings
The Trusted Identity Propagation (TIP) settings for the SageMaker domain. These settings determine how user identities from IAM Identity Center are propagated through the domain to TIP enabled Amazon Web Services services.
24711 24712 24713 24714 24715 24716 24717 24718 24719 24720 24721 24722 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 24711 class DomainSettings < Struct.new( :security_group_ids, :r_studio_server_pro_domain_settings, :execution_role_identity_config, :trusted_identity_propagation_settings, :docker_settings, :amazon_q_settings, :unified_studio_settings, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#unified_studio_settings ⇒ Types::UnifiedStudioSettings
The settings that apply to an SageMaker AI domain when you use it in Amazon SageMaker Unified Studio.
24711 24712 24713 24714 24715 24716 24717 24718 24719 24720 24721 24722 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 24711 class DomainSettings < Struct.new( :security_group_ids, :r_studio_server_pro_domain_settings, :execution_role_identity_config, :trusted_identity_propagation_settings, :docker_settings, :amazon_q_settings, :unified_studio_settings, :ip_address_type) SENSITIVE = [] include Aws::Structure end |