Class: Aws::SageMaker::Types::Endpoint

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

A hosted endpoint for real-time inference.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_time ⇒ Time

The time that the endpoint was created.

Returns:

  • (Time)


26470
26471
26472
26473
26474
26475
26476
26477
26478
26479
26480
26481
26482
26483
26484
26485
# File 'lib/aws-sdk-sagemaker/types.rb', line 26470

class Endpoint < Struct.new(
  :endpoint_name,
  :endpoint_arn,
  :endpoint_config_name,
  :production_variants,
  :data_capture_config,
  :endpoint_status,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :monitoring_schedules,
  :tags,
  :shadow_production_variants)
  SENSITIVE = []
  include Aws::Structure
end

#data_capture_config ⇒ Types::DataCaptureConfigSummary

The currently active data capture configuration used by your Endpoint.



26470
26471
26472
26473
26474
26475
26476
26477
26478
26479
26480
26481
26482
26483
26484
26485
# File 'lib/aws-sdk-sagemaker/types.rb', line 26470

class Endpoint < Struct.new(
  :endpoint_name,
  :endpoint_arn,
  :endpoint_config_name,
  :production_variants,
  :data_capture_config,
  :endpoint_status,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :monitoring_schedules,
  :tags,
  :shadow_production_variants)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_arn ⇒ String

The Amazon Resource Name (ARN) of the endpoint.

Returns:

  • (String)


26470
26471
26472
26473
26474
26475
26476
26477
26478
26479
26480
26481
26482
26483
26484
26485
# File 'lib/aws-sdk-sagemaker/types.rb', line 26470

class Endpoint < Struct.new(
  :endpoint_name,
  :endpoint_arn,
  :endpoint_config_name,
  :production_variants,
  :data_capture_config,
  :endpoint_status,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :monitoring_schedules,
  :tags,
  :shadow_production_variants)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_config_name ⇒ String

The endpoint configuration associated with the endpoint.

Returns:

  • (String)


26470
26471
26472
26473
26474
26475
26476
26477
26478
26479
26480
26481
26482
26483
26484
26485
# File 'lib/aws-sdk-sagemaker/types.rb', line 26470

class Endpoint < Struct.new(
  :endpoint_name,
  :endpoint_arn,
  :endpoint_config_name,
  :production_variants,
  :data_capture_config,
  :endpoint_status,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :monitoring_schedules,
  :tags,
  :shadow_production_variants)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_name ⇒ String

The name of the endpoint.

Returns:

  • (String)


26470
26471
26472
26473
26474
26475
26476
26477
26478
26479
26480
26481
26482
26483
26484
26485
# File 'lib/aws-sdk-sagemaker/types.rb', line 26470

class Endpoint < Struct.new(
  :endpoint_name,
  :endpoint_arn,
  :endpoint_config_name,
  :production_variants,
  :data_capture_config,
  :endpoint_status,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :monitoring_schedules,
  :tags,
  :shadow_production_variants)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_status ⇒ String

The status of the endpoint.

Returns:

  • (String)


26470
26471
26472
26473
26474
26475
26476
26477
26478
26479
26480
26481
26482
26483
26484
26485
# File 'lib/aws-sdk-sagemaker/types.rb', line 26470

class Endpoint < Struct.new(
  :endpoint_name,
  :endpoint_arn,
  :endpoint_config_name,
  :production_variants,
  :data_capture_config,
  :endpoint_status,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :monitoring_schedules,
  :tags,
  :shadow_production_variants)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reason ⇒ String

If the endpoint failed, the reason it failed.

Returns:

  • (String)


26470
26471
26472
26473
26474
26475
26476
26477
26478
26479
26480
26481
26482
26483
26484
26485
# File 'lib/aws-sdk-sagemaker/types.rb', line 26470

class Endpoint < Struct.new(
  :endpoint_name,
  :endpoint_arn,
  :endpoint_config_name,
  :production_variants,
  :data_capture_config,
  :endpoint_status,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :monitoring_schedules,
  :tags,
  :shadow_production_variants)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_time ⇒ Time

The last time the endpoint was modified.

Returns:

  • (Time)


26470
26471
26472
26473
26474
26475
26476
26477
26478
26479
26480
26481
26482
26483
26484
26485
# File 'lib/aws-sdk-sagemaker/types.rb', line 26470

class Endpoint < Struct.new(
  :endpoint_name,
  :endpoint_arn,
  :endpoint_config_name,
  :production_variants,
  :data_capture_config,
  :endpoint_status,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :monitoring_schedules,
  :tags,
  :shadow_production_variants)
  SENSITIVE = []
  include Aws::Structure
end

#monitoring_schedules ⇒ Array<Types::MonitoringSchedule>

A list of monitoring schedules for the endpoint. For information about model monitoring, see Amazon SageMaker Model Monitor.

Returns:



26470
26471
26472
26473
26474
26475
26476
26477
26478
26479
26480
26481
26482
26483
26484
26485
# File 'lib/aws-sdk-sagemaker/types.rb', line 26470

class Endpoint < Struct.new(
  :endpoint_name,
  :endpoint_arn,
  :endpoint_config_name,
  :production_variants,
  :data_capture_config,
  :endpoint_status,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :monitoring_schedules,
  :tags,
  :shadow_production_variants)
  SENSITIVE = []
  include Aws::Structure
end

#production_variants ⇒ Array<Types::ProductionVariantSummary>

A list of the production variants hosted on the endpoint. Each production variant is a model.



26470
26471
26472
26473
26474
26475
26476
26477
26478
26479
26480
26481
26482
26483
26484
26485
# File 'lib/aws-sdk-sagemaker/types.rb', line 26470

class Endpoint < Struct.new(
  :endpoint_name,
  :endpoint_arn,
  :endpoint_config_name,
  :production_variants,
  :data_capture_config,
  :endpoint_status,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :monitoring_schedules,
  :tags,
  :shadow_production_variants)
  SENSITIVE = []
  include Aws::Structure
end

#shadow_production_variants ⇒ Array<Types::ProductionVariantSummary>

A list of the shadow variants hosted on the endpoint. Each shadow variant is a model in shadow mode with production traffic replicated from the production variant.



26470
26471
26472
26473
26474
26475
26476
26477
26478
26479
26480
26481
26482
26483
26484
26485
# File 'lib/aws-sdk-sagemaker/types.rb', line 26470

class Endpoint < Struct.new(
  :endpoint_name,
  :endpoint_arn,
  :endpoint_config_name,
  :production_variants,
  :data_capture_config,
  :endpoint_status,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :monitoring_schedules,
  :tags,
  :shadow_production_variants)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Array<Types::Tag>

A list of the tags associated with the endpoint. For more information, see Tagging Amazon Web Services resources in the Amazon Web Services General Reference Guide.

Returns:



26470
26471
26472
26473
26474
26475
26476
26477
26478
26479
26480
26481
26482
26483
26484
26485
# File 'lib/aws-sdk-sagemaker/types.rb', line 26470

class Endpoint < Struct.new(
  :endpoint_name,
  :endpoint_arn,
  :endpoint_config_name,
  :production_variants,
  :data_capture_config,
  :endpoint_status,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :monitoring_schedules,
  :tags,
  :shadow_production_variants)
  SENSITIVE = []
  include Aws::Structure
end