Class: Aws::SageMaker::Types::EndpointInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Input object for the endpoint

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#end_time_offsetString

If specified, monitoring jobs substract this time from the end time. For information about using offsets for scheduling monitoring jobs, see [Schedule Model Quality Monitoring Jobs].

[1]: docs.aws.amazon.com/sagemaker/latest/dg/model-monitor-model-quality-schedule.html

Returns:



24213
24214
24215
24216
24217
24218
24219
24220
24221
24222
24223
24224
24225
24226
24227
# File 'lib/aws-sdk-sagemaker/types.rb', line 24213

class EndpointInput < Struct.new(
  :endpoint_name,
  :local_path,
  :s3_input_mode,
  :s3_data_distribution_type,
  :features_attribute,
  :inference_attribute,
  :probability_attribute,
  :probability_threshold_attribute,
  :start_time_offset,
  :end_time_offset,
  :exclude_features_attribute)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_nameString

An endpoint in customer’s account which has enabled DataCaptureConfig enabled.

Returns:



24213
24214
24215
24216
24217
24218
24219
24220
24221
24222
24223
24224
24225
24226
24227
# File 'lib/aws-sdk-sagemaker/types.rb', line 24213

class EndpointInput < Struct.new(
  :endpoint_name,
  :local_path,
  :s3_input_mode,
  :s3_data_distribution_type,
  :features_attribute,
  :inference_attribute,
  :probability_attribute,
  :probability_threshold_attribute,
  :start_time_offset,
  :end_time_offset,
  :exclude_features_attribute)
  SENSITIVE = []
  include Aws::Structure
end

#exclude_features_attributeString

The attributes of the input data to exclude from the analysis.

Returns:



24213
24214
24215
24216
24217
24218
24219
24220
24221
24222
24223
24224
24225
24226
24227
# File 'lib/aws-sdk-sagemaker/types.rb', line 24213

class EndpointInput < Struct.new(
  :endpoint_name,
  :local_path,
  :s3_input_mode,
  :s3_data_distribution_type,
  :features_attribute,
  :inference_attribute,
  :probability_attribute,
  :probability_threshold_attribute,
  :start_time_offset,
  :end_time_offset,
  :exclude_features_attribute)
  SENSITIVE = []
  include Aws::Structure
end

#features_attributeString

The attributes of the input data that are the input features.

Returns:



24213
24214
24215
24216
24217
24218
24219
24220
24221
24222
24223
24224
24225
24226
24227
# File 'lib/aws-sdk-sagemaker/types.rb', line 24213

class EndpointInput < Struct.new(
  :endpoint_name,
  :local_path,
  :s3_input_mode,
  :s3_data_distribution_type,
  :features_attribute,
  :inference_attribute,
  :probability_attribute,
  :probability_threshold_attribute,
  :start_time_offset,
  :end_time_offset,
  :exclude_features_attribute)
  SENSITIVE = []
  include Aws::Structure
end

#inference_attributeString

The attribute of the input data that represents the ground truth label.

Returns:



24213
24214
24215
24216
24217
24218
24219
24220
24221
24222
24223
24224
24225
24226
24227
# File 'lib/aws-sdk-sagemaker/types.rb', line 24213

class EndpointInput < Struct.new(
  :endpoint_name,
  :local_path,
  :s3_input_mode,
  :s3_data_distribution_type,
  :features_attribute,
  :inference_attribute,
  :probability_attribute,
  :probability_threshold_attribute,
  :start_time_offset,
  :end_time_offset,
  :exclude_features_attribute)
  SENSITIVE = []
  include Aws::Structure
end

#local_pathString

Path to the filesystem where the endpoint data is available to the container.

Returns:



24213
24214
24215
24216
24217
24218
24219
24220
24221
24222
24223
24224
24225
24226
24227
# File 'lib/aws-sdk-sagemaker/types.rb', line 24213

class EndpointInput < Struct.new(
  :endpoint_name,
  :local_path,
  :s3_input_mode,
  :s3_data_distribution_type,
  :features_attribute,
  :inference_attribute,
  :probability_attribute,
  :probability_threshold_attribute,
  :start_time_offset,
  :end_time_offset,
  :exclude_features_attribute)
  SENSITIVE = []
  include Aws::Structure
end

#probability_attributeString

In a classification problem, the attribute that represents the class probability.

Returns:



24213
24214
24215
24216
24217
24218
24219
24220
24221
24222
24223
24224
24225
24226
24227
# File 'lib/aws-sdk-sagemaker/types.rb', line 24213

class EndpointInput < Struct.new(
  :endpoint_name,
  :local_path,
  :s3_input_mode,
  :s3_data_distribution_type,
  :features_attribute,
  :inference_attribute,
  :probability_attribute,
  :probability_threshold_attribute,
  :start_time_offset,
  :end_time_offset,
  :exclude_features_attribute)
  SENSITIVE = []
  include Aws::Structure
end

#probability_threshold_attributeFloat

The threshold for the class probability to be evaluated as a positive result.

Returns:



24213
24214
24215
24216
24217
24218
24219
24220
24221
24222
24223
24224
24225
24226
24227
# File 'lib/aws-sdk-sagemaker/types.rb', line 24213

class EndpointInput < Struct.new(
  :endpoint_name,
  :local_path,
  :s3_input_mode,
  :s3_data_distribution_type,
  :features_attribute,
  :inference_attribute,
  :probability_attribute,
  :probability_threshold_attribute,
  :start_time_offset,
  :end_time_offset,
  :exclude_features_attribute)
  SENSITIVE = []
  include Aws::Structure
end

#s3_data_distribution_typeString

Whether input data distributed in Amazon S3 is fully replicated or sharded by an Amazon S3 key. Defaults to FullyReplicated

Returns:



24213
24214
24215
24216
24217
24218
24219
24220
24221
24222
24223
24224
24225
24226
24227
# File 'lib/aws-sdk-sagemaker/types.rb', line 24213

class EndpointInput < Struct.new(
  :endpoint_name,
  :local_path,
  :s3_input_mode,
  :s3_data_distribution_type,
  :features_attribute,
  :inference_attribute,
  :probability_attribute,
  :probability_threshold_attribute,
  :start_time_offset,
  :end_time_offset,
  :exclude_features_attribute)
  SENSITIVE = []
  include Aws::Structure
end

#s3_input_modeString

Whether the Pipe or File is used as the input mode for transferring data for the monitoring job. Pipe mode is recommended for large datasets. File mode is useful for small files that fit in memory. Defaults to File.

Returns:



24213
24214
24215
24216
24217
24218
24219
24220
24221
24222
24223
24224
24225
24226
24227
# File 'lib/aws-sdk-sagemaker/types.rb', line 24213

class EndpointInput < Struct.new(
  :endpoint_name,
  :local_path,
  :s3_input_mode,
  :s3_data_distribution_type,
  :features_attribute,
  :inference_attribute,
  :probability_attribute,
  :probability_threshold_attribute,
  :start_time_offset,
  :end_time_offset,
  :exclude_features_attribute)
  SENSITIVE = []
  include Aws::Structure
end

#start_time_offsetString

If specified, monitoring jobs substract this time from the start time. For information about using offsets for scheduling monitoring jobs, see [Schedule Model Quality Monitoring Jobs].

[1]: docs.aws.amazon.com/sagemaker/latest/dg/model-monitor-model-quality-schedule.html

Returns:



24213
24214
24215
24216
24217
24218
24219
24220
24221
24222
24223
24224
24225
24226
24227
# File 'lib/aws-sdk-sagemaker/types.rb', line 24213

class EndpointInput < Struct.new(
  :endpoint_name,
  :local_path,
  :s3_input_mode,
  :s3_data_distribution_type,
  :features_attribute,
  :inference_attribute,
  :probability_attribute,
  :probability_threshold_attribute,
  :start_time_offset,
  :end_time_offset,
  :exclude_features_attribute)
  SENSITIVE = []
  include Aws::Structure
end