Class: Aws::SageMaker::Types::EndpointMetadata

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The metadata of the endpoint.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#endpoint_config_nameString

The name of the endpoint configuration.



26682
26683
26684
26685
26686
26687
26688
26689
# File 'lib/aws-sdk-sagemaker/types.rb', line 26682

class  < Struct.new(
  :endpoint_name,
  :endpoint_config_name,
  :endpoint_status,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_nameString

The name of the endpoint.



26682
26683
26684
26685
26686
26687
26688
26689
# File 'lib/aws-sdk-sagemaker/types.rb', line 26682

class  < Struct.new(
  :endpoint_name,
  :endpoint_config_name,
  :endpoint_status,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_statusString

The status of the endpoint. For possible values of the status of an endpoint, see EndpointSummary.



26682
26683
26684
26685
26686
26687
26688
26689
# File 'lib/aws-sdk-sagemaker/types.rb', line 26682

class  < Struct.new(
  :endpoint_name,
  :endpoint_config_name,
  :endpoint_status,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

If the status of the endpoint is Failed, or the status is InService but update operation fails, this provides the reason why it failed.



26682
26683
26684
26685
26686
26687
26688
26689
# File 'lib/aws-sdk-sagemaker/types.rb', line 26682

class  < Struct.new(
  :endpoint_name,
  :endpoint_config_name,
  :endpoint_status,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end