Class: Aws::SageMaker::Types::EndpointOutputConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The endpoint configuration made by Inference Recommender during a recommendation job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#endpoint_nameString

The name of the endpoint made during a recommendation job.

Returns:



16300
16301
16302
16303
16304
16305
16306
16307
# File 'lib/aws-sdk-sagemaker/types.rb', line 16300

class EndpointOutputConfiguration < Struct.new(
  :endpoint_name,
  :variant_name,
  :instance_type,
  :initial_instance_count)
  SENSITIVE = []
  include Aws::Structure
end

#initial_instance_countInteger

The number of instances recommended to launch initially.

Returns:



16300
16301
16302
16303
16304
16305
16306
16307
# File 'lib/aws-sdk-sagemaker/types.rb', line 16300

class EndpointOutputConfiguration < Struct.new(
  :endpoint_name,
  :variant_name,
  :instance_type,
  :initial_instance_count)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typeString

The instance type recommended by Amazon SageMaker Inference Recommender.

Returns:



16300
16301
16302
16303
16304
16305
16306
16307
# File 'lib/aws-sdk-sagemaker/types.rb', line 16300

class EndpointOutputConfiguration < Struct.new(
  :endpoint_name,
  :variant_name,
  :instance_type,
  :initial_instance_count)
  SENSITIVE = []
  include Aws::Structure
end

#variant_nameString

The name of the production variant (deployed model) made during a recommendation job.

Returns:



16300
16301
16302
16303
16304
16305
16306
16307
# File 'lib/aws-sdk-sagemaker/types.rb', line 16300

class EndpointOutputConfiguration < Struct.new(
  :endpoint_name,
  :variant_name,
  :instance_type,
  :initial_instance_count)
  SENSITIVE = []
  include Aws::Structure
end