Class: Aws::SageMaker::Types::EventDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Detailed information about a specific event, including event metadata.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#event_metadataTypes::EventMetadata

Metadata specific to the event, which may include information about the cluster, instance group, or instance involved.



26000
26001
26002
26003
26004
# File 'lib/aws-sdk-sagemaker/types.rb', line 26000

class EventDetails < Struct.new(
  :event_metadata)
  SENSITIVE = []
  include Aws::Structure
end