Class: Aws::SageMaker::Types::Experiment
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::Experiment
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The properties of an experiment as returned by the Search API. For information about experiments, see the CreateExperiment API.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_by ⇒ Types::UserContext
Who created the experiment.
-
#creation_time ⇒ Time
When the experiment was created.
-
#description ⇒ String
The description of the experiment.
-
#display_name ⇒ String
The name of the experiment as displayed.
-
#experiment_arn ⇒ String
The Amazon Resource Name (ARN) of the experiment.
-
#experiment_name ⇒ String
The name of the experiment.
-
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
-
#last_modified_time ⇒ Time
When the experiment was last modified.
-
#source ⇒ Types::ExperimentSource
The source of the experiment.
-
#tags ⇒ Array<Types::Tag>
The list of tags that are associated with the experiment.
Instance Attribute Details
#created_by ⇒ Types::UserContext
Who created the experiment.
27052 27053 27054 27055 27056 27057 27058 27059 27060 27061 27062 27063 27064 27065 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27052 class Experiment < Struct.new( :experiment_name, :experiment_arn, :display_name, :source, :description, :creation_time, :created_by, :last_modified_time, :last_modified_by, :tags) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
When the experiment was created.
27052 27053 27054 27055 27056 27057 27058 27059 27060 27061 27062 27063 27064 27065 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27052 class Experiment < Struct.new( :experiment_name, :experiment_arn, :display_name, :source, :description, :creation_time, :created_by, :last_modified_time, :last_modified_by, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the experiment.
27052 27053 27054 27055 27056 27057 27058 27059 27060 27061 27062 27063 27064 27065 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27052 class Experiment < Struct.new( :experiment_name, :experiment_arn, :display_name, :source, :description, :creation_time, :created_by, :last_modified_time, :last_modified_by, :tags) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The name of the experiment as displayed. If DisplayName isn't
specified, ExperimentName is displayed.
27052 27053 27054 27055 27056 27057 27058 27059 27060 27061 27062 27063 27064 27065 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27052 class Experiment < Struct.new( :experiment_name, :experiment_arn, :display_name, :source, :description, :creation_time, :created_by, :last_modified_time, :last_modified_by, :tags) SENSITIVE = [] include Aws::Structure end |
#experiment_arn ⇒ String
The Amazon Resource Name (ARN) of the experiment.
27052 27053 27054 27055 27056 27057 27058 27059 27060 27061 27062 27063 27064 27065 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27052 class Experiment < Struct.new( :experiment_name, :experiment_arn, :display_name, :source, :description, :creation_time, :created_by, :last_modified_time, :last_modified_by, :tags) SENSITIVE = [] include Aws::Structure end |
#experiment_name ⇒ String
The name of the experiment.
27052 27053 27054 27055 27056 27057 27058 27059 27060 27061 27062 27063 27064 27065 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27052 class Experiment < Struct.new( :experiment_name, :experiment_arn, :display_name, :source, :description, :creation_time, :created_by, :last_modified_time, :last_modified_by, :tags) SENSITIVE = [] include Aws::Structure end |
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
27052 27053 27054 27055 27056 27057 27058 27059 27060 27061 27062 27063 27064 27065 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27052 class Experiment < Struct.new( :experiment_name, :experiment_arn, :display_name, :source, :description, :creation_time, :created_by, :last_modified_time, :last_modified_by, :tags) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
When the experiment was last modified.
27052 27053 27054 27055 27056 27057 27058 27059 27060 27061 27062 27063 27064 27065 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27052 class Experiment < Struct.new( :experiment_name, :experiment_arn, :display_name, :source, :description, :creation_time, :created_by, :last_modified_time, :last_modified_by, :tags) SENSITIVE = [] include Aws::Structure end |
#source ⇒ Types::ExperimentSource
The source of the experiment.
27052 27053 27054 27055 27056 27057 27058 27059 27060 27061 27062 27063 27064 27065 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27052 class Experiment < Struct.new( :experiment_name, :experiment_arn, :display_name, :source, :description, :creation_time, :created_by, :last_modified_time, :last_modified_by, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The list of tags that are associated with the experiment. You can use Search API to search on the tags.
27052 27053 27054 27055 27056 27057 27058 27059 27060 27061 27062 27063 27064 27065 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27052 class Experiment < Struct.new( :experiment_name, :experiment_arn, :display_name, :source, :description, :creation_time, :created_by, :last_modified_time, :last_modified_by, :tags) SENSITIVE = [] include Aws::Structure end |