Class: Aws::SageMaker::Types::ExtendTrainingPlanRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ExtendTrainingPlanRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#training_plan_extension_offering_id ⇒ String
The unique identifier of the extension offering to purchase.
Instance Attribute Details
#training_plan_extension_offering_id ⇒ String
The unique identifier of the extension offering to purchase. You can retrieve this ID from the TrainingPlanExtensionOfferings in the response of the SearchTrainingPlanOfferings API.
24818 24819 24820 24821 24822 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 24818 class ExtendTrainingPlanRequest < Struct.new( :training_plan_extension_offering_id) SENSITIVE = [] include Aws::Structure end |