Class: Aws::SageMaker::Types::FSxLustreFileSystemConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::FSxLustreFileSystemConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The settings for assigning a custom Amazon FSx for Lustre file system to a user profile or space for an Amazon SageMaker Domain.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#file_system_id ⇒ String
The globally unique, 17-digit, ID of the file system, assigned by Amazon FSx for Lustre.
-
#file_system_path ⇒ String
The path to the file system directory that is accessible in Amazon SageMaker Studio.
Instance Attribute Details
#file_system_id ⇒ String
The globally unique, 17-digit, ID of the file system, assigned by Amazon FSx for Lustre.
27022 27023 27024 27025 27026 27027 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27022 class FSxLustreFileSystemConfig < Struct.new( :file_system_id, :file_system_path) SENSITIVE = [] include Aws::Structure end |
#file_system_path ⇒ String
The path to the file system directory that is accessible in Amazon SageMaker Studio. Permitted users can access only this directory and below.
27022 27023 27024 27025 27026 27027 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27022 class FSxLustreFileSystemConfig < Struct.new( :file_system_id, :file_system_path) SENSITIVE = [] include Aws::Structure end |