Class: Aws::SageMaker::Types::FileSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::FileSource
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Contains details regarding the file source.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#content_digest ⇒ String
The digest of the file source.
-
#content_type ⇒ String
The type of content stored in the file source.
-
#s3_uri ⇒ String
The Amazon S3 URI for the file source.
Instance Attribute Details
#content_digest ⇒ String
The digest of the file source.
26590 26591 26592 26593 26594 26595 26596 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26590 class FileSource < Struct.new( :content_type, :content_digest, :s3_uri) SENSITIVE = [] include Aws::Structure end |
#content_type ⇒ String
The type of content stored in the file source.
26590 26591 26592 26593 26594 26595 26596 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26590 class FileSource < Struct.new( :content_type, :content_digest, :s3_uri) SENSITIVE = [] include Aws::Structure end |
#s3_uri ⇒ String
The Amazon S3 URI for the file source.
26590 26591 26592 26593 26594 26595 26596 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26590 class FileSource < Struct.new( :content_type, :content_digest, :s3_uri) SENSITIVE = [] include Aws::Structure end |