Class: Aws::SageMaker::Types::FinalAutoMLJobObjectiveMetric
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::FinalAutoMLJobObjectiveMetric
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The best candidate result from an AutoML training job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#metric_name ⇒ String
The name of the metric with the best result.
-
#type ⇒ String
The type of metric with the best result.
-
#value ⇒ Float
The value of the metric with the best result.
Instance Attribute Details
#metric_name ⇒ String
The name of the metric with the best result. For a description of the possible objective metrics, see AutoMLJobObjective$MetricName.
17162 17163 17164 17165 17166 17167 17168 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17162 class FinalAutoMLJobObjectiveMetric < Struct.new( :type, :metric_name, :value) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of metric with the best result.
17162 17163 17164 17165 17166 17167 17168 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17162 class FinalAutoMLJobObjectiveMetric < Struct.new( :type, :metric_name, :value) SENSITIVE = [] include Aws::Structure end |
#value ⇒ Float
The value of the metric with the best result.
17162 17163 17164 17165 17166 17167 17168 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17162 class FinalAutoMLJobObjectiveMetric < Struct.new( :type, :metric_name, :value) SENSITIVE = [] include Aws::Structure end |