Class: Aws::SageMaker::Types::FinalHyperParameterTuningJobObjectiveMetric

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Shows the final value for the objective metric for a training job that was launched by a hyperparameter tuning job. You define the objective metric in the HyperParameterTuningJobObjective parameter of HyperParameterTuningJobConfig.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#metric_nameString

The name of the objective metric.

Returns:



17190
17191
17192
17193
17194
17195
17196
# File 'lib/aws-sdk-sagemaker/types.rb', line 17190

class FinalHyperParameterTuningJobObjectiveMetric < Struct.new(
  :type,
  :metric_name,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

Whether to minimize or maximize the objective metric. Valid values are Minimize and Maximize.

Returns:



17190
17191
17192
17193
17194
17195
17196
# File 'lib/aws-sdk-sagemaker/types.rb', line 17190

class FinalHyperParameterTuningJobObjectiveMetric < Struct.new(
  :type,
  :metric_name,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#valueFloat

The value of the objective metric.

Returns:



17190
17191
17192
17193
17194
17195
17196
# File 'lib/aws-sdk-sagemaker/types.rb', line 17190

class FinalHyperParameterTuningJobObjectiveMetric < Struct.new(
  :type,
  :metric_name,
  :value)
  SENSITIVE = []
  include Aws::Structure
end