Class: Aws::SageMaker::Types::GenerativeAiSettings

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The generative AI settings for the SageMaker Canvas application.

Configure these settings for Canvas users starting chats with generative AI foundation models. For more information, see Use generative AI with foundation models.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#amazon_bedrock_role_arnString

The ARN of an Amazon Web Services IAM role that allows fine-tuning of large language models (LLMs) in Amazon Bedrock. The IAM role should have Amazon S3 read and write permissions, as well as a trust relationship that establishes bedrock.amazonaws.com as a service principal.

Returns:

  • (String)


27743
27744
27745
27746
27747
# File 'lib/aws-sdk-sagemaker/types.rb', line 27743

class GenerativeAiSettings < Struct.new(
  :amazon_bedrock_role_arn)
  SENSITIVE = []
  include Aws::Structure
end