Class: Aws::SageMaker::Types::GetScalingConfigurationRecommendationRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#endpoint_nameString

The name of an endpoint benchmarked during a previously completed inference recommendation job. This name should come from one of the recommendations returned by the job specified in the InferenceRecommendationsJobName field.

Specify either this field or the RecommendationId field.

Returns:

  • (String)


28079
28080
28081
28082
28083
28084
28085
28086
28087
# File 'lib/aws-sdk-sagemaker/types.rb', line 28079

class GetScalingConfigurationRecommendationRequest < Struct.new(
  :inference_recommendations_job_name,
  :recommendation_id,
  :endpoint_name,
  :target_cpu_utilization_per_core,
  :scaling_policy_objective)
  SENSITIVE = []
  include Aws::Structure
end

#inference_recommendations_job_nameString

The name of a previously completed Inference Recommender job.

Returns:

  • (String)


28079
28080
28081
28082
28083
28084
28085
28086
28087
# File 'lib/aws-sdk-sagemaker/types.rb', line 28079

class GetScalingConfigurationRecommendationRequest < Struct.new(
  :inference_recommendations_job_name,
  :recommendation_id,
  :endpoint_name,
  :target_cpu_utilization_per_core,
  :scaling_policy_objective)
  SENSITIVE = []
  include Aws::Structure
end

#recommendation_idString

The recommendation ID of a previously completed inference recommendation. This ID should come from one of the recommendations returned by the job specified in the InferenceRecommendationsJobName field.

Specify either this field or the EndpointName field.

Returns:

  • (String)


28079
28080
28081
28082
28083
28084
28085
28086
28087
# File 'lib/aws-sdk-sagemaker/types.rb', line 28079

class GetScalingConfigurationRecommendationRequest < Struct.new(
  :inference_recommendations_job_name,
  :recommendation_id,
  :endpoint_name,
  :target_cpu_utilization_per_core,
  :scaling_policy_objective)
  SENSITIVE = []
  include Aws::Structure
end

#scaling_policy_objectiveTypes::ScalingPolicyObjective

An object where you specify the anticipated traffic pattern for an endpoint.



28079
28080
28081
28082
28083
28084
28085
28086
28087
# File 'lib/aws-sdk-sagemaker/types.rb', line 28079

class GetScalingConfigurationRecommendationRequest < Struct.new(
  :inference_recommendations_job_name,
  :recommendation_id,
  :endpoint_name,
  :target_cpu_utilization_per_core,
  :scaling_policy_objective)
  SENSITIVE = []
  include Aws::Structure
end

#target_cpu_utilization_per_coreInteger

The percentage of how much utilization you want an instance to use before autoscaling. The default value is 50%.

Returns:

  • (Integer)


28079
28080
28081
28082
28083
28084
28085
28086
28087
# File 'lib/aws-sdk-sagemaker/types.rb', line 28079

class GetScalingConfigurationRecommendationRequest < Struct.new(
  :inference_recommendations_job_name,
  :recommendation_id,
  :endpoint_name,
  :target_cpu_utilization_per_core,
  :scaling_policy_objective)
  SENSITIVE = []
  include Aws::Structure
end