Class: Aws::SageMaker::Types::HolidayConfigAttributes
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::HolidayConfigAttributes
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Stores the holiday featurization attributes applicable to each item of time-series datasets during the training of a forecasting model. This allows the model to identify patterns associated with specific holidays.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#country_code ⇒ String
The country code for the holiday calendar.
Instance Attribute Details
#country_code ⇒ String
The country code for the holiday calendar.
For the list of public holiday calendars supported by AutoML job V2, see Country Codes. Use the country code corresponding to the country of your choice.
28300 28301 28302 28303 28304 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 28300 class HolidayConfigAttributes < Struct.new( :country_code) SENSITIVE = [] include Aws::Structure end |