Class: Aws::SageMaker::Types::HumanLoopActivationConditionsConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::HumanLoopActivationConditionsConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Defines under what conditions SageMaker creates a human loop. Used within [CreateFlowDefinition]. See
- HumanLoopActivationConditionsConfig][2
-
for the required format of
activation conditions.
[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateFlowDefinition.html [2]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_HumanLoopActivationConditionsConfig.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#human_loop_activation_conditions ⇒ String
JSON expressing use-case specific conditions declaratively.
Instance Attribute Details
#human_loop_activation_conditions ⇒ String
JSON expressing use-case specific conditions declaratively. If any condition is matched, atomic tasks are created against the configured work team. The set of conditions is different for Rekognition and Textract. For more information about how to structure the JSON, see [JSON Schema for Human Loop Activation Conditions in Amazon Augmented AI] in the *Amazon SageMaker Developer Guide*.
[1]: docs.aws.amazon.com/sagemaker/latest/dg/a2i-human-fallback-conditions-json-schema.html
28282 28283 28284 28285 28286 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 28282 class HumanLoopActivationConditionsConfig < Struct.new( :human_loop_activation_conditions) SENSITIVE = [] include Aws::Structure end |