Class: Aws::SageMaker::Types::HyperParameterTrainingJobSummary

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The container for the summary information about a training job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timeTime

The date and time that the training job was created.

Returns:

  • (Time)


29123
29124
29125
29126
29127
29128
29129
29130
29131
29132
29133
29134
29135
29136
29137
29138
# File 'lib/aws-sdk-sagemaker/types.rb', line 29123

class HyperParameterTrainingJobSummary < Struct.new(
  :training_job_definition_name,
  :training_job_name,
  :training_job_arn,
  :tuning_job_name,
  :creation_time,
  :training_start_time,
  :training_end_time,
  :training_job_status,
  :tuned_hyper_parameters,
  :failure_reason,
  :final_hyper_parameter_tuning_job_objective_metric,
  :objective_status)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

The reason that the training job failed.

Returns:

  • (String)


29123
29124
29125
29126
29127
29128
29129
29130
29131
29132
29133
29134
29135
29136
29137
29138
# File 'lib/aws-sdk-sagemaker/types.rb', line 29123

class HyperParameterTrainingJobSummary < Struct.new(
  :training_job_definition_name,
  :training_job_name,
  :training_job_arn,
  :tuning_job_name,
  :creation_time,
  :training_start_time,
  :training_end_time,
  :training_job_status,
  :tuned_hyper_parameters,
  :failure_reason,
  :final_hyper_parameter_tuning_job_objective_metric,
  :objective_status)
  SENSITIVE = []
  include Aws::Structure
end

#final_hyper_parameter_tuning_job_objective_metricTypes::FinalHyperParameterTuningJobObjectiveMetric

The [FinalHyperParameterTuningJobObjectiveMetric] object that specifies the value of the objective metric of the tuning job that launched this training job.

[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_FinalHyperParameterTuningJobObjectiveMetric.html



29123
29124
29125
29126
29127
29128
29129
29130
29131
29132
29133
29134
29135
29136
29137
29138
# File 'lib/aws-sdk-sagemaker/types.rb', line 29123

class HyperParameterTrainingJobSummary < Struct.new(
  :training_job_definition_name,
  :training_job_name,
  :training_job_arn,
  :tuning_job_name,
  :creation_time,
  :training_start_time,
  :training_end_time,
  :training_job_status,
  :tuned_hyper_parameters,
  :failure_reason,
  :final_hyper_parameter_tuning_job_objective_metric,
  :objective_status)
  SENSITIVE = []
  include Aws::Structure
end

#objective_statusString

The status of the objective metric for the training job:

  • Succeeded: The final objective metric for the training job was evaluated by the hyperparameter tuning job and used in the hyperparameter tuning process.

^ ^

  • Pending: The training job is in progress and evaluation of its final objective metric is pending.

^ ^

  • Failed: The final objective metric for the training job was not evaluated, and was not used in the hyperparameter tuning process. This typically occurs when the training job failed or did not emit an objective metric.

^

Returns:

  • (String)


29123
29124
29125
29126
29127
29128
29129
29130
29131
29132
29133
29134
29135
29136
29137
29138
# File 'lib/aws-sdk-sagemaker/types.rb', line 29123

class HyperParameterTrainingJobSummary < Struct.new(
  :training_job_definition_name,
  :training_job_name,
  :training_job_arn,
  :tuning_job_name,
  :creation_time,
  :training_start_time,
  :training_end_time,
  :training_job_status,
  :tuned_hyper_parameters,
  :failure_reason,
  :final_hyper_parameter_tuning_job_objective_metric,
  :objective_status)
  SENSITIVE = []
  include Aws::Structure
end

#training_end_timeTime

Specifies the time when the training job ends on training instances. You are billed for the time interval between the value of ‘TrainingStartTime` and this time. For successful jobs and stopped jobs, this is the time after model artifacts are uploaded. For failed jobs, this is the time when SageMaker detects a job failure.

Returns:

  • (Time)


29123
29124
29125
29126
29127
29128
29129
29130
29131
29132
29133
29134
29135
29136
29137
29138
# File 'lib/aws-sdk-sagemaker/types.rb', line 29123

class HyperParameterTrainingJobSummary < Struct.new(
  :training_job_definition_name,
  :training_job_name,
  :training_job_arn,
  :tuning_job_name,
  :creation_time,
  :training_start_time,
  :training_end_time,
  :training_job_status,
  :tuned_hyper_parameters,
  :failure_reason,
  :final_hyper_parameter_tuning_job_objective_metric,
  :objective_status)
  SENSITIVE = []
  include Aws::Structure
end

#training_job_arnString

The Amazon Resource Name (ARN) of the training job.

Returns:

  • (String)


29123
29124
29125
29126
29127
29128
29129
29130
29131
29132
29133
29134
29135
29136
29137
29138
# File 'lib/aws-sdk-sagemaker/types.rb', line 29123

class HyperParameterTrainingJobSummary < Struct.new(
  :training_job_definition_name,
  :training_job_name,
  :training_job_arn,
  :tuning_job_name,
  :creation_time,
  :training_start_time,
  :training_end_time,
  :training_job_status,
  :tuned_hyper_parameters,
  :failure_reason,
  :final_hyper_parameter_tuning_job_objective_metric,
  :objective_status)
  SENSITIVE = []
  include Aws::Structure
end

#training_job_definition_nameString

The training job definition name.

Returns:

  • (String)


29123
29124
29125
29126
29127
29128
29129
29130
29131
29132
29133
29134
29135
29136
29137
29138
# File 'lib/aws-sdk-sagemaker/types.rb', line 29123

class HyperParameterTrainingJobSummary < Struct.new(
  :training_job_definition_name,
  :training_job_name,
  :training_job_arn,
  :tuning_job_name,
  :creation_time,
  :training_start_time,
  :training_end_time,
  :training_job_status,
  :tuned_hyper_parameters,
  :failure_reason,
  :final_hyper_parameter_tuning_job_objective_metric,
  :objective_status)
  SENSITIVE = []
  include Aws::Structure
end

#training_job_nameString

The name of the training job.

Returns:

  • (String)


29123
29124
29125
29126
29127
29128
29129
29130
29131
29132
29133
29134
29135
29136
29137
29138
# File 'lib/aws-sdk-sagemaker/types.rb', line 29123

class HyperParameterTrainingJobSummary < Struct.new(
  :training_job_definition_name,
  :training_job_name,
  :training_job_arn,
  :tuning_job_name,
  :creation_time,
  :training_start_time,
  :training_end_time,
  :training_job_status,
  :tuned_hyper_parameters,
  :failure_reason,
  :final_hyper_parameter_tuning_job_objective_metric,
  :objective_status)
  SENSITIVE = []
  include Aws::Structure
end

#training_job_statusString

The status of the training job.

Returns:

  • (String)


29123
29124
29125
29126
29127
29128
29129
29130
29131
29132
29133
29134
29135
29136
29137
29138
# File 'lib/aws-sdk-sagemaker/types.rb', line 29123

class HyperParameterTrainingJobSummary < Struct.new(
  :training_job_definition_name,
  :training_job_name,
  :training_job_arn,
  :tuning_job_name,
  :creation_time,
  :training_start_time,
  :training_end_time,
  :training_job_status,
  :tuned_hyper_parameters,
  :failure_reason,
  :final_hyper_parameter_tuning_job_objective_metric,
  :objective_status)
  SENSITIVE = []
  include Aws::Structure
end

#training_start_timeTime

The date and time that the training job started.

Returns:

  • (Time)


29123
29124
29125
29126
29127
29128
29129
29130
29131
29132
29133
29134
29135
29136
29137
29138
# File 'lib/aws-sdk-sagemaker/types.rb', line 29123

class HyperParameterTrainingJobSummary < Struct.new(
  :training_job_definition_name,
  :training_job_name,
  :training_job_arn,
  :tuning_job_name,
  :creation_time,
  :training_start_time,
  :training_end_time,
  :training_job_status,
  :tuned_hyper_parameters,
  :failure_reason,
  :final_hyper_parameter_tuning_job_objective_metric,
  :objective_status)
  SENSITIVE = []
  include Aws::Structure
end

#tuned_hyper_parametersHash<String,String>

A list of the hyperparameters for which you specified ranges to search.

Returns:

  • (Hash<String,String>)


29123
29124
29125
29126
29127
29128
29129
29130
29131
29132
29133
29134
29135
29136
29137
29138
# File 'lib/aws-sdk-sagemaker/types.rb', line 29123

class HyperParameterTrainingJobSummary < Struct.new(
  :training_job_definition_name,
  :training_job_name,
  :training_job_arn,
  :tuning_job_name,
  :creation_time,
  :training_start_time,
  :training_end_time,
  :training_job_status,
  :tuned_hyper_parameters,
  :failure_reason,
  :final_hyper_parameter_tuning_job_objective_metric,
  :objective_status)
  SENSITIVE = []
  include Aws::Structure
end

#tuning_job_nameString

The HyperParameter tuning job that launched the training job.

Returns:

  • (String)


29123
29124
29125
29126
29127
29128
29129
29130
29131
29132
29133
29134
29135
29136
29137
29138
# File 'lib/aws-sdk-sagemaker/types.rb', line 29123

class HyperParameterTrainingJobSummary < Struct.new(
  :training_job_definition_name,
  :training_job_name,
  :training_job_arn,
  :tuning_job_name,
  :creation_time,
  :training_start_time,
  :training_end_time,
  :training_job_status,
  :tuned_hyper_parameters,
  :failure_reason,
  :final_hyper_parameter_tuning_job_objective_metric,
  :objective_status)
  SENSITIVE = []
  include Aws::Structure
end