Class: Aws::SageMaker::Types::HyperParameterTuningInstanceConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::HyperParameterTuningInstanceConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The configuration for hyperparameter tuning resources for use in training jobs launched by the tuning job. These resources include compute instances and storage volumes. Specify one or more compute instance configurations and allocation strategies to select resources (optional).
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_count ⇒ Integer
The number of instances of the type specified by
InstanceType. -
#instance_type ⇒ String
The instance type used for processing of hyperparameter optimization jobs.
-
#volume_size_in_gb ⇒ Integer
The volume size in GB of the data to be processed for hyperparameter optimization (optional).
Instance Attribute Details
#instance_count ⇒ Integer
The number of instances of the type specified by InstanceType. Choose an instance count larger than 1 for distributed training algorithms. See [Step 2: Launch a SageMaker Distributed Training Job Using the SageMaker Python SDK] for more information.
[1]: docs.aws.amazon.com/sagemaker/latest/dg/data-parallel-use-api.html
27782 27783 27784 27785 27786 27787 27788 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27782 class HyperParameterTuningInstanceConfig < Struct.new( :instance_type, :instance_count, :volume_size_in_gb) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The instance type used for processing of hyperparameter optimization jobs. Choose from general purpose (no GPUs) instance types: ml.m5.xlarge, ml.m5.2xlarge, and ml.m5.4xlarge or compute optimized (no GPUs) instance types: ml.c5.xlarge and ml.c5.2xlarge. For more information about instance types, see [instance type descriptions].
[1]: docs.aws.amazon.com/sagemaker/latest/dg/notebooks-available-instance-types.html
27782 27783 27784 27785 27786 27787 27788 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27782 class HyperParameterTuningInstanceConfig < Struct.new( :instance_type, :instance_count, :volume_size_in_gb) SENSITIVE = [] include Aws::Structure end |
#volume_size_in_gb ⇒ Integer
The volume size in GB of the data to be processed for hyperparameter optimization (optional).
27782 27783 27784 27785 27786 27787 27788 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27782 class HyperParameterTuningInstanceConfig < Struct.new( :instance_type, :instance_count, :volume_size_in_gb) SENSITIVE = [] include Aws::Structure end |