Class: Aws::SageMaker::Types::HyperParameterTuningJobConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::HyperParameterTuningJobConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Configures a hyperparameter tuning job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#hyper_parameter_tuning_job_objective ⇒ Types::HyperParameterTuningJobObjective
The HyperParameterTuningJobObjective specifies the objective metric used to evaluate the performance of training jobs launched by this tuning job.
-
#parameter_ranges ⇒ Types::ParameterRanges
The ParameterRanges object that specifies the ranges of hyperparameters that this tuning job searches over to find the optimal configuration for the highest model performance against your chosen objective metric.
-
#random_seed ⇒ Integer
A value used to initialize a pseudo-random number generator.
-
#resource_limits ⇒ Types::ResourceLimits
The ResourceLimits object that specifies the maximum number of training and parallel training jobs that can be used for this hyperparameter tuning job.
-
#strategy ⇒ String
Specifies how hyperparameter tuning chooses the combinations of hyperparameter values to use for the training job it launches.
-
#strategy_config ⇒ Types::HyperParameterTuningJobStrategyConfig
The configuration for the
Hyperbandoptimization strategy. -
#training_job_early_stopping_type ⇒ String
Specifies whether to use early stopping for training jobs launched by the hyperparameter tuning job.
-
#tuning_job_completion_criteria ⇒ Types::TuningJobCompletionCriteria
The tuning job’s completion criteria.
Instance Attribute Details
#hyper_parameter_tuning_job_objective ⇒ Types::HyperParameterTuningJobObjective
The HyperParameterTuningJobObjective specifies the objective metric used to evaluate the performance of training jobs launched by this tuning job.
19299 19300 19301 19302 19303 19304 19305 19306 19307 19308 19309 19310 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19299 class HyperParameterTuningJobConfig < Struct.new( :strategy, :strategy_config, :hyper_parameter_tuning_job_objective, :resource_limits, :parameter_ranges, :training_job_early_stopping_type, :tuning_job_completion_criteria, :random_seed) SENSITIVE = [] include Aws::Structure end |
#parameter_ranges ⇒ Types::ParameterRanges
The ParameterRanges object that specifies the ranges of hyperparameters that this tuning job searches over to find the optimal configuration for the highest model performance against your chosen objective metric.
19299 19300 19301 19302 19303 19304 19305 19306 19307 19308 19309 19310 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19299 class HyperParameterTuningJobConfig < Struct.new( :strategy, :strategy_config, :hyper_parameter_tuning_job_objective, :resource_limits, :parameter_ranges, :training_job_early_stopping_type, :tuning_job_completion_criteria, :random_seed) SENSITIVE = [] include Aws::Structure end |
#random_seed ⇒ Integer
A value used to initialize a pseudo-random number generator. Setting a random seed and using the same seed later for the same tuning job will allow hyperparameter optimization to find more a consistent hyperparameter configuration between the two runs.
19299 19300 19301 19302 19303 19304 19305 19306 19307 19308 19309 19310 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19299 class HyperParameterTuningJobConfig < Struct.new( :strategy, :strategy_config, :hyper_parameter_tuning_job_objective, :resource_limits, :parameter_ranges, :training_job_early_stopping_type, :tuning_job_completion_criteria, :random_seed) SENSITIVE = [] include Aws::Structure end |
#resource_limits ⇒ Types::ResourceLimits
The ResourceLimits object that specifies the maximum number of training and parallel training jobs that can be used for this hyperparameter tuning job.
19299 19300 19301 19302 19303 19304 19305 19306 19307 19308 19309 19310 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19299 class HyperParameterTuningJobConfig < Struct.new( :strategy, :strategy_config, :hyper_parameter_tuning_job_objective, :resource_limits, :parameter_ranges, :training_job_early_stopping_type, :tuning_job_completion_criteria, :random_seed) SENSITIVE = [] include Aws::Structure end |
#strategy ⇒ String
Specifies how hyperparameter tuning chooses the combinations of hyperparameter values to use for the training job it launches. For information about search strategies, see [How Hyperparameter Tuning Works].
[1]: docs.aws.amazon.com/sagemaker/latest/dg/automatic-model-tuning-how-it-works.html
19299 19300 19301 19302 19303 19304 19305 19306 19307 19308 19309 19310 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19299 class HyperParameterTuningJobConfig < Struct.new( :strategy, :strategy_config, :hyper_parameter_tuning_job_objective, :resource_limits, :parameter_ranges, :training_job_early_stopping_type, :tuning_job_completion_criteria, :random_seed) SENSITIVE = [] include Aws::Structure end |
#strategy_config ⇒ Types::HyperParameterTuningJobStrategyConfig
The configuration for the Hyperband optimization strategy. This parameter should be provided only if Hyperband is selected as the strategy for HyperParameterTuningJobConfig.
19299 19300 19301 19302 19303 19304 19305 19306 19307 19308 19309 19310 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19299 class HyperParameterTuningJobConfig < Struct.new( :strategy, :strategy_config, :hyper_parameter_tuning_job_objective, :resource_limits, :parameter_ranges, :training_job_early_stopping_type, :tuning_job_completion_criteria, :random_seed) SENSITIVE = [] include Aws::Structure end |
#training_job_early_stopping_type ⇒ String
Specifies whether to use early stopping for training jobs launched by the hyperparameter tuning job. Because the Hyperband strategy has its own advanced internal early stopping mechanism, TrainingJobEarlyStoppingType must be OFF to use Hyperband. This parameter can take on one of the following values (the default value is OFF):
OFF
: Training jobs launched by the hyperparameter tuning job do not use
early stopping.
AUTO
: SageMaker stops training jobs launched by the hyperparameter
tuning job when they are unlikely to perform better than
previously completed training jobs. For more information, see
[Stop Training Jobs Early][1].
[1]: docs.aws.amazon.com/sagemaker/latest/dg/automatic-model-tuning-early-stopping.html
19299 19300 19301 19302 19303 19304 19305 19306 19307 19308 19309 19310 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19299 class HyperParameterTuningJobConfig < Struct.new( :strategy, :strategy_config, :hyper_parameter_tuning_job_objective, :resource_limits, :parameter_ranges, :training_job_early_stopping_type, :tuning_job_completion_criteria, :random_seed) SENSITIVE = [] include Aws::Structure end |
#tuning_job_completion_criteria ⇒ Types::TuningJobCompletionCriteria
The tuning job’s completion criteria.
19299 19300 19301 19302 19303 19304 19305 19306 19307 19308 19309 19310 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19299 class HyperParameterTuningJobConfig < Struct.new( :strategy, :strategy_config, :hyper_parameter_tuning_job_objective, :resource_limits, :parameter_ranges, :training_job_early_stopping_type, :tuning_job_completion_criteria, :random_seed) SENSITIVE = [] include Aws::Structure end |