Class: Aws::SageMaker::Types::HyperParameterTuningJobObjective
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::HyperParameterTuningJobObjective
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Defines the objective metric for a hyperparameter tuning job. Hyperparameter tuning uses the value of this metric to evaluate the training jobs it launches, and returns the training job that results in either the highest or lowest value for this metric, depending on the value you specify for the Type parameter.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#metric_name ⇒ String
The name of the metric to use for the objective metric.
-
#type ⇒ String
Whether to minimize or maximize the objective metric.
Instance Attribute Details
#metric_name ⇒ String
The name of the metric to use for the objective metric.
19343 19344 19345 19346 19347 19348 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19343 class HyperParameterTuningJobObjective < Struct.new( :type, :metric_name) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
Whether to minimize or maximize the objective metric.
19343 19344 19345 19346 19347 19348 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19343 class HyperParameterTuningJobObjective < Struct.new( :type, :metric_name) SENSITIVE = [] include Aws::Structure end |