Class: Aws::SageMaker::Types::ImageVersion

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

A version of a SageMaker AI ‘Image`. A version represents an existing container image.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timeTime

When the version was created.

Returns:

  • (Time)


30081
30082
30083
30084
30085
30086
30087
30088
30089
30090
30091
# File 'lib/aws-sdk-sagemaker/types.rb', line 30081

class ImageVersion < Struct.new(
  :creation_time,
  :failure_reason,
  :image_arn,
  :image_version_arn,
  :image_version_status,
  :last_modified_time,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

When a create or delete operation fails, the reason for the failure.

Returns:

  • (String)


30081
30082
30083
30084
30085
30086
30087
30088
30089
30090
30091
# File 'lib/aws-sdk-sagemaker/types.rb', line 30081

class ImageVersion < Struct.new(
  :creation_time,
  :failure_reason,
  :image_arn,
  :image_version_arn,
  :image_version_status,
  :last_modified_time,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#image_arnString

The ARN of the image the version is based on.

Returns:

  • (String)


30081
30082
30083
30084
30085
30086
30087
30088
30089
30090
30091
# File 'lib/aws-sdk-sagemaker/types.rb', line 30081

class ImageVersion < Struct.new(
  :creation_time,
  :failure_reason,
  :image_arn,
  :image_version_arn,
  :image_version_status,
  :last_modified_time,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#image_version_arnString

The ARN of the version.

Returns:

  • (String)


30081
30082
30083
30084
30085
30086
30087
30088
30089
30090
30091
# File 'lib/aws-sdk-sagemaker/types.rb', line 30081

class ImageVersion < Struct.new(
  :creation_time,
  :failure_reason,
  :image_arn,
  :image_version_arn,
  :image_version_status,
  :last_modified_time,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#image_version_statusString

The status of the version.

Returns:

  • (String)


30081
30082
30083
30084
30085
30086
30087
30088
30089
30090
30091
# File 'lib/aws-sdk-sagemaker/types.rb', line 30081

class ImageVersion < Struct.new(
  :creation_time,
  :failure_reason,
  :image_arn,
  :image_version_arn,
  :image_version_status,
  :last_modified_time,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

When the version was last modified.

Returns:

  • (Time)


30081
30082
30083
30084
30085
30086
30087
30088
30089
30090
30091
# File 'lib/aws-sdk-sagemaker/types.rb', line 30081

class ImageVersion < Struct.new(
  :creation_time,
  :failure_reason,
  :image_arn,
  :image_version_arn,
  :image_version_status,
  :last_modified_time,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#versionInteger

The version number.

Returns:

  • (Integer)


30081
30082
30083
30084
30085
30086
30087
30088
30089
30090
30091
# File 'lib/aws-sdk-sagemaker/types.rb', line 30081

class ImageVersion < Struct.new(
  :creation_time,
  :failure_reason,
  :image_arn,
  :image_version_arn,
  :image_version_status,
  :last_modified_time,
  :version)
  SENSITIVE = []
  include Aws::Structure
end