Class: Aws::SageMaker::Types::InferenceComponentAvailabilityZoneBalance
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::InferenceComponentAvailabilityZoneBalance
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Configuration for balancing inference component copies across Availability Zones.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enforcement_mode ⇒ String
Determines how strictly the Availability Zone balance constraint is enforced.
-
#max_imbalance ⇒ Integer
The maximum allowed difference in the number of inference component copies between any two Availability Zones.
Instance Attribute Details
#enforcement_mode ⇒ String
Determines how strictly the Availability Zone balance constraint is enforced.
PERMISSIVE
: The endpoint attempts to balance copies across Availability Zones but proceeds with scheduling even if balance can't be achieved due to available capacity or instance distribution across Availability Zones.
31206 31207 31208 31209 31210 31211 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31206 class InferenceComponentAvailabilityZoneBalance < Struct.new( :enforcement_mode, :max_imbalance) SENSITIVE = [] include Aws::Structure end |
#max_imbalance ⇒ Integer
The maximum allowed difference in the number of inference component copies between any two Availability Zones. This parameter applies only when the endpoint has instances across two or more Availability Zones. A copy placement is allowed if it reduces imbalance or the resulting imbalance is within this value.
Default value: 0.
31206 31207 31208 31209 31210 31211 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31206 class InferenceComponentAvailabilityZoneBalance < Struct.new( :enforcement_mode, :max_imbalance) SENSITIVE = [] include Aws::Structure end |