Class: Aws::SageMaker::Types::InferenceComponentContainerSpecification
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::InferenceComponentContainerSpecification
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Defines a container that provides the runtime environment for a model that you deploy with an inference component.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#artifact_url ⇒ String
The Amazon S3 path where the model artifacts, which result from model training, are stored.
-
#container_metrics_config ⇒ Types::ContainerMetricsConfig
The configuration for container metrics scraping.
-
#environment ⇒ Hash<String,String>
The environment variables to set in the Docker container.
-
#image ⇒ String
The Amazon Elastic Container Registry (Amazon ECR) path where the Docker image for the model is stored.
Instance Attribute Details
#artifact_url ⇒ String
The Amazon S3 path where the model artifacts, which result from model training, are stored. This path must point to a single gzip compressed tar archive (.tar.gz suffix).
30904 30905 30906 30907 30908 30909 30910 30911 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30904 class InferenceComponentContainerSpecification < Struct.new( :image, :artifact_url, :environment, :container_metrics_config) SENSITIVE = [] include Aws::Structure end |
#container_metrics_config ⇒ Types::ContainerMetricsConfig
The configuration for container metrics scraping. Specifies the metrics endpoint path and publishing frequency for the inference component’s container. If not specified when ‘EnableDetailedObservability` is `True`, the default path `/metrics` on port `8080` is used. For first-party and Deep Learning Containers (DLC), the endpoint path is determined automatically and this configuration is optional.
30904 30905 30906 30907 30908 30909 30910 30911 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30904 class InferenceComponentContainerSpecification < Struct.new( :image, :artifact_url, :environment, :container_metrics_config) SENSITIVE = [] include Aws::Structure end |
#environment ⇒ Hash<String,String>
The environment variables to set in the Docker container. Each key and value in the Environment string-to-string map can have length of up to 1024. We support up to 16 entries in the map.
30904 30905 30906 30907 30908 30909 30910 30911 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30904 class InferenceComponentContainerSpecification < Struct.new( :image, :artifact_url, :environment, :container_metrics_config) SENSITIVE = [] include Aws::Structure end |
#image ⇒ String
The Amazon Elastic Container Registry (Amazon ECR) path where the Docker image for the model is stored.
30904 30905 30906 30907 30908 30909 30910 30911 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30904 class InferenceComponentContainerSpecification < Struct.new( :image, :artifact_url, :environment, :container_metrics_config) SENSITIVE = [] include Aws::Structure end |