Class: Aws::SageMaker::Types::InferenceComponentContainerSpecificationSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::InferenceComponentContainerSpecificationSummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Details about the resources that are deployed with this inference component.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#artifact_url ⇒ String
The Amazon S3 path where the model artifacts are stored.
-
#container_metrics_config ⇒ Types::ContainerMetricsConfig
The container metrics scraping configuration for this inference component, including the metrics endpoint path and publishing frequency.
-
#deployed_image ⇒ Types::DeployedImage
Gets the Amazon EC2 Container Registry path of the docker image of the model that is hosted in this [ProductionVariant].
-
#environment ⇒ Hash<String,String>
The environment variables to set in the Docker container.
Instance Attribute Details
#artifact_url ⇒ String
The Amazon S3 path where the model artifacts are stored.
30950 30951 30952 30953 30954 30955 30956 30957 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30950 class InferenceComponentContainerSpecificationSummary < Struct.new( :deployed_image, :artifact_url, :environment, :container_metrics_config) SENSITIVE = [] include Aws::Structure end |
#container_metrics_config ⇒ Types::ContainerMetricsConfig
The container metrics scraping configuration for this inference component, including the metrics endpoint path and publishing frequency.
30950 30951 30952 30953 30954 30955 30956 30957 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30950 class InferenceComponentContainerSpecificationSummary < Struct.new( :deployed_image, :artifact_url, :environment, :container_metrics_config) SENSITIVE = [] include Aws::Structure end |
#deployed_image ⇒ Types::DeployedImage
Gets the Amazon EC2 Container Registry path of the docker image of the model that is hosted in this [ProductionVariant].
If you used the ‘registry/repository` form to specify the image path of the primary container when you created the model hosted in this `ProductionVariant`, the path resolves to a path of the form `registry/repository`. A digest is a hash value that identifies a specific version of an image. For information about Amazon ECR paths, see [Pulling an Image] in the *Amazon ECR User Guide*.
[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_ProductionVariant.html [2]: docs.aws.amazon.com/AmazonECR/latest/userguide/docker-pull-ecr-image.html
30950 30951 30952 30953 30954 30955 30956 30957 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30950 class InferenceComponentContainerSpecificationSummary < Struct.new( :deployed_image, :artifact_url, :environment, :container_metrics_config) SENSITIVE = [] include Aws::Structure end |
#environment ⇒ Hash<String,String>
The environment variables to set in the Docker container.
30950 30951 30952 30953 30954 30955 30956 30957 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30950 class InferenceComponentContainerSpecificationSummary < Struct.new( :deployed_image, :artifact_url, :environment, :container_metrics_config) SENSITIVE = [] include Aws::Structure end |