Class: Aws::SageMaker::Types::InferenceComponentDataCacheConfigSummary

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Settings that affect how the inference component caches data.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enable_cachingBoolean

Indicates whether the inference component caches model artifacts as part of the auto scaling process.

Returns:



28978
28979
28980
28981
28982
# File 'lib/aws-sdk-sagemaker/types.rb', line 28978

class InferenceComponentDataCacheConfigSummary < Struct.new(
  :enable_caching)
  SENSITIVE = []
  include Aws::Structure
end