Class: Aws::SageMaker::Types::InferenceComponentPlacementStatus

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The placement status of an inference component on a specific instance type. Shows the number of inference component copies currently placed on instances of a given type.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#current_copy_countInteger

The number of inference component copies currently placed on instances of this type.

Returns:

  • (Integer)


30466
30467
30468
30469
30470
30471
# File 'lib/aws-sdk-sagemaker/types.rb', line 30466

class InferenceComponentPlacementStatus < Struct.new(
  :instance_type,
  :current_copy_count)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typeString

The ML compute instance type where the inference component copies are placed.

Returns:

  • (String)


30466
30467
30468
30469
30470
30471
# File 'lib/aws-sdk-sagemaker/types.rb', line 30466

class InferenceComponentPlacementStatus < Struct.new(
  :instance_type,
  :current_copy_count)
  SENSITIVE = []
  include Aws::Structure
end