Class: Aws::SageMaker::Types::InferenceComponentRuntimeConfigSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::InferenceComponentRuntimeConfigSummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Details about the runtime settings for the model that is deployed with the inference component.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#current_copy_count ⇒ Integer
The number of runtime copies of the model container that are currently deployed.
-
#desired_copy_count ⇒ Integer
The number of runtime copies of the model container that you requested to deploy with the inference component.
-
#placement_status ⇒ Array<Types::InferenceComponentPlacementStatus>
The placement status of the inference component across instance types.
Instance Attribute Details
#current_copy_count ⇒ Integer
The number of runtime copies of the model container that are currently deployed.
30550 30551 30552 30553 30554 30555 30556 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30550 class InferenceComponentRuntimeConfigSummary < Struct.new( :desired_copy_count, :current_copy_count, :placement_status) SENSITIVE = [] include Aws::Structure end |
#desired_copy_count ⇒ Integer
The number of runtime copies of the model container that you requested to deploy with the inference component.
30550 30551 30552 30553 30554 30555 30556 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30550 class InferenceComponentRuntimeConfigSummary < Struct.new( :desired_copy_count, :current_copy_count, :placement_status) SENSITIVE = [] include Aws::Structure end |
#placement_status ⇒ Array<Types::InferenceComponentPlacementStatus>
The placement status of the inference component across instance types. Shows how the inference component copies are distributed across instance types.
30550 30551 30552 30553 30554 30555 30556 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30550 class InferenceComponentRuntimeConfigSummary < Struct.new( :desired_copy_count, :current_copy_count, :placement_status) SENSITIVE = [] include Aws::Structure end |