Class: Aws::SageMaker::Types::InferenceComponentSpecification

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Details about the resources to deploy with this inference component, including the model, container, and compute resources.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#base_inference_component_nameString

The name of an existing inference component that is to contain the inference component that you’re creating with your request.

Specify this parameter only if your request is meant to create an adapter inference component. An adapter inference component contains the path to an adapter model. The purpose of the adapter model is to tailor the inference output of a base foundation model, which is hosted by the base inference component. The adapter inference component uses the compute resources that you assigned to the base inference component.

When you create an adapter inference component, use the ‘Container` parameter to specify the location of the adapter artifacts. In the parameter value, use the `ArtifactUrl` parameter of the `InferenceComponentContainerSpecification` data type.

Before you can create an adapter inference component, you must have an existing inference component that contains the foundation model that you want to adapt.

Returns:

  • (String)


30660
30661
30662
30663
30664
30665
30666
30667
30668
30669
30670
30671
# File 'lib/aws-sdk-sagemaker/types.rb', line 30660

class InferenceComponentSpecification < Struct.new(
  :instance_type,
  :model_name,
  :container,
  :startup_parameters,
  :compute_resource_requirements,
  :base_inference_component_name,
  :data_cache_config,
  :scheduling_config)
  SENSITIVE = []
  include Aws::Structure
end

#compute_resource_requirementsTypes::InferenceComponentComputeResourceRequirements

The compute resources allocated to run the model, plus any adapter models, that you assign to the inference component.

Omit this parameter if your request is meant to create an adapter inference component. An adapter inference component is loaded by a base inference component, and it uses the compute resources of the base inference component.



30660
30661
30662
30663
30664
30665
30666
30667
30668
30669
30670
30671
# File 'lib/aws-sdk-sagemaker/types.rb', line 30660

class InferenceComponentSpecification < Struct.new(
  :instance_type,
  :model_name,
  :container,
  :startup_parameters,
  :compute_resource_requirements,
  :base_inference_component_name,
  :data_cache_config,
  :scheduling_config)
  SENSITIVE = []
  include Aws::Structure
end

#containerTypes::InferenceComponentContainerSpecification

Defines a container that provides the runtime environment for a model that you deploy with an inference component.



30660
30661
30662
30663
30664
30665
30666
30667
30668
30669
30670
30671
# File 'lib/aws-sdk-sagemaker/types.rb', line 30660

class InferenceComponentSpecification < Struct.new(
  :instance_type,
  :model_name,
  :container,
  :startup_parameters,
  :compute_resource_requirements,
  :base_inference_component_name,
  :data_cache_config,
  :scheduling_config)
  SENSITIVE = []
  include Aws::Structure
end

#data_cache_configTypes::InferenceComponentDataCacheConfig

Settings that affect how the inference component caches data.



30660
30661
30662
30663
30664
30665
30666
30667
30668
30669
30670
30671
# File 'lib/aws-sdk-sagemaker/types.rb', line 30660

class InferenceComponentSpecification < Struct.new(
  :instance_type,
  :model_name,
  :container,
  :startup_parameters,
  :compute_resource_requirements,
  :base_inference_component_name,
  :data_cache_config,
  :scheduling_config)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typeString

The ML compute instance type for the inference component specification. Specifies which instance type this specification applies to. Required when using the ‘Specifications` parameter with multiple entries.

Returns:

  • (String)


30660
30661
30662
30663
30664
30665
30666
30667
30668
30669
30670
30671
# File 'lib/aws-sdk-sagemaker/types.rb', line 30660

class InferenceComponentSpecification < Struct.new(
  :instance_type,
  :model_name,
  :container,
  :startup_parameters,
  :compute_resource_requirements,
  :base_inference_component_name,
  :data_cache_config,
  :scheduling_config)
  SENSITIVE = []
  include Aws::Structure
end

#model_nameString

The name of an existing SageMaker AI model object in your account that you want to deploy with the inference component.

Returns:

  • (String)


30660
30661
30662
30663
30664
30665
30666
30667
30668
30669
30670
30671
# File 'lib/aws-sdk-sagemaker/types.rb', line 30660

class InferenceComponentSpecification < Struct.new(
  :instance_type,
  :model_name,
  :container,
  :startup_parameters,
  :compute_resource_requirements,
  :base_inference_component_name,
  :data_cache_config,
  :scheduling_config)
  SENSITIVE = []
  include Aws::Structure
end

#scheduling_configTypes::InferenceComponentSchedulingConfig

The scheduling configuration that determines how inference component copies are placed across available instances when copies are added or removed.



30660
30661
30662
30663
30664
30665
30666
30667
30668
30669
30670
30671
# File 'lib/aws-sdk-sagemaker/types.rb', line 30660

class InferenceComponentSpecification < Struct.new(
  :instance_type,
  :model_name,
  :container,
  :startup_parameters,
  :compute_resource_requirements,
  :base_inference_component_name,
  :data_cache_config,
  :scheduling_config)
  SENSITIVE = []
  include Aws::Structure
end

#startup_parametersTypes::InferenceComponentStartupParameters

Settings that take effect while the model container starts up.



30660
30661
30662
30663
30664
30665
30666
30667
30668
30669
30670
30671
# File 'lib/aws-sdk-sagemaker/types.rb', line 30660

class InferenceComponentSpecification < Struct.new(
  :instance_type,
  :model_name,
  :container,
  :startup_parameters,
  :compute_resource_requirements,
  :base_inference_component_name,
  :data_cache_config,
  :scheduling_config)
  SENSITIVE = []
  include Aws::Structure
end