Class: Aws::SageMaker::Types::InferenceComponentSpecificationSummary

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Details about the resources that are deployed with this inference component.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#base_inference_component_nameString

The name of the base inference component that contains this inference component.

Returns:



29198
29199
29200
29201
29202
29203
29204
29205
29206
29207
# File 'lib/aws-sdk-sagemaker/types.rb', line 29198

class InferenceComponentSpecificationSummary < Struct.new(
  :model_name,
  :container,
  :startup_parameters,
  :compute_resource_requirements,
  :base_inference_component_name,
  :data_cache_config)
  SENSITIVE = []
  include Aws::Structure
end

#compute_resource_requirementsTypes::InferenceComponentComputeResourceRequirements

The compute resources allocated to run the model, plus any adapter models, that you assign to the inference component.

Returns:



29198
29199
29200
29201
29202
29203
29204
29205
29206
29207
# File 'lib/aws-sdk-sagemaker/types.rb', line 29198

class InferenceComponentSpecificationSummary < Struct.new(
  :model_name,
  :container,
  :startup_parameters,
  :compute_resource_requirements,
  :base_inference_component_name,
  :data_cache_config)
  SENSITIVE = []
  include Aws::Structure
end

#containerTypes::InferenceComponentContainerSpecificationSummary

Details about the container that provides the runtime environment for the model that is deployed with the inference component.

Returns:



29198
29199
29200
29201
29202
29203
29204
29205
29206
29207
# File 'lib/aws-sdk-sagemaker/types.rb', line 29198

class InferenceComponentSpecificationSummary < Struct.new(
  :model_name,
  :container,
  :startup_parameters,
  :compute_resource_requirements,
  :base_inference_component_name,
  :data_cache_config)
  SENSITIVE = []
  include Aws::Structure
end

#data_cache_configTypes::InferenceComponentDataCacheConfigSummary

Settings that affect how the inference component caches data.

Returns:



29198
29199
29200
29201
29202
29203
29204
29205
29206
29207
# File 'lib/aws-sdk-sagemaker/types.rb', line 29198

class InferenceComponentSpecificationSummary < Struct.new(
  :model_name,
  :container,
  :startup_parameters,
  :compute_resource_requirements,
  :base_inference_component_name,
  :data_cache_config)
  SENSITIVE = []
  include Aws::Structure
end

#model_nameString

The name of the SageMaker AI model object that is deployed with the inference component.

Returns:



29198
29199
29200
29201
29202
29203
29204
29205
29206
29207
# File 'lib/aws-sdk-sagemaker/types.rb', line 29198

class InferenceComponentSpecificationSummary < Struct.new(
  :model_name,
  :container,
  :startup_parameters,
  :compute_resource_requirements,
  :base_inference_component_name,
  :data_cache_config)
  SENSITIVE = []
  include Aws::Structure
end

#startup_parametersTypes::InferenceComponentStartupParameters

Settings that take effect while the model container starts up.

Returns:



29198
29199
29200
29201
29202
29203
29204
29205
29206
29207
# File 'lib/aws-sdk-sagemaker/types.rb', line 29198

class InferenceComponentSpecificationSummary < Struct.new(
  :model_name,
  :container,
  :startup_parameters,
  :compute_resource_requirements,
  :base_inference_component_name,
  :data_cache_config)
  SENSITIVE = []
  include Aws::Structure
end