Method: Aws::SageMaker::Types::InferenceExperimentDataStorageConfig#kms_key

Defined in:
lib/aws-sdk-sagemaker/types.rb

#kms_keyString

The Amazon Web Services Key Management Service key that Amazon SageMaker uses to encrypt captured data at rest using Amazon S3 server-side encryption.

Returns:

  • (String)


29237
29238
29239
29240
29241
29242
29243
# File 'lib/aws-sdk-sagemaker/types.rb', line 29237

class InferenceExperimentDataStorageConfig < Struct.new(
  :destination,
  :kms_key,
  :content_type)
  SENSITIVE = []
  include Aws::Structure
end