Class: Aws::SageMaker::Types::InferenceRecommendationsJob
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::InferenceRecommendationsJob
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
A structure that contains a list of recommendation jobs.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#completion_time ⇒ Time
A timestamp that shows when the job completed.
-
#creation_time ⇒ Time
A timestamp that shows when the job was created.
-
#failure_reason ⇒ String
If the job fails, provides information why the job failed.
-
#job_arn ⇒ String
The Amazon Resource Name (ARN) of the recommendation job.
-
#job_description ⇒ String
The job description.
-
#job_name ⇒ String
The name of the job.
-
#job_type ⇒ String
The recommendation job type.
-
#last_modified_time ⇒ Time
A timestamp that shows when the job was last modified.
-
#model_name ⇒ String
The name of the created model.
-
#model_package_version_arn ⇒ String
The Amazon Resource Name (ARN) of a versioned model package.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that enables Amazon SageMaker to perform tasks on your behalf.
-
#sample_payload_url ⇒ String
The Amazon Simple Storage Service (Amazon S3) path where the sample payload is stored.
-
#status ⇒ String
The status of the job.
Instance Attribute Details
#completion_time ⇒ Time
A timestamp that shows when the job completed.
31837 31838 31839 31840 31841 31842 31843 31844 31845 31846 31847 31848 31849 31850 31851 31852 31853 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31837 class InferenceRecommendationsJob < Struct.new( :job_name, :job_description, :job_type, :job_arn, :status, :creation_time, :completion_time, :role_arn, :last_modified_time, :failure_reason, :model_name, :sample_payload_url, :model_package_version_arn) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
A timestamp that shows when the job was created.
31837 31838 31839 31840 31841 31842 31843 31844 31845 31846 31847 31848 31849 31850 31851 31852 31853 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31837 class InferenceRecommendationsJob < Struct.new( :job_name, :job_description, :job_type, :job_arn, :status, :creation_time, :completion_time, :role_arn, :last_modified_time, :failure_reason, :model_name, :sample_payload_url, :model_package_version_arn) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
If the job fails, provides information why the job failed.
31837 31838 31839 31840 31841 31842 31843 31844 31845 31846 31847 31848 31849 31850 31851 31852 31853 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31837 class InferenceRecommendationsJob < Struct.new( :job_name, :job_description, :job_type, :job_arn, :status, :creation_time, :completion_time, :role_arn, :last_modified_time, :failure_reason, :model_name, :sample_payload_url, :model_package_version_arn) SENSITIVE = [] include Aws::Structure end |
#job_arn ⇒ String
The Amazon Resource Name (ARN) of the recommendation job.
31837 31838 31839 31840 31841 31842 31843 31844 31845 31846 31847 31848 31849 31850 31851 31852 31853 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31837 class InferenceRecommendationsJob < Struct.new( :job_name, :job_description, :job_type, :job_arn, :status, :creation_time, :completion_time, :role_arn, :last_modified_time, :failure_reason, :model_name, :sample_payload_url, :model_package_version_arn) SENSITIVE = [] include Aws::Structure end |
#job_description ⇒ String
The job description.
31837 31838 31839 31840 31841 31842 31843 31844 31845 31846 31847 31848 31849 31850 31851 31852 31853 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31837 class InferenceRecommendationsJob < Struct.new( :job_name, :job_description, :job_type, :job_arn, :status, :creation_time, :completion_time, :role_arn, :last_modified_time, :failure_reason, :model_name, :sample_payload_url, :model_package_version_arn) SENSITIVE = [] include Aws::Structure end |
#job_name ⇒ String
The name of the job.
31837 31838 31839 31840 31841 31842 31843 31844 31845 31846 31847 31848 31849 31850 31851 31852 31853 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31837 class InferenceRecommendationsJob < Struct.new( :job_name, :job_description, :job_type, :job_arn, :status, :creation_time, :completion_time, :role_arn, :last_modified_time, :failure_reason, :model_name, :sample_payload_url, :model_package_version_arn) SENSITIVE = [] include Aws::Structure end |
#job_type ⇒ String
The recommendation job type.
31837 31838 31839 31840 31841 31842 31843 31844 31845 31846 31847 31848 31849 31850 31851 31852 31853 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31837 class InferenceRecommendationsJob < Struct.new( :job_name, :job_description, :job_type, :job_arn, :status, :creation_time, :completion_time, :role_arn, :last_modified_time, :failure_reason, :model_name, :sample_payload_url, :model_package_version_arn) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
A timestamp that shows when the job was last modified.
31837 31838 31839 31840 31841 31842 31843 31844 31845 31846 31847 31848 31849 31850 31851 31852 31853 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31837 class InferenceRecommendationsJob < Struct.new( :job_name, :job_description, :job_type, :job_arn, :status, :creation_time, :completion_time, :role_arn, :last_modified_time, :failure_reason, :model_name, :sample_payload_url, :model_package_version_arn) SENSITIVE = [] include Aws::Structure end |
#model_name ⇒ String
The name of the created model.
31837 31838 31839 31840 31841 31842 31843 31844 31845 31846 31847 31848 31849 31850 31851 31852 31853 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31837 class InferenceRecommendationsJob < Struct.new( :job_name, :job_description, :job_type, :job_arn, :status, :creation_time, :completion_time, :role_arn, :last_modified_time, :failure_reason, :model_name, :sample_payload_url, :model_package_version_arn) SENSITIVE = [] include Aws::Structure end |
#model_package_version_arn ⇒ String
The Amazon Resource Name (ARN) of a versioned model package.
31837 31838 31839 31840 31841 31842 31843 31844 31845 31846 31847 31848 31849 31850 31851 31852 31853 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31837 class InferenceRecommendationsJob < Struct.new( :job_name, :job_description, :job_type, :job_arn, :status, :creation_time, :completion_time, :role_arn, :last_modified_time, :failure_reason, :model_name, :sample_payload_url, :model_package_version_arn) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that enables Amazon SageMaker to perform tasks on your behalf.
31837 31838 31839 31840 31841 31842 31843 31844 31845 31846 31847 31848 31849 31850 31851 31852 31853 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31837 class InferenceRecommendationsJob < Struct.new( :job_name, :job_description, :job_type, :job_arn, :status, :creation_time, :completion_time, :role_arn, :last_modified_time, :failure_reason, :model_name, :sample_payload_url, :model_package_version_arn) SENSITIVE = [] include Aws::Structure end |
#sample_payload_url ⇒ String
The Amazon Simple Storage Service (Amazon S3) path where the sample payload is stored. This path must point to a single gzip compressed tar archive (.tar.gz suffix).
31837 31838 31839 31840 31841 31842 31843 31844 31845 31846 31847 31848 31849 31850 31851 31852 31853 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31837 class InferenceRecommendationsJob < Struct.new( :job_name, :job_description, :job_type, :job_arn, :status, :creation_time, :completion_time, :role_arn, :last_modified_time, :failure_reason, :model_name, :sample_payload_url, :model_package_version_arn) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the job.
31837 31838 31839 31840 31841 31842 31843 31844 31845 31846 31847 31848 31849 31850 31851 31852 31853 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31837 class InferenceRecommendationsJob < Struct.new( :job_name, :job_description, :job_type, :job_arn, :status, :creation_time, :completion_time, :role_arn, :last_modified_time, :failure_reason, :model_name, :sample_payload_url, :model_package_version_arn) SENSITIVE = [] include Aws::Structure end |