Class: Aws::SageMaker::Types::InstanceGroupHealthCheckConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The configuration of deep health checks for an instance group.

<note markdown=“1”> Overlapping deep health check configurations will be merged into a single operation.

</note>

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#deep_health_checksArray<String>

A list of deep health checks to be performed.

Returns:

  • (Array<String>)


30213
30214
30215
30216
30217
30218
30219
# File 'lib/aws-sdk-sagemaker/types.rb', line 30213

class InstanceGroupHealthCheckConfiguration < Struct.new(
  :instance_group_name,
  :instance_ids,
  :deep_health_checks)
  SENSITIVE = []
  include Aws::Structure
end

#instance_group_nameString

The name of the instance group.

Returns:

  • (String)


30213
30214
30215
30216
30217
30218
30219
# File 'lib/aws-sdk-sagemaker/types.rb', line 30213

class InstanceGroupHealthCheckConfiguration < Struct.new(
  :instance_group_name,
  :instance_ids,
  :deep_health_checks)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idsArray<String>

A list of Amazon Elastic Compute Cloud (EC2) instance IDs on which to perform deep health checks.

<note markdown=“1”> Leave this field blank to perform deep health checks on the entire instance group.

</note>

Returns:

  • (Array<String>)


30213
30214
30215
30216
30217
30218
30219
# File 'lib/aws-sdk-sagemaker/types.rb', line 30213

class InstanceGroupHealthCheckConfiguration < Struct.new(
  :instance_group_name,
  :instance_ids,
  :deep_health_checks)
  SENSITIVE = []
  include Aws::Structure
end