Class: Aws::SageMaker::Types::InstanceGroupScalingMetadata

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Metadata information about scaling operations for an instance group.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#failure_messageString

An error message describing why the scaling operation failed, if applicable.



32719
32720
32721
32722
32723
32724
32725
32726
# File 'lib/aws-sdk-sagemaker/types.rb', line 32719

class  < Struct.new(
  :instance_count,
  :target_count,
  :min_count,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#instance_countInteger

The current number of instances in the group.



32719
32720
32721
32722
32723
32724
32725
32726
# File 'lib/aws-sdk-sagemaker/types.rb', line 32719

class  < Struct.new(
  :instance_count,
  :target_count,
  :min_count,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#min_countInteger

Minimum instance count of the instance group.



32719
32720
32721
32722
32723
32724
32725
32726
# File 'lib/aws-sdk-sagemaker/types.rb', line 32719

class  < Struct.new(
  :instance_count,
  :target_count,
  :min_count,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end

#target_countInteger

The desired number of instances for the group after scaling.



32719
32720
32721
32722
32723
32724
32725
32726
# File 'lib/aws-sdk-sagemaker/types.rb', line 32719

class  < Struct.new(
  :instance_count,
  :target_count,
  :min_count,
  :failure_message)
  SENSITIVE = []
  include Aws::Structure
end