Class: Aws::SageMaker::Types::InstanceMetadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::InstanceMetadata
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Metadata information about an instance in a HyperPod cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_enis ⇒ Types::AdditionalEnis
Information about additional Elastic Network Interfaces (ENIs) associated with the instance.
-
#capacity_reservation ⇒ Types::CapacityReservation
Information about the Capacity Reservation used by the instance.
-
#customer_eni ⇒ String
The ID of the customer-managed Elastic Network Interface (ENI) associated with the instance.
-
#failure_message ⇒ String
An error message describing why the instance creation or update failed, if applicable.
-
#instance_requirements_eni_configurations ⇒ Array<Types::InstanceRequirementsEniConfiguration>
The ENI configurations for the instance types in the instance requirements, grouped by network interface category (for example, ENI-only or EFA with ENIs).
-
#lcs_execution_state ⇒ String
The execution state of the Lifecycle Script (LCS) for the instance.
-
#node_logical_id ⇒ String
The unique logical identifier of the node within the cluster.
Instance Attribute Details
#additional_enis ⇒ Types::AdditionalEnis
Information about additional Elastic Network Interfaces (ENIs) associated with the instance.
32766 32767 32768 32769 32770 32771 32772 32773 32774 32775 32776 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32766 class InstanceMetadata < Struct.new( :customer_eni, :additional_enis, :instance_requirements_eni_configurations, :capacity_reservation, :failure_message, :lcs_execution_state, :node_logical_id) SENSITIVE = [] include Aws::Structure end |
#capacity_reservation ⇒ Types::CapacityReservation
Information about the Capacity Reservation used by the instance.
32766 32767 32768 32769 32770 32771 32772 32773 32774 32775 32776 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32766 class InstanceMetadata < Struct.new( :customer_eni, :additional_enis, :instance_requirements_eni_configurations, :capacity_reservation, :failure_message, :lcs_execution_state, :node_logical_id) SENSITIVE = [] include Aws::Structure end |
#customer_eni ⇒ String
The ID of the customer-managed Elastic Network Interface (ENI) associated with the instance.
32766 32767 32768 32769 32770 32771 32772 32773 32774 32775 32776 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32766 class InstanceMetadata < Struct.new( :customer_eni, :additional_enis, :instance_requirements_eni_configurations, :capacity_reservation, :failure_message, :lcs_execution_state, :node_logical_id) SENSITIVE = [] include Aws::Structure end |
#failure_message ⇒ String
An error message describing why the instance creation or update failed, if applicable.
32766 32767 32768 32769 32770 32771 32772 32773 32774 32775 32776 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32766 class InstanceMetadata < Struct.new( :customer_eni, :additional_enis, :instance_requirements_eni_configurations, :capacity_reservation, :failure_message, :lcs_execution_state, :node_logical_id) SENSITIVE = [] include Aws::Structure end |
#instance_requirements_eni_configurations ⇒ Array<Types::InstanceRequirementsEniConfiguration>
The ENI configurations for the instance types in the instance requirements, grouped by network interface category (for example, ENI-only or EFA with ENIs). At most one configuration per category.
32766 32767 32768 32769 32770 32771 32772 32773 32774 32775 32776 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32766 class InstanceMetadata < Struct.new( :customer_eni, :additional_enis, :instance_requirements_eni_configurations, :capacity_reservation, :failure_message, :lcs_execution_state, :node_logical_id) SENSITIVE = [] include Aws::Structure end |
#lcs_execution_state ⇒ String
The execution state of the Lifecycle Script (LCS) for the instance.
32766 32767 32768 32769 32770 32771 32772 32773 32774 32775 32776 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32766 class InstanceMetadata < Struct.new( :customer_eni, :additional_enis, :instance_requirements_eni_configurations, :capacity_reservation, :failure_message, :lcs_execution_state, :node_logical_id) SENSITIVE = [] include Aws::Structure end |
#node_logical_id ⇒ String
The unique logical identifier of the node within the cluster. The ID
used here is the same object as in the BatchAddClusterNodes API.
32766 32767 32768 32769 32770 32771 32772 32773 32774 32775 32776 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32766 class InstanceMetadata < Struct.new( :customer_eni, :additional_enis, :instance_requirements_eni_configurations, :capacity_reservation, :failure_message, :lcs_execution_state, :node_logical_id) SENSITIVE = [] include Aws::Structure end |