Class: Aws::SageMaker::Types::InstancePoolSummary

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

A summary of an instance pool for a production variant, including the instance type and the current number of instances.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#current_instance_countInteger

The current number of instances of this type in the instance pool.

Returns:

  • (Integer)


31857
31858
31859
31860
31861
31862
# File 'lib/aws-sdk-sagemaker/types.rb', line 31857

class InstancePoolSummary < Struct.new(
  :instance_type,
  :current_instance_count)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typeString

The ML compute instance type for the instance pool.

Returns:

  • (String)


31857
31858
31859
31860
31861
31862
# File 'lib/aws-sdk-sagemaker/types.rb', line 31857

class InstancePoolSummary < Struct.new(
  :instance_type,
  :current_instance_count)
  SENSITIVE = []
  include Aws::Structure
end