Class: Aws::SageMaker::Types::JobSecondaryStatusTransition

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Represents a secondary status transition for a job. Jobs progress through multiple secondary statuses during execution. Each transition records the status, start time, optional end time, and an optional message with additional details.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#end_timeTime

The date and time that the status transition ended.

Returns:

  • (Time)


33140
33141
33142
33143
33144
33145
33146
33147
# File 'lib/aws-sdk-sagemaker/types.rb', line 33140

class JobSecondaryStatusTransition < Struct.new(
  :status,
  :start_time,
  :end_time,
  :status_message)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The date and time that the status transition started.

Returns:

  • (Time)


33140
33141
33142
33143
33144
33145
33146
33147
# File 'lib/aws-sdk-sagemaker/types.rb', line 33140

class JobSecondaryStatusTransition < Struct.new(
  :status,
  :start_time,
  :end_time,
  :status_message)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The secondary status of the job at this transition point.

Returns:

  • (String)


33140
33141
33142
33143
33144
33145
33146
33147
# File 'lib/aws-sdk-sagemaker/types.rb', line 33140

class JobSecondaryStatusTransition < Struct.new(
  :status,
  :start_time,
  :end_time,
  :status_message)
  SENSITIVE = []
  include Aws::Structure
end

#status_messageString

A detailed message about the status transition.

Returns:

  • (String)


33140
33141
33142
33143
33144
33145
33146
33147
# File 'lib/aws-sdk-sagemaker/types.rb', line 33140

class JobSecondaryStatusTransition < Struct.new(
  :status,
  :start_time,
  :end_time,
  :status_message)
  SENSITIVE = []
  include Aws::Structure
end