Class: Aws::SageMaker::Types::JupyterServerAppSettings

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The JupyterServer app settings.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#code_repositoriesArray<Types::CodeRepository>

A list of Git repositories that SageMaker AI automatically displays to users for cloning in the JupyterServer application.

Returns:



30500
30501
30502
30503
30504
30505
30506
# File 'lib/aws-sdk-sagemaker/types.rb', line 30500

class JupyterServerAppSettings < Struct.new(
  :default_resource_spec,
  :lifecycle_config_arns,
  :code_repositories)
  SENSITIVE = []
  include Aws::Structure
end

#default_resource_specTypes::ResourceSpec

The default instance type and the Amazon Resource Name (ARN) of the default SageMaker AI image used by the JupyterServer app. If you use the LifecycleConfigArns parameter, then this parameter is also required.

Returns:



30500
30501
30502
30503
30504
30505
30506
# File 'lib/aws-sdk-sagemaker/types.rb', line 30500

class JupyterServerAppSettings < Struct.new(
  :default_resource_spec,
  :lifecycle_config_arns,
  :code_repositories)
  SENSITIVE = []
  include Aws::Structure
end

#lifecycle_config_arnsArray<String>

The Amazon Resource Name (ARN) of the Lifecycle Configurations attached to the JupyterServerApp. If you use this parameter, the DefaultResourceSpec parameter is also required.

To remove a Lifecycle Config, you must set LifecycleConfigArns to an empty list.

Returns:

  • (Array<String>)


30500
30501
30502
30503
30504
30505
30506
# File 'lib/aws-sdk-sagemaker/types.rb', line 30500

class JupyterServerAppSettings < Struct.new(
  :default_resource_spec,
  :lifecycle_config_arns,
  :code_repositories)
  SENSITIVE = []
  include Aws::Structure
end