Class: Aws::SageMaker::Types::KernelGatewayAppSettings

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The KernelGateway app settings.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#custom_imagesArray<Types::CustomImage>

A list of custom SageMaker AI images that are configured to run as a KernelGateway app.

The maximum number of custom images are as follows.

  • On a domain level: 200

  • On a space level: 5

  • On a user profile level: 5

Returns:



30332
30333
30334
30335
30336
30337
30338
# File 'lib/aws-sdk-sagemaker/types.rb', line 30332

class KernelGatewayAppSettings < Struct.new(
  :default_resource_spec,
  :custom_images,
  :lifecycle_config_arns)
  SENSITIVE = []
  include Aws::Structure
end

#default_resource_specTypes::ResourceSpec

The default instance type and the Amazon Resource Name (ARN) of the default SageMaker AI image used by the KernelGateway app.

<note markdown=“1”> The Amazon SageMaker AI Studio UI does not use the default instance type value set here. The default instance type set here is used when Apps are created using the CLI or CloudFormation and the instance type parameter value is not passed.

</note>

Returns:



30332
30333
30334
30335
30336
30337
30338
# File 'lib/aws-sdk-sagemaker/types.rb', line 30332

class KernelGatewayAppSettings < Struct.new(
  :default_resource_spec,
  :custom_images,
  :lifecycle_config_arns)
  SENSITIVE = []
  include Aws::Structure
end

#lifecycle_config_arnsArray<String>

The Amazon Resource Name (ARN) of the Lifecycle Configurations attached to the the user profile or domain.

<note markdown=“1”> To remove a Lifecycle Config, you must set LifecycleConfigArns to an empty list.

</note>

Returns:

  • (Array<String>)


30332
30333
30334
30335
30336
30337
30338
# File 'lib/aws-sdk-sagemaker/types.rb', line 30332

class KernelGatewayAppSettings < Struct.new(
  :default_resource_spec,
  :custom_images,
  :lifecycle_config_arns)
  SENSITIVE = []
  include Aws::Structure
end