Class: Aws::SageMaker::Types::ListAlgorithmsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListAlgorithmsInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time_after ⇒ Time
A filter that returns only algorithms created after the specified time (timestamp).
-
#creation_time_before ⇒ Time
A filter that returns only algorithms created before the specified time (timestamp).
-
#max_results ⇒ Integer
The maximum number of algorithms to return in the response.
-
#name_contains ⇒ String
A string in the algorithm name.
-
#next_token ⇒ String
If the response to a previous
ListAlgorithmsrequest was truncated, the response includes aNextToken. -
#sort_by ⇒ String
The parameter by which to sort the results.
-
#sort_order ⇒ String
The sort order for the results.
Instance Attribute Details
#creation_time_after ⇒ Time
A filter that returns only algorithms created after the specified time (timestamp).
31330 31331 31332 31333 31334 31335 31336 31337 31338 31339 31340 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31330 class ListAlgorithmsInput < Struct.new( :creation_time_after, :creation_time_before, :max_results, :name_contains, :next_token, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#creation_time_before ⇒ Time
A filter that returns only algorithms created before the specified time (timestamp).
31330 31331 31332 31333 31334 31335 31336 31337 31338 31339 31340 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31330 class ListAlgorithmsInput < Struct.new( :creation_time_after, :creation_time_before, :max_results, :name_contains, :next_token, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of algorithms to return in the response.
31330 31331 31332 31333 31334 31335 31336 31337 31338 31339 31340 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31330 class ListAlgorithmsInput < Struct.new( :creation_time_after, :creation_time_before, :max_results, :name_contains, :next_token, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#name_contains ⇒ String
A string in the algorithm name. This filter returns only algorithms whose name contains the specified string.
31330 31331 31332 31333 31334 31335 31336 31337 31338 31339 31340 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31330 class ListAlgorithmsInput < Struct.new( :creation_time_after, :creation_time_before, :max_results, :name_contains, :next_token, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the response to a previous ListAlgorithms request was
truncated, the response includes a NextToken. To retrieve the next
set of algorithms, use the token in the next request.
31330 31331 31332 31333 31334 31335 31336 31337 31338 31339 31340 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31330 class ListAlgorithmsInput < Struct.new( :creation_time_after, :creation_time_before, :max_results, :name_contains, :next_token, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
The parameter by which to sort the results. The default is
CreationTime.
31330 31331 31332 31333 31334 31335 31336 31337 31338 31339 31340 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31330 class ListAlgorithmsInput < Struct.new( :creation_time_after, :creation_time_before, :max_results, :name_contains, :next_token, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
The sort order for the results. The default is Ascending.
31330 31331 31332 31333 31334 31335 31336 31337 31338 31339 31340 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31330 class ListAlgorithmsInput < Struct.new( :creation_time_after, :creation_time_before, :max_results, :name_contains, :next_token, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |