Class: Aws::SageMaker::Types::ListAliasesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListAliasesRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias ⇒ String
The alias of the image version.
-
#image_name ⇒ String
The name of the image.
-
#max_results ⇒ Integer
The maximum number of aliases to return.
-
#next_token ⇒ String
If the previous call to
ListAliasesdidn’t return the full set of aliases, the call returns a token for retrieving the next set of aliases. -
#version ⇒ Integer
The version of the image.
Instance Attribute Details
#alias ⇒ String
The alias of the image version.
31156 31157 31158 31159 31160 31161 31162 31163 31164 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31156 class ListAliasesRequest < Struct.new( :image_name, :alias, :version, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#image_name ⇒ String
The name of the image.
31156 31157 31158 31159 31160 31161 31162 31163 31164 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31156 class ListAliasesRequest < Struct.new( :image_name, :alias, :version, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of aliases to return.
31156 31157 31158 31159 31160 31161 31162 31163 31164 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31156 class ListAliasesRequest < Struct.new( :image_name, :alias, :version, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the previous call to ListAliases didn’t return the full set of aliases, the call returns a token for retrieving the next set of aliases.
31156 31157 31158 31159 31160 31161 31162 31163 31164 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31156 class ListAliasesRequest < Struct.new( :image_name, :alias, :version, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#version ⇒ Integer
The version of the image. If image version is not specified, the aliases of all versions of the image are listed.
31156 31157 31158 31159 31160 31161 31162 31163 31164 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31156 class ListAliasesRequest < Struct.new( :image_name, :alias, :version, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |