Class: Aws::SageMaker::Types::ListAppsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListAppsResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#apps ⇒ Array<Types::AppDetails>
The list of apps.
-
#next_token ⇒ String
If the previous response was truncated, you will receive this token.
Instance Attribute Details
#apps ⇒ Array<Types::AppDetails>
The list of apps.
31328 31329 31330 31331 31332 31333 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31328 class ListAppsResponse < Struct.new( :apps, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the previous response was truncated, you will receive this token. Use it in your next request to receive the next set of results.
31328 31329 31330 31331 31332 31333 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31328 class ListAppsResponse < Struct.new( :apps, :next_token) SENSITIVE = [] include Aws::Structure end |