Class: Aws::SageMaker::Types::ListArtifactsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#artifact_typeString

A filter that returns only artifacts of the specified type.

Returns:

  • (String)


31282
31283
31284
31285
31286
31287
31288
31289
31290
31291
31292
31293
# File 'lib/aws-sdk-sagemaker/types.rb', line 31282

class ListArtifactsRequest < Struct.new(
  :source_uri,
  :artifact_type,
  :created_after,
  :created_before,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#created_afterTime

A filter that returns only artifacts created on or after the specified time.

Returns:

  • (Time)


31282
31283
31284
31285
31286
31287
31288
31289
31290
31291
31292
31293
# File 'lib/aws-sdk-sagemaker/types.rb', line 31282

class ListArtifactsRequest < Struct.new(
  :source_uri,
  :artifact_type,
  :created_after,
  :created_before,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#created_beforeTime

A filter that returns only artifacts created on or before the specified time.

Returns:

  • (Time)


31282
31283
31284
31285
31286
31287
31288
31289
31290
31291
31292
31293
# File 'lib/aws-sdk-sagemaker/types.rb', line 31282

class ListArtifactsRequest < Struct.new(
  :source_uri,
  :artifact_type,
  :created_after,
  :created_before,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of artifacts to return in the response. The default value is 10.

Returns:

  • (Integer)


31282
31283
31284
31285
31286
31287
31288
31289
31290
31291
31292
31293
# File 'lib/aws-sdk-sagemaker/types.rb', line 31282

class ListArtifactsRequest < Struct.new(
  :source_uri,
  :artifact_type,
  :created_after,
  :created_before,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the previous call to ListArtifacts didn’t return the full set of artifacts, the call returns a token for getting the next set of artifacts.

Returns:

  • (String)


31282
31283
31284
31285
31286
31287
31288
31289
31290
31291
31292
31293
# File 'lib/aws-sdk-sagemaker/types.rb', line 31282

class ListArtifactsRequest < Struct.new(
  :source_uri,
  :artifact_type,
  :created_after,
  :created_before,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#sort_byString

The property used to sort results. The default value is CreationTime.

Returns:

  • (String)


31282
31283
31284
31285
31286
31287
31288
31289
31290
31291
31292
31293
# File 'lib/aws-sdk-sagemaker/types.rb', line 31282

class ListArtifactsRequest < Struct.new(
  :source_uri,
  :artifact_type,
  :created_after,
  :created_before,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#sort_orderString

The sort order. The default value is Descending.

Returns:

  • (String)


31282
31283
31284
31285
31286
31287
31288
31289
31290
31291
31292
31293
# File 'lib/aws-sdk-sagemaker/types.rb', line 31282

class ListArtifactsRequest < Struct.new(
  :source_uri,
  :artifact_type,
  :created_after,
  :created_before,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#source_uriString

A filter that returns only artifacts with the specified source URI.

Returns:

  • (String)


31282
31283
31284
31285
31286
31287
31288
31289
31290
31291
31292
31293
# File 'lib/aws-sdk-sagemaker/types.rb', line 31282

class ListArtifactsRequest < Struct.new(
  :source_uri,
  :artifact_type,
  :created_after,
  :created_before,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end