Class: Aws::SageMaker::Types::ListAssociationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListAssociationsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#association_type ⇒ String
A filter that returns only associations of the specified type.
-
#created_after ⇒ Time
A filter that returns only associations created on or after the specified time.
-
#created_before ⇒ Time
A filter that returns only associations created on or before the specified time.
-
#destination_arn ⇒ String
A filter that returns only associations with the specified destination Amazon Resource Name (ARN).
-
#destination_type ⇒ String
A filter that returns only associations with the specified destination type.
-
#max_results ⇒ Integer
The maximum number of associations to return in the response.
-
#next_token ⇒ String
If the previous call to
ListAssociationsdidn’t return the full set of associations, the call returns a token for getting the next set of associations. -
#sort_by ⇒ String
The property used to sort results.
-
#sort_order ⇒ String
The sort order.
-
#source_arn ⇒ String
A filter that returns only associations with the specified source ARN.
-
#source_type ⇒ String
A filter that returns only associations with the specified source type.
Instance Attribute Details
#association_type ⇒ String
A filter that returns only associations of the specified type.
31394 31395 31396 31397 31398 31399 31400 31401 31402 31403 31404 31405 31406 31407 31408 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31394 class ListAssociationsRequest < Struct.new( :source_arn, :destination_arn, :source_type, :destination_type, :association_type, :created_after, :created_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#created_after ⇒ Time
A filter that returns only associations created on or after the specified time.
31394 31395 31396 31397 31398 31399 31400 31401 31402 31403 31404 31405 31406 31407 31408 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31394 class ListAssociationsRequest < Struct.new( :source_arn, :destination_arn, :source_type, :destination_type, :association_type, :created_after, :created_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#created_before ⇒ Time
A filter that returns only associations created on or before the specified time.
31394 31395 31396 31397 31398 31399 31400 31401 31402 31403 31404 31405 31406 31407 31408 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31394 class ListAssociationsRequest < Struct.new( :source_arn, :destination_arn, :source_type, :destination_type, :association_type, :created_after, :created_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#destination_arn ⇒ String
A filter that returns only associations with the specified destination Amazon Resource Name (ARN).
31394 31395 31396 31397 31398 31399 31400 31401 31402 31403 31404 31405 31406 31407 31408 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31394 class ListAssociationsRequest < Struct.new( :source_arn, :destination_arn, :source_type, :destination_type, :association_type, :created_after, :created_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#destination_type ⇒ String
A filter that returns only associations with the specified destination type.
31394 31395 31396 31397 31398 31399 31400 31401 31402 31403 31404 31405 31406 31407 31408 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31394 class ListAssociationsRequest < Struct.new( :source_arn, :destination_arn, :source_type, :destination_type, :association_type, :created_after, :created_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of associations to return in the response. The default value is 10.
31394 31395 31396 31397 31398 31399 31400 31401 31402 31403 31404 31405 31406 31407 31408 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31394 class ListAssociationsRequest < Struct.new( :source_arn, :destination_arn, :source_type, :destination_type, :association_type, :created_after, :created_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the previous call to ListAssociations didn’t return the full set of associations, the call returns a token for getting the next set of associations.
31394 31395 31396 31397 31398 31399 31400 31401 31402 31403 31404 31405 31406 31407 31408 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31394 class ListAssociationsRequest < Struct.new( :source_arn, :destination_arn, :source_type, :destination_type, :association_type, :created_after, :created_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
The property used to sort results. The default value is CreationTime.
31394 31395 31396 31397 31398 31399 31400 31401 31402 31403 31404 31405 31406 31407 31408 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31394 class ListAssociationsRequest < Struct.new( :source_arn, :destination_arn, :source_type, :destination_type, :association_type, :created_after, :created_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
The sort order. The default value is Descending.
31394 31395 31396 31397 31398 31399 31400 31401 31402 31403 31404 31405 31406 31407 31408 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31394 class ListAssociationsRequest < Struct.new( :source_arn, :destination_arn, :source_type, :destination_type, :association_type, :created_after, :created_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#source_arn ⇒ String
A filter that returns only associations with the specified source ARN.
31394 31395 31396 31397 31398 31399 31400 31401 31402 31403 31404 31405 31406 31407 31408 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31394 class ListAssociationsRequest < Struct.new( :source_arn, :destination_arn, :source_type, :destination_type, :association_type, :created_after, :created_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#source_type ⇒ String
A filter that returns only associations with the specified source type.
31394 31395 31396 31397 31398 31399 31400 31401 31402 31403 31404 31405 31406 31407 31408 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31394 class ListAssociationsRequest < Struct.new( :source_arn, :destination_arn, :source_type, :destination_type, :association_type, :created_after, :created_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |