Class: Aws::SageMaker::Types::ListAutoMLJobsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListAutoMLJobsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time_after ⇒ Time
Request a list of jobs, using a filter for time.
-
#creation_time_before ⇒ Time
Request a list of jobs, using a filter for time.
-
#last_modified_time_after ⇒ Time
Request a list of jobs, using a filter for time.
-
#last_modified_time_before ⇒ Time
Request a list of jobs, using a filter for time.
-
#max_results ⇒ Integer
Request a list of jobs up to a specified limit.
-
#name_contains ⇒ String
Request a list of jobs, using a search filter for name.
-
#next_token ⇒ String
If the previous response was truncated, you receive this token.
-
#sort_by ⇒ String
The parameter by which to sort the results.
-
#sort_order ⇒ String
The sort order for the results.
-
#status_equals ⇒ String
Request a list of jobs, using a filter for status.
Instance Attribute Details
#creation_time_after ⇒ Time
Request a list of jobs, using a filter for time.
31768 31769 31770 31771 31772 31773 31774 31775 31776 31777 31778 31779 31780 31781 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31768 class ListAutoMLJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_order, :sort_by, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#creation_time_before ⇒ Time
Request a list of jobs, using a filter for time.
31768 31769 31770 31771 31772 31773 31774 31775 31776 31777 31778 31779 31780 31781 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31768 class ListAutoMLJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_order, :sort_by, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#last_modified_time_after ⇒ Time
Request a list of jobs, using a filter for time.
31768 31769 31770 31771 31772 31773 31774 31775 31776 31777 31778 31779 31780 31781 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31768 class ListAutoMLJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_order, :sort_by, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#last_modified_time_before ⇒ Time
Request a list of jobs, using a filter for time.
31768 31769 31770 31771 31772 31773 31774 31775 31776 31777 31778 31779 31780 31781 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31768 class ListAutoMLJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_order, :sort_by, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
Request a list of jobs up to a specified limit.
31768 31769 31770 31771 31772 31773 31774 31775 31776 31777 31778 31779 31780 31781 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31768 class ListAutoMLJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_order, :sort_by, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#name_contains ⇒ String
Request a list of jobs, using a search filter for name.
31768 31769 31770 31771 31772 31773 31774 31775 31776 31777 31778 31779 31780 31781 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31768 class ListAutoMLJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_order, :sort_by, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the previous response was truncated, you receive this token. Use it in your next request to receive the next set of results.
31768 31769 31770 31771 31772 31773 31774 31775 31776 31777 31778 31779 31780 31781 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31768 class ListAutoMLJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_order, :sort_by, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
The parameter by which to sort the results. The default is Name.
31768 31769 31770 31771 31772 31773 31774 31775 31776 31777 31778 31779 31780 31781 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31768 class ListAutoMLJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_order, :sort_by, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
The sort order for the results. The default is Descending.
31768 31769 31770 31771 31772 31773 31774 31775 31776 31777 31778 31779 31780 31781 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31768 class ListAutoMLJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_order, :sort_by, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#status_equals ⇒ String
Request a list of jobs, using a filter for status.
31768 31769 31770 31771 31772 31773 31774 31775 31776 31777 31778 31779 31780 31781 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31768 class ListAutoMLJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_order, :sort_by, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |