Class: Aws::SageMaker::Types::ListClusterEventsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListClusterEventsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster_name ⇒ String
The name or Amazon Resource Name (ARN) of the HyperPod cluster for which to list events.
-
#event_time_after ⇒ Time
The start of the time range for filtering events.
-
#event_time_before ⇒ Time
The end of the time range for filtering events.
-
#instance_group_name ⇒ String
The name of the instance group to filter events.
-
#max_results ⇒ Integer
The maximum number of events to return in the response.
-
#next_token ⇒ String
A token to retrieve the next set of results.
-
#node_id ⇒ String
The EC2 instance ID to filter events.
-
#resource_type ⇒ String
The type of resource for which to filter events.
-
#sort_by ⇒ String
The field to use for sorting the event list.
-
#sort_order ⇒ String
The order in which to sort the results.
Instance Attribute Details
#cluster_name ⇒ String
The name or Amazon Resource Name (ARN) of the HyperPod cluster for which to list events.
34955 34956 34957 34958 34959 34960 34961 34962 34963 34964 34965 34966 34967 34968 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34955 class ListClusterEventsRequest < Struct.new( :cluster_name, :instance_group_name, :node_id, :event_time_after, :event_time_before, :sort_by, :sort_order, :resource_type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#event_time_after ⇒ Time
The start of the time range for filtering events. Only events that occurred after this time are included in the results.
34955 34956 34957 34958 34959 34960 34961 34962 34963 34964 34965 34966 34967 34968 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34955 class ListClusterEventsRequest < Struct.new( :cluster_name, :instance_group_name, :node_id, :event_time_after, :event_time_before, :sort_by, :sort_order, :resource_type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#event_time_before ⇒ Time
The end of the time range for filtering events. Only events that occurred before this time are included in the results.
34955 34956 34957 34958 34959 34960 34961 34962 34963 34964 34965 34966 34967 34968 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34955 class ListClusterEventsRequest < Struct.new( :cluster_name, :instance_group_name, :node_id, :event_time_after, :event_time_before, :sort_by, :sort_order, :resource_type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#instance_group_name ⇒ String
The name of the instance group to filter events. If specified, only events related to this instance group are returned.
34955 34956 34957 34958 34959 34960 34961 34962 34963 34964 34965 34966 34967 34968 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34955 class ListClusterEventsRequest < Struct.new( :cluster_name, :instance_group_name, :node_id, :event_time_after, :event_time_before, :sort_by, :sort_order, :resource_type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of events to return in the response. Valid range is 1 to 100.
34955 34956 34957 34958 34959 34960 34961 34962 34963 34964 34965 34966 34967 34968 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34955 class ListClusterEventsRequest < Struct.new( :cluster_name, :instance_group_name, :node_id, :event_time_after, :event_time_before, :sort_by, :sort_order, :resource_type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token to retrieve the next set of results. This token is obtained
from the output of a previous ListClusterEvents call.
34955 34956 34957 34958 34959 34960 34961 34962 34963 34964 34965 34966 34967 34968 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34955 class ListClusterEventsRequest < Struct.new( :cluster_name, :instance_group_name, :node_id, :event_time_after, :event_time_before, :sort_by, :sort_order, :resource_type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#node_id ⇒ String
The EC2 instance ID to filter events. If specified, only events related to this instance are returned.
34955 34956 34957 34958 34959 34960 34961 34962 34963 34964 34965 34966 34967 34968 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34955 class ListClusterEventsRequest < Struct.new( :cluster_name, :instance_group_name, :node_id, :event_time_after, :event_time_before, :sort_by, :sort_order, :resource_type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of resource for which to filter events. Valid values are
Cluster, InstanceGroup, or Instance.
34955 34956 34957 34958 34959 34960 34961 34962 34963 34964 34965 34966 34967 34968 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34955 class ListClusterEventsRequest < Struct.new( :cluster_name, :instance_group_name, :node_id, :event_time_after, :event_time_before, :sort_by, :sort_order, :resource_type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
The field to use for sorting the event list. Currently, the only
supported value is EventTime.
34955 34956 34957 34958 34959 34960 34961 34962 34963 34964 34965 34966 34967 34968 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34955 class ListClusterEventsRequest < Struct.new( :cluster_name, :instance_group_name, :node_id, :event_time_after, :event_time_before, :sort_by, :sort_order, :resource_type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
The order in which to sort the results. Valid values are Ascending
or Descending (the default is Descending).
34955 34956 34957 34958 34959 34960 34961 34962 34963 34964 34965 34966 34967 34968 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34955 class ListClusterEventsRequest < Struct.new( :cluster_name, :instance_group_name, :node_id, :event_time_after, :event_time_before, :sort_by, :sort_order, :resource_type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |