Class: Aws::SageMaker::Types::ListClusterEventsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListClusterEventsResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#events ⇒ Array<Types::ClusterEventSummary>
A list of event summaries matching the specified criteria.
-
#next_token ⇒ String
A token to retrieve the next set of results.
Instance Attribute Details
#events ⇒ Array<Types::ClusterEventSummary>
A list of event summaries matching the specified criteria.
34981 34982 34983 34984 34985 34986 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34981 class ListClusterEventsResponse < Struct.new( :next_token, :events) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token to retrieve the next set of results. Include this token in
subsequent ListClusterEvents calls to fetch more events.
34981 34982 34983 34984 34985 34986 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34981 class ListClusterEventsResponse < Struct.new( :next_token, :events) SENSITIVE = [] include Aws::Structure end |