Class: Aws::SageMaker::Types::ListClusterNodesRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_nameString

The string name or the Amazon Resource Name (ARN) of the SageMaker HyperPod cluster in which you want to retrieve the list of nodes.

Returns:

  • (String)


34946
34947
34948
34949
34950
34951
34952
34953
34954
34955
34956
34957
34958
# File 'lib/aws-sdk-sagemaker/types.rb', line 34946

class ListClusterNodesRequest < Struct.new(
  :cluster_name,
  :creation_time_after,
  :creation_time_before,
  :instance_group_name_contains,
  :max_results,
  :next_token,
  :sort_by,
  :sort_order,
  :include_node_logical_ids)
  SENSITIVE = []
  include Aws::Structure
end

#creation_time_afterTime

A filter that returns nodes in a SageMaker HyperPod cluster created after the specified time. Timestamps are formatted according to the ISO 8601 standard.

Acceptable formats include:

  • YYYY-MM-DDThh:mm:ss.sssTZD (UTC), for example, 2014-10-01T20:30:00.000Z

  • YYYY-MM-DDThh:mm:ss.sssTZD (with offset), for example, 2014-10-01T12:30:00.000-08:00

  • YYYY-MM-DD, for example, 2014-10-01

  • Unix time in seconds, for example, 1412195400. This is also referred to as Unix Epoch time and represents the number of seconds since midnight, January 1, 1970 UTC.

For more information about the timestamp format, see Timestamp in the Amazon Web Services Command Line Interface User Guide.

Returns:

  • (Time)


34946
34947
34948
34949
34950
34951
34952
34953
34954
34955
34956
34957
34958
# File 'lib/aws-sdk-sagemaker/types.rb', line 34946

class ListClusterNodesRequest < Struct.new(
  :cluster_name,
  :creation_time_after,
  :creation_time_before,
  :instance_group_name_contains,
  :max_results,
  :next_token,
  :sort_by,
  :sort_order,
  :include_node_logical_ids)
  SENSITIVE = []
  include Aws::Structure
end

#creation_time_beforeTime

A filter that returns nodes in a SageMaker HyperPod cluster created before the specified time. The acceptable formats are the same as the timestamp formats for CreationTimeAfter. For more information about the timestamp format, see Timestamp in the Amazon Web Services Command Line Interface User Guide.

Returns:

  • (Time)


34946
34947
34948
34949
34950
34951
34952
34953
34954
34955
34956
34957
34958
# File 'lib/aws-sdk-sagemaker/types.rb', line 34946

class ListClusterNodesRequest < Struct.new(
  :cluster_name,
  :creation_time_after,
  :creation_time_before,
  :instance_group_name_contains,
  :max_results,
  :next_token,
  :sort_by,
  :sort_order,
  :include_node_logical_ids)
  SENSITIVE = []
  include Aws::Structure
end

#include_node_logical_idsBoolean

Specifies whether to include nodes that are still being provisioned in the response. When set to true, the response includes all nodes regardless of their provisioning status. When set to False (default), only nodes with assigned InstanceIds are returned.

Returns:

  • (Boolean)


34946
34947
34948
34949
34950
34951
34952
34953
34954
34955
34956
34957
34958
# File 'lib/aws-sdk-sagemaker/types.rb', line 34946

class ListClusterNodesRequest < Struct.new(
  :cluster_name,
  :creation_time_after,
  :creation_time_before,
  :instance_group_name_contains,
  :max_results,
  :next_token,
  :sort_by,
  :sort_order,
  :include_node_logical_ids)
  SENSITIVE = []
  include Aws::Structure
end

#instance_group_name_containsString

A filter that returns the instance groups whose name contain a specified string.

Returns:

  • (String)


34946
34947
34948
34949
34950
34951
34952
34953
34954
34955
34956
34957
34958
# File 'lib/aws-sdk-sagemaker/types.rb', line 34946

class ListClusterNodesRequest < Struct.new(
  :cluster_name,
  :creation_time_after,
  :creation_time_before,
  :instance_group_name_contains,
  :max_results,
  :next_token,
  :sort_by,
  :sort_order,
  :include_node_logical_ids)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of nodes to return in the response.

Returns:

  • (Integer)


34946
34947
34948
34949
34950
34951
34952
34953
34954
34955
34956
34957
34958
# File 'lib/aws-sdk-sagemaker/types.rb', line 34946

class ListClusterNodesRequest < Struct.new(
  :cluster_name,
  :creation_time_after,
  :creation_time_before,
  :instance_group_name_contains,
  :max_results,
  :next_token,
  :sort_by,
  :sort_order,
  :include_node_logical_ids)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the result of the previous ListClusterNodes request was truncated, the response includes a NextToken. To retrieve the next set of cluster nodes, use the token in the next request.

Returns:

  • (String)


34946
34947
34948
34949
34950
34951
34952
34953
34954
34955
34956
34957
34958
# File 'lib/aws-sdk-sagemaker/types.rb', line 34946

class ListClusterNodesRequest < Struct.new(
  :cluster_name,
  :creation_time_after,
  :creation_time_before,
  :instance_group_name_contains,
  :max_results,
  :next_token,
  :sort_by,
  :sort_order,
  :include_node_logical_ids)
  SENSITIVE = []
  include Aws::Structure
end

#sort_byString

The field by which to sort results. The default value is CREATION_TIME.

Returns:

  • (String)


34946
34947
34948
34949
34950
34951
34952
34953
34954
34955
34956
34957
34958
# File 'lib/aws-sdk-sagemaker/types.rb', line 34946

class ListClusterNodesRequest < Struct.new(
  :cluster_name,
  :creation_time_after,
  :creation_time_before,
  :instance_group_name_contains,
  :max_results,
  :next_token,
  :sort_by,
  :sort_order,
  :include_node_logical_ids)
  SENSITIVE = []
  include Aws::Structure
end

#sort_orderString

The sort order for results. The default value is Ascending.

Returns:

  • (String)


34946
34947
34948
34949
34950
34951
34952
34953
34954
34955
34956
34957
34958
# File 'lib/aws-sdk-sagemaker/types.rb', line 34946

class ListClusterNodesRequest < Struct.new(
  :cluster_name,
  :creation_time_after,
  :creation_time_before,
  :instance_group_name_contains,
  :max_results,
  :next_token,
  :sort_by,
  :sort_order,
  :include_node_logical_ids)
  SENSITIVE = []
  include Aws::Structure
end