Class: Aws::SageMaker::Types::ListClusterNodesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListClusterNodesResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster_node_summaries ⇒ Array<Types::ClusterNodeSummary>
The summaries of listed instances in a SageMaker HyperPod cluster.
-
#next_token ⇒ String
The next token specified for listing instances in a SageMaker HyperPod cluster.
Instance Attribute Details
#cluster_node_summaries ⇒ Array<Types::ClusterNodeSummary>
The summaries of listed instances in a SageMaker HyperPod cluster
35090 35091 35092 35093 35094 35095 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35090 class ListClusterNodesResponse < Struct.new( :next_token, :cluster_node_summaries) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The next token specified for listing instances in a SageMaker HyperPod cluster.
35090 35091 35092 35093 35094 35095 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35090 class ListClusterNodesResponse < Struct.new( :next_token, :cluster_node_summaries) SENSITIVE = [] include Aws::Structure end |