Class: Aws::SageMaker::Types::ListClusterSchedulerConfigsResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_scheduler_config_summaries ⇒ Array<Types::ClusterSchedulerConfigSummary>

Summaries of the cluster policies.



35176
35177
35178
35179
35180
35181
# File 'lib/aws-sdk-sagemaker/types.rb', line 35176

class ListClusterSchedulerConfigsResponse < Struct.new(
  :cluster_scheduler_config_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

If the previous response was truncated, you will receive this token. Use it in your next request to receive the next set of results.

Returns:

  • (String)


35176
35177
35178
35179
35180
35181
# File 'lib/aws-sdk-sagemaker/types.rb', line 35176

class ListClusterSchedulerConfigsResponse < Struct.new(
  :cluster_scheduler_config_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end