Class: Aws::SageMaker::Types::ListClustersResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_summariesArray<Types::ClusterSummary>

The summaries of listed SageMaker HyperPod clusters.

Returns:



32015
32016
32017
32018
32019
32020
# File 'lib/aws-sdk-sagemaker/types.rb', line 32015

class ListClustersResponse < Struct.new(
  :next_token,
  :cluster_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the result of the previous ListClusters request was truncated, the response includes a NextToken. To retrieve the next set of clusters, use the token in the next request.

Returns:

  • (String)


32015
32016
32017
32018
32019
32020
# File 'lib/aws-sdk-sagemaker/types.rb', line 32015

class ListClustersResponse < Struct.new(
  :next_token,
  :cluster_summaries)
  SENSITIVE = []
  include Aws::Structure
end