Class: Aws::SageMaker::Types::ListCodeRepositoriesOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListCodeRepositoriesOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code_repository_summary_list ⇒ Array<Types::CodeRepositorySummary>
Gets a list of summaries of the Git repositories.
-
#next_token ⇒ String
If the result of a
ListCodeRepositoriesOutputrequest was truncated, the response includes aNextToken.
Instance Attribute Details
#code_repository_summary_list ⇒ Array<Types::CodeRepositorySummary>
Gets a list of summaries of the Git repositories. Each summary specifies the following values for the repository:
-
Name
-
Amazon Resource Name (ARN)
-
Creation time
-
Last modified time
-
Configuration information, including the URL location of the repository and the ARN of the Amazon Web Services Secrets Manager secret that contains the credentials used to access the repository.
32107 32108 32109 32110 32111 32112 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32107 class ListCodeRepositoriesOutput < Struct.new( :code_repository_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the result of a ListCodeRepositoriesOutput request was truncated, the response includes a NextToken. To get the next set of Git repositories, use the token in the next request.
32107 32108 32109 32110 32111 32112 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32107 class ListCodeRepositoriesOutput < Struct.new( :code_repository_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |