Class: Aws::SageMaker::Types::ListCompilationJobsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_time_after ⇒ Time

A filter that returns the model compilation jobs that were created after a specified time.



35435
35436
35437
35438
35439
35440
35441
35442
35443
35444
35445
35446
35447
35448
# File 'lib/aws-sdk-sagemaker/types.rb', line 35435

class ListCompilationJobsRequest < Struct.new(
  :next_token,
  :max_results,
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :name_contains,
  :status_equals,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#creation_time_before ⇒ Time

A filter that returns the model compilation jobs that were created before a specified time.



35435
35436
35437
35438
35439
35440
35441
35442
35443
35444
35445
35446
35447
35448
# File 'lib/aws-sdk-sagemaker/types.rb', line 35435

class ListCompilationJobsRequest < Struct.new(
  :next_token,
  :max_results,
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :name_contains,
  :status_equals,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_time_after ⇒ Time

A filter that returns the model compilation jobs that were modified after a specified time.



35435
35436
35437
35438
35439
35440
35441
35442
35443
35444
35445
35446
35447
35448
# File 'lib/aws-sdk-sagemaker/types.rb', line 35435

class ListCompilationJobsRequest < Struct.new(
  :next_token,
  :max_results,
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :name_contains,
  :status_equals,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_time_before ⇒ Time

A filter that returns the model compilation jobs that were modified before a specified time.



35435
35436
35437
35438
35439
35440
35441
35442
35443
35444
35445
35446
35447
35448
# File 'lib/aws-sdk-sagemaker/types.rb', line 35435

class ListCompilationJobsRequest < Struct.new(
  :next_token,
  :max_results,
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :name_contains,
  :status_equals,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of model compilation jobs to return in the response.



35435
35436
35437
35438
35439
35440
35441
35442
35443
35444
35445
35446
35447
35448
# File 'lib/aws-sdk-sagemaker/types.rb', line 35435

class ListCompilationJobsRequest < Struct.new(
  :next_token,
  :max_results,
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :name_contains,
  :status_equals,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#name_contains ⇒ String

A filter that returns the model compilation jobs whose name contains a specified string.



35435
35436
35437
35438
35439
35440
35441
35442
35443
35444
35445
35446
35447
35448
# File 'lib/aws-sdk-sagemaker/types.rb', line 35435

class ListCompilationJobsRequest < Struct.new(
  :next_token,
  :max_results,
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :name_contains,
  :status_equals,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

If the result of the previous ListCompilationJobs request was truncated, the response includes a NextToken. To retrieve the next set of model compilation jobs, use the token in the next request.



35435
35436
35437
35438
35439
35440
35441
35442
35443
35444
35445
35446
35447
35448
# File 'lib/aws-sdk-sagemaker/types.rb', line 35435

class ListCompilationJobsRequest < Struct.new(
  :next_token,
  :max_results,
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :name_contains,
  :status_equals,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#sort_by ⇒ String

The field by which to sort results. The default is CreationTime.



35435
35436
35437
35438
35439
35440
35441
35442
35443
35444
35445
35446
35447
35448
# File 'lib/aws-sdk-sagemaker/types.rb', line 35435

class ListCompilationJobsRequest < Struct.new(
  :next_token,
  :max_results,
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :name_contains,
  :status_equals,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#sort_order ⇒ String

The sort order for results. The default is Ascending.



35435
35436
35437
35438
35439
35440
35441
35442
35443
35444
35445
35446
35447
35448
# File 'lib/aws-sdk-sagemaker/types.rb', line 35435

class ListCompilationJobsRequest < Struct.new(
  :next_token,
  :max_results,
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :name_contains,
  :status_equals,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#status_equals ⇒ String

A filter that retrieves model compilation jobs with a specific CompilationJobStatus status.



35435
35436
35437
35438
35439
35440
35441
35442
35443
35444
35445
35446
35447
35448
# File 'lib/aws-sdk-sagemaker/types.rb', line 35435

class ListCompilationJobsRequest < Struct.new(
  :next_token,
  :max_results,
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :name_contains,
  :status_equals,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end