Class: Aws::SageMaker::Types::ListComputeQuotasResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#compute_quota_summaries ⇒ Array<Types::ComputeQuotaSummary>

Summaries of the compute allocation definitions.

Returns:



35553
35554
35555
35556
35557
35558
# File 'lib/aws-sdk-sagemaker/types.rb', line 35553

class ListComputeQuotasResponse < Struct.new(
  :compute_quota_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

If the previous response was truncated, you will receive this token. Use it in your next request to receive the next set of results.

Returns:

  • (String)


35553
35554
35555
35556
35557
35558
# File 'lib/aws-sdk-sagemaker/types.rb', line 35553

class ListComputeQuotasResponse < Struct.new(
  :compute_quota_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end