Class: Aws::SageMaker::Types::ListDataQualityJobDefinitionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_time_after ⇒ Time

A filter that returns only data quality monitoring job definitions created after the specified time.

Returns:

  • (Time)


35674
35675
35676
35677
35678
35679
35680
35681
35682
35683
35684
35685
# File 'lib/aws-sdk-sagemaker/types.rb', line 35674

class ListDataQualityJobDefinitionsRequest < Struct.new(
  :endpoint_name,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results,
  :name_contains,
  :creation_time_before,
  :creation_time_after)
  SENSITIVE = []
  include Aws::Structure
end

#creation_time_before ⇒ Time

A filter that returns only data quality monitoring job definitions created before the specified time.

Returns:

  • (Time)


35674
35675
35676
35677
35678
35679
35680
35681
35682
35683
35684
35685
# File 'lib/aws-sdk-sagemaker/types.rb', line 35674

class ListDataQualityJobDefinitionsRequest < Struct.new(
  :endpoint_name,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results,
  :name_contains,
  :creation_time_before,
  :creation_time_after)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_name ⇒ String

A filter that lists the data quality job definitions associated with the specified endpoint.

Returns:

  • (String)


35674
35675
35676
35677
35678
35679
35680
35681
35682
35683
35684
35685
# File 'lib/aws-sdk-sagemaker/types.rb', line 35674

class ListDataQualityJobDefinitionsRequest < Struct.new(
  :endpoint_name,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results,
  :name_contains,
  :creation_time_before,
  :creation_time_after)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of data quality monitoring job definitions to return in the response.

Returns:

  • (Integer)


35674
35675
35676
35677
35678
35679
35680
35681
35682
35683
35684
35685
# File 'lib/aws-sdk-sagemaker/types.rb', line 35674

class ListDataQualityJobDefinitionsRequest < Struct.new(
  :endpoint_name,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results,
  :name_contains,
  :creation_time_before,
  :creation_time_after)
  SENSITIVE = []
  include Aws::Structure
end

#name_contains ⇒ String

A string in the data quality monitoring job definition name. This filter returns only data quality monitoring job definitions whose name contains the specified string.

Returns:

  • (String)


35674
35675
35676
35677
35678
35679
35680
35681
35682
35683
35684
35685
# File 'lib/aws-sdk-sagemaker/types.rb', line 35674

class ListDataQualityJobDefinitionsRequest < Struct.new(
  :endpoint_name,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results,
  :name_contains,
  :creation_time_before,
  :creation_time_after)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

If the result of the previous ListDataQualityJobDefinitions request was truncated, the response includes a NextToken. To retrieve the next set of transform jobs, use the token in the next request.>

Returns:

  • (String)


35674
35675
35676
35677
35678
35679
35680
35681
35682
35683
35684
35685
# File 'lib/aws-sdk-sagemaker/types.rb', line 35674

class ListDataQualityJobDefinitionsRequest < Struct.new(
  :endpoint_name,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results,
  :name_contains,
  :creation_time_before,
  :creation_time_after)
  SENSITIVE = []
  include Aws::Structure
end

#sort_by ⇒ String

The field to sort results by. The default is CreationTime.

Returns:

  • (String)


35674
35675
35676
35677
35678
35679
35680
35681
35682
35683
35684
35685
# File 'lib/aws-sdk-sagemaker/types.rb', line 35674

class ListDataQualityJobDefinitionsRequest < Struct.new(
  :endpoint_name,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results,
  :name_contains,
  :creation_time_before,
  :creation_time_after)
  SENSITIVE = []
  include Aws::Structure
end

#sort_order ⇒ String

Whether to sort the results in Ascending or Descending order. The default is Descending.

Returns:

  • (String)


35674
35675
35676
35677
35678
35679
35680
35681
35682
35683
35684
35685
# File 'lib/aws-sdk-sagemaker/types.rb', line 35674

class ListDataQualityJobDefinitionsRequest < Struct.new(
  :endpoint_name,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results,
  :name_contains,
  :creation_time_before,
  :creation_time_after)
  SENSITIVE = []
  include Aws::Structure
end