Class: Aws::SageMaker::Types::ListDeviceFleetsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_time_after ⇒ Time

Filter fleets where packaging job was created after specified time.

Returns:

  • (Time)


35747
35748
35749
35750
35751
35752
35753
35754
35755
35756
35757
35758
35759
# File 'lib/aws-sdk-sagemaker/types.rb', line 35747

class ListDeviceFleetsRequest < Struct.new(
  :next_token,
  :max_results,
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :name_contains,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#creation_time_before ⇒ Time

Filter fleets where the edge packaging job was created before specified time.

Returns:

  • (Time)


35747
35748
35749
35750
35751
35752
35753
35754
35755
35756
35757
35758
35759
# File 'lib/aws-sdk-sagemaker/types.rb', line 35747

class ListDeviceFleetsRequest < Struct.new(
  :next_token,
  :max_results,
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :name_contains,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_time_after ⇒ Time

Select fleets where the job was updated after X

Returns:

  • (Time)


35747
35748
35749
35750
35751
35752
35753
35754
35755
35756
35757
35758
35759
# File 'lib/aws-sdk-sagemaker/types.rb', line 35747

class ListDeviceFleetsRequest < Struct.new(
  :next_token,
  :max_results,
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :name_contains,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_time_before ⇒ Time

Select fleets where the job was updated before X

Returns:

  • (Time)


35747
35748
35749
35750
35751
35752
35753
35754
35755
35756
35757
35758
35759
# File 'lib/aws-sdk-sagemaker/types.rb', line 35747

class ListDeviceFleetsRequest < Struct.new(
  :next_token,
  :max_results,
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :name_contains,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of results to select.

Returns:

  • (Integer)


35747
35748
35749
35750
35751
35752
35753
35754
35755
35756
35757
35758
35759
# File 'lib/aws-sdk-sagemaker/types.rb', line 35747

class ListDeviceFleetsRequest < Struct.new(
  :next_token,
  :max_results,
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :name_contains,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#name_contains ⇒ String

Filter for fleets containing this name in their fleet device name.

Returns:

  • (String)


35747
35748
35749
35750
35751
35752
35753
35754
35755
35756
35757
35758
35759
# File 'lib/aws-sdk-sagemaker/types.rb', line 35747

class ListDeviceFleetsRequest < Struct.new(
  :next_token,
  :max_results,
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :name_contains,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The response from the last list when returning a list large enough to need tokening.

Returns:

  • (String)


35747
35748
35749
35750
35751
35752
35753
35754
35755
35756
35757
35758
35759
# File 'lib/aws-sdk-sagemaker/types.rb', line 35747

class ListDeviceFleetsRequest < Struct.new(
  :next_token,
  :max_results,
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :name_contains,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#sort_by ⇒ String

The column to sort by.

Returns:

  • (String)


35747
35748
35749
35750
35751
35752
35753
35754
35755
35756
35757
35758
35759
# File 'lib/aws-sdk-sagemaker/types.rb', line 35747

class ListDeviceFleetsRequest < Struct.new(
  :next_token,
  :max_results,
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :name_contains,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#sort_order ⇒ String

What direction to sort in.

Returns:

  • (String)


35747
35748
35749
35750
35751
35752
35753
35754
35755
35756
35757
35758
35759
# File 'lib/aws-sdk-sagemaker/types.rb', line 35747

class ListDeviceFleetsRequest < Struct.new(
  :next_token,
  :max_results,
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :name_contains,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end