Class: Aws::SageMaker::Types::ListDomainsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListDomainsResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domains ⇒ Array<Types::DomainDetails>
The list of domains.
-
#next_token ⇒ String
If the previous response was truncated, you will receive this token.
Instance Attribute Details
#domains ⇒ Array<Types::DomainDetails>
The list of domains.
35866 35867 35868 35869 35870 35871 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35866 class ListDomainsResponse < Struct.new( :domains, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the previous response was truncated, you will receive this token. Use it in your next request to receive the next set of results.
35866 35867 35868 35869 35870 35871 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35866 class ListDomainsResponse < Struct.new( :domains, :next_token) SENSITIVE = [] include Aws::Structure end |