Class: Aws::SageMaker::Types::ListEdgeDeploymentPlansRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListEdgeDeploymentPlansRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time_after ⇒ Time
Selects edge deployment plans created after this time.
-
#creation_time_before ⇒ Time
Selects edge deployment plans created before this time.
-
#device_fleet_name_contains ⇒ String
Selects edge deployment plans with a device fleet name containing this name.
-
#last_modified_time_after ⇒ Time
Selects edge deployment plans that were last updated after this time.
-
#last_modified_time_before ⇒ Time
Selects edge deployment plans that were last updated before this time.
-
#max_results ⇒ Integer
The maximum number of results to select (50 by default).
-
#name_contains ⇒ String
Selects edge deployment plans with names containing this name.
-
#next_token ⇒ String
The response from the last list when returning a list large enough to need tokening.
-
#sort_by ⇒ String
The column by which to sort the edge deployment plans.
-
#sort_order ⇒ String
The direction of the sorting (ascending or descending).
Instance Attribute Details
#creation_time_after ⇒ Time
Selects edge deployment plans created after this time.
32881 32882 32883 32884 32885 32886 32887 32888 32889 32890 32891 32892 32893 32894 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32881 class ListEdgeDeploymentPlansRequest < Struct.new( :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :device_fleet_name_contains, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#creation_time_before ⇒ Time
Selects edge deployment plans created before this time.
32881 32882 32883 32884 32885 32886 32887 32888 32889 32890 32891 32892 32893 32894 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32881 class ListEdgeDeploymentPlansRequest < Struct.new( :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :device_fleet_name_contains, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#device_fleet_name_contains ⇒ String
Selects edge deployment plans with a device fleet name containing this name.
32881 32882 32883 32884 32885 32886 32887 32888 32889 32890 32891 32892 32893 32894 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32881 class ListEdgeDeploymentPlansRequest < Struct.new( :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :device_fleet_name_contains, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#last_modified_time_after ⇒ Time
Selects edge deployment plans that were last updated after this time.
32881 32882 32883 32884 32885 32886 32887 32888 32889 32890 32891 32892 32893 32894 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32881 class ListEdgeDeploymentPlansRequest < Struct.new( :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :device_fleet_name_contains, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#last_modified_time_before ⇒ Time
Selects edge deployment plans that were last updated before this time.
32881 32882 32883 32884 32885 32886 32887 32888 32889 32890 32891 32892 32893 32894 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32881 class ListEdgeDeploymentPlansRequest < Struct.new( :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :device_fleet_name_contains, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to select (50 by default).
32881 32882 32883 32884 32885 32886 32887 32888 32889 32890 32891 32892 32893 32894 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32881 class ListEdgeDeploymentPlansRequest < Struct.new( :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :device_fleet_name_contains, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#name_contains ⇒ String
Selects edge deployment plans with names containing this name.
32881 32882 32883 32884 32885 32886 32887 32888 32889 32890 32891 32892 32893 32894 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32881 class ListEdgeDeploymentPlansRequest < Struct.new( :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :device_fleet_name_contains, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The response from the last list when returning a list large enough to need tokening.
32881 32882 32883 32884 32885 32886 32887 32888 32889 32890 32891 32892 32893 32894 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32881 class ListEdgeDeploymentPlansRequest < Struct.new( :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :device_fleet_name_contains, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
The column by which to sort the edge deployment plans. Can be one of
NAME, DEVICEFLEETNAME, CREATIONTIME, LASTMODIFIEDTIME.
32881 32882 32883 32884 32885 32886 32887 32888 32889 32890 32891 32892 32893 32894 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32881 class ListEdgeDeploymentPlansRequest < Struct.new( :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :device_fleet_name_contains, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
The direction of the sorting (ascending or descending).
32881 32882 32883 32884 32885 32886 32887 32888 32889 32890 32891 32892 32893 32894 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32881 class ListEdgeDeploymentPlansRequest < Struct.new( :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :device_fleet_name_contains, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |