Class: Aws::SageMaker::Types::ListFeatureGroupsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListFeatureGroupsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time_after ⇒ Time
Use this parameter to search for ‘FeatureGroups`s created after a specific date and time.
-
#creation_time_before ⇒ Time
Use this parameter to search for ‘FeatureGroups`s created before a specific date and time.
-
#feature_group_status_equals ⇒ String
A
FeatureGroupstatus. -
#max_results ⇒ Integer
The maximum number of results returned by
ListFeatureGroups. -
#name_contains ⇒ String
A string that partially matches one or more ‘FeatureGroup`s names.
-
#next_token ⇒ String
A token to resume pagination of
ListFeatureGroupsresults. -
#offline_store_status_equals ⇒ String
An
OfflineStorestatus. -
#sort_by ⇒ String
The value on which the feature group list is sorted.
-
#sort_order ⇒ String
The order in which feature groups are listed.
Instance Attribute Details
#creation_time_after ⇒ Time
Use this parameter to search for ‘FeatureGroups`s created after a specific date and time.
33014 33015 33016 33017 33018 33019 33020 33021 33022 33023 33024 33025 33026 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33014 class ListFeatureGroupsRequest < Struct.new( :name_contains, :feature_group_status_equals, :offline_store_status_equals, :creation_time_after, :creation_time_before, :sort_order, :sort_by, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#creation_time_before ⇒ Time
Use this parameter to search for ‘FeatureGroups`s created before a specific date and time.
33014 33015 33016 33017 33018 33019 33020 33021 33022 33023 33024 33025 33026 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33014 class ListFeatureGroupsRequest < Struct.new( :name_contains, :feature_group_status_equals, :offline_store_status_equals, :creation_time_after, :creation_time_before, :sort_order, :sort_by, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#feature_group_status_equals ⇒ String
A FeatureGroup status. Filters by FeatureGroup status.
33014 33015 33016 33017 33018 33019 33020 33021 33022 33023 33024 33025 33026 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33014 class ListFeatureGroupsRequest < Struct.new( :name_contains, :feature_group_status_equals, :offline_store_status_equals, :creation_time_after, :creation_time_before, :sort_order, :sort_by, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results returned by ListFeatureGroups.
33014 33015 33016 33017 33018 33019 33020 33021 33022 33023 33024 33025 33026 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33014 class ListFeatureGroupsRequest < Struct.new( :name_contains, :feature_group_status_equals, :offline_store_status_equals, :creation_time_after, :creation_time_before, :sort_order, :sort_by, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#name_contains ⇒ String
A string that partially matches one or more ‘FeatureGroup`s names. Filters `FeatureGroup`s by name.
33014 33015 33016 33017 33018 33019 33020 33021 33022 33023 33024 33025 33026 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33014 class ListFeatureGroupsRequest < Struct.new( :name_contains, :feature_group_status_equals, :offline_store_status_equals, :creation_time_after, :creation_time_before, :sort_order, :sort_by, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token to resume pagination of ListFeatureGroups results.
33014 33015 33016 33017 33018 33019 33020 33021 33022 33023 33024 33025 33026 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33014 class ListFeatureGroupsRequest < Struct.new( :name_contains, :feature_group_status_equals, :offline_store_status_equals, :creation_time_after, :creation_time_before, :sort_order, :sort_by, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#offline_store_status_equals ⇒ String
An OfflineStore status. Filters by OfflineStore status.
33014 33015 33016 33017 33018 33019 33020 33021 33022 33023 33024 33025 33026 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33014 class ListFeatureGroupsRequest < Struct.new( :name_contains, :feature_group_status_equals, :offline_store_status_equals, :creation_time_after, :creation_time_before, :sort_order, :sort_by, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
The value on which the feature group list is sorted.
33014 33015 33016 33017 33018 33019 33020 33021 33022 33023 33024 33025 33026 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33014 class ListFeatureGroupsRequest < Struct.new( :name_contains, :feature_group_status_equals, :offline_store_status_equals, :creation_time_after, :creation_time_before, :sort_order, :sort_by, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
The order in which feature groups are listed.
33014 33015 33016 33017 33018 33019 33020 33021 33022 33023 33024 33025 33026 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33014 class ListFeatureGroupsRequest < Struct.new( :name_contains, :feature_group_status_equals, :offline_store_status_equals, :creation_time_after, :creation_time_before, :sort_order, :sort_by, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |