Class: Aws::SageMaker::Types::ListHubContentsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_time_after ⇒ Time

Only list hub content that was created after the time specified.

Returns:

  • (Time)


36499
36500
36501
36502
36503
36504
36505
36506
36507
36508
36509
36510
36511
36512
# File 'lib/aws-sdk-sagemaker/types.rb', line 36499

class ListHubContentsRequest < Struct.new(
  :hub_name,
  :hub_content_type,
  :name_contains,
  :max_schema_version,
  :creation_time_before,
  :creation_time_after,
  :sort_by,
  :sort_order,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#creation_time_before ⇒ Time

Only list hub content that was created before the time specified.

Returns:

  • (Time)


36499
36500
36501
36502
36503
36504
36505
36506
36507
36508
36509
36510
36511
36512
# File 'lib/aws-sdk-sagemaker/types.rb', line 36499

class ListHubContentsRequest < Struct.new(
  :hub_name,
  :hub_content_type,
  :name_contains,
  :max_schema_version,
  :creation_time_before,
  :creation_time_after,
  :sort_by,
  :sort_order,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#hub_content_type ⇒ String

The type of hub content to list.

Returns:

  • (String)


36499
36500
36501
36502
36503
36504
36505
36506
36507
36508
36509
36510
36511
36512
# File 'lib/aws-sdk-sagemaker/types.rb', line 36499

class ListHubContentsRequest < Struct.new(
  :hub_name,
  :hub_content_type,
  :name_contains,
  :max_schema_version,
  :creation_time_before,
  :creation_time_after,
  :sort_by,
  :sort_order,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#hub_name ⇒ String

The name of the hub to list the contents of.

Returns:

  • (String)


36499
36500
36501
36502
36503
36504
36505
36506
36507
36508
36509
36510
36511
36512
# File 'lib/aws-sdk-sagemaker/types.rb', line 36499

class ListHubContentsRequest < Struct.new(
  :hub_name,
  :hub_content_type,
  :name_contains,
  :max_schema_version,
  :creation_time_before,
  :creation_time_after,
  :sort_by,
  :sort_order,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum amount of hub content to list.

Returns:

  • (Integer)


36499
36500
36501
36502
36503
36504
36505
36506
36507
36508
36509
36510
36511
36512
# File 'lib/aws-sdk-sagemaker/types.rb', line 36499

class ListHubContentsRequest < Struct.new(
  :hub_name,
  :hub_content_type,
  :name_contains,
  :max_schema_version,
  :creation_time_before,
  :creation_time_after,
  :sort_by,
  :sort_order,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_schema_version ⇒ String

The upper bound of the hub content schema verion.

Returns:

  • (String)


36499
36500
36501
36502
36503
36504
36505
36506
36507
36508
36509
36510
36511
36512
# File 'lib/aws-sdk-sagemaker/types.rb', line 36499

class ListHubContentsRequest < Struct.new(
  :hub_name,
  :hub_content_type,
  :name_contains,
  :max_schema_version,
  :creation_time_before,
  :creation_time_after,
  :sort_by,
  :sort_order,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#name_contains ⇒ String

Only list hub content if the name contains the specified string.

Returns:

  • (String)


36499
36500
36501
36502
36503
36504
36505
36506
36507
36508
36509
36510
36511
36512
# File 'lib/aws-sdk-sagemaker/types.rb', line 36499

class ListHubContentsRequest < Struct.new(
  :hub_name,
  :hub_content_type,
  :name_contains,
  :max_schema_version,
  :creation_time_before,
  :creation_time_after,
  :sort_by,
  :sort_order,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

If the response to a previous ListHubContents request was truncated, the response includes a NextToken. To retrieve the next set of hub content, use the token in the next request.

Returns:

  • (String)


36499
36500
36501
36502
36503
36504
36505
36506
36507
36508
36509
36510
36511
36512
# File 'lib/aws-sdk-sagemaker/types.rb', line 36499

class ListHubContentsRequest < Struct.new(
  :hub_name,
  :hub_content_type,
  :name_contains,
  :max_schema_version,
  :creation_time_before,
  :creation_time_after,
  :sort_by,
  :sort_order,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#sort_by ⇒ String

Sort hub content versions by either name or creation time.

Returns:

  • (String)


36499
36500
36501
36502
36503
36504
36505
36506
36507
36508
36509
36510
36511
36512
# File 'lib/aws-sdk-sagemaker/types.rb', line 36499

class ListHubContentsRequest < Struct.new(
  :hub_name,
  :hub_content_type,
  :name_contains,
  :max_schema_version,
  :creation_time_before,
  :creation_time_after,
  :sort_by,
  :sort_order,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#sort_order ⇒ String

Sort hubs by ascending or descending order.

Returns:

  • (String)


36499
36500
36501
36502
36503
36504
36505
36506
36507
36508
36509
36510
36511
36512
# File 'lib/aws-sdk-sagemaker/types.rb', line 36499

class ListHubContentsRequest < Struct.new(
  :hub_name,
  :hub_content_type,
  :name_contains,
  :max_schema_version,
  :creation_time_before,
  :creation_time_after,
  :sort_by,
  :sort_order,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end