Class: Aws::SageMaker::Types::ListHyperParameterTuningJobsResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#hyper_parameter_tuning_job_summariesArray<Types::HyperParameterTuningJobSummary>

A list of HyperParameterTuningJobSummary objects that describe the tuning jobs that the ListHyperParameterTuningJobs request returned.



36743
36744
36745
36746
36747
36748
# File 'lib/aws-sdk-sagemaker/types.rb', line 36743

class ListHyperParameterTuningJobsResponse < Struct.new(
  :hyper_parameter_tuning_job_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the result of this ListHyperParameterTuningJobs request was truncated, the response includes a NextToken. To retrieve the next set of tuning jobs, use the token in the next request.



36743
36744
36745
36746
36747
36748
# File 'lib/aws-sdk-sagemaker/types.rb', line 36743

class ListHyperParameterTuningJobsResponse < Struct.new(
  :hyper_parameter_tuning_job_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end