Class: Aws::SageMaker::Types::ListImageVersionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_time_after ⇒ Time

A filter that returns only versions created on or after the specified time.

Returns:

  • (Time)


36796
36797
36798
36799
36800
36801
36802
36803
36804
36805
36806
36807
36808
# File 'lib/aws-sdk-sagemaker/types.rb', line 36796

class ListImageVersionsRequest < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :image_name,
  :last_modified_time_after,
  :last_modified_time_before,
  :max_results,
  :next_token,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#creation_time_before ⇒ Time

A filter that returns only versions created on or before the specified time.

Returns:

  • (Time)


36796
36797
36798
36799
36800
36801
36802
36803
36804
36805
36806
36807
36808
# File 'lib/aws-sdk-sagemaker/types.rb', line 36796

class ListImageVersionsRequest < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :image_name,
  :last_modified_time_after,
  :last_modified_time_before,
  :max_results,
  :next_token,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#image_name ⇒ String

The name of the image to list the versions of.

Returns:

  • (String)


36796
36797
36798
36799
36800
36801
36802
36803
36804
36805
36806
36807
36808
# File 'lib/aws-sdk-sagemaker/types.rb', line 36796

class ListImageVersionsRequest < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :image_name,
  :last_modified_time_after,
  :last_modified_time_before,
  :max_results,
  :next_token,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_time_after ⇒ Time

A filter that returns only versions modified on or after the specified time.

Returns:

  • (Time)


36796
36797
36798
36799
36800
36801
36802
36803
36804
36805
36806
36807
36808
# File 'lib/aws-sdk-sagemaker/types.rb', line 36796

class ListImageVersionsRequest < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :image_name,
  :last_modified_time_after,
  :last_modified_time_before,
  :max_results,
  :next_token,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_time_before ⇒ Time

A filter that returns only versions modified on or before the specified time.

Returns:

  • (Time)


36796
36797
36798
36799
36800
36801
36802
36803
36804
36805
36806
36807
36808
# File 'lib/aws-sdk-sagemaker/types.rb', line 36796

class ListImageVersionsRequest < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :image_name,
  :last_modified_time_after,
  :last_modified_time_before,
  :max_results,
  :next_token,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of versions to return in the response. The default value is 10.

Returns:

  • (Integer)


36796
36797
36798
36799
36800
36801
36802
36803
36804
36805
36806
36807
36808
# File 'lib/aws-sdk-sagemaker/types.rb', line 36796

class ListImageVersionsRequest < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :image_name,
  :last_modified_time_after,
  :last_modified_time_before,
  :max_results,
  :next_token,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

If the previous call to ListImageVersions didn't return the full set of versions, the call returns a token for getting the next set of versions.

Returns:

  • (String)


36796
36797
36798
36799
36800
36801
36802
36803
36804
36805
36806
36807
36808
# File 'lib/aws-sdk-sagemaker/types.rb', line 36796

class ListImageVersionsRequest < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :image_name,
  :last_modified_time_after,
  :last_modified_time_before,
  :max_results,
  :next_token,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#sort_by ⇒ String

The property used to sort results. The default value is CREATION_TIME.

Returns:

  • (String)


36796
36797
36798
36799
36800
36801
36802
36803
36804
36805
36806
36807
36808
# File 'lib/aws-sdk-sagemaker/types.rb', line 36796

class ListImageVersionsRequest < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :image_name,
  :last_modified_time_after,
  :last_modified_time_before,
  :max_results,
  :next_token,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#sort_order ⇒ String

The sort order. The default value is DESCENDING.

Returns:

  • (String)


36796
36797
36798
36799
36800
36801
36802
36803
36804
36805
36806
36807
36808
# File 'lib/aws-sdk-sagemaker/types.rb', line 36796

class ListImageVersionsRequest < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :image_name,
  :last_modified_time_after,
  :last_modified_time_before,
  :max_results,
  :next_token,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end