Class: Aws::SageMaker::Types::ListImagesRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_time_afterTime

A filter that returns only images created on or after the specified time.



33536
33537
33538
33539
33540
33541
33542
33543
33544
33545
33546
33547
33548
# File 'lib/aws-sdk-sagemaker/types.rb', line 33536

class ListImagesRequest < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :max_results,
  :name_contains,
  :next_token,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#creation_time_beforeTime

A filter that returns only images created on or before the specified time.



33536
33537
33538
33539
33540
33541
33542
33543
33544
33545
33546
33547
33548
# File 'lib/aws-sdk-sagemaker/types.rb', line 33536

class ListImagesRequest < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :max_results,
  :name_contains,
  :next_token,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_time_afterTime

A filter that returns only images modified on or after the specified time.



33536
33537
33538
33539
33540
33541
33542
33543
33544
33545
33546
33547
33548
# File 'lib/aws-sdk-sagemaker/types.rb', line 33536

class ListImagesRequest < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :max_results,
  :name_contains,
  :next_token,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_time_beforeTime

A filter that returns only images modified on or before the specified time.



33536
33537
33538
33539
33540
33541
33542
33543
33544
33545
33546
33547
33548
# File 'lib/aws-sdk-sagemaker/types.rb', line 33536

class ListImagesRequest < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :max_results,
  :name_contains,
  :next_token,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of images to return in the response. The default value is 10.



33536
33537
33538
33539
33540
33541
33542
33543
33544
33545
33546
33547
33548
# File 'lib/aws-sdk-sagemaker/types.rb', line 33536

class ListImagesRequest < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :max_results,
  :name_contains,
  :next_token,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#name_containsString

A filter that returns only images whose name contains the specified string.



33536
33537
33538
33539
33540
33541
33542
33543
33544
33545
33546
33547
33548
# File 'lib/aws-sdk-sagemaker/types.rb', line 33536

class ListImagesRequest < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :max_results,
  :name_contains,
  :next_token,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the previous call to ListImages didn’t return the full set of images, the call returns a token for getting the next set of images.



33536
33537
33538
33539
33540
33541
33542
33543
33544
33545
33546
33547
33548
# File 'lib/aws-sdk-sagemaker/types.rb', line 33536

class ListImagesRequest < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :max_results,
  :name_contains,
  :next_token,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#sort_byString

The property used to sort results. The default value is CREATION_TIME.



33536
33537
33538
33539
33540
33541
33542
33543
33544
33545
33546
33547
33548
# File 'lib/aws-sdk-sagemaker/types.rb', line 33536

class ListImagesRequest < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :max_results,
  :name_contains,
  :next_token,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#sort_orderString

The sort order. The default value is DESCENDING.



33536
33537
33538
33539
33540
33541
33542
33543
33544
33545
33546
33547
33548
# File 'lib/aws-sdk-sagemaker/types.rb', line 33536

class ListImagesRequest < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :max_results,
  :name_contains,
  :next_token,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end