Class: Aws::SageMaker::Types::ListInferenceExperimentsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_time_after ⇒ Time

Selects inference experiments which were created after this timestamp.

Returns:

  • (Time)


37065
37066
37067
37068
37069
37070
37071
37072
37073
37074
37075
37076
37077
37078
37079
# File 'lib/aws-sdk-sagemaker/types.rb', line 37065

class ListInferenceExperimentsRequest < Struct.new(
  :name_contains,
  :type,
  :status_equals,
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#creation_time_before ⇒ Time

Selects inference experiments which were created before this timestamp.

Returns:

  • (Time)


37065
37066
37067
37068
37069
37070
37071
37072
37073
37074
37075
37076
37077
37078
37079
# File 'lib/aws-sdk-sagemaker/types.rb', line 37065

class ListInferenceExperimentsRequest < Struct.new(
  :name_contains,
  :type,
  :status_equals,
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_time_after ⇒ Time

Selects inference experiments which were last modified after this timestamp.

Returns:

  • (Time)


37065
37066
37067
37068
37069
37070
37071
37072
37073
37074
37075
37076
37077
37078
37079
# File 'lib/aws-sdk-sagemaker/types.rb', line 37065

class ListInferenceExperimentsRequest < Struct.new(
  :name_contains,
  :type,
  :status_equals,
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_time_before ⇒ Time

Selects inference experiments which were last modified before this timestamp.

Returns:

  • (Time)


37065
37066
37067
37068
37069
37070
37071
37072
37073
37074
37075
37076
37077
37078
37079
# File 'lib/aws-sdk-sagemaker/types.rb', line 37065

class ListInferenceExperimentsRequest < Struct.new(
  :name_contains,
  :type,
  :status_equals,
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of results to select.

Returns:

  • (Integer)


37065
37066
37067
37068
37069
37070
37071
37072
37073
37074
37075
37076
37077
37078
37079
# File 'lib/aws-sdk-sagemaker/types.rb', line 37065

class ListInferenceExperimentsRequest < Struct.new(
  :name_contains,
  :type,
  :status_equals,
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#name_contains ⇒ String

Selects inference experiments whose names contain this name.

Returns:

  • (String)


37065
37066
37067
37068
37069
37070
37071
37072
37073
37074
37075
37076
37077
37078
37079
# File 'lib/aws-sdk-sagemaker/types.rb', line 37065

class ListInferenceExperimentsRequest < Struct.new(
  :name_contains,
  :type,
  :status_equals,
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The response from the last list when returning a list large enough to need tokening.

Returns:

  • (String)


37065
37066
37067
37068
37069
37070
37071
37072
37073
37074
37075
37076
37077
37078
37079
# File 'lib/aws-sdk-sagemaker/types.rb', line 37065

class ListInferenceExperimentsRequest < Struct.new(
  :name_contains,
  :type,
  :status_equals,
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#sort_by ⇒ String

The column by which to sort the listed inference experiments.

Returns:

  • (String)


37065
37066
37067
37068
37069
37070
37071
37072
37073
37074
37075
37076
37077
37078
37079
# File 'lib/aws-sdk-sagemaker/types.rb', line 37065

class ListInferenceExperimentsRequest < Struct.new(
  :name_contains,
  :type,
  :status_equals,
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#sort_order ⇒ String

The direction of sorting (ascending or descending).

Returns:

  • (String)


37065
37066
37067
37068
37069
37070
37071
37072
37073
37074
37075
37076
37077
37078
37079
# File 'lib/aws-sdk-sagemaker/types.rb', line 37065

class ListInferenceExperimentsRequest < Struct.new(
  :name_contains,
  :type,
  :status_equals,
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#status_equals ⇒ String

Selects inference experiments which are in this status. For the possible statuses, see DescribeInferenceExperiment.

Returns:

  • (String)


37065
37066
37067
37068
37069
37070
37071
37072
37073
37074
37075
37076
37077
37078
37079
# File 'lib/aws-sdk-sagemaker/types.rb', line 37065

class ListInferenceExperimentsRequest < Struct.new(
  :name_contains,
  :type,
  :status_equals,
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#type ⇒ String

Selects inference experiments of this type. For the possible types of inference experiments, see CreateInferenceExperiment.

Returns:

  • (String)


37065
37066
37067
37068
37069
37070
37071
37072
37073
37074
37075
37076
37077
37078
37079
# File 'lib/aws-sdk-sagemaker/types.rb', line 37065

class ListInferenceExperimentsRequest < Struct.new(
  :name_contains,
  :type,
  :status_equals,
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end