Class: Aws::SageMaker::Types::ListInferenceRecommendationsJobStepsResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_token ⇒ String

A token that you can specify in your next request to return more results from the list.

Returns:

  • (String)


37147
37148
37149
37150
37151
37152
# File 'lib/aws-sdk-sagemaker/types.rb', line 37147

class ListInferenceRecommendationsJobStepsResponse < Struct.new(
  :steps,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#steps ⇒ Array<Types::InferenceRecommendationsJobStep>

A list of all subtask details in Inference Recommender.



37147
37148
37149
37150
37151
37152
# File 'lib/aws-sdk-sagemaker/types.rb', line 37147

class ListInferenceRecommendationsJobStepsResponse < Struct.new(
  :steps,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end