Class: Aws::SageMaker::Types::ListJobSchemaVersionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#job_categoryString

The category of job schemas to list.

Returns:



37266
37267
37268
37269
37270
37271
37272
# File 'lib/aws-sdk-sagemaker/types.rb', line 37266

class ListJobSchemaVersionsRequest < Struct.new(
  :job_category,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of schema versions to return in the response. The default value is 5.

Returns:



37266
37267
37268
37269
37270
37271
37272
# File 'lib/aws-sdk-sagemaker/types.rb', line 37266

class ListJobSchemaVersionsRequest < Struct.new(
  :job_category,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the previous response was truncated, this token retrieves the next set of results.

Returns:



37266
37267
37268
37269
37270
37271
37272
# File 'lib/aws-sdk-sagemaker/types.rb', line 37266

class ListJobSchemaVersionsRequest < Struct.new(
  :job_category,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end