Class: Aws::SageMaker::Types::ListJobSchemaVersionsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListJobSchemaVersionsResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_config_schemas ⇒ Array<Types::JobConfigSchemaVersionSummary>
An array of
JobConfigSchemaVersionSummaryobjects listing the available schema versions. -
#next_token ⇒ String
If the response is truncated, this token retrieves the next set of results.
Instance Attribute Details
#job_config_schemas ⇒ Array<Types::JobConfigSchemaVersionSummary>
An array of JobConfigSchemaVersionSummary objects listing the
available schema versions.
37286 37287 37288 37289 37290 37291 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37286 class ListJobSchemaVersionsResponse < Struct.new( :next_token, :job_config_schemas) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the response is truncated, this token retrieves the next set of results.
37286 37287 37288 37289 37290 37291 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37286 class ListJobSchemaVersionsResponse < Struct.new( :next_token, :job_config_schemas) SENSITIVE = [] include Aws::Structure end |