Class: Aws::SageMaker::Types::ListJobsResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#job_summariesArray<Types::JobSummary>

An array of JobSummary objects that provide summary information about the jobs.

Returns:



37371
37372
37373
37374
37375
37376
# File 'lib/aws-sdk-sagemaker/types.rb', line 37371

class ListJobsResponse < Struct.new(
  :next_token,
  :job_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the response is truncated, this token retrieves the next set of results.

Returns:

  • (String)


37371
37372
37373
37374
37375
37376
# File 'lib/aws-sdk-sagemaker/types.rb', line 37371

class ListJobsResponse < Struct.new(
  :next_token,
  :job_summaries)
  SENSITIVE = []
  include Aws::Structure
end