Class: Aws::SageMaker::Types::ListLabelingJobsForWorkteamRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListLabelingJobsForWorkteamRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time_after ⇒ Time
A filter that returns only labeling jobs created after the specified time (timestamp).
-
#creation_time_before ⇒ Time
A filter that returns only labeling jobs created before the specified time (timestamp).
-
#job_reference_code_contains ⇒ String
A filter the limits jobs to only the ones whose job reference code contains the specified string.
-
#max_results ⇒ Integer
The maximum number of labeling jobs to return in each page of the response.
-
#next_token ⇒ String
If the result of the previous
ListLabelingJobsForWorkteamrequest was truncated, the response includes aNextToken. -
#sort_by ⇒ String
The field to sort results by.
-
#sort_order ⇒ String
The sort order for results.
-
#workteam_arn ⇒ String
The Amazon Resource Name (ARN) of the work team for which you want to see labeling jobs for.
Instance Attribute Details
#creation_time_after ⇒ Time
A filter that returns only labeling jobs created after the specified time (timestamp).
33954 33955 33956 33957 33958 33959 33960 33961 33962 33963 33964 33965 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33954 class ListLabelingJobsForWorkteamRequest < Struct.new( :workteam_arn, :max_results, :next_token, :creation_time_after, :creation_time_before, :job_reference_code_contains, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#creation_time_before ⇒ Time
A filter that returns only labeling jobs created before the specified time (timestamp).
33954 33955 33956 33957 33958 33959 33960 33961 33962 33963 33964 33965 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33954 class ListLabelingJobsForWorkteamRequest < Struct.new( :workteam_arn, :max_results, :next_token, :creation_time_after, :creation_time_before, :job_reference_code_contains, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#job_reference_code_contains ⇒ String
A filter the limits jobs to only the ones whose job reference code contains the specified string.
33954 33955 33956 33957 33958 33959 33960 33961 33962 33963 33964 33965 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33954 class ListLabelingJobsForWorkteamRequest < Struct.new( :workteam_arn, :max_results, :next_token, :creation_time_after, :creation_time_before, :job_reference_code_contains, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of labeling jobs to return in each page of the response.
33954 33955 33956 33957 33958 33959 33960 33961 33962 33963 33964 33965 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33954 class ListLabelingJobsForWorkteamRequest < Struct.new( :workteam_arn, :max_results, :next_token, :creation_time_after, :creation_time_before, :job_reference_code_contains, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the result of the previous ListLabelingJobsForWorkteam request was truncated, the response includes a NextToken. To retrieve the next set of labeling jobs, use the token in the next request.
33954 33955 33956 33957 33958 33959 33960 33961 33962 33963 33964 33965 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33954 class ListLabelingJobsForWorkteamRequest < Struct.new( :workteam_arn, :max_results, :next_token, :creation_time_after, :creation_time_before, :job_reference_code_contains, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
The field to sort results by. The default is CreationTime.
33954 33955 33956 33957 33958 33959 33960 33961 33962 33963 33964 33965 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33954 class ListLabelingJobsForWorkteamRequest < Struct.new( :workteam_arn, :max_results, :next_token, :creation_time_after, :creation_time_before, :job_reference_code_contains, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
The sort order for results. The default is Ascending.
33954 33955 33956 33957 33958 33959 33960 33961 33962 33963 33964 33965 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33954 class ListLabelingJobsForWorkteamRequest < Struct.new( :workteam_arn, :max_results, :next_token, :creation_time_after, :creation_time_before, :job_reference_code_contains, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#workteam_arn ⇒ String
The Amazon Resource Name (ARN) of the work team for which you want to see labeling jobs for.
33954 33955 33956 33957 33958 33959 33960 33961 33962 33963 33964 33965 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33954 class ListLabelingJobsForWorkteamRequest < Struct.new( :workteam_arn, :max_results, :next_token, :creation_time_after, :creation_time_before, :job_reference_code_contains, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |