Class: Aws::SageMaker::Types::ListMlflowAppsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_default_status ⇒ String

Filter for MLflow Apps with the specified AccountDefaultStatus.

Returns:

  • (String)


37652
37653
37654
37655
37656
37657
37658
37659
37660
37661
37662
37663
37664
37665
# File 'lib/aws-sdk-sagemaker/types.rb', line 37652

class ListMlflowAppsRequest < Struct.new(
  :created_after,
  :created_before,
  :status,
  :mlflow_version,
  :default_for_domain_id,
  :account_default_status,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#created_after ⇒ Time

Use the CreatedAfter filter to only list MLflow Apps created after a specific date and time. Listed MLflow Apps are shown with a date and time such as "2024-03-16T01:46:56+00:00". The CreatedAfter parameter takes in a Unix timestamp.

Returns:

  • (Time)


37652
37653
37654
37655
37656
37657
37658
37659
37660
37661
37662
37663
37664
37665
# File 'lib/aws-sdk-sagemaker/types.rb', line 37652

class ListMlflowAppsRequest < Struct.new(
  :created_after,
  :created_before,
  :status,
  :mlflow_version,
  :default_for_domain_id,
  :account_default_status,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#created_before ⇒ Time

Use the CreatedBefore filter to only list MLflow Apps created before a specific date and time. Listed MLflow Apps are shown with a date and time such as "2024-03-16T01:46:56+00:00". The CreatedAfter parameter takes in a Unix timestamp.

Returns:

  • (Time)


37652
37653
37654
37655
37656
37657
37658
37659
37660
37661
37662
37663
37664
37665
# File 'lib/aws-sdk-sagemaker/types.rb', line 37652

class ListMlflowAppsRequest < Struct.new(
  :created_after,
  :created_before,
  :status,
  :mlflow_version,
  :default_for_domain_id,
  :account_default_status,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#default_for_domain_id ⇒ String

Filter for MLflow Apps with the specified default SageMaker Domain ID.

Returns:

  • (String)


37652
37653
37654
37655
37656
37657
37658
37659
37660
37661
37662
37663
37664
37665
# File 'lib/aws-sdk-sagemaker/types.rb', line 37652

class ListMlflowAppsRequest < Struct.new(
  :created_after,
  :created_before,
  :status,
  :mlflow_version,
  :default_for_domain_id,
  :account_default_status,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of MLflow Apps to list.

Returns:

  • (Integer)


37652
37653
37654
37655
37656
37657
37658
37659
37660
37661
37662
37663
37664
37665
# File 'lib/aws-sdk-sagemaker/types.rb', line 37652

class ListMlflowAppsRequest < Struct.new(
  :created_after,
  :created_before,
  :status,
  :mlflow_version,
  :default_for_domain_id,
  :account_default_status,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#mlflow_version ⇒ String

Filter for Mlflow Apps with the specified version.

Returns:

  • (String)


37652
37653
37654
37655
37656
37657
37658
37659
37660
37661
37662
37663
37664
37665
# File 'lib/aws-sdk-sagemaker/types.rb', line 37652

class ListMlflowAppsRequest < Struct.new(
  :created_after,
  :created_before,
  :status,
  :mlflow_version,
  :default_for_domain_id,
  :account_default_status,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

If the previous response was truncated, use this token in your next request to receive the next set of results.

Returns:

  • (String)


37652
37653
37654
37655
37656
37657
37658
37659
37660
37661
37662
37663
37664
37665
# File 'lib/aws-sdk-sagemaker/types.rb', line 37652

class ListMlflowAppsRequest < Struct.new(
  :created_after,
  :created_before,
  :status,
  :mlflow_version,
  :default_for_domain_id,
  :account_default_status,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#sort_by ⇒ String

Filter for MLflow Apps sorting by name, creation time, or creation status.

Returns:

  • (String)


37652
37653
37654
37655
37656
37657
37658
37659
37660
37661
37662
37663
37664
37665
# File 'lib/aws-sdk-sagemaker/types.rb', line 37652

class ListMlflowAppsRequest < Struct.new(
  :created_after,
  :created_before,
  :status,
  :mlflow_version,
  :default_for_domain_id,
  :account_default_status,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#sort_order ⇒ String

Change the order of the listed MLflow Apps. By default, MLflow Apps are listed in Descending order by creation time. To change the list order, specify SortOrder to be Ascending.

Returns:

  • (String)


37652
37653
37654
37655
37656
37657
37658
37659
37660
37661
37662
37663
37664
37665
# File 'lib/aws-sdk-sagemaker/types.rb', line 37652

class ListMlflowAppsRequest < Struct.new(
  :created_after,
  :created_before,
  :status,
  :mlflow_version,
  :default_for_domain_id,
  :account_default_status,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

Filter for Mlflow apps with a specific creation status.

Returns:

  • (String)


37652
37653
37654
37655
37656
37657
37658
37659
37660
37661
37662
37663
37664
37665
# File 'lib/aws-sdk-sagemaker/types.rb', line 37652

class ListMlflowAppsRequest < Struct.new(
  :created_after,
  :created_before,
  :status,
  :mlflow_version,
  :default_for_domain_id,
  :account_default_status,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end