Class: Aws::SageMaker::Types::ListModelBiasJobDefinitionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_time_afterTime

A filter that returns only model bias jobs created after a specified time.

Returns:

  • (Time)


37811
37812
37813
37814
37815
37816
37817
37818
37819
37820
37821
37822
# File 'lib/aws-sdk-sagemaker/types.rb', line 37811

class ListModelBiasJobDefinitionsRequest < Struct.new(
  :endpoint_name,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results,
  :name_contains,
  :creation_time_before,
  :creation_time_after)
  SENSITIVE = []
  include Aws::Structure
end

#creation_time_beforeTime

A filter that returns only model bias jobs created before a specified time.

Returns:

  • (Time)


37811
37812
37813
37814
37815
37816
37817
37818
37819
37820
37821
37822
# File 'lib/aws-sdk-sagemaker/types.rb', line 37811

class ListModelBiasJobDefinitionsRequest < Struct.new(
  :endpoint_name,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results,
  :name_contains,
  :creation_time_before,
  :creation_time_after)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_nameString

Name of the endpoint to monitor for model bias.

Returns:

  • (String)


37811
37812
37813
37814
37815
37816
37817
37818
37819
37820
37821
37822
# File 'lib/aws-sdk-sagemaker/types.rb', line 37811

class ListModelBiasJobDefinitionsRequest < Struct.new(
  :endpoint_name,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results,
  :name_contains,
  :creation_time_before,
  :creation_time_after)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of model bias jobs to return in the response. The default value is 10.

Returns:

  • (Integer)


37811
37812
37813
37814
37815
37816
37817
37818
37819
37820
37821
37822
# File 'lib/aws-sdk-sagemaker/types.rb', line 37811

class ListModelBiasJobDefinitionsRequest < Struct.new(
  :endpoint_name,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results,
  :name_contains,
  :creation_time_before,
  :creation_time_after)
  SENSITIVE = []
  include Aws::Structure
end

#name_containsString

Filter for model bias jobs whose name contains a specified string.

Returns:

  • (String)


37811
37812
37813
37814
37815
37816
37817
37818
37819
37820
37821
37822
# File 'lib/aws-sdk-sagemaker/types.rb', line 37811

class ListModelBiasJobDefinitionsRequest < Struct.new(
  :endpoint_name,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results,
  :name_contains,
  :creation_time_before,
  :creation_time_after)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token returned if the response is truncated. To retrieve the next set of job executions, use it in the next request.

Returns:

  • (String)


37811
37812
37813
37814
37815
37816
37817
37818
37819
37820
37821
37822
# File 'lib/aws-sdk-sagemaker/types.rb', line 37811

class ListModelBiasJobDefinitionsRequest < Struct.new(
  :endpoint_name,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results,
  :name_contains,
  :creation_time_before,
  :creation_time_after)
  SENSITIVE = []
  include Aws::Structure
end

#sort_byString

Whether to sort results by the Name or CreationTime field. The default is CreationTime.

Returns:

  • (String)


37811
37812
37813
37814
37815
37816
37817
37818
37819
37820
37821
37822
# File 'lib/aws-sdk-sagemaker/types.rb', line 37811

class ListModelBiasJobDefinitionsRequest < Struct.new(
  :endpoint_name,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results,
  :name_contains,
  :creation_time_before,
  :creation_time_after)
  SENSITIVE = []
  include Aws::Structure
end

#sort_orderString

Whether to sort the results in Ascending or Descending order. The default is Descending.

Returns:

  • (String)


37811
37812
37813
37814
37815
37816
37817
37818
37819
37820
37821
37822
# File 'lib/aws-sdk-sagemaker/types.rb', line 37811

class ListModelBiasJobDefinitionsRequest < Struct.new(
  :endpoint_name,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results,
  :name_contains,
  :creation_time_before,
  :creation_time_after)
  SENSITIVE = []
  include Aws::Structure
end