Class: Aws::SageMaker::Types::ListModelExplainabilityJobDefinitionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListModelExplainabilityJobDefinitionsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time_after ⇒ Time
A filter that returns only model explainability jobs created after a specified time.
-
#creation_time_before ⇒ Time
A filter that returns only model explainability jobs created before a specified time.
-
#endpoint_name ⇒ String
Name of the endpoint to monitor for model explainability.
-
#max_results ⇒ Integer
The maximum number of jobs to return in the response.
-
#name_contains ⇒ String
Filter for model explainability jobs whose name contains a specified string.
-
#next_token ⇒ String
The token returned if the response is truncated.
-
#sort_by ⇒ String
Whether to sort results by the
NameorCreationTimefield. -
#sort_order ⇒ String
Whether to sort the results in
AscendingorDescendingorder.
Instance Attribute Details
#creation_time_after ⇒ Time
A filter that returns only model explainability jobs created after a specified time.
38107 38108 38109 38110 38111 38112 38113 38114 38115 38116 38117 38118 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 38107 class ListModelExplainabilityJobDefinitionsRequest < Struct.new( :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after) SENSITIVE = [] include Aws::Structure end |
#creation_time_before ⇒ Time
A filter that returns only model explainability jobs created before a specified time.
38107 38108 38109 38110 38111 38112 38113 38114 38115 38116 38117 38118 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 38107 class ListModelExplainabilityJobDefinitionsRequest < Struct.new( :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after) SENSITIVE = [] include Aws::Structure end |
#endpoint_name ⇒ String
Name of the endpoint to monitor for model explainability.
38107 38108 38109 38110 38111 38112 38113 38114 38115 38116 38117 38118 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 38107 class ListModelExplainabilityJobDefinitionsRequest < Struct.new( :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of jobs to return in the response. The default value is 10.
38107 38108 38109 38110 38111 38112 38113 38114 38115 38116 38117 38118 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 38107 class ListModelExplainabilityJobDefinitionsRequest < Struct.new( :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after) SENSITIVE = [] include Aws::Structure end |
#name_contains ⇒ String
Filter for model explainability jobs whose name contains a specified string.
38107 38108 38109 38110 38111 38112 38113 38114 38115 38116 38117 38118 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 38107 class ListModelExplainabilityJobDefinitionsRequest < Struct.new( :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token returned if the response is truncated. To retrieve the next set of job executions, use it in the next request.
38107 38108 38109 38110 38111 38112 38113 38114 38115 38116 38117 38118 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 38107 class ListModelExplainabilityJobDefinitionsRequest < Struct.new( :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
Whether to sort results by the Name or CreationTime field. The
default is CreationTime.
38107 38108 38109 38110 38111 38112 38113 38114 38115 38116 38117 38118 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 38107 class ListModelExplainabilityJobDefinitionsRequest < Struct.new( :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
Whether to sort the results in Ascending or Descending order.
The default is Descending.
38107 38108 38109 38110 38111 38112 38113 38114 38115 38116 38117 38118 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 38107 class ListModelExplainabilityJobDefinitionsRequest < Struct.new( :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after) SENSITIVE = [] include Aws::Structure end |