Class: Aws::SageMaker::Types::ListModelPackageGroupsInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_time_afterTime

A filter that returns only model groups created after the specified time.

Returns:

  • (Time)


38228
38229
38230
38231
38232
38233
38234
38235
38236
38237
38238
38239
# File 'lib/aws-sdk-sagemaker/types.rb', line 38228

class ListModelPackageGroupsInput < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :max_results,
  :name_contains,
  :next_token,
  :sort_by,
  :sort_order,
  :cross_account_filter_option)
  SENSITIVE = []
  include Aws::Structure
end

#creation_time_beforeTime

A filter that returns only model groups created before the specified time.

Returns:

  • (Time)


38228
38229
38230
38231
38232
38233
38234
38235
38236
38237
38238
38239
# File 'lib/aws-sdk-sagemaker/types.rb', line 38228

class ListModelPackageGroupsInput < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :max_results,
  :name_contains,
  :next_token,
  :sort_by,
  :sort_order,
  :cross_account_filter_option)
  SENSITIVE = []
  include Aws::Structure
end

#cross_account_filter_optionString

A filter that returns either model groups shared with you or model groups in your own account. When the value is CrossAccount, the results show the resources made discoverable to you from other accounts. When the value is SameAccount or null, the results show resources from your account. The default is SameAccount.

Returns:

  • (String)


38228
38229
38230
38231
38232
38233
38234
38235
38236
38237
38238
38239
# File 'lib/aws-sdk-sagemaker/types.rb', line 38228

class ListModelPackageGroupsInput < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :max_results,
  :name_contains,
  :next_token,
  :sort_by,
  :sort_order,
  :cross_account_filter_option)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in the response.

Returns:

  • (Integer)


38228
38229
38230
38231
38232
38233
38234
38235
38236
38237
38238
38239
# File 'lib/aws-sdk-sagemaker/types.rb', line 38228

class ListModelPackageGroupsInput < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :max_results,
  :name_contains,
  :next_token,
  :sort_by,
  :sort_order,
  :cross_account_filter_option)
  SENSITIVE = []
  include Aws::Structure
end

#name_containsString

A string in the model group name. This filter returns only model groups whose name contains the specified string.

Returns:

  • (String)


38228
38229
38230
38231
38232
38233
38234
38235
38236
38237
38238
38239
# File 'lib/aws-sdk-sagemaker/types.rb', line 38228

class ListModelPackageGroupsInput < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :max_results,
  :name_contains,
  :next_token,
  :sort_by,
  :sort_order,
  :cross_account_filter_option)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the result of the previous ListModelPackageGroups request was truncated, the response includes a NextToken. To retrieve the next set of model groups, use the token in the next request.

Returns:

  • (String)


38228
38229
38230
38231
38232
38233
38234
38235
38236
38237
38238
38239
# File 'lib/aws-sdk-sagemaker/types.rb', line 38228

class ListModelPackageGroupsInput < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :max_results,
  :name_contains,
  :next_token,
  :sort_by,
  :sort_order,
  :cross_account_filter_option)
  SENSITIVE = []
  include Aws::Structure
end

#sort_byString

The field to sort results by. The default is CreationTime.

Returns:

  • (String)


38228
38229
38230
38231
38232
38233
38234
38235
38236
38237
38238
38239
# File 'lib/aws-sdk-sagemaker/types.rb', line 38228

class ListModelPackageGroupsInput < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :max_results,
  :name_contains,
  :next_token,
  :sort_by,
  :sort_order,
  :cross_account_filter_option)
  SENSITIVE = []
  include Aws::Structure
end

#sort_orderString

The sort order for results. The default is Ascending.

Returns:

  • (String)


38228
38229
38230
38231
38232
38233
38234
38235
38236
38237
38238
38239
# File 'lib/aws-sdk-sagemaker/types.rb', line 38228

class ListModelPackageGroupsInput < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :max_results,
  :name_contains,
  :next_token,
  :sort_by,
  :sort_order,
  :cross_account_filter_option)
  SENSITIVE = []
  include Aws::Structure
end