Class: Aws::SageMaker::Types::ListModelsInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_time_after ⇒ Time

A filter that returns only models with a creation time greater than or equal to the specified time (timestamp).

Returns:

  • (Time)


38465
38466
38467
38468
38469
38470
38471
38472
38473
38474
38475
# File 'lib/aws-sdk-sagemaker/types.rb', line 38465

class ListModelsInput < Struct.new(
  :sort_by,
  :sort_order,
  :next_token,
  :max_results,
  :name_contains,
  :creation_time_before,
  :creation_time_after)
  SENSITIVE = []
  include Aws::Structure
end

#creation_time_before ⇒ Time

A filter that returns only models created before the specified time (timestamp).

Returns:

  • (Time)


38465
38466
38467
38468
38469
38470
38471
38472
38473
38474
38475
# File 'lib/aws-sdk-sagemaker/types.rb', line 38465

class ListModelsInput < Struct.new(
  :sort_by,
  :sort_order,
  :next_token,
  :max_results,
  :name_contains,
  :creation_time_before,
  :creation_time_after)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of models to return in the response.

Returns:

  • (Integer)


38465
38466
38467
38468
38469
38470
38471
38472
38473
38474
38475
# File 'lib/aws-sdk-sagemaker/types.rb', line 38465

class ListModelsInput < Struct.new(
  :sort_by,
  :sort_order,
  :next_token,
  :max_results,
  :name_contains,
  :creation_time_before,
  :creation_time_after)
  SENSITIVE = []
  include Aws::Structure
end

#name_contains ⇒ String

A string in the model name. This filter returns only models whose name contains the specified string.

Returns:

  • (String)


38465
38466
38467
38468
38469
38470
38471
38472
38473
38474
38475
# File 'lib/aws-sdk-sagemaker/types.rb', line 38465

class ListModelsInput < Struct.new(
  :sort_by,
  :sort_order,
  :next_token,
  :max_results,
  :name_contains,
  :creation_time_before,
  :creation_time_after)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

If the response to a previous ListModels request was truncated, the response includes a NextToken. To retrieve the next set of models, use the token in the next request.

Returns:

  • (String)


38465
38466
38467
38468
38469
38470
38471
38472
38473
38474
38475
# File 'lib/aws-sdk-sagemaker/types.rb', line 38465

class ListModelsInput < Struct.new(
  :sort_by,
  :sort_order,
  :next_token,
  :max_results,
  :name_contains,
  :creation_time_before,
  :creation_time_after)
  SENSITIVE = []
  include Aws::Structure
end

#sort_by ⇒ String

Sorts the list of results. The default is CreationTime.

Returns:

  • (String)


38465
38466
38467
38468
38469
38470
38471
38472
38473
38474
38475
# File 'lib/aws-sdk-sagemaker/types.rb', line 38465

class ListModelsInput < Struct.new(
  :sort_by,
  :sort_order,
  :next_token,
  :max_results,
  :name_contains,
  :creation_time_before,
  :creation_time_after)
  SENSITIVE = []
  include Aws::Structure
end

#sort_order ⇒ String

The sort order for results. The default is Descending.

Returns:

  • (String)


38465
38466
38467
38468
38469
38470
38471
38472
38473
38474
38475
# File 'lib/aws-sdk-sagemaker/types.rb', line 38465

class ListModelsInput < Struct.new(
  :sort_by,
  :sort_order,
  :next_token,
  :max_results,
  :name_contains,
  :creation_time_before,
  :creation_time_after)
  SENSITIVE = []
  include Aws::Structure
end