Class: Aws::SageMaker::Types::ListMonitoringAlertHistoryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListMonitoringAlertHistoryRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time_after ⇒ Time
A filter that returns only alerts created on or after the specified time.
-
#creation_time_before ⇒ Time
A filter that returns only alerts created on or before the specified time.
-
#max_results ⇒ Integer
The maximum number of results to display.
-
#monitoring_alert_name ⇒ String
The name of a monitoring alert.
-
#monitoring_schedule_name ⇒ String
The name of a monitoring schedule.
-
#next_token ⇒ String
If the result of the previous
ListMonitoringAlertHistoryrequest was truncated, the response includes aNextToken. -
#sort_by ⇒ String
The field used to sort results.
-
#sort_order ⇒ String
The sort order, whether
AscendingorDescending, of the alert history. -
#status_equals ⇒ String
A filter that retrieves only alerts with a specific status.
Instance Attribute Details
#creation_time_after ⇒ Time
A filter that returns only alerts created on or after the specified time.
35074 35075 35076 35077 35078 35079 35080 35081 35082 35083 35084 35085 35086 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35074 class ListMonitoringAlertHistoryRequest < Struct.new( :monitoring_schedule_name, :monitoring_alert_name, :sort_by, :sort_order, :next_token, :max_results, :creation_time_before, :creation_time_after, :status_equals) SENSITIVE = [] include Aws::Structure end |
#creation_time_before ⇒ Time
A filter that returns only alerts created on or before the specified time.
35074 35075 35076 35077 35078 35079 35080 35081 35082 35083 35084 35085 35086 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35074 class ListMonitoringAlertHistoryRequest < Struct.new( :monitoring_schedule_name, :monitoring_alert_name, :sort_by, :sort_order, :next_token, :max_results, :creation_time_before, :creation_time_after, :status_equals) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to display. The default is 100.
35074 35075 35076 35077 35078 35079 35080 35081 35082 35083 35084 35085 35086 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35074 class ListMonitoringAlertHistoryRequest < Struct.new( :monitoring_schedule_name, :monitoring_alert_name, :sort_by, :sort_order, :next_token, :max_results, :creation_time_before, :creation_time_after, :status_equals) SENSITIVE = [] include Aws::Structure end |
#monitoring_alert_name ⇒ String
The name of a monitoring alert.
35074 35075 35076 35077 35078 35079 35080 35081 35082 35083 35084 35085 35086 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35074 class ListMonitoringAlertHistoryRequest < Struct.new( :monitoring_schedule_name, :monitoring_alert_name, :sort_by, :sort_order, :next_token, :max_results, :creation_time_before, :creation_time_after, :status_equals) SENSITIVE = [] include Aws::Structure end |
#monitoring_schedule_name ⇒ String
The name of a monitoring schedule.
35074 35075 35076 35077 35078 35079 35080 35081 35082 35083 35084 35085 35086 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35074 class ListMonitoringAlertHistoryRequest < Struct.new( :monitoring_schedule_name, :monitoring_alert_name, :sort_by, :sort_order, :next_token, :max_results, :creation_time_before, :creation_time_after, :status_equals) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the result of the previous ListMonitoringAlertHistory request was truncated, the response includes a NextToken. To retrieve the next set of alerts in the history, use the token in the next request.
35074 35075 35076 35077 35078 35079 35080 35081 35082 35083 35084 35085 35086 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35074 class ListMonitoringAlertHistoryRequest < Struct.new( :monitoring_schedule_name, :monitoring_alert_name, :sort_by, :sort_order, :next_token, :max_results, :creation_time_before, :creation_time_after, :status_equals) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
The field used to sort results. The default is CreationTime.
35074 35075 35076 35077 35078 35079 35080 35081 35082 35083 35084 35085 35086 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35074 class ListMonitoringAlertHistoryRequest < Struct.new( :monitoring_schedule_name, :monitoring_alert_name, :sort_by, :sort_order, :next_token, :max_results, :creation_time_before, :creation_time_after, :status_equals) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
The sort order, whether Ascending or Descending, of the alert history. The default is Descending.
35074 35075 35076 35077 35078 35079 35080 35081 35082 35083 35084 35085 35086 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35074 class ListMonitoringAlertHistoryRequest < Struct.new( :monitoring_schedule_name, :monitoring_alert_name, :sort_by, :sort_order, :next_token, :max_results, :creation_time_before, :creation_time_after, :status_equals) SENSITIVE = [] include Aws::Structure end |
#status_equals ⇒ String
A filter that retrieves only alerts with a specific status.
35074 35075 35076 35077 35078 35079 35080 35081 35082 35083 35084 35085 35086 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35074 class ListMonitoringAlertHistoryRequest < Struct.new( :monitoring_schedule_name, :monitoring_alert_name, :sort_by, :sort_order, :next_token, :max_results, :creation_time_before, :creation_time_after, :status_equals) SENSITIVE = [] include Aws::Structure end |