Class: Aws::SageMaker::Types::ListMonitoringAlertsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of results to display. The default is 100.

Returns:

  • (Integer)


35122
35123
35124
35125
35126
35127
35128
# File 'lib/aws-sdk-sagemaker/types.rb', line 35122

class ListMonitoringAlertsRequest < Struct.new(
  :monitoring_schedule_name,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#monitoring_schedule_nameString

The name of a monitoring schedule.

Returns:

  • (String)


35122
35123
35124
35125
35126
35127
35128
# File 'lib/aws-sdk-sagemaker/types.rb', line 35122

class ListMonitoringAlertsRequest < Struct.new(
  :monitoring_schedule_name,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the result of the previous ListMonitoringAlerts request was truncated, the response includes a NextToken. To retrieve the next set of alerts in the history, use the token in the next request.

Returns:

  • (String)


35122
35123
35124
35125
35126
35127
35128
# File 'lib/aws-sdk-sagemaker/types.rb', line 35122

class ListMonitoringAlertsRequest < Struct.new(
  :monitoring_schedule_name,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end