Class: Aws::SageMaker::Types::ListMonitoringExecutionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListMonitoringExecutionsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time_after ⇒ Time
A filter that returns only jobs created after a specified time.
-
#creation_time_before ⇒ Time
A filter that returns only jobs created before a specified time.
-
#endpoint_name ⇒ String
Name of a specific endpoint to fetch jobs for.
-
#last_modified_time_after ⇒ Time
A filter that returns only jobs modified before a specified time.
-
#last_modified_time_before ⇒ Time
A filter that returns only jobs modified after a specified time.
-
#max_results ⇒ Integer
The maximum number of jobs to return in the response.
-
#monitoring_job_definition_name ⇒ String
Gets a list of the monitoring job runs of the specified monitoring job definitions.
-
#monitoring_schedule_name ⇒ String
Name of a specific schedule to fetch jobs for.
-
#monitoring_type_equals ⇒ String
A filter that returns only the monitoring job runs of the specified monitoring type.
-
#next_token ⇒ String
The token returned if the response is truncated.
-
#scheduled_time_after ⇒ Time
Filter for jobs scheduled after a specified time.
-
#scheduled_time_before ⇒ Time
Filter for jobs scheduled before a specified time.
-
#sort_by ⇒ String
Whether to sort the results by the
Status,CreationTime, orScheduledTimefield. -
#sort_order ⇒ String
Whether to sort the results in
AscendingorDescendingorder. -
#status_equals ⇒ String
A filter that retrieves only jobs with a specific status.
Instance Attribute Details
#creation_time_after ⇒ Time
A filter that returns only jobs created after a specified time.
35190 35191 35192 35193 35194 35195 35196 35197 35198 35199 35200 35201 35202 35203 35204 35205 35206 35207 35208 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35190 class ListMonitoringExecutionsRequest < Struct.new( :monitoring_schedule_name, :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :scheduled_time_before, :scheduled_time_after, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after, :status_equals, :monitoring_job_definition_name, :monitoring_type_equals) SENSITIVE = [] include Aws::Structure end |
#creation_time_before ⇒ Time
A filter that returns only jobs created before a specified time.
35190 35191 35192 35193 35194 35195 35196 35197 35198 35199 35200 35201 35202 35203 35204 35205 35206 35207 35208 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35190 class ListMonitoringExecutionsRequest < Struct.new( :monitoring_schedule_name, :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :scheduled_time_before, :scheduled_time_after, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after, :status_equals, :monitoring_job_definition_name, :monitoring_type_equals) SENSITIVE = [] include Aws::Structure end |
#endpoint_name ⇒ String
Name of a specific endpoint to fetch jobs for.
35190 35191 35192 35193 35194 35195 35196 35197 35198 35199 35200 35201 35202 35203 35204 35205 35206 35207 35208 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35190 class ListMonitoringExecutionsRequest < Struct.new( :monitoring_schedule_name, :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :scheduled_time_before, :scheduled_time_after, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after, :status_equals, :monitoring_job_definition_name, :monitoring_type_equals) SENSITIVE = [] include Aws::Structure end |
#last_modified_time_after ⇒ Time
A filter that returns only jobs modified before a specified time.
35190 35191 35192 35193 35194 35195 35196 35197 35198 35199 35200 35201 35202 35203 35204 35205 35206 35207 35208 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35190 class ListMonitoringExecutionsRequest < Struct.new( :monitoring_schedule_name, :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :scheduled_time_before, :scheduled_time_after, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after, :status_equals, :monitoring_job_definition_name, :monitoring_type_equals) SENSITIVE = [] include Aws::Structure end |
#last_modified_time_before ⇒ Time
A filter that returns only jobs modified after a specified time.
35190 35191 35192 35193 35194 35195 35196 35197 35198 35199 35200 35201 35202 35203 35204 35205 35206 35207 35208 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35190 class ListMonitoringExecutionsRequest < Struct.new( :monitoring_schedule_name, :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :scheduled_time_before, :scheduled_time_after, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after, :status_equals, :monitoring_job_definition_name, :monitoring_type_equals) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of jobs to return in the response. The default value is 10.
35190 35191 35192 35193 35194 35195 35196 35197 35198 35199 35200 35201 35202 35203 35204 35205 35206 35207 35208 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35190 class ListMonitoringExecutionsRequest < Struct.new( :monitoring_schedule_name, :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :scheduled_time_before, :scheduled_time_after, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after, :status_equals, :monitoring_job_definition_name, :monitoring_type_equals) SENSITIVE = [] include Aws::Structure end |
#monitoring_job_definition_name ⇒ String
Gets a list of the monitoring job runs of the specified monitoring job definitions.
35190 35191 35192 35193 35194 35195 35196 35197 35198 35199 35200 35201 35202 35203 35204 35205 35206 35207 35208 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35190 class ListMonitoringExecutionsRequest < Struct.new( :monitoring_schedule_name, :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :scheduled_time_before, :scheduled_time_after, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after, :status_equals, :monitoring_job_definition_name, :monitoring_type_equals) SENSITIVE = [] include Aws::Structure end |
#monitoring_schedule_name ⇒ String
Name of a specific schedule to fetch jobs for.
35190 35191 35192 35193 35194 35195 35196 35197 35198 35199 35200 35201 35202 35203 35204 35205 35206 35207 35208 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35190 class ListMonitoringExecutionsRequest < Struct.new( :monitoring_schedule_name, :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :scheduled_time_before, :scheduled_time_after, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after, :status_equals, :monitoring_job_definition_name, :monitoring_type_equals) SENSITIVE = [] include Aws::Structure end |
#monitoring_type_equals ⇒ String
A filter that returns only the monitoring job runs of the specified monitoring type.
35190 35191 35192 35193 35194 35195 35196 35197 35198 35199 35200 35201 35202 35203 35204 35205 35206 35207 35208 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35190 class ListMonitoringExecutionsRequest < Struct.new( :monitoring_schedule_name, :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :scheduled_time_before, :scheduled_time_after, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after, :status_equals, :monitoring_job_definition_name, :monitoring_type_equals) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token returned if the response is truncated. To retrieve the next set of job executions, use it in the next request.
35190 35191 35192 35193 35194 35195 35196 35197 35198 35199 35200 35201 35202 35203 35204 35205 35206 35207 35208 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35190 class ListMonitoringExecutionsRequest < Struct.new( :monitoring_schedule_name, :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :scheduled_time_before, :scheduled_time_after, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after, :status_equals, :monitoring_job_definition_name, :monitoring_type_equals) SENSITIVE = [] include Aws::Structure end |
#scheduled_time_after ⇒ Time
Filter for jobs scheduled after a specified time.
35190 35191 35192 35193 35194 35195 35196 35197 35198 35199 35200 35201 35202 35203 35204 35205 35206 35207 35208 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35190 class ListMonitoringExecutionsRequest < Struct.new( :monitoring_schedule_name, :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :scheduled_time_before, :scheduled_time_after, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after, :status_equals, :monitoring_job_definition_name, :monitoring_type_equals) SENSITIVE = [] include Aws::Structure end |
#scheduled_time_before ⇒ Time
Filter for jobs scheduled before a specified time.
35190 35191 35192 35193 35194 35195 35196 35197 35198 35199 35200 35201 35202 35203 35204 35205 35206 35207 35208 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35190 class ListMonitoringExecutionsRequest < Struct.new( :monitoring_schedule_name, :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :scheduled_time_before, :scheduled_time_after, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after, :status_equals, :monitoring_job_definition_name, :monitoring_type_equals) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
Whether to sort the results by the Status, CreationTime, or ScheduledTime field. The default is CreationTime.
35190 35191 35192 35193 35194 35195 35196 35197 35198 35199 35200 35201 35202 35203 35204 35205 35206 35207 35208 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35190 class ListMonitoringExecutionsRequest < Struct.new( :monitoring_schedule_name, :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :scheduled_time_before, :scheduled_time_after, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after, :status_equals, :monitoring_job_definition_name, :monitoring_type_equals) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
Whether to sort the results in Ascending or Descending order. The default is Descending.
35190 35191 35192 35193 35194 35195 35196 35197 35198 35199 35200 35201 35202 35203 35204 35205 35206 35207 35208 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35190 class ListMonitoringExecutionsRequest < Struct.new( :monitoring_schedule_name, :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :scheduled_time_before, :scheduled_time_after, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after, :status_equals, :monitoring_job_definition_name, :monitoring_type_equals) SENSITIVE = [] include Aws::Structure end |
#status_equals ⇒ String
A filter that retrieves only jobs with a specific status.
35190 35191 35192 35193 35194 35195 35196 35197 35198 35199 35200 35201 35202 35203 35204 35205 35206 35207 35208 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35190 class ListMonitoringExecutionsRequest < Struct.new( :monitoring_schedule_name, :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :scheduled_time_before, :scheduled_time_after, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after, :status_equals, :monitoring_job_definition_name, :monitoring_type_equals) SENSITIVE = [] include Aws::Structure end |