Class: Aws::SageMaker::Types::ListNotebookInstanceLifecycleConfigsInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_time_after ⇒ Time

A filter that returns only lifecycle configurations that were created after the specified time (timestamp).

Returns:

  • (Time)


38870
38871
38872
38873
38874
38875
38876
38877
38878
38879
38880
38881
38882
# File 'lib/aws-sdk-sagemaker/types.rb', line 38870

class ListNotebookInstanceLifecycleConfigsInput < Struct.new(
  :next_token,
  :max_results,
  :sort_by,
  :sort_order,
  :name_contains,
  :creation_time_before,
  :creation_time_after,
  :last_modified_time_before,
  :last_modified_time_after)
  SENSITIVE = []
  include Aws::Structure
end

#creation_time_before ⇒ Time

A filter that returns only lifecycle configurations that were created before the specified time (timestamp).

Returns:

  • (Time)


38870
38871
38872
38873
38874
38875
38876
38877
38878
38879
38880
38881
38882
# File 'lib/aws-sdk-sagemaker/types.rb', line 38870

class ListNotebookInstanceLifecycleConfigsInput < Struct.new(
  :next_token,
  :max_results,
  :sort_by,
  :sort_order,
  :name_contains,
  :creation_time_before,
  :creation_time_after,
  :last_modified_time_before,
  :last_modified_time_after)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_time_after ⇒ Time

A filter that returns only lifecycle configurations that were modified after the specified time (timestamp).

Returns:

  • (Time)


38870
38871
38872
38873
38874
38875
38876
38877
38878
38879
38880
38881
38882
# File 'lib/aws-sdk-sagemaker/types.rb', line 38870

class ListNotebookInstanceLifecycleConfigsInput < Struct.new(
  :next_token,
  :max_results,
  :sort_by,
  :sort_order,
  :name_contains,
  :creation_time_before,
  :creation_time_after,
  :last_modified_time_before,
  :last_modified_time_after)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_time_before ⇒ Time

A filter that returns only lifecycle configurations that were modified before the specified time (timestamp).

Returns:

  • (Time)


38870
38871
38872
38873
38874
38875
38876
38877
38878
38879
38880
38881
38882
# File 'lib/aws-sdk-sagemaker/types.rb', line 38870

class ListNotebookInstanceLifecycleConfigsInput < Struct.new(
  :next_token,
  :max_results,
  :sort_by,
  :sort_order,
  :name_contains,
  :creation_time_before,
  :creation_time_after,
  :last_modified_time_before,
  :last_modified_time_after)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of lifecycle configurations to return in the response.

Returns:

  • (Integer)


38870
38871
38872
38873
38874
38875
38876
38877
38878
38879
38880
38881
38882
# File 'lib/aws-sdk-sagemaker/types.rb', line 38870

class ListNotebookInstanceLifecycleConfigsInput < Struct.new(
  :next_token,
  :max_results,
  :sort_by,
  :sort_order,
  :name_contains,
  :creation_time_before,
  :creation_time_after,
  :last_modified_time_before,
  :last_modified_time_after)
  SENSITIVE = []
  include Aws::Structure
end

#name_contains ⇒ String

A string in the lifecycle configuration name. This filter returns only lifecycle configurations whose name contains the specified string.

Returns:

  • (String)


38870
38871
38872
38873
38874
38875
38876
38877
38878
38879
38880
38881
38882
# File 'lib/aws-sdk-sagemaker/types.rb', line 38870

class ListNotebookInstanceLifecycleConfigsInput < Struct.new(
  :next_token,
  :max_results,
  :sort_by,
  :sort_order,
  :name_contains,
  :creation_time_before,
  :creation_time_after,
  :last_modified_time_before,
  :last_modified_time_after)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

If the result of a ListNotebookInstanceLifecycleConfigs request was truncated, the response includes a NextToken. To get the next set of lifecycle configurations, use the token in the next request.

Returns:

  • (String)


38870
38871
38872
38873
38874
38875
38876
38877
38878
38879
38880
38881
38882
# File 'lib/aws-sdk-sagemaker/types.rb', line 38870

class ListNotebookInstanceLifecycleConfigsInput < Struct.new(
  :next_token,
  :max_results,
  :sort_by,
  :sort_order,
  :name_contains,
  :creation_time_before,
  :creation_time_after,
  :last_modified_time_before,
  :last_modified_time_after)
  SENSITIVE = []
  include Aws::Structure
end

#sort_by ⇒ String

Sorts the list of results. The default is CreationTime.

Returns:

  • (String)


38870
38871
38872
38873
38874
38875
38876
38877
38878
38879
38880
38881
38882
# File 'lib/aws-sdk-sagemaker/types.rb', line 38870

class ListNotebookInstanceLifecycleConfigsInput < Struct.new(
  :next_token,
  :max_results,
  :sort_by,
  :sort_order,
  :name_contains,
  :creation_time_before,
  :creation_time_after,
  :last_modified_time_before,
  :last_modified_time_after)
  SENSITIVE = []
  include Aws::Structure
end

#sort_order ⇒ String

The sort order for results.

Returns:

  • (String)


38870
38871
38872
38873
38874
38875
38876
38877
38878
38879
38880
38881
38882
# File 'lib/aws-sdk-sagemaker/types.rb', line 38870

class ListNotebookInstanceLifecycleConfigsInput < Struct.new(
  :next_token,
  :max_results,
  :sort_by,
  :sort_order,
  :name_contains,
  :creation_time_before,
  :creation_time_after,
  :last_modified_time_before,
  :last_modified_time_after)
  SENSITIVE = []
  include Aws::Structure
end