Class: Aws::SageMaker::Types::ListOptimizationJobsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListOptimizationJobsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time_after ⇒ Time
Filters the results to only those optimization jobs that were created after the specified time.
-
#creation_time_before ⇒ Time
Filters the results to only those optimization jobs that were created before the specified time.
-
#last_modified_time_after ⇒ Time
Filters the results to only those optimization jobs that were updated after the specified time.
-
#last_modified_time_before ⇒ Time
Filters the results to only those optimization jobs that were updated before the specified time.
-
#max_results ⇒ Integer
The maximum number of optimization jobs to return in the response.
-
#name_contains ⇒ String
Filters the results to only those optimization jobs with a name that contains the specified string.
-
#next_token ⇒ String
A token that you use to get the next set of results following a truncated response.
-
#optimization_contains ⇒ String
Filters the results to only those optimization jobs that apply the specified optimization techniques.
-
#sort_by ⇒ String
The field by which to sort the optimization jobs in the response.
-
#sort_order ⇒ String
The sort order for results.
-
#status_equals ⇒ String
Filters the results to only those optimization jobs with the specified status.
Instance Attribute Details
#creation_time_after ⇒ Time
Filters the results to only those optimization jobs that were created after the specified time.
39076 39077 39078 39079 39080 39081 39082 39083 39084 39085 39086 39087 39088 39089 39090 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39076 class ListOptimizationJobsRequest < Struct.new( :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :optimization_contains, :name_contains, :status_equals, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#creation_time_before ⇒ Time
Filters the results to only those optimization jobs that were created before the specified time.
39076 39077 39078 39079 39080 39081 39082 39083 39084 39085 39086 39087 39088 39089 39090 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39076 class ListOptimizationJobsRequest < Struct.new( :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :optimization_contains, :name_contains, :status_equals, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#last_modified_time_after ⇒ Time
Filters the results to only those optimization jobs that were updated after the specified time.
39076 39077 39078 39079 39080 39081 39082 39083 39084 39085 39086 39087 39088 39089 39090 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39076 class ListOptimizationJobsRequest < Struct.new( :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :optimization_contains, :name_contains, :status_equals, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#last_modified_time_before ⇒ Time
Filters the results to only those optimization jobs that were updated before the specified time.
39076 39077 39078 39079 39080 39081 39082 39083 39084 39085 39086 39087 39088 39089 39090 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39076 class ListOptimizationJobsRequest < Struct.new( :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :optimization_contains, :name_contains, :status_equals, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of optimization jobs to return in the response. The default is 50.
39076 39077 39078 39079 39080 39081 39082 39083 39084 39085 39086 39087 39088 39089 39090 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39076 class ListOptimizationJobsRequest < Struct.new( :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :optimization_contains, :name_contains, :status_equals, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#name_contains ⇒ String
Filters the results to only those optimization jobs with a name that contains the specified string.
39076 39077 39078 39079 39080 39081 39082 39083 39084 39085 39086 39087 39088 39089 39090 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39076 class ListOptimizationJobsRequest < Struct.new( :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :optimization_contains, :name_contains, :status_equals, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that you use to get the next set of results following a truncated response. If the response to the previous request was truncated, that response provides the value for this token.
39076 39077 39078 39079 39080 39081 39082 39083 39084 39085 39086 39087 39088 39089 39090 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39076 class ListOptimizationJobsRequest < Struct.new( :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :optimization_contains, :name_contains, :status_equals, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#optimization_contains ⇒ String
Filters the results to only those optimization jobs that apply the
specified optimization techniques. You can specify either
Quantization or Compilation.
39076 39077 39078 39079 39080 39081 39082 39083 39084 39085 39086 39087 39088 39089 39090 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39076 class ListOptimizationJobsRequest < Struct.new( :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :optimization_contains, :name_contains, :status_equals, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
The field by which to sort the optimization jobs in the response.
The default is CreationTime
39076 39077 39078 39079 39080 39081 39082 39083 39084 39085 39086 39087 39088 39089 39090 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39076 class ListOptimizationJobsRequest < Struct.new( :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :optimization_contains, :name_contains, :status_equals, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
The sort order for results. The default is Ascending
39076 39077 39078 39079 39080 39081 39082 39083 39084 39085 39086 39087 39088 39089 39090 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39076 class ListOptimizationJobsRequest < Struct.new( :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :optimization_contains, :name_contains, :status_equals, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#status_equals ⇒ String
Filters the results to only those optimization jobs with the specified status.
39076 39077 39078 39079 39080 39081 39082 39083 39084 39085 39086 39087 39088 39089 39090 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39076 class ListOptimizationJobsRequest < Struct.new( :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :optimization_contains, :name_contains, :status_equals, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |