Class: Aws::SageMaker::Types::ListPartnerAppsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListPartnerAppsResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If the previous response was truncated, you will receive this token.
-
#summaries ⇒ Array<Types::PartnerAppSummary>
The information related to each of the SageMaker Partner AI Apps in an account.
Instance Attribute Details
#next_token ⇒ String
If the previous response was truncated, you will receive this token. Use it in your next request to receive the next set of results.
39147 39148 39149 39150 39151 39152 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39147 class ListPartnerAppsResponse < Struct.new( :summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#summaries ⇒ Array<Types::PartnerAppSummary>
The information related to each of the SageMaker Partner AI Apps in an account.
39147 39148 39149 39150 39151 39152 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39147 class ListPartnerAppsResponse < Struct.new( :summaries, :next_token) SENSITIVE = [] include Aws::Structure end |