Class: Aws::SageMaker::Types::ListPipelineExecutionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListPipelineExecutionsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_after ⇒ Time
A filter that returns the pipeline executions that were created after a specified time.
-
#created_before ⇒ Time
A filter that returns the pipeline executions that were created before a specified time.
-
#max_results ⇒ Integer
The maximum number of pipeline executions to return in the response.
-
#next_token ⇒ String
If the result of the previous
ListPipelineExecutionsrequest was truncated, the response includes aNextToken. -
#pipeline_name ⇒ String
The name or Amazon Resource Name (ARN) of the pipeline.
-
#sort_by ⇒ String
The field by which to sort results.
-
#sort_order ⇒ String
The sort order for results.
Instance Attribute Details
#created_after ⇒ Time
A filter that returns the pipeline executions that were created after a specified time.
39243 39244 39245 39246 39247 39248 39249 39250 39251 39252 39253 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39243 class ListPipelineExecutionsRequest < Struct.new( :pipeline_name, :created_after, :created_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#created_before ⇒ Time
A filter that returns the pipeline executions that were created before a specified time.
39243 39244 39245 39246 39247 39248 39249 39250 39251 39252 39253 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39243 class ListPipelineExecutionsRequest < Struct.new( :pipeline_name, :created_after, :created_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of pipeline executions to return in the response.
39243 39244 39245 39246 39247 39248 39249 39250 39251 39252 39253 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39243 class ListPipelineExecutionsRequest < Struct.new( :pipeline_name, :created_after, :created_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the result of the previous ListPipelineExecutions request was
truncated, the response includes a NextToken. To retrieve the next
set of pipeline executions, use the token in the next request.
39243 39244 39245 39246 39247 39248 39249 39250 39251 39252 39253 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39243 class ListPipelineExecutionsRequest < Struct.new( :pipeline_name, :created_after, :created_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#pipeline_name ⇒ String
The name or Amazon Resource Name (ARN) of the pipeline.
39243 39244 39245 39246 39247 39248 39249 39250 39251 39252 39253 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39243 class ListPipelineExecutionsRequest < Struct.new( :pipeline_name, :created_after, :created_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
The field by which to sort results. The default is CreatedTime.
39243 39244 39245 39246 39247 39248 39249 39250 39251 39252 39253 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39243 class ListPipelineExecutionsRequest < Struct.new( :pipeline_name, :created_after, :created_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
The sort order for results.
39243 39244 39245 39246 39247 39248 39249 39250 39251 39252 39253 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39243 class ListPipelineExecutionsRequest < Struct.new( :pipeline_name, :created_after, :created_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |