Class: Aws::SageMaker::Types::ListPipelineExecutionsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListPipelineExecutionsResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If the result of the previous
ListPipelineExecutionsrequest was truncated, the response includes aNextToken. -
#pipeline_execution_summaries ⇒ Array<Types::PipelineExecutionSummary>
Contains a sorted list of pipeline execution summary objects matching the specified filters.
Instance Attribute Details
#next_token ⇒ String
If the result of the previous ListPipelineExecutions request was
truncated, the response includes a NextToken. To retrieve the next
set of pipeline executions, use the token in the next request.
39270 39271 39272 39273 39274 39275 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39270 class ListPipelineExecutionsResponse < Struct.new( :pipeline_execution_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#pipeline_execution_summaries ⇒ Array<Types::PipelineExecutionSummary>
Contains a sorted list of pipeline execution summary objects matching the specified filters. Each run summary includes the Amazon Resource Name (ARN) of the pipeline execution, the run date, and the status. This list can be empty.
39270 39271 39272 39273 39274 39275 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39270 class ListPipelineExecutionsResponse < Struct.new( :pipeline_execution_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |