Class: Aws::SageMaker::Types::ListPipelineParametersForExecutionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListPipelineParametersForExecutionRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of parameters to return in the response.
-
#next_token ⇒ String
If the result of the previous
ListPipelineParametersForExecutionrequest was truncated, the response includes aNextToken. -
#pipeline_execution_arn ⇒ String
The Amazon Resource Name (ARN) of the pipeline execution.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of parameters to return in the response.
36127 36128 36129 36130 36131 36132 36133 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36127 class ListPipelineParametersForExecutionRequest < Struct.new( :pipeline_execution_arn, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the result of the previous ListPipelineParametersForExecution
request was truncated, the response includes a NextToken. To
retrieve the next set of parameters, use the token in the next
request.
36127 36128 36129 36130 36131 36132 36133 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36127 class ListPipelineParametersForExecutionRequest < Struct.new( :pipeline_execution_arn, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#pipeline_execution_arn ⇒ String
The Amazon Resource Name (ARN) of the pipeline execution.
36127 36128 36129 36130 36131 36132 36133 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36127 class ListPipelineParametersForExecutionRequest < Struct.new( :pipeline_execution_arn, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |