Class: Aws::SageMaker::Types::ListPipelineParametersForExecutionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListPipelineParametersForExecutionResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If the result of the previous
ListPipelineParametersForExecutionrequest was truncated, the response includes aNextToken. -
#pipeline_parameters ⇒ Array<Types::Parameter>
Contains a list of pipeline parameters.
Instance Attribute Details
#next_token ⇒ String
If the result of the previous ListPipelineParametersForExecution request was truncated, the response includes a NextToken. To retrieve the next set of parameters, use the token in the next request.
35917 35918 35919 35920 35921 35922 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35917 class ListPipelineParametersForExecutionResponse < Struct.new( :pipeline_parameters, :next_token) SENSITIVE = [] include Aws::Structure end |
#pipeline_parameters ⇒ Array<Types::Parameter>
Contains a list of pipeline parameters. This list can be empty.
35917 35918 35919 35920 35921 35922 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35917 class ListPipelineParametersForExecutionResponse < Struct.new( :pipeline_parameters, :next_token) SENSITIVE = [] include Aws::Structure end |