Class: Aws::SageMaker::Types::ListPipelineVersionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_afterTime

A filter that returns the pipeline versions that were created after a specified time.

Returns:

  • (Time)


35861
35862
35863
35864
35865
35866
35867
35868
35869
35870
# File 'lib/aws-sdk-sagemaker/types.rb', line 35861

class ListPipelineVersionsRequest < Struct.new(
  :pipeline_name,
  :created_after,
  :created_before,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#created_beforeTime

A filter that returns the pipeline versions that were created before a specified time.

Returns:

  • (Time)


35861
35862
35863
35864
35865
35866
35867
35868
35869
35870
# File 'lib/aws-sdk-sagemaker/types.rb', line 35861

class ListPipelineVersionsRequest < Struct.new(
  :pipeline_name,
  :created_after,
  :created_before,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of pipeline versions to return in the response.

Returns:

  • (Integer)


35861
35862
35863
35864
35865
35866
35867
35868
35869
35870
# File 'lib/aws-sdk-sagemaker/types.rb', line 35861

class ListPipelineVersionsRequest < Struct.new(
  :pipeline_name,
  :created_after,
  :created_before,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the result of the previous ListPipelineVersions request was truncated, the response includes a NextToken. To retrieve the next set of pipeline versions, use this token in your next request.

Returns:

  • (String)


35861
35862
35863
35864
35865
35866
35867
35868
35869
35870
# File 'lib/aws-sdk-sagemaker/types.rb', line 35861

class ListPipelineVersionsRequest < Struct.new(
  :pipeline_name,
  :created_after,
  :created_before,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#pipeline_nameString

The Amazon Resource Name (ARN) of the pipeline.

Returns:

  • (String)


35861
35862
35863
35864
35865
35866
35867
35868
35869
35870
# File 'lib/aws-sdk-sagemaker/types.rb', line 35861

class ListPipelineVersionsRequest < Struct.new(
  :pipeline_name,
  :created_after,
  :created_before,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#sort_orderString

The sort order for the results.

Returns:

  • (String)


35861
35862
35863
35864
35865
35866
35867
35868
35869
35870
# File 'lib/aws-sdk-sagemaker/types.rb', line 35861

class ListPipelineVersionsRequest < Struct.new(
  :pipeline_name,
  :created_after,
  :created_before,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end