Class: Aws::SageMaker::Types::ListPipelineVersionsResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_token ⇒ String

If the result of the previous ListPipelineVersions request was truncated, the response includes a NextToken. To retrieve the next set of pipeline versions, use this token in your next request.

Returns:

  • (String)


39378
39379
39380
39381
39382
39383
# File 'lib/aws-sdk-sagemaker/types.rb', line 39378

class ListPipelineVersionsResponse < Struct.new(
  :pipeline_version_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#pipeline_version_summaries ⇒ Array<Types::PipelineVersionSummary>

Contains a sorted list of pipeline version summary objects matching the specified filters. Each version summary includes the pipeline version ID, the creation date, and the last pipeline execution created from that version. This list can be empty.

Returns:



39378
39379
39380
39381
39382
39383
# File 'lib/aws-sdk-sagemaker/types.rb', line 39378

class ListPipelineVersionsResponse < Struct.new(
  :pipeline_version_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end