Class: Aws::SageMaker::Types::ListPipelinesRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_after ⇒ Time

A filter that returns the pipelines that were created after a specified time.

Returns:

  • (Time)


39419
39420
39421
39422
39423
39424
39425
39426
39427
39428
39429
# File 'lib/aws-sdk-sagemaker/types.rb', line 39419

class ListPipelinesRequest < Struct.new(
  :pipeline_name_prefix,
  :created_after,
  :created_before,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#created_before ⇒ Time

A filter that returns the pipelines that were created before a specified time.

Returns:

  • (Time)


39419
39420
39421
39422
39423
39424
39425
39426
39427
39428
39429
# File 'lib/aws-sdk-sagemaker/types.rb', line 39419

class ListPipelinesRequest < Struct.new(
  :pipeline_name_prefix,
  :created_after,
  :created_before,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of pipelines to return in the response.

Returns:

  • (Integer)


39419
39420
39421
39422
39423
39424
39425
39426
39427
39428
39429
# File 'lib/aws-sdk-sagemaker/types.rb', line 39419

class ListPipelinesRequest < Struct.new(
  :pipeline_name_prefix,
  :created_after,
  :created_before,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

If the result of the previous ListPipelines request was truncated, the response includes a NextToken. To retrieve the next set of pipelines, use the token in the next request.

Returns:

  • (String)


39419
39420
39421
39422
39423
39424
39425
39426
39427
39428
39429
# File 'lib/aws-sdk-sagemaker/types.rb', line 39419

class ListPipelinesRequest < Struct.new(
  :pipeline_name_prefix,
  :created_after,
  :created_before,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#pipeline_name_prefix ⇒ String

The prefix of the pipeline name.

Returns:

  • (String)


39419
39420
39421
39422
39423
39424
39425
39426
39427
39428
39429
# File 'lib/aws-sdk-sagemaker/types.rb', line 39419

class ListPipelinesRequest < Struct.new(
  :pipeline_name_prefix,
  :created_after,
  :created_before,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#sort_by ⇒ String

The field by which to sort results. The default is CreatedTime.

Returns:

  • (String)


39419
39420
39421
39422
39423
39424
39425
39426
39427
39428
39429
# File 'lib/aws-sdk-sagemaker/types.rb', line 39419

class ListPipelinesRequest < Struct.new(
  :pipeline_name_prefix,
  :created_after,
  :created_before,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#sort_order ⇒ String

The sort order for results.

Returns:

  • (String)


39419
39420
39421
39422
39423
39424
39425
39426
39427
39428
39429
# File 'lib/aws-sdk-sagemaker/types.rb', line 39419

class ListPipelinesRequest < Struct.new(
  :pipeline_name_prefix,
  :created_after,
  :created_before,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end