Class: Aws::SageMaker::Types::ListPipelinesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListPipelinesResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If the result of the previous
ListPipelinesrequest was truncated, the response includes aNextToken. -
#pipeline_summaries ⇒ Array<Types::PipelineSummary>
Contains a sorted list of
PipelineSummaryobjects matching the specified filters.
Instance Attribute Details
#next_token ⇒ String
If the result of the previous ListPipelines request was truncated, the response includes a NextToken. To retrieve the next set of pipelines, use the token in the next request.
35955 35956 35957 35958 35959 35960 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35955 class ListPipelinesResponse < Struct.new( :pipeline_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#pipeline_summaries ⇒ Array<Types::PipelineSummary>
Contains a sorted list of PipelineSummary objects matching the specified filters. Each PipelineSummary consists of PipelineArn, PipelineName, ExperimentName, PipelineDescription, CreationTime, LastModifiedTime, LastRunTime, and RoleArn. This list can be empty.
35955 35956 35957 35958 35959 35960 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35955 class ListPipelinesResponse < Struct.new( :pipeline_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |