Class: Aws::SageMaker::Types::ListProcessingJobsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListProcessingJobsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time_after ⇒ Time
A filter that returns only processing jobs created after the specified time.
-
#creation_time_before ⇒ Time
A filter that returns only processing jobs created after the specified time.
-
#last_modified_time_after ⇒ Time
A filter that returns only processing jobs modified after the specified time.
-
#last_modified_time_before ⇒ Time
A filter that returns only processing jobs modified before the specified time.
-
#max_results ⇒ Integer
The maximum number of processing jobs to return in the response.
-
#name_contains ⇒ String
A string in the processing job name.
-
#next_token ⇒ String
If the result of the previous
ListProcessingJobsrequest was truncated, the response includes aNextToken. -
#sort_by ⇒ String
The field to sort results by.
-
#sort_order ⇒ String
The sort order for results.
-
#status_equals ⇒ String
A filter that retrieves only processing jobs with a specific status.
Instance Attribute Details
#creation_time_after ⇒ Time
A filter that returns only processing jobs created after the specified time.
39502 39503 39504 39505 39506 39507 39508 39509 39510 39511 39512 39513 39514 39515 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39502 class ListProcessingJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#creation_time_before ⇒ Time
A filter that returns only processing jobs created after the specified time.
39502 39503 39504 39505 39506 39507 39508 39509 39510 39511 39512 39513 39514 39515 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39502 class ListProcessingJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#last_modified_time_after ⇒ Time
A filter that returns only processing jobs modified after the specified time.
39502 39503 39504 39505 39506 39507 39508 39509 39510 39511 39512 39513 39514 39515 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39502 class ListProcessingJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#last_modified_time_before ⇒ Time
A filter that returns only processing jobs modified before the specified time.
39502 39503 39504 39505 39506 39507 39508 39509 39510 39511 39512 39513 39514 39515 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39502 class ListProcessingJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of processing jobs to return in the response.
39502 39503 39504 39505 39506 39507 39508 39509 39510 39511 39512 39513 39514 39515 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39502 class ListProcessingJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#name_contains ⇒ String
A string in the processing job name. This filter returns only processing jobs whose name contains the specified string.
39502 39503 39504 39505 39506 39507 39508 39509 39510 39511 39512 39513 39514 39515 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39502 class ListProcessingJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the result of the previous ListProcessingJobs request was
truncated, the response includes a NextToken. To retrieve the next
set of processing jobs, use the token in the next request.
39502 39503 39504 39505 39506 39507 39508 39509 39510 39511 39512 39513 39514 39515 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39502 class ListProcessingJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
The field to sort results by. The default is CreationTime.
39502 39503 39504 39505 39506 39507 39508 39509 39510 39511 39512 39513 39514 39515 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39502 class ListProcessingJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
The sort order for results. The default is Ascending.
39502 39503 39504 39505 39506 39507 39508 39509 39510 39511 39512 39513 39514 39515 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39502 class ListProcessingJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#status_equals ⇒ String
A filter that retrieves only processing jobs with a specific status.
39502 39503 39504 39505 39506 39507 39508 39509 39510 39511 39512 39513 39514 39515 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39502 class ListProcessingJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |