Class: Aws::SageMaker::Types::ListResourceCatalogsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListResourceCatalogsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time_after ⇒ Time
Use this parameter to search for ‘ResourceCatalog`s created after a specific date and time.
-
#creation_time_before ⇒ Time
Use this parameter to search for ‘ResourceCatalog`s created before a specific date and time.
-
#max_results ⇒ Integer
The maximum number of results returned by
ListResourceCatalogs. -
#name_contains ⇒ String
A string that partially matches one or more ‘ResourceCatalog`s names.
-
#next_token ⇒ String
A token to resume pagination of
ListResourceCatalogsresults. -
#sort_by ⇒ String
The value on which the resource catalog list is sorted.
-
#sort_order ⇒ String
The order in which the resource catalogs are listed.
Instance Attribute Details
#creation_time_after ⇒ Time
Use this parameter to search for ‘ResourceCatalog`s created after a specific date and time.
36171 36172 36173 36174 36175 36176 36177 36178 36179 36180 36181 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36171 class ListResourceCatalogsRequest < Struct.new( :name_contains, :creation_time_after, :creation_time_before, :sort_order, :sort_by, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#creation_time_before ⇒ Time
Use this parameter to search for ‘ResourceCatalog`s created before a specific date and time.
36171 36172 36173 36174 36175 36176 36177 36178 36179 36180 36181 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36171 class ListResourceCatalogsRequest < Struct.new( :name_contains, :creation_time_after, :creation_time_before, :sort_order, :sort_by, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results returned by ListResourceCatalogs.
36171 36172 36173 36174 36175 36176 36177 36178 36179 36180 36181 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36171 class ListResourceCatalogsRequest < Struct.new( :name_contains, :creation_time_after, :creation_time_before, :sort_order, :sort_by, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#name_contains ⇒ String
A string that partially matches one or more ‘ResourceCatalog`s names. Filters ResourceCatalog by name.
36171 36172 36173 36174 36175 36176 36177 36178 36179 36180 36181 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36171 class ListResourceCatalogsRequest < Struct.new( :name_contains, :creation_time_after, :creation_time_before, :sort_order, :sort_by, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token to resume pagination of ListResourceCatalogs results.
36171 36172 36173 36174 36175 36176 36177 36178 36179 36180 36181 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36171 class ListResourceCatalogsRequest < Struct.new( :name_contains, :creation_time_after, :creation_time_before, :sort_order, :sort_by, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
The value on which the resource catalog list is sorted.
36171 36172 36173 36174 36175 36176 36177 36178 36179 36180 36181 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36171 class ListResourceCatalogsRequest < Struct.new( :name_contains, :creation_time_after, :creation_time_before, :sort_order, :sort_by, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
The order in which the resource catalogs are listed.
36171 36172 36173 36174 36175 36176 36177 36178 36179 36180 36181 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36171 class ListResourceCatalogsRequest < Struct.new( :name_contains, :creation_time_after, :creation_time_before, :sort_order, :sort_by, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |