Class: Aws::SageMaker::Types::ListSpacesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListSpacesRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_id_equals ⇒ String
A parameter to search for the domain ID.
-
#max_results ⇒ Integer
This parameter defines the maximum number of results that can be return in a single response.
-
#next_token ⇒ String
If the previous response was truncated, you will receive this token.
-
#sort_by ⇒ String
The parameter by which to sort the results.
-
#sort_order ⇒ String
The sort order for the results.
-
#space_name_contains ⇒ String
A parameter by which to filter the results.
Instance Attribute Details
#domain_id_equals ⇒ String
A parameter to search for the domain ID.
39699 39700 39701 39702 39703 39704 39705 39706 39707 39708 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39699 class ListSpacesRequest < Struct.new( :next_token, :max_results, :sort_order, :sort_by, :domain_id_equals, :space_name_contains) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
This parameter defines the maximum number of results that can be
return in a single response. The MaxResults parameter is an upper
bound, not a target. If there are more results available than the
value specified, a NextToken is provided in the response. The
NextToken indicates that the user should get the next set of
results by providing this token as a part of a subsequent call. The
default value for MaxResults is 10.
39699 39700 39701 39702 39703 39704 39705 39706 39707 39708 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39699 class ListSpacesRequest < Struct.new( :next_token, :max_results, :sort_order, :sort_by, :domain_id_equals, :space_name_contains) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the previous response was truncated, you will receive this token. Use it in your next request to receive the next set of results.
39699 39700 39701 39702 39703 39704 39705 39706 39707 39708 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39699 class ListSpacesRequest < Struct.new( :next_token, :max_results, :sort_order, :sort_by, :domain_id_equals, :space_name_contains) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
The parameter by which to sort the results. The default is
CreationTime.
39699 39700 39701 39702 39703 39704 39705 39706 39707 39708 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39699 class ListSpacesRequest < Struct.new( :next_token, :max_results, :sort_order, :sort_by, :domain_id_equals, :space_name_contains) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
The sort order for the results. The default is Ascending.
39699 39700 39701 39702 39703 39704 39705 39706 39707 39708 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39699 class ListSpacesRequest < Struct.new( :next_token, :max_results, :sort_order, :sort_by, :domain_id_equals, :space_name_contains) SENSITIVE = [] include Aws::Structure end |
#space_name_contains ⇒ String
A parameter by which to filter the results.
39699 39700 39701 39702 39703 39704 39705 39706 39707 39708 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39699 class ListSpacesRequest < Struct.new( :next_token, :max_results, :sort_order, :sort_by, :domain_id_equals, :space_name_contains) SENSITIVE = [] include Aws::Structure end |