Class: Aws::SageMaker::Types::ListStudioLifecycleConfigsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListStudioLifecycleConfigsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#app_type_equals ⇒ String
A parameter to search for the App Type to which the Lifecycle Configuration is attached.
-
#creation_time_after ⇒ Time
A filter that returns only Lifecycle Configurations created on or after the specified time.
-
#creation_time_before ⇒ Time
A filter that returns only Lifecycle Configurations created on or before the specified time.
-
#max_results ⇒ Integer
The total number of items to return in the response.
-
#modified_time_after ⇒ Time
A filter that returns only Lifecycle Configurations modified after the specified time.
-
#modified_time_before ⇒ Time
A filter that returns only Lifecycle Configurations modified before the specified time.
-
#name_contains ⇒ String
A string in the Lifecycle Configuration name.
-
#next_token ⇒ String
If the previous call to ListStudioLifecycleConfigs didn’t return the full set of Lifecycle Configurations, the call returns a token for getting the next set of Lifecycle Configurations.
-
#sort_by ⇒ String
The property used to sort results.
-
#sort_order ⇒ String
The sort order.
Instance Attribute Details
#app_type_equals ⇒ String
A parameter to search for the App Type to which the Lifecycle Configuration is attached.
36436 36437 36438 36439 36440 36441 36442 36443 36444 36445 36446 36447 36448 36449 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36436 class ListStudioLifecycleConfigsRequest < Struct.new( :max_results, :next_token, :name_contains, :app_type_equals, :creation_time_before, :creation_time_after, :modified_time_before, :modified_time_after, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#creation_time_after ⇒ Time
A filter that returns only Lifecycle Configurations created on or after the specified time.
36436 36437 36438 36439 36440 36441 36442 36443 36444 36445 36446 36447 36448 36449 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36436 class ListStudioLifecycleConfigsRequest < Struct.new( :max_results, :next_token, :name_contains, :app_type_equals, :creation_time_before, :creation_time_after, :modified_time_before, :modified_time_after, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#creation_time_before ⇒ Time
A filter that returns only Lifecycle Configurations created on or before the specified time.
36436 36437 36438 36439 36440 36441 36442 36443 36444 36445 36446 36447 36448 36449 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36436 class ListStudioLifecycleConfigsRequest < Struct.new( :max_results, :next_token, :name_contains, :app_type_equals, :creation_time_before, :creation_time_after, :modified_time_before, :modified_time_after, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The total number of items to return in the response. If the total number of items available is more than the value specified, a NextToken is provided in the response. To resume pagination, provide the NextToken value in the as part of a subsequent call. The default value is 10.
36436 36437 36438 36439 36440 36441 36442 36443 36444 36445 36446 36447 36448 36449 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36436 class ListStudioLifecycleConfigsRequest < Struct.new( :max_results, :next_token, :name_contains, :app_type_equals, :creation_time_before, :creation_time_after, :modified_time_before, :modified_time_after, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#modified_time_after ⇒ Time
A filter that returns only Lifecycle Configurations modified after the specified time.
36436 36437 36438 36439 36440 36441 36442 36443 36444 36445 36446 36447 36448 36449 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36436 class ListStudioLifecycleConfigsRequest < Struct.new( :max_results, :next_token, :name_contains, :app_type_equals, :creation_time_before, :creation_time_after, :modified_time_before, :modified_time_after, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#modified_time_before ⇒ Time
A filter that returns only Lifecycle Configurations modified before the specified time.
36436 36437 36438 36439 36440 36441 36442 36443 36444 36445 36446 36447 36448 36449 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36436 class ListStudioLifecycleConfigsRequest < Struct.new( :max_results, :next_token, :name_contains, :app_type_equals, :creation_time_before, :creation_time_after, :modified_time_before, :modified_time_after, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#name_contains ⇒ String
A string in the Lifecycle Configuration name. This filter returns only Lifecycle Configurations whose name contains the specified string.
36436 36437 36438 36439 36440 36441 36442 36443 36444 36445 36446 36447 36448 36449 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36436 class ListStudioLifecycleConfigsRequest < Struct.new( :max_results, :next_token, :name_contains, :app_type_equals, :creation_time_before, :creation_time_after, :modified_time_before, :modified_time_after, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the previous call to ListStudioLifecycleConfigs didn’t return the full set of Lifecycle Configurations, the call returns a token for getting the next set of Lifecycle Configurations.
36436 36437 36438 36439 36440 36441 36442 36443 36444 36445 36446 36447 36448 36449 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36436 class ListStudioLifecycleConfigsRequest < Struct.new( :max_results, :next_token, :name_contains, :app_type_equals, :creation_time_before, :creation_time_after, :modified_time_before, :modified_time_after, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
The property used to sort results. The default value is CreationTime.
36436 36437 36438 36439 36440 36441 36442 36443 36444 36445 36446 36447 36448 36449 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36436 class ListStudioLifecycleConfigsRequest < Struct.new( :max_results, :next_token, :name_contains, :app_type_equals, :creation_time_before, :creation_time_after, :modified_time_before, :modified_time_after, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
The sort order. The default value is Descending.
36436 36437 36438 36439 36440 36441 36442 36443 36444 36445 36446 36447 36448 36449 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36436 class ListStudioLifecycleConfigsRequest < Struct.new( :max_results, :next_token, :name_contains, :app_type_equals, :creation_time_before, :creation_time_after, :modified_time_before, :modified_time_after, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |