Class: Aws::SageMaker::Types::ListTagsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListTagsInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
Maximum number of tags to return.
-
#next_token ⇒ String
If the response to the previous
ListTagsrequest is truncated, SageMaker returns this token. -
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the resource whose tags you want to retrieve.
Instance Attribute Details
#max_results ⇒ Integer
Maximum number of tags to return.
36464 36465 36466 36467 36468 36469 36470 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36464 class ListTagsInput < Struct.new( :resource_arn, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the response to the previous ListTags request is truncated, SageMaker returns this token. To retrieve the next set of tags, use it in the subsequent request.
36464 36465 36466 36467 36468 36469 36470 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36464 class ListTagsInput < Struct.new( :resource_arn, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the resource whose tags you want to retrieve.
36464 36465 36466 36467 36468 36469 36470 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36464 class ListTagsInput < Struct.new( :resource_arn, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |