Class: Aws::SageMaker::Types::ListTagsOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

If response is truncated, SageMaker includes a token in the response. You can use this token in your subsequent request to fetch next set of tokens.

Returns:

  • (String)


36551
36552
36553
36554
36555
36556
# File 'lib/aws-sdk-sagemaker/types.rb', line 36551

class ListTagsOutput < Struct.new(
  :tags,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

An array of Tag objects, each with a tag key and a value.

Returns:



36551
36552
36553
36554
36555
36556
# File 'lib/aws-sdk-sagemaker/types.rb', line 36551

class ListTagsOutput < Struct.new(
  :tags,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end