Class: Aws::SageMaker::Types::ListTrainingJobsForHyperParameterTuningJobRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#hyper_parameter_tuning_job_nameString

The name of the tuning job whose training jobs you want to list.

Returns:

  • (String)


36592
36593
36594
36595
36596
36597
36598
36599
36600
36601
# File 'lib/aws-sdk-sagemaker/types.rb', line 36592

class ListTrainingJobsForHyperParameterTuningJobRequest < Struct.new(
  :hyper_parameter_tuning_job_name,
  :next_token,
  :max_results,
  :status_equals,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of training jobs to return. The default value is 10.

Returns:

  • (Integer)


36592
36593
36594
36595
36596
36597
36598
36599
36600
36601
# File 'lib/aws-sdk-sagemaker/types.rb', line 36592

class ListTrainingJobsForHyperParameterTuningJobRequest < Struct.new(
  :hyper_parameter_tuning_job_name,
  :next_token,
  :max_results,
  :status_equals,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the result of the previous ListTrainingJobsForHyperParameterTuningJob request was truncated, the response includes a NextToken. To retrieve the next set of training jobs, use the token in the next request.

Returns:

  • (String)


36592
36593
36594
36595
36596
36597
36598
36599
36600
36601
# File 'lib/aws-sdk-sagemaker/types.rb', line 36592

class ListTrainingJobsForHyperParameterTuningJobRequest < Struct.new(
  :hyper_parameter_tuning_job_name,
  :next_token,
  :max_results,
  :status_equals,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#sort_byString

The field to sort results by. The default is Name.

If the value of this field is FinalObjectiveMetricValue, any training jobs that did not return an objective metric are not listed.

Returns:

  • (String)


36592
36593
36594
36595
36596
36597
36598
36599
36600
36601
# File 'lib/aws-sdk-sagemaker/types.rb', line 36592

class ListTrainingJobsForHyperParameterTuningJobRequest < Struct.new(
  :hyper_parameter_tuning_job_name,
  :next_token,
  :max_results,
  :status_equals,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#sort_orderString

The sort order for results. The default is Ascending.

Returns:

  • (String)


36592
36593
36594
36595
36596
36597
36598
36599
36600
36601
# File 'lib/aws-sdk-sagemaker/types.rb', line 36592

class ListTrainingJobsForHyperParameterTuningJobRequest < Struct.new(
  :hyper_parameter_tuning_job_name,
  :next_token,
  :max_results,
  :status_equals,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#status_equalsString

A filter that returns only training jobs with the specified status.

Returns:

  • (String)


36592
36593
36594
36595
36596
36597
36598
36599
36600
36601
# File 'lib/aws-sdk-sagemaker/types.rb', line 36592

class ListTrainingJobsForHyperParameterTuningJobRequest < Struct.new(
  :hyper_parameter_tuning_job_name,
  :next_token,
  :max_results,
  :status_equals,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end