Class: Aws::SageMaker::Types::ListTrainingJobsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListTrainingJobsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time_after ⇒ Time
A filter that returns only training jobs created after the specified time (timestamp).
-
#creation_time_before ⇒ Time
A filter that returns only training jobs created before the specified time (timestamp).
-
#last_modified_time_after ⇒ Time
A filter that returns only training jobs modified after the specified time (timestamp).
-
#last_modified_time_before ⇒ Time
A filter that returns only training jobs modified before the specified time (timestamp).
-
#max_results ⇒ Integer
The maximum number of training jobs to return in the response.
-
#name_contains ⇒ String
A string in the training job name.
-
#next_token ⇒ String
If the result of the previous
ListTrainingJobsrequest was truncated, the response includes aNextToken. -
#sort_by ⇒ String
The field to sort results by.
-
#sort_order ⇒ String
The sort order for results.
-
#status_equals ⇒ String
A filter that retrieves only training jobs with a specific status.
-
#training_plan_arn_equals ⇒ String
The Amazon Resource Name (ARN); of the training plan to filter training jobs by.
-
#warm_pool_status_equals ⇒ String
A filter that retrieves only training jobs with a specific warm pool status.
Instance Attribute Details
#creation_time_after ⇒ Time
A filter that returns only training jobs created after the specified time (timestamp).
40088 40089 40090 40091 40092 40093 40094 40095 40096 40097 40098 40099 40100 40101 40102 40103 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40088 class ListTrainingJobsRequest < Struct.new( :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :warm_pool_status_equals, :training_plan_arn_equals) SENSITIVE = [] include Aws::Structure end |
#creation_time_before ⇒ Time
A filter that returns only training jobs created before the specified time (timestamp).
40088 40089 40090 40091 40092 40093 40094 40095 40096 40097 40098 40099 40100 40101 40102 40103 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40088 class ListTrainingJobsRequest < Struct.new( :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :warm_pool_status_equals, :training_plan_arn_equals) SENSITIVE = [] include Aws::Structure end |
#last_modified_time_after ⇒ Time
A filter that returns only training jobs modified after the specified time (timestamp).
40088 40089 40090 40091 40092 40093 40094 40095 40096 40097 40098 40099 40100 40101 40102 40103 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40088 class ListTrainingJobsRequest < Struct.new( :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :warm_pool_status_equals, :training_plan_arn_equals) SENSITIVE = [] include Aws::Structure end |
#last_modified_time_before ⇒ Time
A filter that returns only training jobs modified before the specified time (timestamp).
40088 40089 40090 40091 40092 40093 40094 40095 40096 40097 40098 40099 40100 40101 40102 40103 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40088 class ListTrainingJobsRequest < Struct.new( :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :warm_pool_status_equals, :training_plan_arn_equals) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of training jobs to return in the response.
40088 40089 40090 40091 40092 40093 40094 40095 40096 40097 40098 40099 40100 40101 40102 40103 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40088 class ListTrainingJobsRequest < Struct.new( :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :warm_pool_status_equals, :training_plan_arn_equals) SENSITIVE = [] include Aws::Structure end |
#name_contains ⇒ String
A string in the training job name. This filter returns only training jobs whose name contains the specified string.
40088 40089 40090 40091 40092 40093 40094 40095 40096 40097 40098 40099 40100 40101 40102 40103 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40088 class ListTrainingJobsRequest < Struct.new( :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :warm_pool_status_equals, :training_plan_arn_equals) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the result of the previous ListTrainingJobs request was
truncated, the response includes a NextToken. To retrieve the next
set of training jobs, use the token in the next request.
40088 40089 40090 40091 40092 40093 40094 40095 40096 40097 40098 40099 40100 40101 40102 40103 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40088 class ListTrainingJobsRequest < Struct.new( :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :warm_pool_status_equals, :training_plan_arn_equals) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
The field to sort results by. The default is CreationTime.
40088 40089 40090 40091 40092 40093 40094 40095 40096 40097 40098 40099 40100 40101 40102 40103 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40088 class ListTrainingJobsRequest < Struct.new( :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :warm_pool_status_equals, :training_plan_arn_equals) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
The sort order for results. The default is Ascending.
40088 40089 40090 40091 40092 40093 40094 40095 40096 40097 40098 40099 40100 40101 40102 40103 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40088 class ListTrainingJobsRequest < Struct.new( :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :warm_pool_status_equals, :training_plan_arn_equals) SENSITIVE = [] include Aws::Structure end |
#status_equals ⇒ String
A filter that retrieves only training jobs with a specific status.
40088 40089 40090 40091 40092 40093 40094 40095 40096 40097 40098 40099 40100 40101 40102 40103 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40088 class ListTrainingJobsRequest < Struct.new( :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :warm_pool_status_equals, :training_plan_arn_equals) SENSITIVE = [] include Aws::Structure end |
#training_plan_arn_equals ⇒ String
The Amazon Resource Name (ARN); of the training plan to filter
training jobs by. For more information about reserving GPU capacity
for your SageMaker training jobs using Amazon SageMaker Training
Plan, see CreateTrainingPlan.
40088 40089 40090 40091 40092 40093 40094 40095 40096 40097 40098 40099 40100 40101 40102 40103 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40088 class ListTrainingJobsRequest < Struct.new( :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :warm_pool_status_equals, :training_plan_arn_equals) SENSITIVE = [] include Aws::Structure end |
#warm_pool_status_equals ⇒ String
A filter that retrieves only training jobs with a specific warm pool status.
40088 40089 40090 40091 40092 40093 40094 40095 40096 40097 40098 40099 40100 40101 40102 40103 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40088 class ListTrainingJobsRequest < Struct.new( :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :warm_pool_status_equals, :training_plan_arn_equals) SENSITIVE = [] include Aws::Structure end |