Class: Aws::SageMaker::Types::ListTrainingPlansResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

A token to continue pagination if more results are available.

Returns:



40180
40181
40182
40183
40184
40185
# File 'lib/aws-sdk-sagemaker/types.rb', line 40180

class ListTrainingPlansResponse < Struct.new(
  :next_token,
  :training_plan_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#training_plan_summariesArray<Types::TrainingPlanSummary>

A list of summary information for the training plans.

Returns:



40180
40181
40182
40183
40184
40185
# File 'lib/aws-sdk-sagemaker/types.rb', line 40180

class ListTrainingPlansResponse < Struct.new(
  :next_token,
  :training_plan_summaries)
  SENSITIVE = []
  include Aws::Structure
end