Class: Aws::SageMaker::Types::ListTransformJobsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListTransformJobsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time_after ⇒ Time
A filter that returns only transform jobs created after the specified time.
-
#creation_time_before ⇒ Time
A filter that returns only transform jobs created before the specified time.
-
#last_modified_time_after ⇒ Time
A filter that returns only transform jobs modified after the specified time.
-
#last_modified_time_before ⇒ Time
A filter that returns only transform jobs modified before the specified time.
-
#max_results ⇒ Integer
The maximum number of transform jobs to return in the response.
-
#name_contains ⇒ String
A string in the transform job name.
-
#next_token ⇒ String
If the result of the previous
ListTransformJobsrequest was truncated, the response includes aNextToken. -
#sort_by ⇒ String
The field to sort results by.
-
#sort_order ⇒ String
The sort order for results.
-
#status_equals ⇒ String
A filter that retrieves only transform jobs with a specific status.
Instance Attribute Details
#creation_time_after ⇒ Time
A filter that returns only transform jobs created after the specified time.
36839 36840 36841 36842 36843 36844 36845 36846 36847 36848 36849 36850 36851 36852 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36839 class ListTransformJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#creation_time_before ⇒ Time
A filter that returns only transform jobs created before the specified time.
36839 36840 36841 36842 36843 36844 36845 36846 36847 36848 36849 36850 36851 36852 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36839 class ListTransformJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#last_modified_time_after ⇒ Time
A filter that returns only transform jobs modified after the specified time.
36839 36840 36841 36842 36843 36844 36845 36846 36847 36848 36849 36850 36851 36852 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36839 class ListTransformJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#last_modified_time_before ⇒ Time
A filter that returns only transform jobs modified before the specified time.
36839 36840 36841 36842 36843 36844 36845 36846 36847 36848 36849 36850 36851 36852 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36839 class ListTransformJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of transform jobs to return in the response. The default value is 10.
36839 36840 36841 36842 36843 36844 36845 36846 36847 36848 36849 36850 36851 36852 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36839 class ListTransformJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#name_contains ⇒ String
A string in the transform job name. This filter returns only transform jobs whose name contains the specified string.
36839 36840 36841 36842 36843 36844 36845 36846 36847 36848 36849 36850 36851 36852 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36839 class ListTransformJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the result of the previous ListTransformJobs request was truncated, the response includes a NextToken. To retrieve the next set of transform jobs, use the token in the next request.
36839 36840 36841 36842 36843 36844 36845 36846 36847 36848 36849 36850 36851 36852 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36839 class ListTransformJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
The field to sort results by. The default is CreationTime.
36839 36840 36841 36842 36843 36844 36845 36846 36847 36848 36849 36850 36851 36852 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36839 class ListTransformJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
The sort order for results. The default is Descending.
36839 36840 36841 36842 36843 36844 36845 36846 36847 36848 36849 36850 36851 36852 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36839 class ListTransformJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#status_equals ⇒ String
A filter that retrieves only transform jobs with a specific status.
36839 36840 36841 36842 36843 36844 36845 36846 36847 36848 36849 36850 36851 36852 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36839 class ListTransformJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |