Class: Aws::SageMaker::Types::ListTrialComponentsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListTrialComponentsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_after ⇒ Time
A filter that returns only components created after the specified time.
-
#created_before ⇒ Time
A filter that returns only components created before the specified time.
-
#experiment_name ⇒ String
A filter that returns only components that are part of the specified experiment.
-
#max_results ⇒ Integer
The maximum number of components to return in the response.
-
#next_token ⇒ String
If the previous call to
ListTrialComponentsdidn't return the full set of components, the call returns a token for getting the next set of components. -
#sort_by ⇒ String
The property used to sort results.
-
#sort_order ⇒ String
The sort order.
-
#source_arn ⇒ String
A filter that returns only components that have the specified source Amazon Resource Name (ARN).
-
#trial_name ⇒ String
A filter that returns only components that are part of the specified trial.
Instance Attribute Details
#created_after ⇒ Time
A filter that returns only components created after the specified time.
40321 40322 40323 40324 40325 40326 40327 40328 40329 40330 40331 40332 40333 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40321 class ListTrialComponentsRequest < Struct.new( :experiment_name, :trial_name, :source_arn, :created_after, :created_before, :sort_by, :sort_order, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#created_before ⇒ Time
A filter that returns only components created before the specified time.
40321 40322 40323 40324 40325 40326 40327 40328 40329 40330 40331 40332 40333 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40321 class ListTrialComponentsRequest < Struct.new( :experiment_name, :trial_name, :source_arn, :created_after, :created_before, :sort_by, :sort_order, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#experiment_name ⇒ String
A filter that returns only components that are part of the specified
experiment. If you specify ExperimentName, you can't filter by
SourceArn or TrialName.
40321 40322 40323 40324 40325 40326 40327 40328 40329 40330 40331 40332 40333 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40321 class ListTrialComponentsRequest < Struct.new( :experiment_name, :trial_name, :source_arn, :created_after, :created_before, :sort_by, :sort_order, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of components to return in the response. The default value is 10.
40321 40322 40323 40324 40325 40326 40327 40328 40329 40330 40331 40332 40333 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40321 class ListTrialComponentsRequest < Struct.new( :experiment_name, :trial_name, :source_arn, :created_after, :created_before, :sort_by, :sort_order, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the previous call to ListTrialComponents didn't return the
full set of components, the call returns a token for getting the
next set of components.
40321 40322 40323 40324 40325 40326 40327 40328 40329 40330 40331 40332 40333 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40321 class ListTrialComponentsRequest < Struct.new( :experiment_name, :trial_name, :source_arn, :created_after, :created_before, :sort_by, :sort_order, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
The property used to sort results. The default value is
CreationTime.
40321 40322 40323 40324 40325 40326 40327 40328 40329 40330 40331 40332 40333 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40321 class ListTrialComponentsRequest < Struct.new( :experiment_name, :trial_name, :source_arn, :created_after, :created_before, :sort_by, :sort_order, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
The sort order. The default value is Descending.
40321 40322 40323 40324 40325 40326 40327 40328 40329 40330 40331 40332 40333 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40321 class ListTrialComponentsRequest < Struct.new( :experiment_name, :trial_name, :source_arn, :created_after, :created_before, :sort_by, :sort_order, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#source_arn ⇒ String
A filter that returns only components that have the specified source
Amazon Resource Name (ARN). If you specify SourceArn, you can't
filter by ExperimentName or TrialName.
40321 40322 40323 40324 40325 40326 40327 40328 40329 40330 40331 40332 40333 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40321 class ListTrialComponentsRequest < Struct.new( :experiment_name, :trial_name, :source_arn, :created_after, :created_before, :sort_by, :sort_order, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#trial_name ⇒ String
A filter that returns only components that are part of the specified
trial. If you specify TrialName, you can't filter by
ExperimentName or SourceArn.
40321 40322 40323 40324 40325 40326 40327 40328 40329 40330 40331 40332 40333 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40321 class ListTrialComponentsRequest < Struct.new( :experiment_name, :trial_name, :source_arn, :created_after, :created_before, :sort_by, :sort_order, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |