Class: Aws::SageMaker::Types::ListUltraServersByReservedCapacityRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListUltraServersByReservedCapacityRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of UltraServers to return in the response.
-
#next_token ⇒ String
If the previous response was truncated, you receive this token.
-
#reserved_capacity_arn ⇒ String
The ARN of the reserved capacity to list UltraServers for.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of UltraServers to return in the response. The default value is 10.
40437 40438 40439 40440 40441 40442 40443 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40437 class ListUltraServersByReservedCapacityRequest < Struct.new( :reserved_capacity_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the previous response was truncated, you receive this token. Use it in your next request to receive the next set of results.
40437 40438 40439 40440 40441 40442 40443 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40437 class ListUltraServersByReservedCapacityRequest < Struct.new( :reserved_capacity_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#reserved_capacity_arn ⇒ String
The ARN of the reserved capacity to list UltraServers for.
40437 40438 40439 40440 40441 40442 40443 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40437 class ListUltraServersByReservedCapacityRequest < Struct.new( :reserved_capacity_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |