Class: Aws::SageMaker::Types::ListUserProfilesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListUserProfilesResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If the previous response was truncated, you will receive this token.
-
#user_profiles ⇒ Array<Types::UserProfileDetails>
The list of user profiles.
Instance Attribute Details
#next_token ⇒ String
If the previous response was truncated, you will receive this token. Use it in your next request to receive the next set of results.
40520 40521 40522 40523 40524 40525 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40520 class ListUserProfilesResponse < Struct.new( :user_profiles, :next_token) SENSITIVE = [] include Aws::Structure end |
#user_profiles ⇒ Array<Types::UserProfileDetails>
The list of user profiles.
40520 40521 40522 40523 40524 40525 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40520 class ListUserProfilesResponse < Struct.new( :user_profiles, :next_token) SENSITIVE = [] include Aws::Structure end |