Class: Aws::SageMaker::Types::MetricData
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::MetricData
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The name, value, and date and time of a metric that was emitted to Amazon CloudWatch.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#metric_name ⇒ String
The name of the metric.
-
#timestamp ⇒ Time
The date and time that the algorithm emitted the metric.
-
#value ⇒ Float
The value of the metric.
Instance Attribute Details
#metric_name ⇒ String
The name of the metric.
39993 39994 39995 39996 39997 39998 39999 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39993 class MetricData < Struct.new( :metric_name, :value, :timestamp) SENSITIVE = [] include Aws::Structure end |
#timestamp ⇒ Time
The date and time that the algorithm emitted the metric.
39993 39994 39995 39996 39997 39998 39999 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39993 class MetricData < Struct.new( :metric_name, :value, :timestamp) SENSITIVE = [] include Aws::Structure end |
#value ⇒ Float
The value of the metric.
39993 39994 39995 39996 39997 39998 39999 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39993 class MetricData < Struct.new( :metric_name, :value, :timestamp) SENSITIVE = [] include Aws::Structure end |