Class: Aws::SageMaker::Types::MetricDatum

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Information about the metric for a candidate produced by an AutoML job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#metric_name ⇒ String

The name of the metric.

Returns:

  • (String)


40774
40775
40776
40777
40778
40779
40780
40781
# File 'lib/aws-sdk-sagemaker/types.rb', line 40774

class MetricDatum < Struct.new(
  :metric_name,
  :standard_metric_name,
  :value,
  :set)
  SENSITIVE = []
  include Aws::Structure
end

#set ⇒ String

The dataset split from which the AutoML job produced the metric.

Returns:

  • (String)


40774
40775
40776
40777
40778
40779
40780
40781
# File 'lib/aws-sdk-sagemaker/types.rb', line 40774

class MetricDatum < Struct.new(
  :metric_name,
  :standard_metric_name,
  :value,
  :set)
  SENSITIVE = []
  include Aws::Structure
end

#standard_metric_name ⇒ String

The name of the standard metric.

For definitions of the standard metrics, see Autopilot candidate metrics .

Returns:

  • (String)


40774
40775
40776
40777
40778
40779
40780
40781
# File 'lib/aws-sdk-sagemaker/types.rb', line 40774

class MetricDatum < Struct.new(
  :metric_name,
  :standard_metric_name,
  :value,
  :set)
  SENSITIVE = []
  include Aws::Structure
end

#value ⇒ Float

The value of the metric.

Returns:

  • (Float)


40774
40775
40776
40777
40778
40779
40780
40781
# File 'lib/aws-sdk-sagemaker/types.rb', line 40774

class MetricDatum < Struct.new(
  :metric_name,
  :standard_metric_name,
  :value,
  :set)
  SENSITIVE = []
  include Aws::Structure
end