Class: Aws::SageMaker::Types::MetricSpecification

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure, Aws::Structure::Union
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Note:

MetricSpecification is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of MetricSpecification corresponding to the set member.

An object containing information about a metric.

Direct Known Subclasses

Customized, Predefined, Unknown

Defined Under Namespace

Classes: Customized, Predefined, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#customizedTypes::CustomizedMetricSpecification

Information about a customized metric.



37355
37356
37357
37358
37359
37360
37361
37362
37363
37364
37365
37366
# File 'lib/aws-sdk-sagemaker/types.rb', line 37355

class MetricSpecification < Struct.new(
  :predefined,
  :customized,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Predefined < MetricSpecification; end
  class Customized < MetricSpecification; end
  class Unknown < MetricSpecification; end
end

#predefinedTypes::PredefinedMetricSpecification

Information about a predefined metric.



37355
37356
37357
37358
37359
37360
37361
37362
37363
37364
37365
37366
# File 'lib/aws-sdk-sagemaker/types.rb', line 37355

class MetricSpecification < Struct.new(
  :predefined,
  :customized,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Predefined < MetricSpecification; end
  class Customized < MetricSpecification; end
  class Unknown < MetricSpecification; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



37355
37356
37357
# File 'lib/aws-sdk-sagemaker/types.rb', line 37355

def unknown
  @unknown
end