Class: Aws::SageMaker::Types::Model

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The properties of a model as returned by the Search API.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#containersArray<Types::ContainerDefinition>

The containers in the inference pipeline.

Returns:



41117
41118
41119
41120
41121
41122
41123
41124
41125
41126
41127
41128
41129
41130
41131
# File 'lib/aws-sdk-sagemaker/types.rb', line 41117

class Model < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :tags,
  :deployment_recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

A timestamp that indicates when the model was created.

Returns:



41117
41118
41119
41120
41121
41122
41123
41124
41125
41126
41127
41128
41129
41130
41131
# File 'lib/aws-sdk-sagemaker/types.rb', line 41117

class Model < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :tags,
  :deployment_recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_recommendationTypes::DeploymentRecommendation

A set of recommended deployment configurations for the model.

Returns:



41117
41118
41119
41120
41121
41122
41123
41124
41125
41126
41127
41128
41129
41130
41131
# File 'lib/aws-sdk-sagemaker/types.rb', line 41117

class Model < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :tags,
  :deployment_recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#enable_network_isolationBoolean

Isolates the model container. No inbound or outbound network calls can be made to or from the model container.

Returns:



41117
41118
41119
41120
41121
41122
41123
41124
41125
41126
41127
41128
41129
41130
41131
# File 'lib/aws-sdk-sagemaker/types.rb', line 41117

class Model < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :tags,
  :deployment_recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#execution_role_arnString

The Amazon Resource Name (ARN) of the IAM role that you specified for the model.

Returns:



41117
41118
41119
41120
41121
41122
41123
41124
41125
41126
41127
41128
41129
41130
41131
# File 'lib/aws-sdk-sagemaker/types.rb', line 41117

class Model < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :tags,
  :deployment_recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#inference_execution_configTypes::InferenceExecutionConfig

Specifies details about how containers in a multi-container endpoint are run.

Returns:



41117
41118
41119
41120
41121
41122
41123
41124
41125
41126
41127
41128
41129
41130
41131
# File 'lib/aws-sdk-sagemaker/types.rb', line 41117

class Model < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :tags,
  :deployment_recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#model_arnString

The Amazon Resource Name (ARN) of the model.

Returns:



41117
41118
41119
41120
41121
41122
41123
41124
41125
41126
41127
41128
41129
41130
41131
# File 'lib/aws-sdk-sagemaker/types.rb', line 41117

class Model < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :tags,
  :deployment_recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#model_nameString

The name of the model.

Returns:



41117
41118
41119
41120
41121
41122
41123
41124
41125
41126
41127
41128
41129
41130
41131
# File 'lib/aws-sdk-sagemaker/types.rb', line 41117

class Model < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :tags,
  :deployment_recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#primary_containerTypes::ContainerDefinition

Describes the container, as part of model definition.

Returns:



41117
41118
41119
41120
41121
41122
41123
41124
41125
41126
41127
41128
41129
41130
41131
# File 'lib/aws-sdk-sagemaker/types.rb', line 41117

class Model < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :tags,
  :deployment_recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

A list of key-value pairs associated with the model. For more information, see Tagging Amazon Web Services resources in the Amazon Web Services General Reference Guide.

Returns:



41117
41118
41119
41120
41121
41122
41123
41124
41125
41126
41127
41128
41129
41130
41131
# File 'lib/aws-sdk-sagemaker/types.rb', line 41117

class Model < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :tags,
  :deployment_recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_configTypes::VpcConfig

Specifies an Amazon Virtual Private Cloud (VPC) that your SageMaker jobs, hosted models, and compute resources have access to. You can control access to and from your resources by configuring a VPC. For more information, see Give SageMaker Access to Resources in your Amazon VPC.

Returns:



41117
41118
41119
41120
41121
41122
41123
41124
41125
41126
41127
41128
41129
41130
41131
# File 'lib/aws-sdk-sagemaker/types.rb', line 41117

class Model < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :tags,
  :deployment_recommendation)
  SENSITIVE = []
  include Aws::Structure
end