Class: Aws::SageMaker::Types::ModelCardExportJobSummary

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The summary of the Amazon SageMaker Model Card export job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The date and time that the model card export job was created.

Returns:



37930
37931
37932
37933
37934
37935
37936
37937
37938
37939
37940
# File 'lib/aws-sdk-sagemaker/types.rb', line 37930

class ModelCardExportJobSummary < Struct.new(
  :model_card_export_job_name,
  :model_card_export_job_arn,
  :status,
  :model_card_name,
  :model_card_version,
  :created_at,
  :last_modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_atTime

The date and time that the model card export job was last modified..

Returns:



37930
37931
37932
37933
37934
37935
37936
37937
37938
37939
37940
# File 'lib/aws-sdk-sagemaker/types.rb', line 37930

class ModelCardExportJobSummary < Struct.new(
  :model_card_export_job_name,
  :model_card_export_job_arn,
  :status,
  :model_card_name,
  :model_card_version,
  :created_at,
  :last_modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#model_card_export_job_arnString

The Amazon Resource Name (ARN) of the model card export job.

Returns:



37930
37931
37932
37933
37934
37935
37936
37937
37938
37939
37940
# File 'lib/aws-sdk-sagemaker/types.rb', line 37930

class ModelCardExportJobSummary < Struct.new(
  :model_card_export_job_name,
  :model_card_export_job_arn,
  :status,
  :model_card_name,
  :model_card_version,
  :created_at,
  :last_modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#model_card_export_job_nameString

The name of the model card export job.

Returns:



37930
37931
37932
37933
37934
37935
37936
37937
37938
37939
37940
# File 'lib/aws-sdk-sagemaker/types.rb', line 37930

class ModelCardExportJobSummary < Struct.new(
  :model_card_export_job_name,
  :model_card_export_job_arn,
  :status,
  :model_card_name,
  :model_card_version,
  :created_at,
  :last_modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#model_card_nameString

The name of the model card that the export job exports.

Returns:



37930
37931
37932
37933
37934
37935
37936
37937
37938
37939
37940
# File 'lib/aws-sdk-sagemaker/types.rb', line 37930

class ModelCardExportJobSummary < Struct.new(
  :model_card_export_job_name,
  :model_card_export_job_arn,
  :status,
  :model_card_name,
  :model_card_version,
  :created_at,
  :last_modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#model_card_versionInteger

The version of the model card that the export job exports.

Returns:



37930
37931
37932
37933
37934
37935
37936
37937
37938
37939
37940
# File 'lib/aws-sdk-sagemaker/types.rb', line 37930

class ModelCardExportJobSummary < Struct.new(
  :model_card_export_job_name,
  :model_card_export_job_arn,
  :status,
  :model_card_name,
  :model_card_version,
  :created_at,
  :last_modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The completion status of the model card export job.

Returns:



37930
37931
37932
37933
37934
37935
37936
37937
37938
37939
37940
# File 'lib/aws-sdk-sagemaker/types.rb', line 37930

class ModelCardExportJobSummary < Struct.new(
  :model_card_export_job_name,
  :model_card_export_job_arn,
  :status,
  :model_card_name,
  :model_card_version,
  :created_at,
  :last_modified_at)
  SENSITIVE = []
  include Aws::Structure
end