Class: Aws::SageMaker::Types::ModelClientConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Configures the timeout and maximum number of retries for processing a transform job invocation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#invocations_max_retriesInteger

The maximum number of retries when invocation requests are failing. The default value is 3.

Returns:

  • (Integer)


38385
38386
38387
38388
38389
38390
# File 'lib/aws-sdk-sagemaker/types.rb', line 38385

class ModelClientConfig < Struct.new(
  :invocations_timeout_in_seconds,
  :invocations_max_retries)
  SENSITIVE = []
  include Aws::Structure
end

#invocations_timeout_in_secondsInteger

The timeout value in seconds for an invocation request. The default value is 600.

Returns:

  • (Integer)


38385
38386
38387
38388
38389
38390
# File 'lib/aws-sdk-sagemaker/types.rb', line 38385

class ModelClientConfig < Struct.new(
  :invocations_timeout_in_seconds,
  :invocations_max_retries)
  SENSITIVE = []
  include Aws::Structure
end