Class: Aws::SageMaker::Types::ModelDashboardModelCard
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ModelDashboardModelCard
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The model card for a model displayed in the Amazon SageMaker Model Dashboard.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_by ⇒ Types::UserContext
Information about the user who created or modified an experiment, trial, trial component, lineage group, project, or model card.
-
#creation_time ⇒ Time
A timestamp that indicates when the model card was created.
-
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified an experiment, trial, trial component, lineage group, project, or model card.
-
#last_modified_time ⇒ Time
A timestamp that indicates when the model card was last updated.
-
#model_card_arn ⇒ String
The Amazon Resource Name (ARN) for a model card.
-
#model_card_name ⇒ String
The name of a model card.
-
#model_card_status ⇒ String
The model card status.
-
#model_card_version ⇒ Integer
The model card version.
-
#model_id ⇒ String
For models created in SageMaker, this is the model ARN.
-
#risk_rating ⇒ String
A model card’s risk rating.
-
#security_config ⇒ Types::ModelCardSecurityConfig
The KMS Key ID (
KMSKeyId) for encryption of model card information. -
#tags ⇒ Array<Types::Tag>
The tags associated with a model card.
Instance Attribute Details
#created_by ⇒ Types::UserContext
Information about the user who created or modified an experiment, trial, trial component, lineage group, project, or model card.
27283 27284 27285 27286 27287 27288 27289 27290 27291 27292 27293 27294 27295 27296 27297 27298 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27283 class ModelDashboardModelCard < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :tags, :model_id, :risk_rating) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
A timestamp that indicates when the model card was created.
27283 27284 27285 27286 27287 27288 27289 27290 27291 27292 27293 27294 27295 27296 27297 27298 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27283 class ModelDashboardModelCard < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :tags, :model_id, :risk_rating) SENSITIVE = [] include Aws::Structure end |
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified an experiment, trial, trial component, lineage group, project, or model card.
27283 27284 27285 27286 27287 27288 27289 27290 27291 27292 27293 27294 27295 27296 27297 27298 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27283 class ModelDashboardModelCard < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :tags, :model_id, :risk_rating) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
A timestamp that indicates when the model card was last updated.
27283 27284 27285 27286 27287 27288 27289 27290 27291 27292 27293 27294 27295 27296 27297 27298 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27283 class ModelDashboardModelCard < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :tags, :model_id, :risk_rating) SENSITIVE = [] include Aws::Structure end |
#model_card_arn ⇒ String
The Amazon Resource Name (ARN) for a model card.
27283 27284 27285 27286 27287 27288 27289 27290 27291 27292 27293 27294 27295 27296 27297 27298 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27283 class ModelDashboardModelCard < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :tags, :model_id, :risk_rating) SENSITIVE = [] include Aws::Structure end |
#model_card_name ⇒ String
The name of a model card.
27283 27284 27285 27286 27287 27288 27289 27290 27291 27292 27293 27294 27295 27296 27297 27298 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27283 class ModelDashboardModelCard < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :tags, :model_id, :risk_rating) SENSITIVE = [] include Aws::Structure end |
#model_card_status ⇒ String
The model card status.
27283 27284 27285 27286 27287 27288 27289 27290 27291 27292 27293 27294 27295 27296 27297 27298 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27283 class ModelDashboardModelCard < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :tags, :model_id, :risk_rating) SENSITIVE = [] include Aws::Structure end |
#model_card_version ⇒ Integer
The model card version.
27283 27284 27285 27286 27287 27288 27289 27290 27291 27292 27293 27294 27295 27296 27297 27298 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27283 class ModelDashboardModelCard < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :tags, :model_id, :risk_rating) SENSITIVE = [] include Aws::Structure end |
#model_id ⇒ String
For models created in SageMaker, this is the model ARN. For models created outside of SageMaker, this is a user-customized string.
27283 27284 27285 27286 27287 27288 27289 27290 27291 27292 27293 27294 27295 27296 27297 27298 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27283 class ModelDashboardModelCard < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :tags, :model_id, :risk_rating) SENSITIVE = [] include Aws::Structure end |
#risk_rating ⇒ String
A model card’s risk rating. Can be low, medium, or high.
27283 27284 27285 27286 27287 27288 27289 27290 27291 27292 27293 27294 27295 27296 27297 27298 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27283 class ModelDashboardModelCard < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :tags, :model_id, :risk_rating) SENSITIVE = [] include Aws::Structure end |
#security_config ⇒ Types::ModelCardSecurityConfig
The KMS Key ID (KMSKeyId) for encryption of model card information.
27283 27284 27285 27286 27287 27288 27289 27290 27291 27292 27293 27294 27295 27296 27297 27298 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27283 class ModelDashboardModelCard < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :tags, :model_id, :risk_rating) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags associated with a model card.
27283 27284 27285 27286 27287 27288 27289 27290 27291 27292 27293 27294 27295 27296 27297 27298 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27283 class ModelDashboardModelCard < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :tags, :model_id, :risk_rating) SENSITIVE = [] include Aws::Structure end |