Class: Aws::SageMaker::Types::ModelDashboardMonitoringSchedule

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

A monitoring schedule for a model displayed in the Amazon SageMaker Model Dashboard.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#batch_transform_input ⇒ Types::BatchTransformInput

Input object for the batch transform job.



41844
41845
41846
41847
41848
41849
41850
41851
41852
41853
41854
41855
41856
41857
41858
41859
# File 'lib/aws-sdk-sagemaker/types.rb', line 41844

class ModelDashboardMonitoringSchedule < Struct.new(
  :monitoring_schedule_arn,
  :monitoring_schedule_name,
  :monitoring_schedule_status,
  :monitoring_type,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :monitoring_schedule_config,
  :endpoint_name,
  :monitoring_alert_summaries,
  :last_monitoring_execution_summary,
  :batch_transform_input)
  SENSITIVE = []
  include Aws::Structure
end

#creation_time ⇒ Time

A timestamp that indicates when the monitoring schedule was created.

Returns:

  • (Time)


41844
41845
41846
41847
41848
41849
41850
41851
41852
41853
41854
41855
41856
41857
41858
41859
# File 'lib/aws-sdk-sagemaker/types.rb', line 41844

class ModelDashboardMonitoringSchedule < Struct.new(
  :monitoring_schedule_arn,
  :monitoring_schedule_name,
  :monitoring_schedule_status,
  :monitoring_type,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :monitoring_schedule_config,
  :endpoint_name,
  :monitoring_alert_summaries,
  :last_monitoring_execution_summary,
  :batch_transform_input)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_name ⇒ String

The endpoint which is monitored.

Returns:

  • (String)


41844
41845
41846
41847
41848
41849
41850
41851
41852
41853
41854
41855
41856
41857
41858
41859
# File 'lib/aws-sdk-sagemaker/types.rb', line 41844

class ModelDashboardMonitoringSchedule < Struct.new(
  :monitoring_schedule_arn,
  :monitoring_schedule_name,
  :monitoring_schedule_status,
  :monitoring_type,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :monitoring_schedule_config,
  :endpoint_name,
  :monitoring_alert_summaries,
  :last_monitoring_execution_summary,
  :batch_transform_input)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reason ⇒ String

If a monitoring job failed, provides the reason.

Returns:

  • (String)


41844
41845
41846
41847
41848
41849
41850
41851
41852
41853
41854
41855
41856
41857
41858
41859
# File 'lib/aws-sdk-sagemaker/types.rb', line 41844

class ModelDashboardMonitoringSchedule < Struct.new(
  :monitoring_schedule_arn,
  :monitoring_schedule_name,
  :monitoring_schedule_status,
  :monitoring_type,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :monitoring_schedule_config,
  :endpoint_name,
  :monitoring_alert_summaries,
  :last_monitoring_execution_summary,
  :batch_transform_input)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_time ⇒ Time

A timestamp that indicates when the monitoring schedule was last updated.

Returns:

  • (Time)


41844
41845
41846
41847
41848
41849
41850
41851
41852
41853
41854
41855
41856
41857
41858
41859
# File 'lib/aws-sdk-sagemaker/types.rb', line 41844

class ModelDashboardMonitoringSchedule < Struct.new(
  :monitoring_schedule_arn,
  :monitoring_schedule_name,
  :monitoring_schedule_status,
  :monitoring_type,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :monitoring_schedule_config,
  :endpoint_name,
  :monitoring_alert_summaries,
  :last_monitoring_execution_summary,
  :batch_transform_input)
  SENSITIVE = []
  include Aws::Structure
end

#last_monitoring_execution_summary ⇒ Types::MonitoringExecutionSummary

Summary of information about the last monitoring job to run.



41844
41845
41846
41847
41848
41849
41850
41851
41852
41853
41854
41855
41856
41857
41858
41859
# File 'lib/aws-sdk-sagemaker/types.rb', line 41844

class ModelDashboardMonitoringSchedule < Struct.new(
  :monitoring_schedule_arn,
  :monitoring_schedule_name,
  :monitoring_schedule_status,
  :monitoring_type,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :monitoring_schedule_config,
  :endpoint_name,
  :monitoring_alert_summaries,
  :last_monitoring_execution_summary,
  :batch_transform_input)
  SENSITIVE = []
  include Aws::Structure
end

#monitoring_alert_summaries ⇒ Array<Types::MonitoringAlertSummary>

A JSON array where each element is a summary for a monitoring alert.

Returns:



41844
41845
41846
41847
41848
41849
41850
41851
41852
41853
41854
41855
41856
41857
41858
41859
# File 'lib/aws-sdk-sagemaker/types.rb', line 41844

class ModelDashboardMonitoringSchedule < Struct.new(
  :monitoring_schedule_arn,
  :monitoring_schedule_name,
  :monitoring_schedule_status,
  :monitoring_type,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :monitoring_schedule_config,
  :endpoint_name,
  :monitoring_alert_summaries,
  :last_monitoring_execution_summary,
  :batch_transform_input)
  SENSITIVE = []
  include Aws::Structure
end

#monitoring_schedule_arn ⇒ String

The Amazon Resource Name (ARN) of a monitoring schedule.

Returns:

  • (String)


41844
41845
41846
41847
41848
41849
41850
41851
41852
41853
41854
41855
41856
41857
41858
41859
# File 'lib/aws-sdk-sagemaker/types.rb', line 41844

class ModelDashboardMonitoringSchedule < Struct.new(
  :monitoring_schedule_arn,
  :monitoring_schedule_name,
  :monitoring_schedule_status,
  :monitoring_type,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :monitoring_schedule_config,
  :endpoint_name,
  :monitoring_alert_summaries,
  :last_monitoring_execution_summary,
  :batch_transform_input)
  SENSITIVE = []
  include Aws::Structure
end

#monitoring_schedule_config ⇒ Types::MonitoringScheduleConfig

Configures the monitoring schedule and defines the monitoring job.



41844
41845
41846
41847
41848
41849
41850
41851
41852
41853
41854
41855
41856
41857
41858
41859
# File 'lib/aws-sdk-sagemaker/types.rb', line 41844

class ModelDashboardMonitoringSchedule < Struct.new(
  :monitoring_schedule_arn,
  :monitoring_schedule_name,
  :monitoring_schedule_status,
  :monitoring_type,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :monitoring_schedule_config,
  :endpoint_name,
  :monitoring_alert_summaries,
  :last_monitoring_execution_summary,
  :batch_transform_input)
  SENSITIVE = []
  include Aws::Structure
end

#monitoring_schedule_name ⇒ String

The name of a monitoring schedule.

Returns:

  • (String)


41844
41845
41846
41847
41848
41849
41850
41851
41852
41853
41854
41855
41856
41857
41858
41859
# File 'lib/aws-sdk-sagemaker/types.rb', line 41844

class ModelDashboardMonitoringSchedule < Struct.new(
  :monitoring_schedule_arn,
  :monitoring_schedule_name,
  :monitoring_schedule_status,
  :monitoring_type,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :monitoring_schedule_config,
  :endpoint_name,
  :monitoring_alert_summaries,
  :last_monitoring_execution_summary,
  :batch_transform_input)
  SENSITIVE = []
  include Aws::Structure
end

#monitoring_schedule_status ⇒ String

The status of the monitoring schedule.

Returns:

  • (String)


41844
41845
41846
41847
41848
41849
41850
41851
41852
41853
41854
41855
41856
41857
41858
41859
# File 'lib/aws-sdk-sagemaker/types.rb', line 41844

class ModelDashboardMonitoringSchedule < Struct.new(
  :monitoring_schedule_arn,
  :monitoring_schedule_name,
  :monitoring_schedule_status,
  :monitoring_type,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :monitoring_schedule_config,
  :endpoint_name,
  :monitoring_alert_summaries,
  :last_monitoring_execution_summary,
  :batch_transform_input)
  SENSITIVE = []
  include Aws::Structure
end

#monitoring_type ⇒ String

The monitor type of a model monitor.

Returns:

  • (String)


41844
41845
41846
41847
41848
41849
41850
41851
41852
41853
41854
41855
41856
41857
41858
41859
# File 'lib/aws-sdk-sagemaker/types.rb', line 41844

class ModelDashboardMonitoringSchedule < Struct.new(
  :monitoring_schedule_arn,
  :monitoring_schedule_name,
  :monitoring_schedule_status,
  :monitoring_type,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :monitoring_schedule_config,
  :endpoint_name,
  :monitoring_alert_summaries,
  :last_monitoring_execution_summary,
  :batch_transform_input)
  SENSITIVE = []
  include Aws::Structure
end