Class: Aws::SageMaker::Types::ModelPackageGroup

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

A group of versioned models in the Model Registry.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_byTypes::UserContext

Information about the user who created or modified a SageMaker resource.



42660
42661
42662
42663
42664
42665
42666
42667
42668
42669
42670
# File 'lib/aws-sdk-sagemaker/types.rb', line 42660

class ModelPackageGroup < Struct.new(
  :model_package_group_name,
  :model_package_group_arn,
  :model_package_group_description,
  :creation_time,
  :created_by,
  :model_package_group_status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

The time that the model group was created.



42660
42661
42662
42663
42664
42665
42666
42667
42668
42669
42670
# File 'lib/aws-sdk-sagemaker/types.rb', line 42660

class ModelPackageGroup < Struct.new(
  :model_package_group_name,
  :model_package_group_arn,
  :model_package_group_description,
  :creation_time,
  :created_by,
  :model_package_group_status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#model_package_group_arnString

The Amazon Resource Name (ARN) of the model group.



42660
42661
42662
42663
42664
42665
42666
42667
42668
42669
42670
# File 'lib/aws-sdk-sagemaker/types.rb', line 42660

class ModelPackageGroup < Struct.new(
  :model_package_group_name,
  :model_package_group_arn,
  :model_package_group_description,
  :creation_time,
  :created_by,
  :model_package_group_status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#model_package_group_descriptionString

The description for the model group.



42660
42661
42662
42663
42664
42665
42666
42667
42668
42669
42670
# File 'lib/aws-sdk-sagemaker/types.rb', line 42660

class ModelPackageGroup < Struct.new(
  :model_package_group_name,
  :model_package_group_arn,
  :model_package_group_description,
  :creation_time,
  :created_by,
  :model_package_group_status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#model_package_group_nameString

The name of the model group.



42660
42661
42662
42663
42664
42665
42666
42667
42668
42669
42670
# File 'lib/aws-sdk-sagemaker/types.rb', line 42660

class ModelPackageGroup < Struct.new(
  :model_package_group_name,
  :model_package_group_arn,
  :model_package_group_description,
  :creation_time,
  :created_by,
  :model_package_group_status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#model_package_group_statusString

The status of the model group. This can be one of the following values.

  • PENDING - The model group is pending being created.

  • IN_PROGRESS - The model group is in the process of being created.

  • COMPLETED - The model group was successfully created.

  • FAILED - The model group failed.

  • DELETING - The model group is in the process of being deleted.

  • DELETE_FAILED - SageMaker failed to delete the model group.



42660
42661
42662
42663
42664
42665
42666
42667
42668
42669
42670
# File 'lib/aws-sdk-sagemaker/types.rb', line 42660

class ModelPackageGroup < Struct.new(
  :model_package_group_name,
  :model_package_group_arn,
  :model_package_group_description,
  :creation_time,
  :created_by,
  :model_package_group_status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

A list of the tags associated with the model group. For more information, see Tagging Amazon Web Services resources in the Amazon Web Services General Reference Guide.



42660
42661
42662
42663
42664
42665
42666
42667
42668
42669
42670
# File 'lib/aws-sdk-sagemaker/types.rb', line 42660

class ModelPackageGroup < Struct.new(
  :model_package_group_name,
  :model_package_group_arn,
  :model_package_group_description,
  :creation_time,
  :created_by,
  :model_package_group_status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end