Class: Aws::SageMaker::Types::ModelPackageSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ModelPackageSummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Provides summary information about a model package.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Time
A timestamp that shows when the model package was created.
-
#model_approval_status ⇒ String
The approval status of the model.
-
#model_life_cycle ⇒ Types::ModelLifeCycle
A structure describing the current state of the model in its life cycle.
-
#model_package_arn ⇒ String
The Amazon Resource Name (ARN) of the model package.
-
#model_package_description ⇒ String
A brief description of the model package.
-
#model_package_group_name ⇒ String
If the model package is a versioned model, the model group that the versioned model belongs to.
-
#model_package_name ⇒ String
The name of the model package.
-
#model_package_registration_type ⇒ String
The package registration type of the model package summary.
-
#model_package_status ⇒ String
The overall status of the model package.
-
#model_package_version ⇒ Integer
If the model package is a versioned model, the version of the model.
Instance Attribute Details
#creation_time ⇒ Time
A timestamp that shows when the model package was created.
42068 42069 42070 42071 42072 42073 42074 42075 42076 42077 42078 42079 42080 42081 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42068 class ModelPackageSummary < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_arn, :model_package_description, :creation_time, :model_package_status, :model_approval_status, :model_life_cycle, :model_package_registration_type) SENSITIVE = [] include Aws::Structure end |
#model_approval_status ⇒ String
The approval status of the model. This can be one of the following values.
-
‘APPROVED` - The model is approved
-
‘REJECTED` - The model is rejected.
-
‘PENDING_MANUAL_APPROVAL` - The model is waiting for manual approval.
42068 42069 42070 42071 42072 42073 42074 42075 42076 42077 42078 42079 42080 42081 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42068 class ModelPackageSummary < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_arn, :model_package_description, :creation_time, :model_package_status, :model_approval_status, :model_life_cycle, :model_package_registration_type) SENSITIVE = [] include Aws::Structure end |
#model_life_cycle ⇒ Types::ModelLifeCycle
A structure describing the current state of the model in its life cycle.
42068 42069 42070 42071 42072 42073 42074 42075 42076 42077 42078 42079 42080 42081 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42068 class ModelPackageSummary < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_arn, :model_package_description, :creation_time, :model_package_status, :model_approval_status, :model_life_cycle, :model_package_registration_type) SENSITIVE = [] include Aws::Structure end |
#model_package_arn ⇒ String
The Amazon Resource Name (ARN) of the model package.
42068 42069 42070 42071 42072 42073 42074 42075 42076 42077 42078 42079 42080 42081 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42068 class ModelPackageSummary < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_arn, :model_package_description, :creation_time, :model_package_status, :model_approval_status, :model_life_cycle, :model_package_registration_type) SENSITIVE = [] include Aws::Structure end |
#model_package_description ⇒ String
A brief description of the model package.
42068 42069 42070 42071 42072 42073 42074 42075 42076 42077 42078 42079 42080 42081 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42068 class ModelPackageSummary < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_arn, :model_package_description, :creation_time, :model_package_status, :model_approval_status, :model_life_cycle, :model_package_registration_type) SENSITIVE = [] include Aws::Structure end |
#model_package_group_name ⇒ String
If the model package is a versioned model, the model group that the versioned model belongs to.
42068 42069 42070 42071 42072 42073 42074 42075 42076 42077 42078 42079 42080 42081 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42068 class ModelPackageSummary < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_arn, :model_package_description, :creation_time, :model_package_status, :model_approval_status, :model_life_cycle, :model_package_registration_type) SENSITIVE = [] include Aws::Structure end |
#model_package_name ⇒ String
The name of the model package.
42068 42069 42070 42071 42072 42073 42074 42075 42076 42077 42078 42079 42080 42081 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42068 class ModelPackageSummary < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_arn, :model_package_description, :creation_time, :model_package_status, :model_approval_status, :model_life_cycle, :model_package_registration_type) SENSITIVE = [] include Aws::Structure end |
#model_package_registration_type ⇒ String
The package registration type of the model package summary.
42068 42069 42070 42071 42072 42073 42074 42075 42076 42077 42078 42079 42080 42081 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42068 class ModelPackageSummary < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_arn, :model_package_description, :creation_time, :model_package_status, :model_approval_status, :model_life_cycle, :model_package_registration_type) SENSITIVE = [] include Aws::Structure end |
#model_package_status ⇒ String
The overall status of the model package.
42068 42069 42070 42071 42072 42073 42074 42075 42076 42077 42078 42079 42080 42081 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42068 class ModelPackageSummary < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_arn, :model_package_description, :creation_time, :model_package_status, :model_approval_status, :model_life_cycle, :model_package_registration_type) SENSITIVE = [] include Aws::Structure end |
#model_package_version ⇒ Integer
If the model package is a versioned model, the version of the model.
42068 42069 42070 42071 42072 42073 42074 42075 42076 42077 42078 42079 42080 42081 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42068 class ModelPackageSummary < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_arn, :model_package_description, :creation_time, :model_package_status, :model_approval_status, :model_life_cycle, :model_package_registration_type) SENSITIVE = [] include Aws::Structure end |