Class: Aws::SageMaker::Types::ModelPackageValidationSpecification
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ModelPackageValidationSpecification
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Specifies batch transform jobs that SageMaker runs to validate your model package.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#validation_profiles ⇒ Array<Types::ModelPackageValidationProfile>
An array of ‘ModelPackageValidationProfile` objects, each of which specifies a batch transform job that SageMaker runs to validate your model package.
-
#validation_role ⇒ String
The IAM roles to be used for the validation of the model package.
Instance Attribute Details
#validation_profiles ⇒ Array<Types::ModelPackageValidationProfile>
An array of ‘ModelPackageValidationProfile` objects, each of which specifies a batch transform job that SageMaker runs to validate your model package.
42122 42123 42124 42125 42126 42127 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42122 class ModelPackageValidationSpecification < Struct.new( :validation_role, :validation_profiles) SENSITIVE = [] include Aws::Structure end |
#validation_role ⇒ String
The IAM roles to be used for the validation of the model package.
42122 42123 42124 42125 42126 42127 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42122 class ModelPackageValidationSpecification < Struct.new( :validation_role, :validation_profiles) SENSITIVE = [] include Aws::Structure end |