Class: Aws::SageMaker::Types::ModelSpeculativeDecodingConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ModelSpeculativeDecodingConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Settings for the model speculative decoding technique that's applied by a model optimization job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#technique ⇒ String
The speculative decoding technique to apply during model optimization.
-
#training_data_source ⇒ Types::ModelSpeculativeDecodingTrainingDataSource
The location of the training data to use for speculative decoding.
Instance Attribute Details
#technique ⇒ String
The speculative decoding technique to apply during model optimization.
42840 42841 42842 42843 42844 42845 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42840 class ModelSpeculativeDecodingConfig < Struct.new( :technique, :training_data_source) SENSITIVE = [] include Aws::Structure end |
#training_data_source ⇒ Types::ModelSpeculativeDecodingTrainingDataSource
The location of the training data to use for speculative decoding. The data must be formatted as ShareGPT, OpenAI Completions or OpenAI Chat Completions. The input can also be unencrypted captured data from a SageMaker endpoint as long as the endpoint uses one of the above formats.
42840 42841 42842 42843 42844 42845 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42840 class ModelSpeculativeDecodingConfig < Struct.new( :technique, :training_data_source) SENSITIVE = [] include Aws::Structure end |