Class: Aws::SageMaker::Types::ModelSpeculativeDecodingTrainingDataSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ModelSpeculativeDecodingTrainingDataSource
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Contains information about the training data source for speculative decoding.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#s3_data_type ⇒ String
The type of data stored in the Amazon S3 location.
-
#s3_uri ⇒ String
The Amazon S3 URI that points to the training data for speculative decoding.
Instance Attribute Details
#s3_data_type ⇒ String
The type of data stored in the Amazon S3 location. Valid values are ‘S3Prefix` or `ManifestFile`.
41501 41502 41503 41504 41505 41506 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 41501 class ModelSpeculativeDecodingTrainingDataSource < Struct.new( :s3_uri, :s3_data_type) SENSITIVE = [] include Aws::Structure end |
#s3_uri ⇒ String
The Amazon S3 URI that points to the training data for speculative decoding.
41501 41502 41503 41504 41505 41506 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 41501 class ModelSpeculativeDecodingTrainingDataSource < Struct.new( :s3_uri, :s3_data_type) SENSITIVE = [] include Aws::Structure end |