Class: Aws::SageMaker::Types::MonitoringExecutionSummary

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Summary of information about the last monitoring job to run.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_time ⇒ Time

The time at which the monitoring job was created.

Returns:

  • (Time)


43578
43579
43580
43581
43582
43583
43584
43585
43586
43587
43588
43589
43590
43591
# File 'lib/aws-sdk-sagemaker/types.rb', line 43578

class MonitoringExecutionSummary < Struct.new(
  :monitoring_schedule_name,
  :scheduled_time,
  :creation_time,
  :last_modified_time,
  :monitoring_execution_status,
  :processing_job_arn,
  :endpoint_name,
  :failure_reason,
  :monitoring_job_definition_name,
  :monitoring_type)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_name ⇒ String

The name of the endpoint used to run the monitoring job.

Returns:

  • (String)


43578
43579
43580
43581
43582
43583
43584
43585
43586
43587
43588
43589
43590
43591
# File 'lib/aws-sdk-sagemaker/types.rb', line 43578

class MonitoringExecutionSummary < Struct.new(
  :monitoring_schedule_name,
  :scheduled_time,
  :creation_time,
  :last_modified_time,
  :monitoring_execution_status,
  :processing_job_arn,
  :endpoint_name,
  :failure_reason,
  :monitoring_job_definition_name,
  :monitoring_type)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reason ⇒ String

Contains the reason a monitoring job failed, if it failed.

Returns:

  • (String)


43578
43579
43580
43581
43582
43583
43584
43585
43586
43587
43588
43589
43590
43591
# File 'lib/aws-sdk-sagemaker/types.rb', line 43578

class MonitoringExecutionSummary < Struct.new(
  :monitoring_schedule_name,
  :scheduled_time,
  :creation_time,
  :last_modified_time,
  :monitoring_execution_status,
  :processing_job_arn,
  :endpoint_name,
  :failure_reason,
  :monitoring_job_definition_name,
  :monitoring_type)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_time ⇒ Time

A timestamp that indicates the last time the monitoring job was modified.

Returns:

  • (Time)


43578
43579
43580
43581
43582
43583
43584
43585
43586
43587
43588
43589
43590
43591
# File 'lib/aws-sdk-sagemaker/types.rb', line 43578

class MonitoringExecutionSummary < Struct.new(
  :monitoring_schedule_name,
  :scheduled_time,
  :creation_time,
  :last_modified_time,
  :monitoring_execution_status,
  :processing_job_arn,
  :endpoint_name,
  :failure_reason,
  :monitoring_job_definition_name,
  :monitoring_type)
  SENSITIVE = []
  include Aws::Structure
end

#monitoring_execution_status ⇒ String

The status of the monitoring job.

Returns:

  • (String)


43578
43579
43580
43581
43582
43583
43584
43585
43586
43587
43588
43589
43590
43591
# File 'lib/aws-sdk-sagemaker/types.rb', line 43578

class MonitoringExecutionSummary < Struct.new(
  :monitoring_schedule_name,
  :scheduled_time,
  :creation_time,
  :last_modified_time,
  :monitoring_execution_status,
  :processing_job_arn,
  :endpoint_name,
  :failure_reason,
  :monitoring_job_definition_name,
  :monitoring_type)
  SENSITIVE = []
  include Aws::Structure
end

#monitoring_job_definition_name ⇒ String

The name of the monitoring job.

Returns:

  • (String)


43578
43579
43580
43581
43582
43583
43584
43585
43586
43587
43588
43589
43590
43591
# File 'lib/aws-sdk-sagemaker/types.rb', line 43578

class MonitoringExecutionSummary < Struct.new(
  :monitoring_schedule_name,
  :scheduled_time,
  :creation_time,
  :last_modified_time,
  :monitoring_execution_status,
  :processing_job_arn,
  :endpoint_name,
  :failure_reason,
  :monitoring_job_definition_name,
  :monitoring_type)
  SENSITIVE = []
  include Aws::Structure
end

#monitoring_schedule_name ⇒ String

The name of the monitoring schedule.

Returns:

  • (String)


43578
43579
43580
43581
43582
43583
43584
43585
43586
43587
43588
43589
43590
43591
# File 'lib/aws-sdk-sagemaker/types.rb', line 43578

class MonitoringExecutionSummary < Struct.new(
  :monitoring_schedule_name,
  :scheduled_time,
  :creation_time,
  :last_modified_time,
  :monitoring_execution_status,
  :processing_job_arn,
  :endpoint_name,
  :failure_reason,
  :monitoring_job_definition_name,
  :monitoring_type)
  SENSITIVE = []
  include Aws::Structure
end

#monitoring_type ⇒ String

The type of the monitoring job.

Returns:

  • (String)


43578
43579
43580
43581
43582
43583
43584
43585
43586
43587
43588
43589
43590
43591
# File 'lib/aws-sdk-sagemaker/types.rb', line 43578

class MonitoringExecutionSummary < Struct.new(
  :monitoring_schedule_name,
  :scheduled_time,
  :creation_time,
  :last_modified_time,
  :monitoring_execution_status,
  :processing_job_arn,
  :endpoint_name,
  :failure_reason,
  :monitoring_job_definition_name,
  :monitoring_type)
  SENSITIVE = []
  include Aws::Structure
end

#processing_job_arn ⇒ String

The Amazon Resource Name (ARN) of the monitoring job.

Returns:

  • (String)


43578
43579
43580
43581
43582
43583
43584
43585
43586
43587
43588
43589
43590
43591
# File 'lib/aws-sdk-sagemaker/types.rb', line 43578

class MonitoringExecutionSummary < Struct.new(
  :monitoring_schedule_name,
  :scheduled_time,
  :creation_time,
  :last_modified_time,
  :monitoring_execution_status,
  :processing_job_arn,
  :endpoint_name,
  :failure_reason,
  :monitoring_job_definition_name,
  :monitoring_type)
  SENSITIVE = []
  include Aws::Structure
end

#scheduled_time ⇒ Time

The time the monitoring job was scheduled.

Returns:

  • (Time)


43578
43579
43580
43581
43582
43583
43584
43585
43586
43587
43588
43589
43590
43591
# File 'lib/aws-sdk-sagemaker/types.rb', line 43578

class MonitoringExecutionSummary < Struct.new(
  :monitoring_schedule_name,
  :scheduled_time,
  :creation_time,
  :last_modified_time,
  :monitoring_execution_status,
  :processing_job_arn,
  :endpoint_name,
  :failure_reason,
  :monitoring_job_definition_name,
  :monitoring_type)
  SENSITIVE = []
  include Aws::Structure
end