Class: Aws::SageMaker::Types::MonitoringJobDefinition

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Defines the monitoring job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#baseline_config ⇒ Types::MonitoringBaselineConfig

Baseline configuration used to validate that the data conforms to the specified constraints and statistics



43674
43675
43676
43677
43678
43679
43680
43681
43682
43683
43684
43685
43686
# File 'lib/aws-sdk-sagemaker/types.rb', line 43674

class MonitoringJobDefinition < Struct.new(
  :baseline_config,
  :monitoring_inputs,
  :monitoring_output_config,
  :monitoring_resources,
  :monitoring_app_specification,
  :stopping_condition,
  :environment,
  :network_config,
  :role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#environment ⇒ Hash<String,String>

Sets the environment variables in the Docker container.

Returns:

  • (Hash<String,String>)


43674
43675
43676
43677
43678
43679
43680
43681
43682
43683
43684
43685
43686
# File 'lib/aws-sdk-sagemaker/types.rb', line 43674

class MonitoringJobDefinition < Struct.new(
  :baseline_config,
  :monitoring_inputs,
  :monitoring_output_config,
  :monitoring_resources,
  :monitoring_app_specification,
  :stopping_condition,
  :environment,
  :network_config,
  :role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#monitoring_app_specification ⇒ Types::MonitoringAppSpecification

Configures the monitoring job to run a specified Docker container image.



43674
43675
43676
43677
43678
43679
43680
43681
43682
43683
43684
43685
43686
# File 'lib/aws-sdk-sagemaker/types.rb', line 43674

class MonitoringJobDefinition < Struct.new(
  :baseline_config,
  :monitoring_inputs,
  :monitoring_output_config,
  :monitoring_resources,
  :monitoring_app_specification,
  :stopping_condition,
  :environment,
  :network_config,
  :role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#monitoring_inputs ⇒ Array<Types::MonitoringInput>

The array of inputs for the monitoring job. Currently we support monitoring an Amazon SageMaker AI Endpoint.

Returns:



43674
43675
43676
43677
43678
43679
43680
43681
43682
43683
43684
43685
43686
# File 'lib/aws-sdk-sagemaker/types.rb', line 43674

class MonitoringJobDefinition < Struct.new(
  :baseline_config,
  :monitoring_inputs,
  :monitoring_output_config,
  :monitoring_resources,
  :monitoring_app_specification,
  :stopping_condition,
  :environment,
  :network_config,
  :role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#monitoring_output_config ⇒ Types::MonitoringOutputConfig

The array of outputs from the monitoring job to be uploaded to Amazon S3.



43674
43675
43676
43677
43678
43679
43680
43681
43682
43683
43684
43685
43686
# File 'lib/aws-sdk-sagemaker/types.rb', line 43674

class MonitoringJobDefinition < Struct.new(
  :baseline_config,
  :monitoring_inputs,
  :monitoring_output_config,
  :monitoring_resources,
  :monitoring_app_specification,
  :stopping_condition,
  :environment,
  :network_config,
  :role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#monitoring_resources ⇒ Types::MonitoringResources

Identifies the resources, ML compute instances, and ML storage volumes to deploy for a monitoring job. In distributed processing, you specify more than one instance.



43674
43675
43676
43677
43678
43679
43680
43681
43682
43683
43684
43685
43686
# File 'lib/aws-sdk-sagemaker/types.rb', line 43674

class MonitoringJobDefinition < Struct.new(
  :baseline_config,
  :monitoring_inputs,
  :monitoring_output_config,
  :monitoring_resources,
  :monitoring_app_specification,
  :stopping_condition,
  :environment,
  :network_config,
  :role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#network_config ⇒ Types::NetworkConfig

Specifies networking options for an monitoring job.



43674
43675
43676
43677
43678
43679
43680
43681
43682
43683
43684
43685
43686
# File 'lib/aws-sdk-sagemaker/types.rb', line 43674

class MonitoringJobDefinition < Struct.new(
  :baseline_config,
  :monitoring_inputs,
  :monitoring_output_config,
  :monitoring_resources,
  :monitoring_app_specification,
  :stopping_condition,
  :environment,
  :network_config,
  :role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#role_arn ⇒ String

The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker AI can assume to perform tasks on your behalf.

Returns:

  • (String)


43674
43675
43676
43677
43678
43679
43680
43681
43682
43683
43684
43685
43686
# File 'lib/aws-sdk-sagemaker/types.rb', line 43674

class MonitoringJobDefinition < Struct.new(
  :baseline_config,
  :monitoring_inputs,
  :monitoring_output_config,
  :monitoring_resources,
  :monitoring_app_specification,
  :stopping_condition,
  :environment,
  :network_config,
  :role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#stopping_condition ⇒ Types::MonitoringStoppingCondition

Specifies a time limit for how long the monitoring job is allowed to run.



43674
43675
43676
43677
43678
43679
43680
43681
43682
43683
43684
43685
43686
# File 'lib/aws-sdk-sagemaker/types.rb', line 43674

class MonitoringJobDefinition < Struct.new(
  :baseline_config,
  :monitoring_inputs,
  :monitoring_output_config,
  :monitoring_resources,
  :monitoring_app_specification,
  :stopping_condition,
  :environment,
  :network_config,
  :role_arn)
  SENSITIVE = []
  include Aws::Structure
end