Class: Aws::SageMaker::Types::MonitoringNetworkConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The networking configuration for the monitoring job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enable_inter_container_traffic_encryption ⇒ Boolean

Whether to encrypt all communications between the instances used for the monitoring jobs. Choose True to encrypt communications. Encryption provides greater security for distributed jobs, but the processing might take longer.

Returns:

  • (Boolean)


43759
43760
43761
43762
43763
43764
43765
# File 'lib/aws-sdk-sagemaker/types.rb', line 43759

class MonitoringNetworkConfig < Struct.new(
  :enable_inter_container_traffic_encryption,
  :enable_network_isolation,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#enable_network_isolation ⇒ Boolean

Whether to allow inbound and outbound network calls to and from the containers used for the monitoring job.

Returns:

  • (Boolean)


43759
43760
43761
43762
43763
43764
43765
# File 'lib/aws-sdk-sagemaker/types.rb', line 43759

class MonitoringNetworkConfig < Struct.new(
  :enable_inter_container_traffic_encryption,
  :enable_network_isolation,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_config ⇒ Types::VpcConfig

Specifies an Amazon Virtual Private Cloud (VPC) that your SageMaker jobs, hosted models, and compute resources have access to. You can control access to and from your resources by configuring a VPC. For more information, see Give SageMaker Access to Resources in your Amazon VPC.

Returns:



43759
43760
43761
43762
43763
43764
43765
# File 'lib/aws-sdk-sagemaker/types.rb', line 43759

class MonitoringNetworkConfig < Struct.new(
  :enable_inter_container_traffic_encryption,
  :enable_network_isolation,
  :vpc_config)
  SENSITIVE = []
  include Aws::Structure
end