Class: Aws::SageMaker::Types::MonitoringSchedule

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

A schedule for a model monitoring job. For information about model monitor, see Amazon SageMaker Model Monitor.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_time ⇒ Time

The time that the monitoring schedule was created.

Returns:

  • (Time)


43925
43926
43927
43928
43929
43930
43931
43932
43933
43934
43935
43936
43937
43938
43939
# File 'lib/aws-sdk-sagemaker/types.rb', line 43925

class MonitoringSchedule < Struct.new(
  :monitoring_schedule_arn,
  :monitoring_schedule_name,
  :monitoring_schedule_status,
  :monitoring_type,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :monitoring_schedule_config,
  :endpoint_name,
  :last_monitoring_execution_summary,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_name ⇒ String

The endpoint that hosts the model being monitored.

Returns:

  • (String)


43925
43926
43927
43928
43929
43930
43931
43932
43933
43934
43935
43936
43937
43938
43939
# File 'lib/aws-sdk-sagemaker/types.rb', line 43925

class MonitoringSchedule < Struct.new(
  :monitoring_schedule_arn,
  :monitoring_schedule_name,
  :monitoring_schedule_status,
  :monitoring_type,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :monitoring_schedule_config,
  :endpoint_name,
  :last_monitoring_execution_summary,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reason ⇒ String

If the monitoring schedule failed, the reason it failed.

Returns:

  • (String)


43925
43926
43927
43928
43929
43930
43931
43932
43933
43934
43935
43936
43937
43938
43939
# File 'lib/aws-sdk-sagemaker/types.rb', line 43925

class MonitoringSchedule < Struct.new(
  :monitoring_schedule_arn,
  :monitoring_schedule_name,
  :monitoring_schedule_status,
  :monitoring_type,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :monitoring_schedule_config,
  :endpoint_name,
  :last_monitoring_execution_summary,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_time ⇒ Time

The last time the monitoring schedule was changed.

Returns:

  • (Time)


43925
43926
43927
43928
43929
43930
43931
43932
43933
43934
43935
43936
43937
43938
43939
# File 'lib/aws-sdk-sagemaker/types.rb', line 43925

class MonitoringSchedule < Struct.new(
  :monitoring_schedule_arn,
  :monitoring_schedule_name,
  :monitoring_schedule_status,
  :monitoring_type,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :monitoring_schedule_config,
  :endpoint_name,
  :last_monitoring_execution_summary,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#last_monitoring_execution_summary ⇒ Types::MonitoringExecutionSummary

Summary of information about the last monitoring job to run.



43925
43926
43927
43928
43929
43930
43931
43932
43933
43934
43935
43936
43937
43938
43939
# File 'lib/aws-sdk-sagemaker/types.rb', line 43925

class MonitoringSchedule < Struct.new(
  :monitoring_schedule_arn,
  :monitoring_schedule_name,
  :monitoring_schedule_status,
  :monitoring_type,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :monitoring_schedule_config,
  :endpoint_name,
  :last_monitoring_execution_summary,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#monitoring_schedule_arn ⇒ String

The Amazon Resource Name (ARN) of the monitoring schedule.

Returns:

  • (String)


43925
43926
43927
43928
43929
43930
43931
43932
43933
43934
43935
43936
43937
43938
43939
# File 'lib/aws-sdk-sagemaker/types.rb', line 43925

class MonitoringSchedule < Struct.new(
  :monitoring_schedule_arn,
  :monitoring_schedule_name,
  :monitoring_schedule_status,
  :monitoring_type,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :monitoring_schedule_config,
  :endpoint_name,
  :last_monitoring_execution_summary,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#monitoring_schedule_config ⇒ Types::MonitoringScheduleConfig

Configures the monitoring schedule and defines the monitoring job.



43925
43926
43927
43928
43929
43930
43931
43932
43933
43934
43935
43936
43937
43938
43939
# File 'lib/aws-sdk-sagemaker/types.rb', line 43925

class MonitoringSchedule < Struct.new(
  :monitoring_schedule_arn,
  :monitoring_schedule_name,
  :monitoring_schedule_status,
  :monitoring_type,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :monitoring_schedule_config,
  :endpoint_name,
  :last_monitoring_execution_summary,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#monitoring_schedule_name ⇒ String

The name of the monitoring schedule.

Returns:

  • (String)


43925
43926
43927
43928
43929
43930
43931
43932
43933
43934
43935
43936
43937
43938
43939
# File 'lib/aws-sdk-sagemaker/types.rb', line 43925

class MonitoringSchedule < Struct.new(
  :monitoring_schedule_arn,
  :monitoring_schedule_name,
  :monitoring_schedule_status,
  :monitoring_type,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :monitoring_schedule_config,
  :endpoint_name,
  :last_monitoring_execution_summary,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#monitoring_schedule_status ⇒ String

The status of the monitoring schedule. This can be one of the following values.

  • PENDING - The schedule is pending being created.

  • FAILED - The schedule failed.

  • SCHEDULED - The schedule was successfully created.

  • STOPPED - The schedule was stopped.

Returns:

  • (String)


43925
43926
43927
43928
43929
43930
43931
43932
43933
43934
43935
43936
43937
43938
43939
# File 'lib/aws-sdk-sagemaker/types.rb', line 43925

class MonitoringSchedule < Struct.new(
  :monitoring_schedule_arn,
  :monitoring_schedule_name,
  :monitoring_schedule_status,
  :monitoring_type,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :monitoring_schedule_config,
  :endpoint_name,
  :last_monitoring_execution_summary,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#monitoring_type ⇒ String

The type of the monitoring job definition to schedule.

Returns:

  • (String)


43925
43926
43927
43928
43929
43930
43931
43932
43933
43934
43935
43936
43937
43938
43939
# File 'lib/aws-sdk-sagemaker/types.rb', line 43925

class MonitoringSchedule < Struct.new(
  :monitoring_schedule_arn,
  :monitoring_schedule_name,
  :monitoring_schedule_status,
  :monitoring_type,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :monitoring_schedule_config,
  :endpoint_name,
  :last_monitoring_execution_summary,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Array<Types::Tag>

A list of the tags associated with the monitoring schedlue. For more information, see Tagging Amazon Web Services resources in the Amazon Web Services General Reference Guide.

Returns:



43925
43926
43927
43928
43929
43930
43931
43932
43933
43934
43935
43936
43937
43938
43939
# File 'lib/aws-sdk-sagemaker/types.rb', line 43925

class MonitoringSchedule < Struct.new(
  :monitoring_schedule_arn,
  :monitoring_schedule_name,
  :monitoring_schedule_status,
  :monitoring_type,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :monitoring_schedule_config,
  :endpoint_name,
  :last_monitoring_execution_summary,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end