Class: Aws::SageMaker::Types::MonitoringScheduleConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Configures the monitoring schedule and defines the monitoring job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#monitoring_job_definition ⇒ Types::MonitoringJobDefinition

Defines the monitoring job.



43961
43962
43963
43964
43965
43966
43967
43968
# File 'lib/aws-sdk-sagemaker/types.rb', line 43961

class MonitoringScheduleConfig < Struct.new(
  :schedule_config,
  :monitoring_job_definition,
  :monitoring_job_definition_name,
  :monitoring_type)
  SENSITIVE = []
  include Aws::Structure
end

#monitoring_job_definition_name ⇒ String

The name of the monitoring job definition to schedule.

Returns:

  • (String)


43961
43962
43963
43964
43965
43966
43967
43968
# File 'lib/aws-sdk-sagemaker/types.rb', line 43961

class MonitoringScheduleConfig < Struct.new(
  :schedule_config,
  :monitoring_job_definition,
  :monitoring_job_definition_name,
  :monitoring_type)
  SENSITIVE = []
  include Aws::Structure
end

#monitoring_type ⇒ String

The type of the monitoring job definition to schedule.

Returns:

  • (String)


43961
43962
43963
43964
43965
43966
43967
43968
# File 'lib/aws-sdk-sagemaker/types.rb', line 43961

class MonitoringScheduleConfig < Struct.new(
  :schedule_config,
  :monitoring_job_definition,
  :monitoring_job_definition_name,
  :monitoring_type)
  SENSITIVE = []
  include Aws::Structure
end

#schedule_config ⇒ Types::ScheduleConfig

Configures the monitoring schedule.



43961
43962
43963
43964
43965
43966
43967
43968
# File 'lib/aws-sdk-sagemaker/types.rb', line 43961

class MonitoringScheduleConfig < Struct.new(
  :schedule_config,
  :monitoring_job_definition,
  :monitoring_job_definition_name,
  :monitoring_type)
  SENSITIVE = []
  include Aws::Structure
end