Class: Aws::SageMaker::Types::MonitoringScheduleSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::MonitoringScheduleSummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Summarizes the monitoring schedule.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Time
The creation time of the monitoring schedule.
-
#endpoint_name ⇒ String
The name of the endpoint using the monitoring schedule.
-
#last_modified_time ⇒ Time
The last time the monitoring schedule was modified.
-
#monitoring_job_definition_name ⇒ String
The name of the monitoring job definition that the schedule is for.
-
#monitoring_schedule_arn ⇒ String
The Amazon Resource Name (ARN) of the monitoring schedule.
-
#monitoring_schedule_name ⇒ String
The name of the monitoring schedule.
-
#monitoring_schedule_status ⇒ String
The status of the monitoring schedule.
-
#monitoring_type ⇒ String
The type of the monitoring job definition that the schedule is for.
Instance Attribute Details
#creation_time ⇒ Time
The creation time of the monitoring schedule.
43782 43783 43784 43785 43786 43787 43788 43789 43790 43791 43792 43793 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43782 class MonitoringScheduleSummary < Struct.new( :monitoring_schedule_name, :monitoring_schedule_arn, :creation_time, :last_modified_time, :monitoring_schedule_status, :endpoint_name, :monitoring_job_definition_name, :monitoring_type) SENSITIVE = [] include Aws::Structure end |
#endpoint_name ⇒ String
The name of the endpoint using the monitoring schedule.
43782 43783 43784 43785 43786 43787 43788 43789 43790 43791 43792 43793 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43782 class MonitoringScheduleSummary < Struct.new( :monitoring_schedule_name, :monitoring_schedule_arn, :creation_time, :last_modified_time, :monitoring_schedule_status, :endpoint_name, :monitoring_job_definition_name, :monitoring_type) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The last time the monitoring schedule was modified.
43782 43783 43784 43785 43786 43787 43788 43789 43790 43791 43792 43793 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43782 class MonitoringScheduleSummary < Struct.new( :monitoring_schedule_name, :monitoring_schedule_arn, :creation_time, :last_modified_time, :monitoring_schedule_status, :endpoint_name, :monitoring_job_definition_name, :monitoring_type) SENSITIVE = [] include Aws::Structure end |
#monitoring_job_definition_name ⇒ String
The name of the monitoring job definition that the schedule is for.
43782 43783 43784 43785 43786 43787 43788 43789 43790 43791 43792 43793 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43782 class MonitoringScheduleSummary < Struct.new( :monitoring_schedule_name, :monitoring_schedule_arn, :creation_time, :last_modified_time, :monitoring_schedule_status, :endpoint_name, :monitoring_job_definition_name, :monitoring_type) SENSITIVE = [] include Aws::Structure end |
#monitoring_schedule_arn ⇒ String
The Amazon Resource Name (ARN) of the monitoring schedule.
43782 43783 43784 43785 43786 43787 43788 43789 43790 43791 43792 43793 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43782 class MonitoringScheduleSummary < Struct.new( :monitoring_schedule_name, :monitoring_schedule_arn, :creation_time, :last_modified_time, :monitoring_schedule_status, :endpoint_name, :monitoring_job_definition_name, :monitoring_type) SENSITIVE = [] include Aws::Structure end |
#monitoring_schedule_name ⇒ String
The name of the monitoring schedule.
43782 43783 43784 43785 43786 43787 43788 43789 43790 43791 43792 43793 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43782 class MonitoringScheduleSummary < Struct.new( :monitoring_schedule_name, :monitoring_schedule_arn, :creation_time, :last_modified_time, :monitoring_schedule_status, :endpoint_name, :monitoring_job_definition_name, :monitoring_type) SENSITIVE = [] include Aws::Structure end |
#monitoring_schedule_status ⇒ String
The status of the monitoring schedule.
43782 43783 43784 43785 43786 43787 43788 43789 43790 43791 43792 43793 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43782 class MonitoringScheduleSummary < Struct.new( :monitoring_schedule_name, :monitoring_schedule_arn, :creation_time, :last_modified_time, :monitoring_schedule_status, :endpoint_name, :monitoring_job_definition_name, :monitoring_type) SENSITIVE = [] include Aws::Structure end |
#monitoring_type ⇒ String
The type of the monitoring job definition that the schedule is for.
43782 43783 43784 43785 43786 43787 43788 43789 43790 43791 43792 43793 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43782 class MonitoringScheduleSummary < Struct.new( :monitoring_schedule_name, :monitoring_schedule_arn, :creation_time, :last_modified_time, :monitoring_schedule_status, :endpoint_name, :monitoring_job_definition_name, :monitoring_type) SENSITIVE = [] include Aws::Structure end |