Class: Aws::SageMaker::Types::NeoVpcConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::NeoVpcConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The [VpcConfig] configuration object that specifies the VPC that you want the compilation jobs to connect to. For more information on controlling access to your Amazon S3 buckets used for compilation job, see [Give Amazon SageMaker AI Compilation Jobs Access to Resources in Your Amazon VPC].
[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_VpcConfig.html [2]: docs.aws.amazon.com/sagemaker/latest/dg/neo-vpc.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#security_group_ids ⇒ Array<String>
The VPC security group IDs.
-
#subnets ⇒ Array<String>
The ID of the subnets in the VPC that you want to connect the compilation job to for accessing the model in Amazon S3.
Instance Attribute Details
#security_group_ids ⇒ Array<String>
The VPC security group IDs. IDs have the form of sg-xxxxxxxx. Specify the security groups for the VPC that is specified in the Subnets field.
40604 40605 40606 40607 40608 40609 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40604 class NeoVpcConfig < Struct.new( :security_group_ids, :subnets) SENSITIVE = [] include Aws::Structure end |
#subnets ⇒ Array<String>
The ID of the subnets in the VPC that you want to connect the compilation job to for accessing the model in Amazon S3.
40604 40605 40606 40607 40608 40609 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40604 class NeoVpcConfig < Struct.new( :security_group_ids, :subnets) SENSITIVE = [] include Aws::Structure end |