Class: Aws::SageMaker::Types::NodeAdditionResult

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Information about a node that was successfully added to the cluster.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#availability_zonesArray<String>

The availability zones associated with the successfully added node.

Returns:

  • (Array<String>)


41016
41017
41018
41019
41020
41021
41022
41023
41024
# File 'lib/aws-sdk-sagemaker/types.rb', line 41016

class NodeAdditionResult < Struct.new(
  :node_logical_id,
  :instance_group_name,
  :status,
  :availability_zones,
  :instance_types)
  SENSITIVE = []
  include Aws::Structure
end

#instance_group_nameString

The name of the instance group to which the node was added.

Returns:

  • (String)


41016
41017
41018
41019
41020
41021
41022
41023
41024
# File 'lib/aws-sdk-sagemaker/types.rb', line 41016

class NodeAdditionResult < Struct.new(
  :node_logical_id,
  :instance_group_name,
  :status,
  :availability_zones,
  :instance_types)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typesArray<String>

The instance types associated with the successfully added node.

Returns:

  • (Array<String>)


41016
41017
41018
41019
41020
41021
41022
41023
41024
# File 'lib/aws-sdk-sagemaker/types.rb', line 41016

class NodeAdditionResult < Struct.new(
  :node_logical_id,
  :instance_group_name,
  :status,
  :availability_zones,
  :instance_types)
  SENSITIVE = []
  include Aws::Structure
end

#node_logical_idString

A unique identifier assigned to the node that can be used to track its provisioning status through the ‘DescribeClusterNode` operation.

Returns:

  • (String)


41016
41017
41018
41019
41020
41021
41022
41023
41024
# File 'lib/aws-sdk-sagemaker/types.rb', line 41016

class NodeAdditionResult < Struct.new(
  :node_logical_id,
  :instance_group_name,
  :status,
  :availability_zones,
  :instance_types)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the node. Possible values include ‘Pending`, `Running`, `Failed`, `ShuttingDown`, `SystemUpdating`, `DeepHealthCheckInProgress`, and `NotFound`.

Returns:

  • (String)


41016
41017
41018
41019
41020
41021
41022
41023
41024
# File 'lib/aws-sdk-sagemaker/types.rb', line 41016

class NodeAdditionResult < Struct.new(
  :node_logical_id,
  :instance_group_name,
  :status,
  :availability_zones,
  :instance_types)
  SENSITIVE = []
  include Aws::Structure
end