Class: Aws::SageMaker::Types::OnlineStoreConfigUpdate
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::OnlineStoreConfigUpdate
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Updates the feature group online store configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#storage_type ⇒ String
The online store storage type to migrate the feature group to.
-
#ttl_duration ⇒ Types::TtlDuration
Time to live duration, where the record is hard deleted after the expiration time is reached;
ExpiresAt=EventTime+TtlDuration.
Instance Attribute Details
#storage_type ⇒ String
The online store storage type to migrate the feature group to. Use
this parameter to migrate an existing feature group from Standard
to Standard_V2 storage format, enabling support for the
UpdateRecord operation. Migration is a one-way operation and
cannot be reversed.
44754 44755 44756 44757 44758 44759 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44754 class OnlineStoreConfigUpdate < Struct.new( :ttl_duration, :storage_type) SENSITIVE = [] include Aws::Structure end |
#ttl_duration ⇒ Types::TtlDuration
Time to live duration, where the record is hard deleted after the
expiration time is reached; ExpiresAt = EventTime +
TtlDuration. For information on HardDelete, see the
DeleteRecord API in the Amazon SageMaker API Reference guide.
44754 44755 44756 44757 44758 44759 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44754 class OnlineStoreConfigUpdate < Struct.new( :ttl_duration, :storage_type) SENSITIVE = [] include Aws::Structure end |