Class: Aws::SageMaker::Types::OnlineStoreSecurityConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::OnlineStoreSecurityConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The security configuration for OnlineStore.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#kms_key_id ⇒ String
The Amazon Web Services Key Management Service (KMS) key ARN that SageMaker Feature Store uses to encrypt the Amazon S3 objects at rest using Amazon S3 server-side encryption.
Instance Attribute Details
#kms_key_id ⇒ String
The Amazon Web Services Key Management Service (KMS) key ARN that SageMaker Feature Store uses to encrypt the Amazon S3 objects at rest using Amazon S3 server-side encryption.
The caller (either user or IAM role) of CreateFeatureGroup must
have below permissions to the OnlineStore KmsKeyId:
-
"kms:Encrypt" -
"kms:Decrypt" -
"kms:DescribeKey" -
"kms:CreateGrant" -
"kms:RetireGrant" -
"kms:ReEncryptFrom" -
"kms:ReEncryptTo" -
"kms:GenerateDataKey" -
"kms:ListAliases" -
"kms:ListGrants" -
"kms:RevokeGrant"
The caller (either user or IAM role) to all DataPlane operations
(PutRecord, GetRecord, DeleteRecord) must have the following
permissions to the KmsKeyId:
"kms:Decrypt"
^
44287 44288 44289 44290 44291 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44287 class OnlineStoreSecurityConfig < Struct.new( :kms_key_id) SENSITIVE = [] include Aws::Structure end |