Class: Aws::SageMaker::Types::OptimizationJobOutputConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::OptimizationJobOutputConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Details for where to store the optimized model that you create with the optimization job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#kms_key_id ⇒ String
The Amazon Resource Name (ARN) of a key in Amazon Web Services KMS.
-
#s3_output_location ⇒ String
The Amazon S3 URI for where to store the optimized model that you create with an optimization job.
-
#sage_maker_model ⇒ Types::OptimizationSageMakerModel
The name of a SageMaker model to use as the output destination for an optimization job.
Instance Attribute Details
#kms_key_id ⇒ String
The Amazon Resource Name (ARN) of a key in Amazon Web Services KMS. SageMaker uses they key to encrypt the artifacts of the optimized model when SageMaker uploads the model to Amazon S3.
44256 44257 44258 44259 44260 44261 44262 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44256 class OptimizationJobOutputConfig < Struct.new( :kms_key_id, :s3_output_location, :sage_maker_model) SENSITIVE = [] include Aws::Structure end |
#s3_output_location ⇒ String
The Amazon S3 URI for where to store the optimized model that you create with an optimization job.
44256 44257 44258 44259 44260 44261 44262 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44256 class OptimizationJobOutputConfig < Struct.new( :kms_key_id, :s3_output_location, :sage_maker_model) SENSITIVE = [] include Aws::Structure end |
#sage_maker_model ⇒ Types::OptimizationSageMakerModel
The name of a SageMaker model to use as the output destination for an optimization job.
44256 44257 44258 44259 44260 44261 44262 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44256 class OptimizationJobOutputConfig < Struct.new( :kms_key_id, :s3_output_location, :sage_maker_model) SENSITIVE = [] include Aws::Structure end |