Class: Aws::SageMaker::Types::OptimizationOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Output values produced by an optimization job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

The image that SageMaker recommends that you use to host the optimized model that you created with an optimization job.



45021
45022
45023
45024
45025
# File 'lib/aws-sdk-sagemaker/types.rb', line 45021

class OptimizationOutput < Struct.new(
  :recommended_inference_image)
  SENSITIVE = []
  include Aws::Structure
end