Class: Aws::SageMaker::Types::OutputDataConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Provides information about how to store model training results (model artifacts).

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#kms_key_idString

The Amazon Web Services Key Management Service (Amazon Web Services KMS) key that SageMaker uses to encrypt the model artifacts at rest using Amazon S3 server-side encryption. The KmsKeyId can be any of the following formats:

  • // KMS Key ID

    ‘“1234abcd-12ab-34cd-56ef-1234567890ab”`

  • // Amazon Resource Name (ARN) of a KMS Key

    ‘“arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab”`

  • // KMS Key Alias

    ‘“alias/ExampleAlias”`

  • // Amazon Resource Name (ARN) of a KMS Key Alias

    ‘“arn:aws:kms:us-west-2:111122223333:alias/ExampleAlias”`

If you use a KMS key ID or an alias of your KMS key, the SageMaker execution role must include permissions to call kms:Encrypt. If you don’t provide a KMS key ID, SageMaker uses the default KMS key for Amazon S3 for your role’s account. SageMaker uses server-side encryption with KMS-managed keys for OutputDataConfig. If you use a bucket policy with an s3:PutObject permission that only allows objects with server-side encryption, set the condition key of s3:x-amz-server-side-encryption to ‘“aws:kms”`. For more information, see [KMS-Managed Encryption Keys] in the *Amazon Simple Storage Service Developer Guide.*

The KMS key policy must grant permission to the IAM role that you specify in your CreateTrainingJob, CreateTransformJob, or CreateHyperParameterTuningJob requests. For more information, see

Using Key Policies in Amazon Web Services KMS][2

in the *Amazon

Web Services Key Management Service Developer Guide*.

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/UsingKMSEncryption.html [2]: docs.aws.amazon.com/kms/latest/developerguide/key-policies.html

Returns:

  • (String)


30059
30060
30061
30062
30063
30064
# File 'lib/aws-sdk-sagemaker/types.rb', line 30059

class OutputDataConfig < Struct.new(
  :kms_key_id,
  :s3_output_path)
  SENSITIVE = []
  include Aws::Structure
end

#s3_output_pathString

Identifies the S3 path where you want SageMaker to store the model artifacts. For example, s3://bucket-name/key-name-prefix.

Returns:

  • (String)


30059
30060
30061
30062
30063
30064
# File 'lib/aws-sdk-sagemaker/types.rb', line 30059

class OutputDataConfig < Struct.new(
  :kms_key_id,
  :s3_output_path)
  SENSITIVE = []
  include Aws::Structure
end