Class: Aws::SageMaker::Types::ParameterRanges
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ParameterRanges
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Specifies ranges of integer, continuous, and categorical hyperparameters that a hyperparameter tuning job searches. The hyperparameter tuning job launches training jobs with hyperparameter values within these ranges to find the combination of values that result in the training job with the best performance as measured by the objective metric of the hyperparameter tuning job.
<note markdown=“1”> The maximum number of items specified for ‘Array Members` refers to the maximum number of hyperparameters for each range and also the maximum for the hyperparameter tuning job itself. That is, the sum of the number of hyperparameters for all the ranges can’t exceed the maximum number specified.
</note>
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_parameters ⇒ Array<Types::AutoParameter>
A list containing hyperparameter names and example values to be used by Autotune to determine optimal ranges for your tuning job.
-
#categorical_parameter_ranges ⇒ Array<Types::CategoricalParameterRange>
The array of [CategoricalParameterRange] objects that specify ranges of categorical hyperparameters that a hyperparameter tuning job searches.
-
#continuous_parameter_ranges ⇒ Array<Types::ContinuousParameterRange>
The array of [ContinuousParameterRange] objects that specify ranges of continuous hyperparameters that a hyperparameter tuning job searches.
-
#integer_parameter_ranges ⇒ Array<Types::IntegerParameterRange>
The array of [IntegerParameterRange] objects that specify ranges of integer hyperparameters that a hyperparameter tuning job searches.
Instance Attribute Details
#auto_parameters ⇒ Array<Types::AutoParameter>
A list containing hyperparameter names and example values to be used by Autotune to determine optimal ranges for your tuning job.
44828 44829 44830 44831 44832 44833 44834 44835 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44828 class ParameterRanges < Struct.new( :integer_parameter_ranges, :continuous_parameter_ranges, :categorical_parameter_ranges, :auto_parameters) SENSITIVE = [] include Aws::Structure end |
#categorical_parameter_ranges ⇒ Array<Types::CategoricalParameterRange>
The array of [CategoricalParameterRange] objects that specify ranges of categorical hyperparameters that a hyperparameter tuning job searches.
[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_CategoricalParameterRange.html
44828 44829 44830 44831 44832 44833 44834 44835 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44828 class ParameterRanges < Struct.new( :integer_parameter_ranges, :continuous_parameter_ranges, :categorical_parameter_ranges, :auto_parameters) SENSITIVE = [] include Aws::Structure end |
#continuous_parameter_ranges ⇒ Array<Types::ContinuousParameterRange>
The array of [ContinuousParameterRange] objects that specify ranges of continuous hyperparameters that a hyperparameter tuning job searches.
[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_ContinuousParameterRange.html
44828 44829 44830 44831 44832 44833 44834 44835 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44828 class ParameterRanges < Struct.new( :integer_parameter_ranges, :continuous_parameter_ranges, :categorical_parameter_ranges, :auto_parameters) SENSITIVE = [] include Aws::Structure end |
#integer_parameter_ranges ⇒ Array<Types::IntegerParameterRange>
The array of [IntegerParameterRange] objects that specify ranges of integer hyperparameters that a hyperparameter tuning job searches.
[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_IntegerParameterRange.html
44828 44829 44830 44831 44832 44833 44834 44835 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44828 class ParameterRanges < Struct.new( :integer_parameter_ranges, :continuous_parameter_ranges, :categorical_parameter_ranges, :auto_parameters) SENSITIVE = [] include Aws::Structure end |