Class: Aws::SageMaker::Types::Phase

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Defines the traffic pattern.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#duration_in_secondsInteger

Specifies how long a traffic phase should be. For custom load tests, the value should be between 120 and 3600. This value should not exceed JobDurationInSeconds.



45809
45810
45811
45812
45813
45814
45815
# File 'lib/aws-sdk-sagemaker/types.rb', line 45809

class Phase < Struct.new(
  :initial_number_of_users,
  :spawn_rate,
  :duration_in_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#initial_number_of_usersInteger

Specifies how many concurrent users to start with. The value should be between 1 and 3.



45809
45810
45811
45812
45813
45814
45815
# File 'lib/aws-sdk-sagemaker/types.rb', line 45809

class Phase < Struct.new(
  :initial_number_of_users,
  :spawn_rate,
  :duration_in_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#spawn_rateInteger

Specified how many new users to spawn in a minute.



45809
45810
45811
45812
45813
45814
45815
# File 'lib/aws-sdk-sagemaker/types.rb', line 45809

class Phase < Struct.new(
  :initial_number_of_users,
  :spawn_rate,
  :duration_in_seconds)
  SENSITIVE = []
  include Aws::Structure
end