Class: Aws::SageMaker::Types::PrefixAwareRoutingConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The configuration for prefix-aware routing on a SageMaker real-time inference endpoint. Specify PrefixLength and ConcurrencyThreshold to control routing behavior.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#concurrency_thresholdInteger

The maximum number of in-flight requests on the target instance before the endpoint routes to another instance. Required when RoutingStrategy is PREFIX_AWARE. When in-flight requests on the prefix-selected instance reach this threshold, the endpoint routes the request to an instance with more available capacity.

Returns:

  • (Integer)


46223
46224
46225
46226
46227
46228
# File 'lib/aws-sdk-sagemaker/types.rb', line 46223

class PrefixAwareRoutingConfig < Struct.new(
  :prefix_length,
  :concurrency_threshold)
  SENSITIVE = []
  include Aws::Structure
end

#prefix_lengthInteger

The maximum length of the prefix used for routing decisions. Required when RoutingStrategy is PREFIX_AWARE.

  • For the SageMaker Runtime InvokeEndpoint and InvokeEndpointWithResponseStream APIs, this value specifies the number of bytes from the beginning of the request body.

  • For OpenAI-compatible API, this value specifies the number of characters from the text content of the messages array.

The endpoint routes requests that share the same prefix to the same instance. Set this value to cover shared content (such as system prompts) plus enough unique content to distribute workloads across instances.

Returns:

  • (Integer)


46223
46224
46225
46226
46227
46228
# File 'lib/aws-sdk-sagemaker/types.rb', line 46223

class PrefixAwareRoutingConfig < Struct.new(
  :prefix_length,
  :concurrency_threshold)
  SENSITIVE = []
  include Aws::Structure
end