Class: Aws::SageMaker::Types::ProcessingFeatureStoreOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Configuration for processing job outputs in Amazon SageMaker Feature Store.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#feature_group_nameString

The name of the Amazon SageMaker FeatureGroup to use as the destination for processing job output. Note that your processing script is responsible for putting records into your Feature Store.

Returns:



43095
43096
43097
43098
43099
# File 'lib/aws-sdk-sagemaker/types.rb', line 43095

class ProcessingFeatureStoreOutput < Struct.new(
  :feature_group_name)
  SENSITIVE = []
  include Aws::Structure
end