Class: Aws::SageMaker::Types::ProcessingInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The inputs for a processing job. The processing input must specify exactly one of either S3Input or DatasetDefinition types.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#app_managedBoolean

When True, input operations such as data download are managed natively by the processing job application. When False (default), input operations are managed by Amazon SageMaker.



46746
46747
46748
46749
46750
46751
46752
46753
# File 'lib/aws-sdk-sagemaker/types.rb', line 46746

class ProcessingInput < Struct.new(
  :input_name,
  :app_managed,
  :s3_input,
  :dataset_definition)
  SENSITIVE = []
  include Aws::Structure
end

#dataset_definitionTypes::DatasetDefinition

Configuration for a Dataset Definition input.



46746
46747
46748
46749
46750
46751
46752
46753
# File 'lib/aws-sdk-sagemaker/types.rb', line 46746

class ProcessingInput < Struct.new(
  :input_name,
  :app_managed,
  :s3_input,
  :dataset_definition)
  SENSITIVE = []
  include Aws::Structure
end

#input_nameString

The name for the processing job input.



46746
46747
46748
46749
46750
46751
46752
46753
# File 'lib/aws-sdk-sagemaker/types.rb', line 46746

class ProcessingInput < Struct.new(
  :input_name,
  :app_managed,
  :s3_input,
  :dataset_definition)
  SENSITIVE = []
  include Aws::Structure
end

#s3_inputTypes::ProcessingS3Input

Configuration for downloading input data from Amazon S3 into the processing container.



46746
46747
46748
46749
46750
46751
46752
46753
# File 'lib/aws-sdk-sagemaker/types.rb', line 46746

class ProcessingInput < Struct.new(
  :input_name,
  :app_managed,
  :s3_input,
  :dataset_definition)
  SENSITIVE = []
  include Aws::Structure
end