Class: Aws::SageMaker::Types::ProcessingOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ProcessingOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Describes the results of a processing job. The processing output must
specify exactly one of either S3Output or FeatureStoreOutput
types.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#app_managed ⇒ Boolean
When
True, output operations such as data upload are managed natively by the processing job application. -
#feature_store_output ⇒ Types::ProcessingFeatureStoreOutput
Configuration for processing job outputs in Amazon SageMaker Feature Store.
-
#output_name ⇒ String
The name for the processing job output.
-
#s3_output ⇒ Types::ProcessingS3Output
Configuration for processing job outputs in Amazon S3.
Instance Attribute Details
#app_managed ⇒ Boolean
When True, output operations such as data upload are managed
natively by the processing job application. When False (default),
output operations are managed by Amazon SageMaker.
47043 47044 47045 47046 47047 47048 47049 47050 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 47043 class ProcessingOutput < Struct.new( :output_name, :s3_output, :feature_store_output, :app_managed) SENSITIVE = [] include Aws::Structure end |
#feature_store_output ⇒ Types::ProcessingFeatureStoreOutput
Configuration for processing job outputs in Amazon SageMaker Feature
Store. This processing output type is only supported when
AppManaged is specified.
47043 47044 47045 47046 47047 47048 47049 47050 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 47043 class ProcessingOutput < Struct.new( :output_name, :s3_output, :feature_store_output, :app_managed) SENSITIVE = [] include Aws::Structure end |
#output_name ⇒ String
The name for the processing job output.
47043 47044 47045 47046 47047 47048 47049 47050 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 47043 class ProcessingOutput < Struct.new( :output_name, :s3_output, :feature_store_output, :app_managed) SENSITIVE = [] include Aws::Structure end |
#s3_output ⇒ Types::ProcessingS3Output
Configuration for processing job outputs in Amazon S3.
47043 47044 47045 47046 47047 47048 47049 47050 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 47043 class ProcessingOutput < Struct.new( :output_name, :s3_output, :feature_store_output, :app_managed) SENSITIVE = [] include Aws::Structure end |