Class: Aws::SageMaker::Types::ProductionVariantCapacityReservationSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ProductionVariantCapacityReservationSummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Details about an ML capacity reservation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#available_instance_count ⇒ Integer
The number of instances that are currently available in the ML capacity reservation.
-
#capacity_reservation_preference ⇒ String
The option that you chose for the capacity reservation.
-
#ec2_capacity_reservations ⇒ Array<Types::Ec2CapacityReservation>
The EC2 capacity reservations that are shared to this ML capacity reservation, if any.
-
#ml_reservation_arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the ML capacity reservation that SageMaker AI applies when it deploys the endpoint.
-
#total_instance_count ⇒ Integer
The number of instances that you allocated to the ML capacity reservation.
-
#used_by_current_endpoint ⇒ Integer
The number of instances from the ML capacity reservation that are being used by the endpoint.
Instance Attribute Details
#available_instance_count ⇒ Integer
The number of instances that are currently available in the ML capacity reservation.
43788 43789 43790 43791 43792 43793 43794 43795 43796 43797 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43788 class ProductionVariantCapacityReservationSummary < Struct.new( :ml_reservation_arn, :capacity_reservation_preference, :total_instance_count, :available_instance_count, :used_by_current_endpoint, :ec2_capacity_reservations) SENSITIVE = [] include Aws::Structure end |
#capacity_reservation_preference ⇒ String
The option that you chose for the capacity reservation. SageMaker AI supports the following options:
capacity-reservations-only
: SageMaker AI launches instances only into an ML capacity
reservation. If no capacity is available, the instances fail to
launch.
43788 43789 43790 43791 43792 43793 43794 43795 43796 43797 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43788 class ProductionVariantCapacityReservationSummary < Struct.new( :ml_reservation_arn, :capacity_reservation_preference, :total_instance_count, :available_instance_count, :used_by_current_endpoint, :ec2_capacity_reservations) SENSITIVE = [] include Aws::Structure end |
#ec2_capacity_reservations ⇒ Array<Types::Ec2CapacityReservation>
The EC2 capacity reservations that are shared to this ML capacity reservation, if any.
43788 43789 43790 43791 43792 43793 43794 43795 43796 43797 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43788 class ProductionVariantCapacityReservationSummary < Struct.new( :ml_reservation_arn, :capacity_reservation_preference, :total_instance_count, :available_instance_count, :used_by_current_endpoint, :ec2_capacity_reservations) SENSITIVE = [] include Aws::Structure end |
#ml_reservation_arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the ML capacity reservation that SageMaker AI applies when it deploys the endpoint.
43788 43789 43790 43791 43792 43793 43794 43795 43796 43797 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43788 class ProductionVariantCapacityReservationSummary < Struct.new( :ml_reservation_arn, :capacity_reservation_preference, :total_instance_count, :available_instance_count, :used_by_current_endpoint, :ec2_capacity_reservations) SENSITIVE = [] include Aws::Structure end |
#total_instance_count ⇒ Integer
The number of instances that you allocated to the ML capacity reservation.
43788 43789 43790 43791 43792 43793 43794 43795 43796 43797 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43788 class ProductionVariantCapacityReservationSummary < Struct.new( :ml_reservation_arn, :capacity_reservation_preference, :total_instance_count, :available_instance_count, :used_by_current_endpoint, :ec2_capacity_reservations) SENSITIVE = [] include Aws::Structure end |
#used_by_current_endpoint ⇒ Integer
The number of instances from the ML capacity reservation that are being used by the endpoint.
43788 43789 43790 43791 43792 43793 43794 43795 43796 43797 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43788 class ProductionVariantCapacityReservationSummary < Struct.new( :ml_reservation_arn, :capacity_reservation_preference, :total_instance_count, :available_instance_count, :used_by_current_endpoint, :ec2_capacity_reservations) SENSITIVE = [] include Aws::Structure end |