Class: Aws::SageMaker::Types::ProductionVariantSummary

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Describes weight and capacities for a production variant associated with an endpoint. If you sent a request to the UpdateEndpointWeightsAndCapacities API and the endpoint status is Updating, you get different desired and current values.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_reservation_config ⇒ Types::ProductionVariantCapacityReservationSummary

Settings for the capacity reservation for the compute instances that SageMaker AI reserves for an endpoint.



47819
47820
47821
47822
47823
47824
47825
47826
47827
47828
47829
47830
47831
47832
47833
47834
47835
# File 'lib/aws-sdk-sagemaker/types.rb', line 47819

class ProductionVariantSummary < Struct.new(
  :variant_name,
  :deployed_images,
  :current_weight,
  :desired_weight,
  :current_instance_count,
  :desired_instance_count,
  :instance_pools,
  :variant_status,
  :current_serverless_config,
  :desired_serverless_config,
  :managed_instance_scaling,
  :routing_config,
  :capacity_reservation_config)
  SENSITIVE = []
  include Aws::Structure
end

#current_instance_count ⇒ Integer

The number of instances associated with the variant.

Returns:

  • (Integer)


47819
47820
47821
47822
47823
47824
47825
47826
47827
47828
47829
47830
47831
47832
47833
47834
47835
# File 'lib/aws-sdk-sagemaker/types.rb', line 47819

class ProductionVariantSummary < Struct.new(
  :variant_name,
  :deployed_images,
  :current_weight,
  :desired_weight,
  :current_instance_count,
  :desired_instance_count,
  :instance_pools,
  :variant_status,
  :current_serverless_config,
  :desired_serverless_config,
  :managed_instance_scaling,
  :routing_config,
  :capacity_reservation_config)
  SENSITIVE = []
  include Aws::Structure
end

#current_serverless_config ⇒ Types::ProductionVariantServerlessConfig

The serverless configuration for the endpoint.



47819
47820
47821
47822
47823
47824
47825
47826
47827
47828
47829
47830
47831
47832
47833
47834
47835
# File 'lib/aws-sdk-sagemaker/types.rb', line 47819

class ProductionVariantSummary < Struct.new(
  :variant_name,
  :deployed_images,
  :current_weight,
  :desired_weight,
  :current_instance_count,
  :desired_instance_count,
  :instance_pools,
  :variant_status,
  :current_serverless_config,
  :desired_serverless_config,
  :managed_instance_scaling,
  :routing_config,
  :capacity_reservation_config)
  SENSITIVE = []
  include Aws::Structure
end

#current_weight ⇒ Float

The weight associated with the variant.

Returns:

  • (Float)


47819
47820
47821
47822
47823
47824
47825
47826
47827
47828
47829
47830
47831
47832
47833
47834
47835
# File 'lib/aws-sdk-sagemaker/types.rb', line 47819

class ProductionVariantSummary < Struct.new(
  :variant_name,
  :deployed_images,
  :current_weight,
  :desired_weight,
  :current_instance_count,
  :desired_instance_count,
  :instance_pools,
  :variant_status,
  :current_serverless_config,
  :desired_serverless_config,
  :managed_instance_scaling,
  :routing_config,
  :capacity_reservation_config)
  SENSITIVE = []
  include Aws::Structure
end

#deployed_images ⇒ Array<Types::DeployedImage>

An array of DeployedImage objects that specify the Amazon EC2 Container Registry paths of the inference images deployed on instances of this ProductionVariant.

Returns:



47819
47820
47821
47822
47823
47824
47825
47826
47827
47828
47829
47830
47831
47832
47833
47834
47835
# File 'lib/aws-sdk-sagemaker/types.rb', line 47819

class ProductionVariantSummary < Struct.new(
  :variant_name,
  :deployed_images,
  :current_weight,
  :desired_weight,
  :current_instance_count,
  :desired_instance_count,
  :instance_pools,
  :variant_status,
  :current_serverless_config,
  :desired_serverless_config,
  :managed_instance_scaling,
  :routing_config,
  :capacity_reservation_config)
  SENSITIVE = []
  include Aws::Structure
end

#desired_instance_count ⇒ Integer

The number of instances requested in the UpdateEndpointWeightsAndCapacities request.

Returns:

  • (Integer)


47819
47820
47821
47822
47823
47824
47825
47826
47827
47828
47829
47830
47831
47832
47833
47834
47835
# File 'lib/aws-sdk-sagemaker/types.rb', line 47819

class ProductionVariantSummary < Struct.new(
  :variant_name,
  :deployed_images,
  :current_weight,
  :desired_weight,
  :current_instance_count,
  :desired_instance_count,
  :instance_pools,
  :variant_status,
  :current_serverless_config,
  :desired_serverless_config,
  :managed_instance_scaling,
  :routing_config,
  :capacity_reservation_config)
  SENSITIVE = []
  include Aws::Structure
end

#desired_serverless_config ⇒ Types::ProductionVariantServerlessConfig

The serverless configuration requested for the endpoint update.



47819
47820
47821
47822
47823
47824
47825
47826
47827
47828
47829
47830
47831
47832
47833
47834
47835
# File 'lib/aws-sdk-sagemaker/types.rb', line 47819

class ProductionVariantSummary < Struct.new(
  :variant_name,
  :deployed_images,
  :current_weight,
  :desired_weight,
  :current_instance_count,
  :desired_instance_count,
  :instance_pools,
  :variant_status,
  :current_serverless_config,
  :desired_serverless_config,
  :managed_instance_scaling,
  :routing_config,
  :capacity_reservation_config)
  SENSITIVE = []
  include Aws::Structure
end

#desired_weight ⇒ Float

The requested weight, as specified in the UpdateEndpointWeightsAndCapacities request.

Returns:

  • (Float)


47819
47820
47821
47822
47823
47824
47825
47826
47827
47828
47829
47830
47831
47832
47833
47834
47835
# File 'lib/aws-sdk-sagemaker/types.rb', line 47819

class ProductionVariantSummary < Struct.new(
  :variant_name,
  :deployed_images,
  :current_weight,
  :desired_weight,
  :current_instance_count,
  :desired_instance_count,
  :instance_pools,
  :variant_status,
  :current_serverless_config,
  :desired_serverless_config,
  :managed_instance_scaling,
  :routing_config,
  :capacity_reservation_config)
  SENSITIVE = []
  include Aws::Structure
end

#instance_pools ⇒ Array<Types::InstancePoolSummary>

A list of instance pools for the production variant. Each pool indicates the instance type and the current number of instances of that type.

Returns:



47819
47820
47821
47822
47823
47824
47825
47826
47827
47828
47829
47830
47831
47832
47833
47834
47835
# File 'lib/aws-sdk-sagemaker/types.rb', line 47819

class ProductionVariantSummary < Struct.new(
  :variant_name,
  :deployed_images,
  :current_weight,
  :desired_weight,
  :current_instance_count,
  :desired_instance_count,
  :instance_pools,
  :variant_status,
  :current_serverless_config,
  :desired_serverless_config,
  :managed_instance_scaling,
  :routing_config,
  :capacity_reservation_config)
  SENSITIVE = []
  include Aws::Structure
end

#managed_instance_scaling ⇒ Types::ProductionVariantManagedInstanceScaling

Settings that control the range in the number of instances that the endpoint provisions as it scales up or down to accommodate traffic.



47819
47820
47821
47822
47823
47824
47825
47826
47827
47828
47829
47830
47831
47832
47833
47834
47835
# File 'lib/aws-sdk-sagemaker/types.rb', line 47819

class ProductionVariantSummary < Struct.new(
  :variant_name,
  :deployed_images,
  :current_weight,
  :desired_weight,
  :current_instance_count,
  :desired_instance_count,
  :instance_pools,
  :variant_status,
  :current_serverless_config,
  :desired_serverless_config,
  :managed_instance_scaling,
  :routing_config,
  :capacity_reservation_config)
  SENSITIVE = []
  include Aws::Structure
end

#routing_config ⇒ Types::ProductionVariantRoutingConfig

Settings that control how the endpoint routes incoming traffic to the instances that the endpoint hosts.



47819
47820
47821
47822
47823
47824
47825
47826
47827
47828
47829
47830
47831
47832
47833
47834
47835
# File 'lib/aws-sdk-sagemaker/types.rb', line 47819

class ProductionVariantSummary < Struct.new(
  :variant_name,
  :deployed_images,
  :current_weight,
  :desired_weight,
  :current_instance_count,
  :desired_instance_count,
  :instance_pools,
  :variant_status,
  :current_serverless_config,
  :desired_serverless_config,
  :managed_instance_scaling,
  :routing_config,
  :capacity_reservation_config)
  SENSITIVE = []
  include Aws::Structure
end

#variant_name ⇒ String

The name of the variant.

Returns:

  • (String)


47819
47820
47821
47822
47823
47824
47825
47826
47827
47828
47829
47830
47831
47832
47833
47834
47835
# File 'lib/aws-sdk-sagemaker/types.rb', line 47819

class ProductionVariantSummary < Struct.new(
  :variant_name,
  :deployed_images,
  :current_weight,
  :desired_weight,
  :current_instance_count,
  :desired_instance_count,
  :instance_pools,
  :variant_status,
  :current_serverless_config,
  :desired_serverless_config,
  :managed_instance_scaling,
  :routing_config,
  :capacity_reservation_config)
  SENSITIVE = []
  include Aws::Structure
end

#variant_status ⇒ Array<Types::ProductionVariantStatus>

The endpoint variant status which describes the current deployment stage status or operational status.

Returns:



47819
47820
47821
47822
47823
47824
47825
47826
47827
47828
47829
47830
47831
47832
47833
47834
47835
# File 'lib/aws-sdk-sagemaker/types.rb', line 47819

class ProductionVariantSummary < Struct.new(
  :variant_name,
  :deployed_images,
  :current_weight,
  :desired_weight,
  :current_instance_count,
  :desired_instance_count,
  :instance_pools,
  :variant_status,
  :current_serverless_config,
  :desired_serverless_config,
  :managed_instance_scaling,
  :routing_config,
  :capacity_reservation_config)
  SENSITIVE = []
  include Aws::Structure
end