Class: Aws::SageMaker::Types::Project
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::Project
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The properties of a project as returned by the Search API.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_by ⇒ Types::UserContext
Who created the project.
-
#creation_time ⇒ Time
A timestamp specifying when the project was created.
-
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
-
#last_modified_time ⇒ Time
A timestamp container for when the project was last modified.
-
#project_arn ⇒ String
The Amazon Resource Name (ARN) of the project.
-
#project_description ⇒ String
The description of the project.
-
#project_id ⇒ String
The ID of the project.
-
#project_name ⇒ String
The name of the project.
-
#project_status ⇒ String
The status of the project.
-
#service_catalog_provisioned_product_details ⇒ Types::ServiceCatalogProvisionedProductDetails
Details of a provisioned service catalog product.
-
#service_catalog_provisioning_details ⇒ Types::ServiceCatalogProvisioningDetails
Details that you specify to provision a service catalog product.
-
#tags ⇒ Array<Types::Tag>
An array of key-value pairs.
-
#template_provider_details ⇒ Array<Types::TemplateProviderDetail>
An array of template providers associated with the project.
Instance Attribute Details
#created_by ⇒ Types::UserContext
Who created the project.
47969 47970 47971 47972 47973 47974 47975 47976 47977 47978 47979 47980 47981 47982 47983 47984 47985 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 47969 class Project < Struct.new( :project_arn, :project_name, :project_id, :project_description, :service_catalog_provisioning_details, :service_catalog_provisioned_product_details, :project_status, :created_by, :creation_time, :template_provider_details, :tags, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
A timestamp specifying when the project was created.
47969 47970 47971 47972 47973 47974 47975 47976 47977 47978 47979 47980 47981 47982 47983 47984 47985 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 47969 class Project < Struct.new( :project_arn, :project_name, :project_id, :project_description, :service_catalog_provisioning_details, :service_catalog_provisioned_product_details, :project_status, :created_by, :creation_time, :template_provider_details, :tags, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
47969 47970 47971 47972 47973 47974 47975 47976 47977 47978 47979 47980 47981 47982 47983 47984 47985 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 47969 class Project < Struct.new( :project_arn, :project_name, :project_id, :project_description, :service_catalog_provisioning_details, :service_catalog_provisioned_product_details, :project_status, :created_by, :creation_time, :template_provider_details, :tags, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
A timestamp container for when the project was last modified.
47969 47970 47971 47972 47973 47974 47975 47976 47977 47978 47979 47980 47981 47982 47983 47984 47985 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 47969 class Project < Struct.new( :project_arn, :project_name, :project_id, :project_description, :service_catalog_provisioning_details, :service_catalog_provisioned_product_details, :project_status, :created_by, :creation_time, :template_provider_details, :tags, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#project_arn ⇒ String
The Amazon Resource Name (ARN) of the project.
47969 47970 47971 47972 47973 47974 47975 47976 47977 47978 47979 47980 47981 47982 47983 47984 47985 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 47969 class Project < Struct.new( :project_arn, :project_name, :project_id, :project_description, :service_catalog_provisioning_details, :service_catalog_provisioned_product_details, :project_status, :created_by, :creation_time, :template_provider_details, :tags, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#project_description ⇒ String
The description of the project.
47969 47970 47971 47972 47973 47974 47975 47976 47977 47978 47979 47980 47981 47982 47983 47984 47985 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 47969 class Project < Struct.new( :project_arn, :project_name, :project_id, :project_description, :service_catalog_provisioning_details, :service_catalog_provisioned_product_details, :project_status, :created_by, :creation_time, :template_provider_details, :tags, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#project_id ⇒ String
The ID of the project.
47969 47970 47971 47972 47973 47974 47975 47976 47977 47978 47979 47980 47981 47982 47983 47984 47985 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 47969 class Project < Struct.new( :project_arn, :project_name, :project_id, :project_description, :service_catalog_provisioning_details, :service_catalog_provisioned_product_details, :project_status, :created_by, :creation_time, :template_provider_details, :tags, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#project_name ⇒ String
The name of the project.
47969 47970 47971 47972 47973 47974 47975 47976 47977 47978 47979 47980 47981 47982 47983 47984 47985 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 47969 class Project < Struct.new( :project_arn, :project_name, :project_id, :project_description, :service_catalog_provisioning_details, :service_catalog_provisioned_product_details, :project_status, :created_by, :creation_time, :template_provider_details, :tags, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#project_status ⇒ String
The status of the project.
47969 47970 47971 47972 47973 47974 47975 47976 47977 47978 47979 47980 47981 47982 47983 47984 47985 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 47969 class Project < Struct.new( :project_arn, :project_name, :project_id, :project_description, :service_catalog_provisioning_details, :service_catalog_provisioned_product_details, :project_status, :created_by, :creation_time, :template_provider_details, :tags, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#service_catalog_provisioned_product_details ⇒ Types::ServiceCatalogProvisionedProductDetails
Details of a provisioned service catalog product. For information about service catalog, see What is Amazon Web Services Service Catalog.
47969 47970 47971 47972 47973 47974 47975 47976 47977 47978 47979 47980 47981 47982 47983 47984 47985 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 47969 class Project < Struct.new( :project_arn, :project_name, :project_id, :project_description, :service_catalog_provisioning_details, :service_catalog_provisioned_product_details, :project_status, :created_by, :creation_time, :template_provider_details, :tags, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#service_catalog_provisioning_details ⇒ Types::ServiceCatalogProvisioningDetails
Details that you specify to provision a service catalog product. For information about service catalog, see What is Amazon Web Services Service Catalog.
47969 47970 47971 47972 47973 47974 47975 47976 47977 47978 47979 47980 47981 47982 47983 47984 47985 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 47969 class Project < Struct.new( :project_arn, :project_name, :project_id, :project_description, :service_catalog_provisioning_details, :service_catalog_provisioned_product_details, :project_status, :created_by, :creation_time, :template_provider_details, :tags, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
An array of key-value pairs. You can use tags to categorize your Amazon Web Services resources in different ways, for example, by purpose, owner, or environment. For more information, see Tagging Amazon Web Services Resources.
47969 47970 47971 47972 47973 47974 47975 47976 47977 47978 47979 47980 47981 47982 47983 47984 47985 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 47969 class Project < Struct.new( :project_arn, :project_name, :project_id, :project_description, :service_catalog_provisioning_details, :service_catalog_provisioned_product_details, :project_status, :created_by, :creation_time, :template_provider_details, :tags, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#template_provider_details ⇒ Array<Types::TemplateProviderDetail>
An array of template providers associated with the project.
47969 47970 47971 47972 47973 47974 47975 47976 47977 47978 47979 47980 47981 47982 47983 47984 47985 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 47969 class Project < Struct.new( :project_arn, :project_name, :project_id, :project_description, :service_catalog_provisioning_details, :service_catalog_provisioned_product_details, :project_status, :created_by, :creation_time, :template_provider_details, :tags, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |