Class: Aws::SageMaker::Types::QueryFilters
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::QueryFilters
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
A set of filters to narrow the set of lineage entities connected to the StartArn(s) returned by the QueryLineage API action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_after ⇒ Time
Filter the lineage entities connected to the
StartArn(s) after the create date. -
#created_before ⇒ Time
Filter the lineage entities connected to the
StartArn(s) by created date. -
#lineage_types ⇒ Array<String>
Filter the lineage entities connected to the
StartArn(s) by the type of the lineage entity. -
#modified_after ⇒ Time
Filter the lineage entities connected to the
StartArn(s) after the last modified date. -
#modified_before ⇒ Time
Filter the lineage entities connected to the
StartArn(s) before the last modified date. -
#properties ⇒ Hash<String,String>
Filter the lineage entities connected to the
StartArn(s) by a set if property key value pairs. -
#types ⇒ Array<String>
Filter the lineage entities connected to the
StartArnby type.
Instance Attribute Details
#created_after ⇒ Time
Filter the lineage entities connected to the StartArn(s) after the create date.
44819 44820 44821 44822 44823 44824 44825 44826 44827 44828 44829 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44819 class QueryFilters < Struct.new( :types, :lineage_types, :created_before, :created_after, :modified_before, :modified_after, :properties) SENSITIVE = [] include Aws::Structure end |
#created_before ⇒ Time
Filter the lineage entities connected to the StartArn(s) by created date.
44819 44820 44821 44822 44823 44824 44825 44826 44827 44828 44829 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44819 class QueryFilters < Struct.new( :types, :lineage_types, :created_before, :created_after, :modified_before, :modified_after, :properties) SENSITIVE = [] include Aws::Structure end |
#lineage_types ⇒ Array<String>
Filter the lineage entities connected to the StartArn(s) by the type of the lineage entity.
44819 44820 44821 44822 44823 44824 44825 44826 44827 44828 44829 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44819 class QueryFilters < Struct.new( :types, :lineage_types, :created_before, :created_after, :modified_before, :modified_after, :properties) SENSITIVE = [] include Aws::Structure end |
#modified_after ⇒ Time
Filter the lineage entities connected to the StartArn(s) after the last modified date.
44819 44820 44821 44822 44823 44824 44825 44826 44827 44828 44829 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44819 class QueryFilters < Struct.new( :types, :lineage_types, :created_before, :created_after, :modified_before, :modified_after, :properties) SENSITIVE = [] include Aws::Structure end |
#modified_before ⇒ Time
Filter the lineage entities connected to the StartArn(s) before the last modified date.
44819 44820 44821 44822 44823 44824 44825 44826 44827 44828 44829 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44819 class QueryFilters < Struct.new( :types, :lineage_types, :created_before, :created_after, :modified_before, :modified_after, :properties) SENSITIVE = [] include Aws::Structure end |
#properties ⇒ Hash<String,String>
Filter the lineage entities connected to the StartArn(s) by a set if property key value pairs. If multiple pairs are provided, an entity is included in the results if it matches any of the provided pairs.
44819 44820 44821 44822 44823 44824 44825 44826 44827 44828 44829 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44819 class QueryFilters < Struct.new( :types, :lineage_types, :created_before, :created_after, :modified_before, :modified_after, :properties) SENSITIVE = [] include Aws::Structure end |
#types ⇒ Array<String>
Filter the lineage entities connected to the StartArn by type. For example: DataSet, Model, Endpoint, or ModelDeployment.
44819 44820 44821 44822 44823 44824 44825 44826 44827 44828 44829 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44819 class QueryFilters < Struct.new( :types, :lineage_types, :created_before, :created_after, :modified_before, :modified_after, :properties) SENSITIVE = [] include Aws::Structure end |