Class: Aws::SageMaker::Types::QueryLineageResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#edges ⇒ Array<Types::Edge>

A list of edges that connect vertices in the response.

Returns:



48664
48665
48666
48667
48668
48669
48670
# File 'lib/aws-sdk-sagemaker/types.rb', line 48664

class QueryLineageResponse < Struct.new(
  :vertices,
  :edges,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

Limits the number of vertices in the response. Use the NextToken in a response to to retrieve the next page of results.

Returns:

  • (String)


48664
48665
48666
48667
48668
48669
48670
# File 'lib/aws-sdk-sagemaker/types.rb', line 48664

class QueryLineageResponse < Struct.new(
  :vertices,
  :edges,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#vertices ⇒ Array<Types::Vertex>

A list of vertices connected to the start entity(ies) in the lineage graph.

Returns:



48664
48665
48666
48667
48668
48669
48670
# File 'lib/aws-sdk-sagemaker/types.rb', line 48664

class QueryLineageResponse < Struct.new(
  :vertices,
  :edges,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end