Class: Aws::SageMaker::Types::RSessionAppSettings

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

A collection of settings that apply to an RSessionGateway app.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#custom_imagesArray<Types::CustomImage>

A list of custom SageMaker AI images that are configured to run as a RSession app.

Returns:



48299
48300
48301
48302
48303
48304
# File 'lib/aws-sdk-sagemaker/types.rb', line 48299

class RSessionAppSettings < Struct.new(
  :default_resource_spec,
  :custom_images)
  SENSITIVE = []
  include Aws::Structure
end

#default_resource_specTypes::ResourceSpec

Specifies the ARN's of a SageMaker AI image and SageMaker AI image version, and the instance type that the version runs on.

When both SageMakerImageVersionArn and SageMakerImageArn are passed, SageMakerImageVersionArn is used. Any updates to SageMakerImageArn will not take effect if SageMakerImageVersionArn already exists in the ResourceSpec because SageMakerImageVersionArn always takes precedence. To clear the value set for SageMakerImageVersionArn, pass None as the value.

Returns:



48299
48300
48301
48302
48303
48304
# File 'lib/aws-sdk-sagemaker/types.rb', line 48299

class RSessionAppSettings < Struct.new(
  :default_resource_spec,
  :custom_images)
  SENSITIVE = []
  include Aws::Structure
end