Class: Aws::SageMaker::Types::RStudioServerProAppSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::RStudioServerProAppSettings
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
A collection of settings that configure user interaction with the RStudioServerPro app.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_status ⇒ String
Indicates whether the current user has access to the
RStudioServerProapp. -
#user_group ⇒ String
The level of permissions that the user has within the
RStudioServerProapp.
Instance Attribute Details
#access_status ⇒ String
Indicates whether the current user has access to the RStudioServerPro app.
44972 44973 44974 44975 44976 44977 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44972 class RStudioServerProAppSettings < Struct.new( :access_status, :user_group) SENSITIVE = [] include Aws::Structure end |
#user_group ⇒ String
The level of permissions that the user has within the RStudioServerPro app. This value defaults to User. The Admin value allows the user access to the RStudio Administrative Dashboard.
44972 44973 44974 44975 44976 44977 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44972 class RStudioServerProAppSettings < Struct.new( :access_status, :user_group) SENSITIVE = [] include Aws::Structure end |