Class: Aws::SageMaker::Types::RecommendationJobStoppingConditions
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::RecommendationJobStoppingConditions
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Specifies conditions for stopping a job. When a job reaches a stopping condition limit, SageMaker ends the job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#flat_invocations ⇒ String
Stops a load test when the number of invocations (TPS) peaks and flattens, which means that the instance has reached capacity.
-
#max_invocations ⇒ Integer
The maximum number of requests per minute expected for the endpoint.
-
#model_latency_thresholds ⇒ Array<Types::ModelLatencyThreshold>
The interval of time taken by a model to respond as viewed from SageMaker.
Instance Attribute Details
#flat_invocations ⇒ String
Stops a load test when the number of invocations (TPS) peaks and
flattens, which means that the instance has reached capacity. The
default value is Stop. If you want the load test to continue after
invocations have flattened, set the value to Continue.
48788 48789 48790 48791 48792 48793 48794 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 48788 class RecommendationJobStoppingConditions < Struct.new( :max_invocations, :model_latency_thresholds, :flat_invocations) SENSITIVE = [] include Aws::Structure end |
#max_invocations ⇒ Integer
The maximum number of requests per minute expected for the endpoint.
48788 48789 48790 48791 48792 48793 48794 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 48788 class RecommendationJobStoppingConditions < Struct.new( :max_invocations, :model_latency_thresholds, :flat_invocations) SENSITIVE = [] include Aws::Structure end |
#model_latency_thresholds ⇒ Array<Types::ModelLatencyThreshold>
The interval of time taken by a model to respond as viewed from SageMaker. The interval includes the local communication time taken to send the request and to fetch the response from the container of a model and the time taken to complete the inference in the container.
48788 48789 48790 48791 48792 48793 48794 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 48788 class RecommendationJobStoppingConditions < Struct.new( :max_invocations, :model_latency_thresholds, :flat_invocations) SENSITIVE = [] include Aws::Structure end |