Class: Aws::SageMaker::Types::RecommendationMetrics

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The metrics of recommendations.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cost_per_hourFloat

Defines the cost per hour for the instance.



49307
49308
49309
49310
49311
49312
49313
49314
49315
49316
49317
# File 'lib/aws-sdk-sagemaker/types.rb', line 49307

class RecommendationMetrics < Struct.new(
  :cost_per_hour,
  :cost_per_inference,
  :max_invocations,
  :model_latency,
  :cpu_utilization,
  :memory_utilization,
  :model_setup_time)
  SENSITIVE = []
  include Aws::Structure
end

#cost_per_inferenceFloat

Defines the cost per inference for the instance .



49307
49308
49309
49310
49311
49312
49313
49314
49315
49316
49317
# File 'lib/aws-sdk-sagemaker/types.rb', line 49307

class RecommendationMetrics < Struct.new(
  :cost_per_hour,
  :cost_per_inference,
  :max_invocations,
  :model_latency,
  :cpu_utilization,
  :memory_utilization,
  :model_setup_time)
  SENSITIVE = []
  include Aws::Structure
end

#cpu_utilizationFloat

The expected CPU utilization at maximum invocations per minute for the instance.

NaN indicates that the value is not available.



49307
49308
49309
49310
49311
49312
49313
49314
49315
49316
49317
# File 'lib/aws-sdk-sagemaker/types.rb', line 49307

class RecommendationMetrics < Struct.new(
  :cost_per_hour,
  :cost_per_inference,
  :max_invocations,
  :model_latency,
  :cpu_utilization,
  :memory_utilization,
  :model_setup_time)
  SENSITIVE = []
  include Aws::Structure
end

#max_invocationsInteger

The expected maximum number of requests per minute for the instance.



49307
49308
49309
49310
49311
49312
49313
49314
49315
49316
49317
# File 'lib/aws-sdk-sagemaker/types.rb', line 49307

class RecommendationMetrics < Struct.new(
  :cost_per_hour,
  :cost_per_inference,
  :max_invocations,
  :model_latency,
  :cpu_utilization,
  :memory_utilization,
  :model_setup_time)
  SENSITIVE = []
  include Aws::Structure
end

#memory_utilizationFloat

The expected memory utilization at maximum invocations per minute for the instance.

NaN indicates that the value is not available.



49307
49308
49309
49310
49311
49312
49313
49314
49315
49316
49317
# File 'lib/aws-sdk-sagemaker/types.rb', line 49307

class RecommendationMetrics < Struct.new(
  :cost_per_hour,
  :cost_per_inference,
  :max_invocations,
  :model_latency,
  :cpu_utilization,
  :memory_utilization,
  :model_setup_time)
  SENSITIVE = []
  include Aws::Structure
end

#model_latencyInteger

The expected model latency at maximum invocation per minute for the instance.



49307
49308
49309
49310
49311
49312
49313
49314
49315
49316
49317
# File 'lib/aws-sdk-sagemaker/types.rb', line 49307

class RecommendationMetrics < Struct.new(
  :cost_per_hour,
  :cost_per_inference,
  :max_invocations,
  :model_latency,
  :cpu_utilization,
  :memory_utilization,
  :model_setup_time)
  SENSITIVE = []
  include Aws::Structure
end

#model_setup_timeInteger

The time it takes to launch new compute resources for a serverless endpoint. The time can vary depending on the model size, how long it takes to download the model, and the start-up time of the container.

NaN indicates that the value is not available.



49307
49308
49309
49310
49311
49312
49313
49314
49315
49316
49317
# File 'lib/aws-sdk-sagemaker/types.rb', line 49307

class RecommendationMetrics < Struct.new(
  :cost_per_hour,
  :cost_per_inference,
  :max_invocations,
  :model_latency,
  :cpu_utilization,
  :memory_utilization,
  :model_setup_time)
  SENSITIVE = []
  include Aws::Structure
end