Class: Aws::SageMaker::Types::RemoteDebugConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Configuration for remote debugging for the CreateTrainingJob API. To learn more about the remote debugging functionality of SageMaker, see Access a training container through Amazon Web Services Systems Manager (SSM) for remote debugging.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enable_remote_debugBoolean

If set to True, enables remote debugging.



49429
49430
49431
49432
49433
# File 'lib/aws-sdk-sagemaker/types.rb', line 49429

class RemoteDebugConfig < Struct.new(
  :enable_remote_debug)
  SENSITIVE = []
  include Aws::Structure
end