Class: Aws::SageMaker::Types::RenderUiTemplateResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#errorsArray<Types::RenderingError>

A list of one or more ‘RenderingError` objects if any were encountered while rendering the template. If there were no errors, the list is empty.

Returns:



48724
48725
48726
48727
48728
48729
# File 'lib/aws-sdk-sagemaker/types.rb', line 48724

class RenderUiTemplateResponse < Struct.new(
  :rendered_content,
  :errors)
  SENSITIVE = []
  include Aws::Structure
end

#rendered_contentString

A Liquid template that renders the HTML for the worker UI.

Returns:

  • (String)


48724
48725
48726
48727
48728
48729
# File 'lib/aws-sdk-sagemaker/types.rb', line 48724

class RenderUiTemplateResponse < Struct.new(
  :rendered_content,
  :errors)
  SENSITIVE = []
  include Aws::Structure
end