Class: Aws::SageMaker::Types::RepositoryAuthConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::RepositoryAuthConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Specifies an authentication configuration for the private docker registry where your model image is hosted. Specify a value for this property only if you specified Vpc as the value for the RepositoryAccessMode field of the ImageConfig object that you passed to a call to CreateModel and the private Docker registry where the model image is hosted requires authentication.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#repository_credentials_provider_arn ⇒ String
The Amazon Resource Name (ARN) of an Amazon Web Services Lambda function that provides credentials to authenticate to the private Docker registry where your model image is hosted.
Instance Attribute Details
#repository_credentials_provider_arn ⇒ String
The Amazon Resource Name (ARN) of an Amazon Web Services Lambda function that provides credentials to authenticate to the private Docker registry where your model image is hosted. For information about how to create an Amazon Web Services Lambda function, see
- Create a Lambda function with the console][1
-
in the *Amazon Web
Services Lambda Developer Guide*.
[1]: docs.aws.amazon.com/lambda/latest/dg/getting-started-create-function.html
45723 45724 45725 45726 45727 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 45723 class RepositoryAuthConfig < Struct.new( :repository_credentials_provider_arn) SENSITIVE = [] include Aws::Structure end |