Class: Aws::SageMaker::Types::RetentionPolicy
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::RetentionPolicy
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The retention policy for data stored on an Amazon Elastic File System volume.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#home_efs_file_system ⇒ String
The default is
Retain, which specifies to keep the data stored on the Amazon EFS volume.
Instance Attribute Details
#home_efs_file_system ⇒ String
The default is Retain, which specifies to keep the data stored on
the Amazon EFS volume.
Specify Delete to delete the data stored on the Amazon EFS volume.
49734 49735 49736 49737 49738 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49734 class RetentionPolicy < Struct.new( :home_efs_file_system) SENSITIVE = [] include Aws::Structure end |