Class: Aws::SageMaker::Types::RetryStrategy

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The retry strategy to use when a training job fails due to an InternalServerError. RetryStrategy is specified as part of the CreateTrainingJob and CreateHyperParameterTuningJob requests. You can add the StoppingCondition parameter to the request to limit the training time for the complete job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#maximum_retry_attemptsInteger

The number of times to retry the job. When the job is retried, it’s SecondaryStatus is changed to STARTING.

Returns:



46421
46422
46423
46424
46425
# File 'lib/aws-sdk-sagemaker/types.rb', line 46421

class RetryStrategy < Struct.new(
  :maximum_retry_attempts)
  SENSITIVE = []
  include Aws::Structure
end