Class: Aws::SageMaker::Types::RoleGroupAssignment

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Defines the mapping between an in-app role and the Amazon Web Services IAM Identity Center group patterns that should be assigned to that role within the SageMaker Partner AI App.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#group_patternsArray<String>

A list of Amazon Web Services IAM Identity Center group patterns that should be assigned to the specified role. Group patterns support wildcard matching using ‘*`.

Returns:

  • (Array<String>)


46444
46445
46446
46447
46448
46449
# File 'lib/aws-sdk-sagemaker/types.rb', line 46444

class RoleGroupAssignment < Struct.new(
  :role_name,
  :group_patterns)
  SENSITIVE = []
  include Aws::Structure
end

#role_nameString

The name of the in-app role within the SageMaker Partner AI App. The specific roles available depend on the app type and version.

Returns:

  • (String)


46444
46445
46446
46447
46448
46449
# File 'lib/aws-sdk-sagemaker/types.rb', line 46444

class RoleGroupAssignment < Struct.new(
  :role_name,
  :group_patterns)
  SENSITIVE = []
  include Aws::Structure
end