Class: Aws::SageMaker::Types::RollingUpdatePolicy

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Specifies a rolling deployment strategy for updating a SageMaker endpoint.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#maximum_batch_sizeTypes::CapacitySize

Batch size for each rolling step to provision capacity and turn on traffic on the new endpoint fleet, and terminate capacity on the old endpoint fleet. Value must be between 5% to 50% of the variant’s total instance count.

Returns:



48457
48458
48459
48460
48461
48462
48463
48464
# File 'lib/aws-sdk-sagemaker/types.rb', line 48457

class RollingUpdatePolicy < Struct.new(
  :maximum_batch_size,
  :wait_interval_in_seconds,
  :maximum_execution_timeout_in_seconds,
  :rollback_maximum_batch_size)
  SENSITIVE = []
  include Aws::Structure
end

#maximum_execution_timeout_in_secondsInteger

The time limit for the total deployment. Exceeding this limit causes a timeout.

Returns:

  • (Integer)


48457
48458
48459
48460
48461
48462
48463
48464
# File 'lib/aws-sdk-sagemaker/types.rb', line 48457

class RollingUpdatePolicy < Struct.new(
  :maximum_batch_size,
  :wait_interval_in_seconds,
  :maximum_execution_timeout_in_seconds,
  :rollback_maximum_batch_size)
  SENSITIVE = []
  include Aws::Structure
end

#rollback_maximum_batch_sizeTypes::CapacitySize

Batch size for rollback to the old endpoint fleet. Each rolling step to provision capacity and turn on traffic on the old endpoint fleet, and terminate capacity on the new endpoint fleet. If this field is absent, the default value will be set to 100% of total capacity which means to bring up the whole capacity of the old fleet at once during rollback.

Returns:



48457
48458
48459
48460
48461
48462
48463
48464
# File 'lib/aws-sdk-sagemaker/types.rb', line 48457

class RollingUpdatePolicy < Struct.new(
  :maximum_batch_size,
  :wait_interval_in_seconds,
  :maximum_execution_timeout_in_seconds,
  :rollback_maximum_batch_size)
  SENSITIVE = []
  include Aws::Structure
end

#wait_interval_in_secondsInteger

The length of the baking period, during which SageMaker monitors alarms for each batch on the new fleet.

Returns:

  • (Integer)


48457
48458
48459
48460
48461
48462
48463
48464
# File 'lib/aws-sdk-sagemaker/types.rb', line 48457

class RollingUpdatePolicy < Struct.new(
  :maximum_batch_size,
  :wait_interval_in_seconds,
  :maximum_execution_timeout_in_seconds,
  :rollback_maximum_batch_size)
  SENSITIVE = []
  include Aws::Structure
end