Class: Aws::SageMaker::Types::S3StorageConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The Amazon Simple Storage (Amazon S3) location and security configuration for OfflineStore.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#kms_key_id ⇒ String

The Amazon Web Services Key Management Service (KMS) key ARN of the key used to encrypt any objects written into the OfflineStore S3 location.

The IAM roleARN that is passed as a parameter to CreateFeatureGroup must have below permissions to the KmsKeyId:

  • "kms:GenerateDataKey"

^

Returns:

  • (String)


50677
50678
50679
50680
50681
50682
50683
# File 'lib/aws-sdk-sagemaker/types.rb', line 50677

class S3StorageConfig < Struct.new(
  :s3_uri,
  :kms_key_id,
  :resolved_output_s3_uri)
  SENSITIVE = []
  include Aws::Structure
end

#resolved_output_s3_uri ⇒ String

The S3 path where offline records are written.

Returns:

  • (String)


50677
50678
50679
50680
50681
50682
50683
# File 'lib/aws-sdk-sagemaker/types.rb', line 50677

class S3StorageConfig < Struct.new(
  :s3_uri,
  :kms_key_id,
  :resolved_output_s3_uri)
  SENSITIVE = []
  include Aws::Structure
end

#s3_uri ⇒ String

The S3 URI, or location in Amazon S3, of OfflineStore.

S3 URIs have a format similar to the following: s3://example-bucket/prefix/.

Returns:

  • (String)


50677
50678
50679
50680
50681
50682
50683
# File 'lib/aws-sdk-sagemaker/types.rb', line 50677

class S3StorageConfig < Struct.new(
  :s3_uri,
  :kms_key_id,
  :resolved_output_s3_uri)
  SENSITIVE = []
  include Aws::Structure
end