Class: Aws::SageMaker::Types::ScalingPolicyMetric
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ScalingPolicyMetric
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The metric for a scaling policy.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#invocations_per_instance ⇒ Integer
The number of invocations sent to a model, normalized by
InstanceCountin each ProductionVariant. -
#model_latency ⇒ Integer
The interval of time taken by a model to respond as viewed from SageMaker.
Instance Attribute Details
#invocations_per_instance ⇒ Integer
The number of invocations sent to a model, normalized by
InstanceCount in each ProductionVariant. 1/numberOfInstances is
sent as the value on each request, where numberOfInstances is the
number of active instances for the ProductionVariant behind the
endpoint at the time of the request.
50380 50381 50382 50383 50384 50385 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 50380 class ScalingPolicyMetric < Struct.new( :invocations_per_instance, :model_latency) SENSITIVE = [] include Aws::Structure end |
#model_latency ⇒ Integer
The interval of time taken by a model to respond as viewed from SageMaker. This interval includes the local communication times taken to send the request and to fetch the response from the container of a model and the time taken to complete the inference in the container.
50380 50381 50382 50383 50384 50385 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 50380 class ScalingPolicyMetric < Struct.new( :invocations_per_instance, :model_latency) SENSITIVE = [] include Aws::Structure end |