Class: Aws::SageMaker::Types::SchedulerConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Cluster policy configuration. This policy is used for task prioritization and fair-share allocation. This helps prioritize critical workloads and distributes idle compute across entities.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#fair_shareString

When enabled, entities borrow idle compute based on their assigned FairShareWeight.

When disabled, entities borrow idle compute based on a first-come first-serve basis.

Default is Enabled.



50898
50899
50900
50901
50902
50903
50904
# File 'lib/aws-sdk-sagemaker/types.rb', line 50898

class SchedulerConfig < Struct.new(
  :priority_classes,
  :fair_share,
  :idle_resource_sharing)
  SENSITIVE = []
  include Aws::Structure
end

#idle_resource_sharingString

Configuration for sharing idle compute resources across entities in the cluster. When enabled, unallocated resources are automatically calculated and made available for entities to borrow.



50898
50899
50900
50901
50902
50903
50904
# File 'lib/aws-sdk-sagemaker/types.rb', line 50898

class SchedulerConfig < Struct.new(
  :priority_classes,
  :fair_share,
  :idle_resource_sharing)
  SENSITIVE = []
  include Aws::Structure
end

#priority_classesArray<Types::PriorityClass>

List of the priority classes, PriorityClass, of the cluster policy. When specified, these class configurations define how tasks are queued.



50898
50899
50900
50901
50902
50903
50904
# File 'lib/aws-sdk-sagemaker/types.rb', line 50898

class SchedulerConfig < Struct.new(
  :priority_classes,
  :fair_share,
  :idle_resource_sharing)
  SENSITIVE = []
  include Aws::Structure
end