Class: Aws::SageMaker::Types::SearchRecord
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::SearchRecord
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
A single resource returned as part of the [Search] API response.
[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_Search.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#endpoint ⇒ Types::Endpoint
A hosted endpoint for real-time inference.
-
#experiment ⇒ Types::Experiment
The properties of an experiment.
-
#feature_group ⇒ Types::FeatureGroup
Amazon SageMaker Feature Store stores features in a collection called Feature Group.
-
#feature_metadata ⇒ Types::FeatureMetadata
The feature metadata used to search through the features.
-
#hyper_parameter_tuning_job ⇒ Types::HyperParameterTuningJobSearchEntity
The properties of a hyperparameter tuning job.
-
#model ⇒ Types::ModelDashboardModel
A model displayed in the Amazon SageMaker Model Dashboard.
-
#model_card ⇒ Types::ModelCard
An Amazon SageMaker Model Card that documents details about a machine learning model.
-
#model_package ⇒ Types::ModelPackage
A container for your trained model that can be deployed for SageMaker inference.
-
#model_package_group ⇒ Types::ModelPackageGroup
A group of versioned models in the Model Registry.
-
#pipeline ⇒ Types::Pipeline
A SageMaker Model Building Pipeline instance.
-
#pipeline_execution ⇒ Types::PipelineExecution
An execution of a pipeline.
-
#pipeline_version ⇒ Types::PipelineVersion
The version of the pipeline.
-
#project ⇒ Types::Project
The properties of a project.
-
#training_job ⇒ Types::TrainingJob
The properties of a training job.
-
#trial ⇒ Types::Trial
The properties of a trial.
-
#trial_component ⇒ Types::TrialComponent
The properties of a trial component.
Instance Attribute Details
#endpoint ⇒ Types::Endpoint
A hosted endpoint for real-time inference.
47172 47173 47174 47175 47176 47177 47178 47179 47180 47181 47182 47183 47184 47185 47186 47187 47188 47189 47190 47191 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 47172 class SearchRecord < Struct.new( :training_job, :experiment, :trial, :trial_component, :endpoint, :model_package, :model_package_group, :pipeline, :pipeline_execution, :pipeline_version, :feature_group, :feature_metadata, :project, :hyper_parameter_tuning_job, :model_card, :model) SENSITIVE = [] include Aws::Structure end |
#experiment ⇒ Types::Experiment
The properties of an experiment.
47172 47173 47174 47175 47176 47177 47178 47179 47180 47181 47182 47183 47184 47185 47186 47187 47188 47189 47190 47191 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 47172 class SearchRecord < Struct.new( :training_job, :experiment, :trial, :trial_component, :endpoint, :model_package, :model_package_group, :pipeline, :pipeline_execution, :pipeline_version, :feature_group, :feature_metadata, :project, :hyper_parameter_tuning_job, :model_card, :model) SENSITIVE = [] include Aws::Structure end |
#feature_group ⇒ Types::FeatureGroup
Amazon SageMaker Feature Store stores features in a collection called Feature Group. A Feature Group can be visualized as a table which has rows, with a unique identifier for each row where each column in the table is a feature. In principle, a Feature Group is composed of features and values per features.
47172 47173 47174 47175 47176 47177 47178 47179 47180 47181 47182 47183 47184 47185 47186 47187 47188 47189 47190 47191 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 47172 class SearchRecord < Struct.new( :training_job, :experiment, :trial, :trial_component, :endpoint, :model_package, :model_package_group, :pipeline, :pipeline_execution, :pipeline_version, :feature_group, :feature_metadata, :project, :hyper_parameter_tuning_job, :model_card, :model) SENSITIVE = [] include Aws::Structure end |
#feature_metadata ⇒ Types::FeatureMetadata
The feature metadata used to search through the features.
47172 47173 47174 47175 47176 47177 47178 47179 47180 47181 47182 47183 47184 47185 47186 47187 47188 47189 47190 47191 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 47172 class SearchRecord < Struct.new( :training_job, :experiment, :trial, :trial_component, :endpoint, :model_package, :model_package_group, :pipeline, :pipeline_execution, :pipeline_version, :feature_group, :feature_metadata, :project, :hyper_parameter_tuning_job, :model_card, :model) SENSITIVE = [] include Aws::Structure end |
#hyper_parameter_tuning_job ⇒ Types::HyperParameterTuningJobSearchEntity
The properties of a hyperparameter tuning job.
47172 47173 47174 47175 47176 47177 47178 47179 47180 47181 47182 47183 47184 47185 47186 47187 47188 47189 47190 47191 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 47172 class SearchRecord < Struct.new( :training_job, :experiment, :trial, :trial_component, :endpoint, :model_package, :model_package_group, :pipeline, :pipeline_execution, :pipeline_version, :feature_group, :feature_metadata, :project, :hyper_parameter_tuning_job, :model_card, :model) SENSITIVE = [] include Aws::Structure end |
#model ⇒ Types::ModelDashboardModel
A model displayed in the Amazon SageMaker Model Dashboard.
47172 47173 47174 47175 47176 47177 47178 47179 47180 47181 47182 47183 47184 47185 47186 47187 47188 47189 47190 47191 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 47172 class SearchRecord < Struct.new( :training_job, :experiment, :trial, :trial_component, :endpoint, :model_package, :model_package_group, :pipeline, :pipeline_execution, :pipeline_version, :feature_group, :feature_metadata, :project, :hyper_parameter_tuning_job, :model_card, :model) SENSITIVE = [] include Aws::Structure end |
#model_card ⇒ Types::ModelCard
An Amazon SageMaker Model Card that documents details about a machine learning model.
47172 47173 47174 47175 47176 47177 47178 47179 47180 47181 47182 47183 47184 47185 47186 47187 47188 47189 47190 47191 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 47172 class SearchRecord < Struct.new( :training_job, :experiment, :trial, :trial_component, :endpoint, :model_package, :model_package_group, :pipeline, :pipeline_execution, :pipeline_version, :feature_group, :feature_metadata, :project, :hyper_parameter_tuning_job, :model_card, :model) SENSITIVE = [] include Aws::Structure end |
#model_package ⇒ Types::ModelPackage
A container for your trained model that can be deployed for SageMaker inference. This can include inference code, artifacts, and metadata. The model package type can be one of the following.
-
Versioned model: A part of a model package group in Model Registry.
-
Unversioned model: Not part of a model package group and used in Amazon Web Services Marketplace.
For more information, see [ CreateModelPackage ][1].
[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateModelPackage.html
47172 47173 47174 47175 47176 47177 47178 47179 47180 47181 47182 47183 47184 47185 47186 47187 47188 47189 47190 47191 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 47172 class SearchRecord < Struct.new( :training_job, :experiment, :trial, :trial_component, :endpoint, :model_package, :model_package_group, :pipeline, :pipeline_execution, :pipeline_version, :feature_group, :feature_metadata, :project, :hyper_parameter_tuning_job, :model_card, :model) SENSITIVE = [] include Aws::Structure end |
#model_package_group ⇒ Types::ModelPackageGroup
A group of versioned models in the Model Registry.
47172 47173 47174 47175 47176 47177 47178 47179 47180 47181 47182 47183 47184 47185 47186 47187 47188 47189 47190 47191 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 47172 class SearchRecord < Struct.new( :training_job, :experiment, :trial, :trial_component, :endpoint, :model_package, :model_package_group, :pipeline, :pipeline_execution, :pipeline_version, :feature_group, :feature_metadata, :project, :hyper_parameter_tuning_job, :model_card, :model) SENSITIVE = [] include Aws::Structure end |
#pipeline ⇒ Types::Pipeline
A SageMaker Model Building Pipeline instance.
47172 47173 47174 47175 47176 47177 47178 47179 47180 47181 47182 47183 47184 47185 47186 47187 47188 47189 47190 47191 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 47172 class SearchRecord < Struct.new( :training_job, :experiment, :trial, :trial_component, :endpoint, :model_package, :model_package_group, :pipeline, :pipeline_execution, :pipeline_version, :feature_group, :feature_metadata, :project, :hyper_parameter_tuning_job, :model_card, :model) SENSITIVE = [] include Aws::Structure end |
#pipeline_execution ⇒ Types::PipelineExecution
An execution of a pipeline.
47172 47173 47174 47175 47176 47177 47178 47179 47180 47181 47182 47183 47184 47185 47186 47187 47188 47189 47190 47191 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 47172 class SearchRecord < Struct.new( :training_job, :experiment, :trial, :trial_component, :endpoint, :model_package, :model_package_group, :pipeline, :pipeline_execution, :pipeline_version, :feature_group, :feature_metadata, :project, :hyper_parameter_tuning_job, :model_card, :model) SENSITIVE = [] include Aws::Structure end |
#pipeline_version ⇒ Types::PipelineVersion
The version of the pipeline.
47172 47173 47174 47175 47176 47177 47178 47179 47180 47181 47182 47183 47184 47185 47186 47187 47188 47189 47190 47191 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 47172 class SearchRecord < Struct.new( :training_job, :experiment, :trial, :trial_component, :endpoint, :model_package, :model_package_group, :pipeline, :pipeline_execution, :pipeline_version, :feature_group, :feature_metadata, :project, :hyper_parameter_tuning_job, :model_card, :model) SENSITIVE = [] include Aws::Structure end |
#project ⇒ Types::Project
The properties of a project.
47172 47173 47174 47175 47176 47177 47178 47179 47180 47181 47182 47183 47184 47185 47186 47187 47188 47189 47190 47191 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 47172 class SearchRecord < Struct.new( :training_job, :experiment, :trial, :trial_component, :endpoint, :model_package, :model_package_group, :pipeline, :pipeline_execution, :pipeline_version, :feature_group, :feature_metadata, :project, :hyper_parameter_tuning_job, :model_card, :model) SENSITIVE = [] include Aws::Structure end |
#training_job ⇒ Types::TrainingJob
The properties of a training job.
47172 47173 47174 47175 47176 47177 47178 47179 47180 47181 47182 47183 47184 47185 47186 47187 47188 47189 47190 47191 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 47172 class SearchRecord < Struct.new( :training_job, :experiment, :trial, :trial_component, :endpoint, :model_package, :model_package_group, :pipeline, :pipeline_execution, :pipeline_version, :feature_group, :feature_metadata, :project, :hyper_parameter_tuning_job, :model_card, :model) SENSITIVE = [] include Aws::Structure end |
#trial ⇒ Types::Trial
The properties of a trial.
47172 47173 47174 47175 47176 47177 47178 47179 47180 47181 47182 47183 47184 47185 47186 47187 47188 47189 47190 47191 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 47172 class SearchRecord < Struct.new( :training_job, :experiment, :trial, :trial_component, :endpoint, :model_package, :model_package_group, :pipeline, :pipeline_execution, :pipeline_version, :feature_group, :feature_metadata, :project, :hyper_parameter_tuning_job, :model_card, :model) SENSITIVE = [] include Aws::Structure end |
#trial_component ⇒ Types::TrialComponent
The properties of a trial component.
47172 47173 47174 47175 47176 47177 47178 47179 47180 47181 47182 47183 47184 47185 47186 47187 47188 47189 47190 47191 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 47172 class SearchRecord < Struct.new( :training_job, :experiment, :trial, :trial_component, :endpoint, :model_package, :model_package_group, :pipeline, :pipeline_execution, :pipeline_version, :feature_group, :feature_metadata, :project, :hyper_parameter_tuning_job, :model_card, :model) SENSITIVE = [] include Aws::Structure end |