Class: Aws::SageMaker::Types::SearchResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

If the result of the previous Search request was truncated, the response includes a NextToken. To retrieve the next set of results, use the token in the next request.

Returns:



47354
47355
47356
47357
47358
47359
47360
# File 'lib/aws-sdk-sagemaker/types.rb', line 47354

class SearchResponse < Struct.new(
  :results,
  :next_token,
  :total_hits)
  SENSITIVE = []
  include Aws::Structure
end

#resultsArray<Types::SearchRecord>

A list of SearchRecord objects.

Returns:



47354
47355
47356
47357
47358
47359
47360
# File 'lib/aws-sdk-sagemaker/types.rb', line 47354

class SearchResponse < Struct.new(
  :results,
  :next_token,
  :total_hits)
  SENSITIVE = []
  include Aws::Structure
end

#total_hitsTypes::TotalHits

The total number of matching results.

Returns:



47354
47355
47356
47357
47358
47359
47360
# File 'lib/aws-sdk-sagemaker/types.rb', line 47354

class SearchResponse < Struct.new(
  :results,
  :next_token,
  :total_hits)
  SENSITIVE = []
  include Aws::Structure
end