Class: Aws::SageMaker::Types::SelectiveExecutionConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::SelectiveExecutionConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The selective execution configuration applied to the pipeline run.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#selected_steps ⇒ Array<Types::SelectedStep>
A list of pipeline steps to run.
-
#source_pipeline_execution_arn ⇒ String
The ARN from a reference execution of the current pipeline.
Instance Attribute Details
#selected_steps ⇒ Array<Types::SelectedStep>
A list of pipeline steps to run. All step(s) in all path(s) between two selected steps should be included.
42573 42574 42575 42576 42577 42578 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42573 class SelectiveExecutionConfig < Struct.new( :source_pipeline_execution_arn, :selected_steps) SENSITIVE = [] include Aws::Structure end |
#source_pipeline_execution_arn ⇒ String
The ARN from a reference execution of the current pipeline. Used to copy input collaterals needed for the selected steps to run. The execution status of the pipeline can be either Failed or Success.
This field is required if the steps you specify for SelectedSteps depend on output collaterals from any non-specified pipeline steps. For more information, see [Selective Execution for Pipeline Steps].
[1]: docs.aws.amazon.com/sagemaker/latest/dg/pipelines-selective-ex.html
42573 42574 42575 42576 42577 42578 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42573 class SelectiveExecutionConfig < Struct.new( :source_pipeline_execution_arn, :selected_steps) SENSITIVE = [] include Aws::Structure end |