Class: Aws::SageMaker::Types::SharingSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::SharingSettings
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Specifies options for sharing Amazon SageMaker AI Studio notebooks.
These settings are specified as part of DefaultUserSettings when the
CreateDomain API is called, and as part of UserSettings when the
CreateUserProfile API is called. When SharingSettings is not
specified, notebook sharing isn't allowed.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#notebook_output_option ⇒ String
Whether to include the notebook cell output when sharing the notebook.
-
#s3_kms_key_id ⇒ String
When
NotebookOutputOptionisAllowed, the Amazon Web Services Key Management Service (KMS) encryption key ID used to encrypt the notebook cell output in the Amazon S3 bucket. -
#s3_output_path ⇒ String
When
NotebookOutputOptionisAllowed, the Amazon S3 bucket used to store the shared notebook snapshots.
Instance Attribute Details
#notebook_output_option ⇒ String
Whether to include the notebook cell output when sharing the
notebook. The default is Disabled.
51838 51839 51840 51841 51842 51843 51844 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 51838 class SharingSettings < Struct.new( :notebook_output_option, :s3_output_path, :s3_kms_key_id) SENSITIVE = [] include Aws::Structure end |
#s3_kms_key_id ⇒ String
When NotebookOutputOption is Allowed, the Amazon Web Services
Key Management Service (KMS) encryption key ID used to encrypt the
notebook cell output in the Amazon S3 bucket.
51838 51839 51840 51841 51842 51843 51844 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 51838 class SharingSettings < Struct.new( :notebook_output_option, :s3_output_path, :s3_kms_key_id) SENSITIVE = [] include Aws::Structure end |
#s3_output_path ⇒ String
When NotebookOutputOption is Allowed, the Amazon S3 bucket used
to store the shared notebook snapshots.
51838 51839 51840 51841 51842 51843 51844 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 51838 class SharingSettings < Struct.new( :notebook_output_option, :s3_output_path, :s3_kms_key_id) SENSITIVE = [] include Aws::Structure end |