Class: Aws::SageMaker::Types::Stairs

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Defines the stairs traffic pattern for an Inference Recommender load test. This pattern type consists of multiple steps where the number of users increases at each step.

Specify either the stairs or phases traffic pattern.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#duration_in_secondsInteger

Defines how long each traffic step should be.

Returns:

  • (Integer)


48432
48433
48434
48435
48436
48437
48438
# File 'lib/aws-sdk-sagemaker/types.rb', line 48432

class Stairs < Struct.new(
  :duration_in_seconds,
  :number_of_steps,
  :users_per_step)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_stepsInteger

Specifies how many steps to perform during traffic.

Returns:

  • (Integer)


48432
48433
48434
48435
48436
48437
48438
# File 'lib/aws-sdk-sagemaker/types.rb', line 48432

class Stairs < Struct.new(
  :duration_in_seconds,
  :number_of_steps,
  :users_per_step)
  SENSITIVE = []
  include Aws::Structure
end

#users_per_stepInteger

Specifies how many new users to spawn in each step.

Returns:

  • (Integer)


48432
48433
48434
48435
48436
48437
48438
# File 'lib/aws-sdk-sagemaker/types.rb', line 48432

class Stairs < Struct.new(
  :duration_in_seconds,
  :number_of_steps,
  :users_per_step)
  SENSITIVE = []
  include Aws::Structure
end