Class: Aws::SageMaker::Types::StartClusterHealthCheckRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_nameString

The string name or the Amazon Resource Name (ARN) of the SageMaker HyperPod cluster.

Returns:

  • (String)


48808
48809
48810
48811
48812
48813
# File 'lib/aws-sdk-sagemaker/types.rb', line 48808

class StartClusterHealthCheckRequest < Struct.new(
  :cluster_name,
  :deep_health_check_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#deep_health_check_configurationsArray<Types::InstanceGroupHealthCheckConfiguration>

A list of configurations containing instance group names, EC2 instance IDs, and deep health checks to perform.



48808
48809
48810
48811
48812
48813
# File 'lib/aws-sdk-sagemaker/types.rb', line 48808

class StartClusterHealthCheckRequest < Struct.new(
  :cluster_name,
  :deep_health_check_configurations)
  SENSITIVE = []
  include Aws::Structure
end