Class: Aws::SageMaker::Types::StopInferenceExperimentRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#desired_model_variantsArray<Types::ModelVariantConfig>

An array of ModelVariantConfig objects. There is one for each variant that you want to deploy after the inference experiment stops. Each ModelVariantConfig describes the infrastructure configuration for deploying the corresponding variant.

Returns:



52152
52153
52154
52155
52156
52157
52158
52159
52160
# File 'lib/aws-sdk-sagemaker/types.rb', line 52152

class StopInferenceExperimentRequest < Struct.new(
  :name,
  :model_variant_actions,
  :desired_model_variants,
  :desired_state,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end

#desired_stateString

The desired state of the experiment after stopping. The possible states are the following:

  • Completed: The experiment completed successfully

  • Cancelled: The experiment was canceled

Returns:

  • (String)


52152
52153
52154
52155
52156
52157
52158
52159
52160
# File 'lib/aws-sdk-sagemaker/types.rb', line 52152

class StopInferenceExperimentRequest < Struct.new(
  :name,
  :model_variant_actions,
  :desired_model_variants,
  :desired_state,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end

#model_variant_actionsHash<String,String>

Array of key-value pairs, with names of variants mapped to actions. The possible actions are the following:

  • Promote - Promote the shadow variant to a production variant

  • Remove - Delete the variant

  • Retain - Keep the variant as it is

Returns:

  • (Hash<String,String>)


52152
52153
52154
52155
52156
52157
52158
52159
52160
# File 'lib/aws-sdk-sagemaker/types.rb', line 52152

class StopInferenceExperimentRequest < Struct.new(
  :name,
  :model_variant_actions,
  :desired_model_variants,
  :desired_state,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the inference experiment to stop.

Returns:

  • (String)


52152
52153
52154
52155
52156
52157
52158
52159
52160
# File 'lib/aws-sdk-sagemaker/types.rb', line 52152

class StopInferenceExperimentRequest < Struct.new(
  :name,
  :model_variant_actions,
  :desired_model_variants,
  :desired_state,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end

#reasonString

The reason for stopping the experiment.

Returns:

  • (String)


52152
52153
52154
52155
52156
52157
52158
52159
52160
# File 'lib/aws-sdk-sagemaker/types.rb', line 52152

class StopInferenceExperimentRequest < Struct.new(
  :name,
  :model_variant_actions,
  :desired_model_variants,
  :desired_state,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end