Class: Aws::SageMaker::Types::SubscribedWorkteam

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Describes a work team of a vendor that does the labelling job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#listing_idString

Marketplace product listing ID.

Returns:

  • (String)


51858
51859
51860
51861
51862
51863
51864
51865
51866
# File 'lib/aws-sdk-sagemaker/types.rb', line 51858

class SubscribedWorkteam < Struct.new(
  :workteam_arn,
  :marketplace_title,
  :seller_name,
  :marketplace_description,
  :listing_id)
  SENSITIVE = []
  include Aws::Structure
end

#marketplace_descriptionString

The description of the vendor from the Amazon Marketplace.

Returns:

  • (String)


51858
51859
51860
51861
51862
51863
51864
51865
51866
# File 'lib/aws-sdk-sagemaker/types.rb', line 51858

class SubscribedWorkteam < Struct.new(
  :workteam_arn,
  :marketplace_title,
  :seller_name,
  :marketplace_description,
  :listing_id)
  SENSITIVE = []
  include Aws::Structure
end

#marketplace_titleString

The title of the service provided by the vendor in the Amazon Marketplace.

Returns:

  • (String)


51858
51859
51860
51861
51862
51863
51864
51865
51866
# File 'lib/aws-sdk-sagemaker/types.rb', line 51858

class SubscribedWorkteam < Struct.new(
  :workteam_arn,
  :marketplace_title,
  :seller_name,
  :marketplace_description,
  :listing_id)
  SENSITIVE = []
  include Aws::Structure
end

#seller_nameString

The name of the vendor in the Amazon Marketplace.

Returns:

  • (String)


51858
51859
51860
51861
51862
51863
51864
51865
51866
# File 'lib/aws-sdk-sagemaker/types.rb', line 51858

class SubscribedWorkteam < Struct.new(
  :workteam_arn,
  :marketplace_title,
  :seller_name,
  :marketplace_description,
  :listing_id)
  SENSITIVE = []
  include Aws::Structure
end

#workteam_arnString

The Amazon Resource Name (ARN) of the vendor that you have subscribed.

Returns:

  • (String)


51858
51859
51860
51861
51862
51863
51864
51865
51866
# File 'lib/aws-sdk-sagemaker/types.rb', line 51858

class SubscribedWorkteam < Struct.new(
  :workteam_arn,
  :marketplace_title,
  :seller_name,
  :marketplace_description,
  :listing_id)
  SENSITIVE = []
  include Aws::Structure
end