Class: Aws::SageMaker::Types::SuggestionQuery
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::SuggestionQuery
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Specified in the GetSearchSuggestions request. Limits the property names that are included in the response.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#property_name_query ⇒ Types::PropertyNameQuery
Defines a property name hint.
Instance Attribute Details
#property_name_query ⇒ Types::PropertyNameQuery
Defines a property name hint. Only property names that begin with the specified hint are included in the response.
35062 35063 35064 35065 35066 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35062 class SuggestionQuery < Struct.new( :property_name_query) SENSITIVE = [] include Aws::Structure end |