Class: Aws::SageMaker::Types::TimeSeriesForecastingSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::TimeSeriesForecastingSettings
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Time series forecast settings for the SageMaker Canvas application.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#amazon_forecast_role_arn ⇒ String
The IAM role that Canvas passes to Amazon Forecast for time series forecasting.
-
#status ⇒ String
Describes whether time series forecasting is enabled or disabled in the Canvas application.
Instance Attribute Details
#amazon_forecast_role_arn ⇒ String
The IAM role that Canvas passes to Amazon Forecast for time series
forecasting. By default, Canvas uses the execution role specified in
the UserProfile that launches the Canvas application. If an
execution role is not specified in the UserProfile, Canvas uses
the execution role specified in the Domain that owns the
UserProfile. To allow time series forecasting, this IAM role
should have the AmazonSageMakerCanvasForecastAccess policy
attached and forecast.amazonaws.com added in the trust
relationship as a service principal.
53165 53166 53167 53168 53169 53170 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53165 class TimeSeriesForecastingSettings < Struct.new( :status, :amazon_forecast_role_arn) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Describes whether time series forecasting is enabled or disabled in the Canvas application.
53165 53166 53167 53168 53169 53170 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53165 class TimeSeriesForecastingSettings < Struct.new( :status, :amazon_forecast_role_arn) SENSITIVE = [] include Aws::Structure end |