Class: Aws::SageMaker::Types::TrainingJobSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::TrainingJobSummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Provides summary information about a training job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Time
A timestamp that shows when the training job was created.
-
#last_modified_time ⇒ Time
Timestamp when the training job was last modified.
-
#secondary_status ⇒ String
The secondary status of the training job.
-
#training_end_time ⇒ Time
A timestamp that shows when the training job ended.
-
#training_job_arn ⇒ String
The Amazon Resource Name (ARN) of the training job.
-
#training_job_name ⇒ String
The name of the training job that you want a summary for.
-
#training_job_status ⇒ String
The status of the training job.
-
#training_plan_arn ⇒ String
The Amazon Resource Name (ARN); of the training plan associated with this training job.
-
#warm_pool_status ⇒ Types::WarmPoolStatus
The status of the warm pool associated with the training job.
Instance Attribute Details
#creation_time ⇒ Time
A timestamp that shows when the training job was created.
54222 54223 54224 54225 54226 54227 54228 54229 54230 54231 54232 54233 54234 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 54222 class TrainingJobSummary < Struct.new( :training_job_name, :training_job_arn, :creation_time, :training_end_time, :last_modified_time, :training_job_status, :secondary_status, :warm_pool_status, :training_plan_arn) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
Timestamp when the training job was last modified.
54222 54223 54224 54225 54226 54227 54228 54229 54230 54231 54232 54233 54234 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 54222 class TrainingJobSummary < Struct.new( :training_job_name, :training_job_arn, :creation_time, :training_end_time, :last_modified_time, :training_job_status, :secondary_status, :warm_pool_status, :training_plan_arn) SENSITIVE = [] include Aws::Structure end |
#secondary_status ⇒ String
The secondary status of the training job.
54222 54223 54224 54225 54226 54227 54228 54229 54230 54231 54232 54233 54234 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 54222 class TrainingJobSummary < Struct.new( :training_job_name, :training_job_arn, :creation_time, :training_end_time, :last_modified_time, :training_job_status, :secondary_status, :warm_pool_status, :training_plan_arn) SENSITIVE = [] include Aws::Structure end |
#training_end_time ⇒ Time
A timestamp that shows when the training job ended. This field is
set only if the training job has one of the terminal statuses
(Completed, Failed, or Stopped).
54222 54223 54224 54225 54226 54227 54228 54229 54230 54231 54232 54233 54234 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 54222 class TrainingJobSummary < Struct.new( :training_job_name, :training_job_arn, :creation_time, :training_end_time, :last_modified_time, :training_job_status, :secondary_status, :warm_pool_status, :training_plan_arn) SENSITIVE = [] include Aws::Structure end |
#training_job_arn ⇒ String
The Amazon Resource Name (ARN) of the training job.
54222 54223 54224 54225 54226 54227 54228 54229 54230 54231 54232 54233 54234 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 54222 class TrainingJobSummary < Struct.new( :training_job_name, :training_job_arn, :creation_time, :training_end_time, :last_modified_time, :training_job_status, :secondary_status, :warm_pool_status, :training_plan_arn) SENSITIVE = [] include Aws::Structure end |
#training_job_name ⇒ String
The name of the training job that you want a summary for.
54222 54223 54224 54225 54226 54227 54228 54229 54230 54231 54232 54233 54234 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 54222 class TrainingJobSummary < Struct.new( :training_job_name, :training_job_arn, :creation_time, :training_end_time, :last_modified_time, :training_job_status, :secondary_status, :warm_pool_status, :training_plan_arn) SENSITIVE = [] include Aws::Structure end |
#training_job_status ⇒ String
The status of the training job.
54222 54223 54224 54225 54226 54227 54228 54229 54230 54231 54232 54233 54234 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 54222 class TrainingJobSummary < Struct.new( :training_job_name, :training_job_arn, :creation_time, :training_end_time, :last_modified_time, :training_job_status, :secondary_status, :warm_pool_status, :training_plan_arn) SENSITIVE = [] include Aws::Structure end |
#training_plan_arn ⇒ String
The Amazon Resource Name (ARN); of the training plan associated with this training job.
For more information about how to reserve GPU capacity for your
SageMaker HyperPod clusters using Amazon SageMaker Training Plan,
see CreateTrainingPlan.
54222 54223 54224 54225 54226 54227 54228 54229 54230 54231 54232 54233 54234 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 54222 class TrainingJobSummary < Struct.new( :training_job_name, :training_job_arn, :creation_time, :training_end_time, :last_modified_time, :training_job_status, :secondary_status, :warm_pool_status, :training_plan_arn) SENSITIVE = [] include Aws::Structure end |
#warm_pool_status ⇒ Types::WarmPoolStatus
The status of the warm pool associated with the training job.
54222 54223 54224 54225 54226 54227 54228 54229 54230 54231 54232 54233 54234 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 54222 class TrainingJobSummary < Struct.new( :training_job_name, :training_job_arn, :creation_time, :training_end_time, :last_modified_time, :training_job_status, :secondary_status, :warm_pool_status, :training_plan_arn) SENSITIVE = [] include Aws::Structure end |