Class: Aws::SageMaker::Types::TrainingPlanExtension

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Details about an extension to a training plan, including the offering ID, dates, status, and cost information.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#availability_zoneString

The Availability Zone of the extension.

Returns:

  • (String)


52915
52916
52917
52918
52919
52920
52921
52922
52923
52924
52925
52926
52927
52928
52929
# File 'lib/aws-sdk-sagemaker/types.rb', line 52915

class TrainingPlanExtension < Struct.new(
  :training_plan_extension_offering_id,
  :extended_at,
  :start_date,
  :end_date,
  :status,
  :payment_status,
  :availability_zone,
  :availability_zone_id,
  :duration_hours,
  :upfront_fee,
  :currency_code)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zone_idString

The Availability Zone ID of the extension.

Returns:

  • (String)


52915
52916
52917
52918
52919
52920
52921
52922
52923
52924
52925
52926
52927
52928
52929
# File 'lib/aws-sdk-sagemaker/types.rb', line 52915

class TrainingPlanExtension < Struct.new(
  :training_plan_extension_offering_id,
  :extended_at,
  :start_date,
  :end_date,
  :status,
  :payment_status,
  :availability_zone,
  :availability_zone_id,
  :duration_hours,
  :upfront_fee,
  :currency_code)
  SENSITIVE = []
  include Aws::Structure
end

#currency_codeString

The currency code for the upfront fee (e.g., USD).

Returns:

  • (String)


52915
52916
52917
52918
52919
52920
52921
52922
52923
52924
52925
52926
52927
52928
52929
# File 'lib/aws-sdk-sagemaker/types.rb', line 52915

class TrainingPlanExtension < Struct.new(
  :training_plan_extension_offering_id,
  :extended_at,
  :start_date,
  :end_date,
  :status,
  :payment_status,
  :availability_zone,
  :availability_zone_id,
  :duration_hours,
  :upfront_fee,
  :currency_code)
  SENSITIVE = []
  include Aws::Structure
end

#duration_hoursInteger

The duration of the extension in hours.

Returns:

  • (Integer)


52915
52916
52917
52918
52919
52920
52921
52922
52923
52924
52925
52926
52927
52928
52929
# File 'lib/aws-sdk-sagemaker/types.rb', line 52915

class TrainingPlanExtension < Struct.new(
  :training_plan_extension_offering_id,
  :extended_at,
  :start_date,
  :end_date,
  :status,
  :payment_status,
  :availability_zone,
  :availability_zone_id,
  :duration_hours,
  :upfront_fee,
  :currency_code)
  SENSITIVE = []
  include Aws::Structure
end

#end_dateTime

The end date of the extension period.

Returns:

  • (Time)


52915
52916
52917
52918
52919
52920
52921
52922
52923
52924
52925
52926
52927
52928
52929
# File 'lib/aws-sdk-sagemaker/types.rb', line 52915

class TrainingPlanExtension < Struct.new(
  :training_plan_extension_offering_id,
  :extended_at,
  :start_date,
  :end_date,
  :status,
  :payment_status,
  :availability_zone,
  :availability_zone_id,
  :duration_hours,
  :upfront_fee,
  :currency_code)
  SENSITIVE = []
  include Aws::Structure
end

#extended_atTime

The timestamp when the extension was created.

Returns:

  • (Time)


52915
52916
52917
52918
52919
52920
52921
52922
52923
52924
52925
52926
52927
52928
52929
# File 'lib/aws-sdk-sagemaker/types.rb', line 52915

class TrainingPlanExtension < Struct.new(
  :training_plan_extension_offering_id,
  :extended_at,
  :start_date,
  :end_date,
  :status,
  :payment_status,
  :availability_zone,
  :availability_zone_id,
  :duration_hours,
  :upfront_fee,
  :currency_code)
  SENSITIVE = []
  include Aws::Structure
end

#payment_statusString

The payment processing status of the extension.

Returns:

  • (String)


52915
52916
52917
52918
52919
52920
52921
52922
52923
52924
52925
52926
52927
52928
52929
# File 'lib/aws-sdk-sagemaker/types.rb', line 52915

class TrainingPlanExtension < Struct.new(
  :training_plan_extension_offering_id,
  :extended_at,
  :start_date,
  :end_date,
  :status,
  :payment_status,
  :availability_zone,
  :availability_zone_id,
  :duration_hours,
  :upfront_fee,
  :currency_code)
  SENSITIVE = []
  include Aws::Structure
end

#start_dateTime

The start date of the extension period.

Returns:

  • (Time)


52915
52916
52917
52918
52919
52920
52921
52922
52923
52924
52925
52926
52927
52928
52929
# File 'lib/aws-sdk-sagemaker/types.rb', line 52915

class TrainingPlanExtension < Struct.new(
  :training_plan_extension_offering_id,
  :extended_at,
  :start_date,
  :end_date,
  :status,
  :payment_status,
  :availability_zone,
  :availability_zone_id,
  :duration_hours,
  :upfront_fee,
  :currency_code)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the extension (e.g., Pending, Active, Scheduled, Failed, Expired).

Returns:

  • (String)


52915
52916
52917
52918
52919
52920
52921
52922
52923
52924
52925
52926
52927
52928
52929
# File 'lib/aws-sdk-sagemaker/types.rb', line 52915

class TrainingPlanExtension < Struct.new(
  :training_plan_extension_offering_id,
  :extended_at,
  :start_date,
  :end_date,
  :status,
  :payment_status,
  :availability_zone,
  :availability_zone_id,
  :duration_hours,
  :upfront_fee,
  :currency_code)
  SENSITIVE = []
  include Aws::Structure
end

#training_plan_extension_offering_idString

The unique identifier of the extension offering that was used to create this extension.

Returns:

  • (String)


52915
52916
52917
52918
52919
52920
52921
52922
52923
52924
52925
52926
52927
52928
52929
# File 'lib/aws-sdk-sagemaker/types.rb', line 52915

class TrainingPlanExtension < Struct.new(
  :training_plan_extension_offering_id,
  :extended_at,
  :start_date,
  :end_date,
  :status,
  :payment_status,
  :availability_zone,
  :availability_zone_id,
  :duration_hours,
  :upfront_fee,
  :currency_code)
  SENSITIVE = []
  include Aws::Structure
end

#upfront_feeString

The upfront fee for the extension.

Returns:

  • (String)


52915
52916
52917
52918
52919
52920
52921
52922
52923
52924
52925
52926
52927
52928
52929
# File 'lib/aws-sdk-sagemaker/types.rb', line 52915

class TrainingPlanExtension < Struct.new(
  :training_plan_extension_offering_id,
  :extended_at,
  :start_date,
  :end_date,
  :status,
  :payment_status,
  :availability_zone,
  :availability_zone_id,
  :duration_hours,
  :upfront_fee,
  :currency_code)
  SENSITIVE = []
  include Aws::Structure
end