Class: Aws::SageMaker::Types::TrainingPlanFilter

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

A filter to apply when listing or searching for training plans.

For more information about how to reserve GPU capacity for your SageMaker HyperPod clusters using Amazon SageMaker Training Plan, see ‘ CreateTrainingPlan `.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

The name of the filter field (e.g., Status, InstanceType).

Returns:

  • (String)


50634
50635
50636
50637
50638
50639
# File 'lib/aws-sdk-sagemaker/types.rb', line 50634

class TrainingPlanFilter < Struct.new(
  :name,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#valueString

The value to filter by for the specified field.

Returns:

  • (String)


50634
50635
50636
50637
50638
50639
# File 'lib/aws-sdk-sagemaker/types.rb', line 50634

class TrainingPlanFilter < Struct.new(
  :name,
  :value)
  SENSITIVE = []
  include Aws::Structure
end