Class: Aws::SageMaker::Types::TrainingPlanSummary

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Details of the training plan.

For more information about how to reserve GPU capacity for your SageMaker HyperPod clusters using Amazon SageMaker Training Plan, see CreateTrainingPlan.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#available_instance_count ⇒ Integer

The number of instances currently available for use in this training plan.

Returns:

  • (Integer)


54996
54997
54998
54999
55000
55001
55002
55003
55004
55005
55006
55007
55008
55009
55010
55011
55012
55013
55014
55015
# File 'lib/aws-sdk-sagemaker/types.rb', line 54996

class TrainingPlanSummary < Struct.new(
  :training_plan_arn,
  :training_plan_name,
  :status,
  :status_message,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :upfront_fee,
  :currency_code,
  :total_instance_count,
  :available_instance_count,
  :in_use_instance_count,
  :total_ultra_server_count,
  :target_resources,
  :reserved_capacity_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#currency_code ⇒ String

The currency code for the upfront fee (e.g., USD).

Returns:

  • (String)


54996
54997
54998
54999
55000
55001
55002
55003
55004
55005
55006
55007
55008
55009
55010
55011
55012
55013
55014
55015
# File 'lib/aws-sdk-sagemaker/types.rb', line 54996

class TrainingPlanSummary < Struct.new(
  :training_plan_arn,
  :training_plan_name,
  :status,
  :status_message,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :upfront_fee,
  :currency_code,
  :total_instance_count,
  :available_instance_count,
  :in_use_instance_count,
  :total_ultra_server_count,
  :target_resources,
  :reserved_capacity_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#duration_hours ⇒ Integer

The number of whole hours in the total duration for this training plan.

Returns:

  • (Integer)


54996
54997
54998
54999
55000
55001
55002
55003
55004
55005
55006
55007
55008
55009
55010
55011
55012
55013
55014
55015
# File 'lib/aws-sdk-sagemaker/types.rb', line 54996

class TrainingPlanSummary < Struct.new(
  :training_plan_arn,
  :training_plan_name,
  :status,
  :status_message,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :upfront_fee,
  :currency_code,
  :total_instance_count,
  :available_instance_count,
  :in_use_instance_count,
  :total_ultra_server_count,
  :target_resources,
  :reserved_capacity_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#duration_minutes ⇒ Integer

The additional minutes beyond whole hours in the total duration for this training plan.

Returns:

  • (Integer)


54996
54997
54998
54999
55000
55001
55002
55003
55004
55005
55006
55007
55008
55009
55010
55011
55012
55013
55014
55015
# File 'lib/aws-sdk-sagemaker/types.rb', line 54996

class TrainingPlanSummary < Struct.new(
  :training_plan_arn,
  :training_plan_name,
  :status,
  :status_message,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :upfront_fee,
  :currency_code,
  :total_instance_count,
  :available_instance_count,
  :in_use_instance_count,
  :total_ultra_server_count,
  :target_resources,
  :reserved_capacity_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#end_time ⇒ Time

The end time of the training plan.

Returns:

  • (Time)


54996
54997
54998
54999
55000
55001
55002
55003
55004
55005
55006
55007
55008
55009
55010
55011
55012
55013
55014
55015
# File 'lib/aws-sdk-sagemaker/types.rb', line 54996

class TrainingPlanSummary < Struct.new(
  :training_plan_arn,
  :training_plan_name,
  :status,
  :status_message,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :upfront_fee,
  :currency_code,
  :total_instance_count,
  :available_instance_count,
  :in_use_instance_count,
  :total_ultra_server_count,
  :target_resources,
  :reserved_capacity_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#in_use_instance_count ⇒ Integer

The number of instances currently in use from this training plan.

Returns:

  • (Integer)


54996
54997
54998
54999
55000
55001
55002
55003
55004
55005
55006
55007
55008
55009
55010
55011
55012
55013
55014
55015
# File 'lib/aws-sdk-sagemaker/types.rb', line 54996

class TrainingPlanSummary < Struct.new(
  :training_plan_arn,
  :training_plan_name,
  :status,
  :status_message,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :upfront_fee,
  :currency_code,
  :total_instance_count,
  :available_instance_count,
  :in_use_instance_count,
  :total_ultra_server_count,
  :target_resources,
  :reserved_capacity_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#reserved_capacity_summaries ⇒ Array<Types::ReservedCapacitySummary>

A list of reserved capacities associated with this training plan, including details such as instance types, counts, and availability zones.

Returns:



54996
54997
54998
54999
55000
55001
55002
55003
55004
55005
55006
55007
55008
55009
55010
55011
55012
55013
55014
55015
# File 'lib/aws-sdk-sagemaker/types.rb', line 54996

class TrainingPlanSummary < Struct.new(
  :training_plan_arn,
  :training_plan_name,
  :status,
  :status_message,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :upfront_fee,
  :currency_code,
  :total_instance_count,
  :available_instance_count,
  :in_use_instance_count,
  :total_ultra_server_count,
  :target_resources,
  :reserved_capacity_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#start_time ⇒ Time

The start time of the training plan.

Returns:

  • (Time)


54996
54997
54998
54999
55000
55001
55002
55003
55004
55005
55006
55007
55008
55009
55010
55011
55012
55013
55014
55015
# File 'lib/aws-sdk-sagemaker/types.rb', line 54996

class TrainingPlanSummary < Struct.new(
  :training_plan_arn,
  :training_plan_name,
  :status,
  :status_message,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :upfront_fee,
  :currency_code,
  :total_instance_count,
  :available_instance_count,
  :in_use_instance_count,
  :total_ultra_server_count,
  :target_resources,
  :reserved_capacity_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The current status of the training plan (e.g., Pending, Active, Expired). To see the complete list of status values available for a training plan, refer to the Status attribute within the TrainingPlanSummary object.

Returns:

  • (String)


54996
54997
54998
54999
55000
55001
55002
55003
55004
55005
55006
55007
55008
55009
55010
55011
55012
55013
55014
55015
# File 'lib/aws-sdk-sagemaker/types.rb', line 54996

class TrainingPlanSummary < Struct.new(
  :training_plan_arn,
  :training_plan_name,
  :status,
  :status_message,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :upfront_fee,
  :currency_code,
  :total_instance_count,
  :available_instance_count,
  :in_use_instance_count,
  :total_ultra_server_count,
  :target_resources,
  :reserved_capacity_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#status_message ⇒ String

A message providing additional information about the current status of the training plan.

Returns:

  • (String)


54996
54997
54998
54999
55000
55001
55002
55003
55004
55005
55006
55007
55008
55009
55010
55011
55012
55013
55014
55015
# File 'lib/aws-sdk-sagemaker/types.rb', line 54996

class TrainingPlanSummary < Struct.new(
  :training_plan_arn,
  :training_plan_name,
  :status,
  :status_message,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :upfront_fee,
  :currency_code,
  :total_instance_count,
  :available_instance_count,
  :in_use_instance_count,
  :total_ultra_server_count,
  :target_resources,
  :reserved_capacity_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#target_resources ⇒ Array<String>

The target resources (e.g., training jobs, HyperPod clusters, Endpoints, Studio apps) that can use this training plan.

Training plans are specific to their target resource.

  • A training plan designed for SageMaker training jobs can only be used to schedule and run training jobs.

  • A training plan for HyperPod clusters can be used exclusively to provide compute resources to a cluster's instance group.

  • A training plan for SageMaker endpoints can be used exclusively to provide compute resources to SageMaker endpoints for model deployment.

  • A training plan for Studio apps can be used to launch JupyterLab and Code Editor apps on reserved training plan capacity.

Returns:

  • (Array<String>)


54996
54997
54998
54999
55000
55001
55002
55003
55004
55005
55006
55007
55008
55009
55010
55011
55012
55013
55014
55015
# File 'lib/aws-sdk-sagemaker/types.rb', line 54996

class TrainingPlanSummary < Struct.new(
  :training_plan_arn,
  :training_plan_name,
  :status,
  :status_message,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :upfront_fee,
  :currency_code,
  :total_instance_count,
  :available_instance_count,
  :in_use_instance_count,
  :total_ultra_server_count,
  :target_resources,
  :reserved_capacity_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#total_instance_count ⇒ Integer

The total number of instances reserved in this training plan.

Returns:

  • (Integer)


54996
54997
54998
54999
55000
55001
55002
55003
55004
55005
55006
55007
55008
55009
55010
55011
55012
55013
55014
55015
# File 'lib/aws-sdk-sagemaker/types.rb', line 54996

class TrainingPlanSummary < Struct.new(
  :training_plan_arn,
  :training_plan_name,
  :status,
  :status_message,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :upfront_fee,
  :currency_code,
  :total_instance_count,
  :available_instance_count,
  :in_use_instance_count,
  :total_ultra_server_count,
  :target_resources,
  :reserved_capacity_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#total_ultra_server_count ⇒ Integer

The total number of UltraServers allocated to this training plan.

Returns:

  • (Integer)


54996
54997
54998
54999
55000
55001
55002
55003
55004
55005
55006
55007
55008
55009
55010
55011
55012
55013
55014
55015
# File 'lib/aws-sdk-sagemaker/types.rb', line 54996

class TrainingPlanSummary < Struct.new(
  :training_plan_arn,
  :training_plan_name,
  :status,
  :status_message,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :upfront_fee,
  :currency_code,
  :total_instance_count,
  :available_instance_count,
  :in_use_instance_count,
  :total_ultra_server_count,
  :target_resources,
  :reserved_capacity_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#training_plan_arn ⇒ String

The Amazon Resource Name (ARN); of the training plan.

Returns:

  • (String)


54996
54997
54998
54999
55000
55001
55002
55003
55004
55005
55006
55007
55008
55009
55010
55011
55012
55013
55014
55015
# File 'lib/aws-sdk-sagemaker/types.rb', line 54996

class TrainingPlanSummary < Struct.new(
  :training_plan_arn,
  :training_plan_name,
  :status,
  :status_message,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :upfront_fee,
  :currency_code,
  :total_instance_count,
  :available_instance_count,
  :in_use_instance_count,
  :total_ultra_server_count,
  :target_resources,
  :reserved_capacity_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#training_plan_name ⇒ String

The name of the training plan.

Returns:

  • (String)


54996
54997
54998
54999
55000
55001
55002
55003
55004
55005
55006
55007
55008
55009
55010
55011
55012
55013
55014
55015
# File 'lib/aws-sdk-sagemaker/types.rb', line 54996

class TrainingPlanSummary < Struct.new(
  :training_plan_arn,
  :training_plan_name,
  :status,
  :status_message,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :upfront_fee,
  :currency_code,
  :total_instance_count,
  :available_instance_count,
  :in_use_instance_count,
  :total_ultra_server_count,
  :target_resources,
  :reserved_capacity_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#upfront_fee ⇒ String

The upfront fee for the training plan.

Returns:

  • (String)


54996
54997
54998
54999
55000
55001
55002
55003
55004
55005
55006
55007
55008
55009
55010
55011
55012
55013
55014
55015
# File 'lib/aws-sdk-sagemaker/types.rb', line 54996

class TrainingPlanSummary < Struct.new(
  :training_plan_arn,
  :training_plan_name,
  :status,
  :status_message,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :upfront_fee,
  :currency_code,
  :total_instance_count,
  :available_instance_count,
  :in_use_instance_count,
  :total_ultra_server_count,
  :target_resources,
  :reserved_capacity_summaries)
  SENSITIVE = []
  include Aws::Structure
end