Class: Aws::SageMaker::Types::TrainingSpecification
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::TrainingSpecification
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Defines how the algorithm is used for a training job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_s3_data_source ⇒ Types::AdditionalS3DataSource
The additional data source used during the training job.
-
#metric_definitions ⇒ Array<Types::MetricDefinition>
A list of
MetricDefinitionobjects, which are used for parsing metrics generated by the algorithm. -
#supported_hyper_parameters ⇒ Array<Types::HyperParameterSpecification>
A list of the
HyperParameterSpecificationobjects, that define the supported hyperparameters. -
#supported_training_instance_types ⇒ Array<String>
A list of the instance types that this algorithm can use for training.
-
#supported_tuning_job_objective_metrics ⇒ Array<Types::HyperParameterTuningJobObjective>
A list of the metrics that the algorithm emits that can be used as the objective metric in a hyperparameter tuning job.
-
#supports_distributed_training ⇒ Boolean
Indicates whether the algorithm supports distributed training.
-
#training_channels ⇒ Array<Types::ChannelSpecification>
A list of
ChannelSpecificationobjects, which specify the input sources to be used by the algorithm. -
#training_image ⇒ String
The Amazon ECR registry path of the Docker image that contains the training algorithm.
-
#training_image_digest ⇒ String
An MD5 hash of the training algorithm that identifies the Docker image used for training.
Instance Attribute Details
#additional_s3_data_source ⇒ Types::AdditionalS3DataSource
The additional data source used during the training job.
55113 55114 55115 55116 55117 55118 55119 55120 55121 55122 55123 55124 55125 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55113 class TrainingSpecification < Struct.new( :training_image, :training_image_digest, :supported_hyper_parameters, :supported_training_instance_types, :supports_distributed_training, :metric_definitions, :training_channels, :supported_tuning_job_objective_metrics, :additional_s3_data_source) SENSITIVE = [] include Aws::Structure end |
#metric_definitions ⇒ Array<Types::MetricDefinition>
A list of MetricDefinition objects, which are used for parsing
metrics generated by the algorithm.
55113 55114 55115 55116 55117 55118 55119 55120 55121 55122 55123 55124 55125 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55113 class TrainingSpecification < Struct.new( :training_image, :training_image_digest, :supported_hyper_parameters, :supported_training_instance_types, :supports_distributed_training, :metric_definitions, :training_channels, :supported_tuning_job_objective_metrics, :additional_s3_data_source) SENSITIVE = [] include Aws::Structure end |
#supported_hyper_parameters ⇒ Array<Types::HyperParameterSpecification>
A list of the HyperParameterSpecification objects, that define the
supported hyperparameters. This is required if the algorithm
supports automatic model tuning.>
55113 55114 55115 55116 55117 55118 55119 55120 55121 55122 55123 55124 55125 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55113 class TrainingSpecification < Struct.new( :training_image, :training_image_digest, :supported_hyper_parameters, :supported_training_instance_types, :supports_distributed_training, :metric_definitions, :training_channels, :supported_tuning_job_objective_metrics, :additional_s3_data_source) SENSITIVE = [] include Aws::Structure end |
#supported_training_instance_types ⇒ Array<String>
A list of the instance types that this algorithm can use for training.
55113 55114 55115 55116 55117 55118 55119 55120 55121 55122 55123 55124 55125 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55113 class TrainingSpecification < Struct.new( :training_image, :training_image_digest, :supported_hyper_parameters, :supported_training_instance_types, :supports_distributed_training, :metric_definitions, :training_channels, :supported_tuning_job_objective_metrics, :additional_s3_data_source) SENSITIVE = [] include Aws::Structure end |
#supported_tuning_job_objective_metrics ⇒ Array<Types::HyperParameterTuningJobObjective>
A list of the metrics that the algorithm emits that can be used as the objective metric in a hyperparameter tuning job.
55113 55114 55115 55116 55117 55118 55119 55120 55121 55122 55123 55124 55125 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55113 class TrainingSpecification < Struct.new( :training_image, :training_image_digest, :supported_hyper_parameters, :supported_training_instance_types, :supports_distributed_training, :metric_definitions, :training_channels, :supported_tuning_job_objective_metrics, :additional_s3_data_source) SENSITIVE = [] include Aws::Structure end |
#supports_distributed_training ⇒ Boolean
Indicates whether the algorithm supports distributed training. If set to false, buyers can't request more than one instance during training.
55113 55114 55115 55116 55117 55118 55119 55120 55121 55122 55123 55124 55125 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55113 class TrainingSpecification < Struct.new( :training_image, :training_image_digest, :supported_hyper_parameters, :supported_training_instance_types, :supports_distributed_training, :metric_definitions, :training_channels, :supported_tuning_job_objective_metrics, :additional_s3_data_source) SENSITIVE = [] include Aws::Structure end |
#training_channels ⇒ Array<Types::ChannelSpecification>
A list of ChannelSpecification objects, which specify the input
sources to be used by the algorithm.
55113 55114 55115 55116 55117 55118 55119 55120 55121 55122 55123 55124 55125 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55113 class TrainingSpecification < Struct.new( :training_image, :training_image_digest, :supported_hyper_parameters, :supported_training_instance_types, :supports_distributed_training, :metric_definitions, :training_channels, :supported_tuning_job_objective_metrics, :additional_s3_data_source) SENSITIVE = [] include Aws::Structure end |
#training_image ⇒ String
The Amazon ECR registry path of the Docker image that contains the training algorithm.
55113 55114 55115 55116 55117 55118 55119 55120 55121 55122 55123 55124 55125 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55113 class TrainingSpecification < Struct.new( :training_image, :training_image_digest, :supported_hyper_parameters, :supported_training_instance_types, :supports_distributed_training, :metric_definitions, :training_channels, :supported_tuning_job_objective_metrics, :additional_s3_data_source) SENSITIVE = [] include Aws::Structure end |
#training_image_digest ⇒ String
An MD5 hash of the training algorithm that identifies the Docker image used for training.
55113 55114 55115 55116 55117 55118 55119 55120 55121 55122 55123 55124 55125 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55113 class TrainingSpecification < Struct.new( :training_image, :training_image_digest, :supported_hyper_parameters, :supported_training_instance_types, :supports_distributed_training, :metric_definitions, :training_channels, :supported_tuning_job_objective_metrics, :additional_s3_data_source) SENSITIVE = [] include Aws::Structure end |