Class: Aws::SageMaker::Types::TransformJobSummary

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Provides a summary of a transform job. Multiple TransformJobSummary objects are returned as a list after in response to a ListTransformJobs call.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_time ⇒ Time

A timestamp that shows when the transform Job was created.

Returns:

  • (Time)


55520
55521
55522
55523
55524
55525
55526
55527
55528
55529
55530
# File 'lib/aws-sdk-sagemaker/types.rb', line 55520

class TransformJobSummary < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :creation_time,
  :transform_end_time,
  :last_modified_time,
  :transform_job_status,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reason ⇒ String

If the transform job failed, the reason it failed.

Returns:

  • (String)


55520
55521
55522
55523
55524
55525
55526
55527
55528
55529
55530
# File 'lib/aws-sdk-sagemaker/types.rb', line 55520

class TransformJobSummary < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :creation_time,
  :transform_end_time,
  :last_modified_time,
  :transform_job_status,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_time ⇒ Time

Indicates when the transform job was last modified.

Returns:

  • (Time)


55520
55521
55522
55523
55524
55525
55526
55527
55528
55529
55530
# File 'lib/aws-sdk-sagemaker/types.rb', line 55520

class TransformJobSummary < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :creation_time,
  :transform_end_time,
  :last_modified_time,
  :transform_job_status,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#transform_end_time ⇒ Time

Indicates when the transform job ends on compute instances. For successful jobs and stopped jobs, this is the exact time recorded after the results are uploaded. For failed jobs, this is when Amazon SageMaker detected that the job failed.

Returns:

  • (Time)


55520
55521
55522
55523
55524
55525
55526
55527
55528
55529
55530
# File 'lib/aws-sdk-sagemaker/types.rb', line 55520

class TransformJobSummary < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :creation_time,
  :transform_end_time,
  :last_modified_time,
  :transform_job_status,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#transform_job_arn ⇒ String

The Amazon Resource Name (ARN) of the transform job.

Returns:

  • (String)


55520
55521
55522
55523
55524
55525
55526
55527
55528
55529
55530
# File 'lib/aws-sdk-sagemaker/types.rb', line 55520

class TransformJobSummary < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :creation_time,
  :transform_end_time,
  :last_modified_time,
  :transform_job_status,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#transform_job_name ⇒ String

The name of the transform job.

Returns:

  • (String)


55520
55521
55522
55523
55524
55525
55526
55527
55528
55529
55530
# File 'lib/aws-sdk-sagemaker/types.rb', line 55520

class TransformJobSummary < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :creation_time,
  :transform_end_time,
  :last_modified_time,
  :transform_job_status,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#transform_job_status ⇒ String

The status of the transform job.

Returns:

  • (String)


55520
55521
55522
55523
55524
55525
55526
55527
55528
55529
55530
# File 'lib/aws-sdk-sagemaker/types.rb', line 55520

class TransformJobSummary < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :creation_time,
  :transform_end_time,
  :last_modified_time,
  :transform_job_status,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end