Class: Aws::SageMaker::Types::Trial

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The properties of a trial as returned by the Search API.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_byTypes::UserContext

Who created the trial.



55823
55824
55825
55826
55827
55828
55829
55830
55831
55832
55833
55834
55835
55836
55837
55838
# File 'lib/aws-sdk-sagemaker/types.rb', line 55823

class Trial < Struct.new(
  :trial_name,
  :trial_arn,
  :display_name,
  :experiment_name,
  :source,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :metadata_properties,
  :tags,
  :trial_component_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

When the trial was created.



55823
55824
55825
55826
55827
55828
55829
55830
55831
55832
55833
55834
55835
55836
55837
55838
# File 'lib/aws-sdk-sagemaker/types.rb', line 55823

class Trial < Struct.new(
  :trial_name,
  :trial_arn,
  :display_name,
  :experiment_name,
  :source,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :metadata_properties,
  :tags,
  :trial_component_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

The name of the trial as displayed. If DisplayName isn't specified, TrialName is displayed.



55823
55824
55825
55826
55827
55828
55829
55830
55831
55832
55833
55834
55835
55836
55837
55838
# File 'lib/aws-sdk-sagemaker/types.rb', line 55823

class Trial < Struct.new(
  :trial_name,
  :trial_arn,
  :display_name,
  :experiment_name,
  :source,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :metadata_properties,
  :tags,
  :trial_component_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#experiment_nameString

The name of the experiment the trial is part of.



55823
55824
55825
55826
55827
55828
55829
55830
55831
55832
55833
55834
55835
55836
55837
55838
# File 'lib/aws-sdk-sagemaker/types.rb', line 55823

class Trial < Struct.new(
  :trial_name,
  :trial_arn,
  :display_name,
  :experiment_name,
  :source,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :metadata_properties,
  :tags,
  :trial_component_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_byTypes::UserContext

Information about the user who created or modified a SageMaker resource.



55823
55824
55825
55826
55827
55828
55829
55830
55831
55832
55833
55834
55835
55836
55837
55838
# File 'lib/aws-sdk-sagemaker/types.rb', line 55823

class Trial < Struct.new(
  :trial_name,
  :trial_arn,
  :display_name,
  :experiment_name,
  :source,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :metadata_properties,
  :tags,
  :trial_component_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

Who last modified the trial.



55823
55824
55825
55826
55827
55828
55829
55830
55831
55832
55833
55834
55835
55836
55837
55838
# File 'lib/aws-sdk-sagemaker/types.rb', line 55823

class Trial < Struct.new(
  :trial_name,
  :trial_arn,
  :display_name,
  :experiment_name,
  :source,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :metadata_properties,
  :tags,
  :trial_component_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#metadata_propertiesTypes::MetadataProperties

Metadata properties of the tracking entity, trial, or trial component.



55823
55824
55825
55826
55827
55828
55829
55830
55831
55832
55833
55834
55835
55836
55837
55838
# File 'lib/aws-sdk-sagemaker/types.rb', line 55823

class Trial < Struct.new(
  :trial_name,
  :trial_arn,
  :display_name,
  :experiment_name,
  :source,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :metadata_properties,
  :tags,
  :trial_component_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#sourceTypes::TrialSource

The source of the trial.



55823
55824
55825
55826
55827
55828
55829
55830
55831
55832
55833
55834
55835
55836
55837
55838
# File 'lib/aws-sdk-sagemaker/types.rb', line 55823

class Trial < Struct.new(
  :trial_name,
  :trial_arn,
  :display_name,
  :experiment_name,
  :source,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :metadata_properties,
  :tags,
  :trial_component_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The list of tags that are associated with the trial. You can use Search API to search on the tags.



55823
55824
55825
55826
55827
55828
55829
55830
55831
55832
55833
55834
55835
55836
55837
55838
# File 'lib/aws-sdk-sagemaker/types.rb', line 55823

class Trial < Struct.new(
  :trial_name,
  :trial_arn,
  :display_name,
  :experiment_name,
  :source,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :metadata_properties,
  :tags,
  :trial_component_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#trial_arnString

The Amazon Resource Name (ARN) of the trial.



55823
55824
55825
55826
55827
55828
55829
55830
55831
55832
55833
55834
55835
55836
55837
55838
# File 'lib/aws-sdk-sagemaker/types.rb', line 55823

class Trial < Struct.new(
  :trial_name,
  :trial_arn,
  :display_name,
  :experiment_name,
  :source,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :metadata_properties,
  :tags,
  :trial_component_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#trial_component_summariesArray<Types::TrialComponentSimpleSummary>

A list of the components associated with the trial. For each component, a summary of the component's properties is included.



55823
55824
55825
55826
55827
55828
55829
55830
55831
55832
55833
55834
55835
55836
55837
55838
# File 'lib/aws-sdk-sagemaker/types.rb', line 55823

class Trial < Struct.new(
  :trial_name,
  :trial_arn,
  :display_name,
  :experiment_name,
  :source,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :metadata_properties,
  :tags,
  :trial_component_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#trial_nameString

The name of the trial.



55823
55824
55825
55826
55827
55828
55829
55830
55831
55832
55833
55834
55835
55836
55837
55838
# File 'lib/aws-sdk-sagemaker/types.rb', line 55823

class Trial < Struct.new(
  :trial_name,
  :trial_arn,
  :display_name,
  :experiment_name,
  :source,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :metadata_properties,
  :tags,
  :trial_component_summaries)
  SENSITIVE = []
  include Aws::Structure
end