Class: Aws::SageMaker::Types::TrialComponentArtifact

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Represents an input or output artifact of a trial component. You specify TrialComponentArtifact as part of the InputArtifacts and OutputArtifacts parameters in the CreateTrialComponent request.

Examples of input artifacts are datasets, algorithms, hyperparameters, source code, and instance types. Examples of output artifacts are metrics, snapshots, logs, and images.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#media_typeString

The media type of the artifact, which indicates the type of data in the artifact file. The media type consists of a type and a subtype concatenated with a slash (/) character, for example, text/csv, image/jpeg, and s3/uri. The type specifies the category of the media. The subtype specifies the kind of data.

Returns:

  • (String)


55549
55550
55551
55552
55553
55554
# File 'lib/aws-sdk-sagemaker/types.rb', line 55549

class TrialComponentArtifact < Struct.new(
  :media_type,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#valueString

The location of the artifact.

Returns:

  • (String)


55549
55550
55551
55552
55553
55554
# File 'lib/aws-sdk-sagemaker/types.rb', line 55549

class TrialComponentArtifact < Struct.new(
  :media_type,
  :value)
  SENSITIVE = []
  include Aws::Structure
end