Class: Aws::SageMaker::Types::UnifiedStudioSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::UnifiedStudioSettings
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The settings that apply to an Amazon SageMaker AI domain when you use it in Amazon SageMaker Unified Studio.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_account_id ⇒ String
The ID of the Amazon Web Services account that has the Amazon SageMaker Unified Studio domain.
-
#domain_id ⇒ String
The ID of the Amazon SageMaker Unified Studio domain associated with this domain.
-
#domain_region ⇒ String
The Amazon Web Services Region where the domain is located in Amazon SageMaker Unified Studio.
-
#environment_id ⇒ String
The ID of the environment that Amazon SageMaker Unified Studio associates with the domain.
-
#project_id ⇒ String
The ID of the Amazon SageMaker Unified Studio project that corresponds to the domain.
-
#project_s3_path ⇒ String
The location where Amazon S3 stores temporary execution data and other artifacts for the project that corresponds to the domain.
-
#single_sign_on_application_arn ⇒ String
The ARN of the Amazon DataZone application managed by Amazon SageMaker Unified Studio in the Amazon Web Services IAM Identity Center.
-
#studio_web_portal_access ⇒ String
Sets whether you can access the domain in Amazon SageMaker Studio:.
Instance Attribute Details
#domain_account_id ⇒ String
The ID of the Amazon Web Services account that has the Amazon SageMaker Unified Studio domain. The default value, if you don’t specify an ID, is the ID of the account that has the Amazon SageMaker AI domain.
54652 54653 54654 54655 54656 54657 54658 54659 54660 54661 54662 54663 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 54652 class UnifiedStudioSettings < Struct.new( :studio_web_portal_access, :domain_account_id, :domain_region, :domain_id, :project_id, :environment_id, :project_s3_path, :single_sign_on_application_arn) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
The ID of the Amazon SageMaker Unified Studio domain associated with this domain.
54652 54653 54654 54655 54656 54657 54658 54659 54660 54661 54662 54663 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 54652 class UnifiedStudioSettings < Struct.new( :studio_web_portal_access, :domain_account_id, :domain_region, :domain_id, :project_id, :environment_id, :project_s3_path, :single_sign_on_application_arn) SENSITIVE = [] include Aws::Structure end |
#domain_region ⇒ String
The Amazon Web Services Region where the domain is located in Amazon SageMaker Unified Studio. The default value, if you don’t specify a Region, is the Region where the Amazon SageMaker AI domain is located.
54652 54653 54654 54655 54656 54657 54658 54659 54660 54661 54662 54663 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 54652 class UnifiedStudioSettings < Struct.new( :studio_web_portal_access, :domain_account_id, :domain_region, :domain_id, :project_id, :environment_id, :project_s3_path, :single_sign_on_application_arn) SENSITIVE = [] include Aws::Structure end |
#environment_id ⇒ String
The ID of the environment that Amazon SageMaker Unified Studio associates with the domain.
54652 54653 54654 54655 54656 54657 54658 54659 54660 54661 54662 54663 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 54652 class UnifiedStudioSettings < Struct.new( :studio_web_portal_access, :domain_account_id, :domain_region, :domain_id, :project_id, :environment_id, :project_s3_path, :single_sign_on_application_arn) SENSITIVE = [] include Aws::Structure end |
#project_id ⇒ String
The ID of the Amazon SageMaker Unified Studio project that corresponds to the domain.
54652 54653 54654 54655 54656 54657 54658 54659 54660 54661 54662 54663 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 54652 class UnifiedStudioSettings < Struct.new( :studio_web_portal_access, :domain_account_id, :domain_region, :domain_id, :project_id, :environment_id, :project_s3_path, :single_sign_on_application_arn) SENSITIVE = [] include Aws::Structure end |
#project_s3_path ⇒ String
The location where Amazon S3 stores temporary execution data and other artifacts for the project that corresponds to the domain.
54652 54653 54654 54655 54656 54657 54658 54659 54660 54661 54662 54663 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 54652 class UnifiedStudioSettings < Struct.new( :studio_web_portal_access, :domain_account_id, :domain_region, :domain_id, :project_id, :environment_id, :project_s3_path, :single_sign_on_application_arn) SENSITIVE = [] include Aws::Structure end |
#single_sign_on_application_arn ⇒ String
The ARN of the Amazon DataZone application managed by Amazon SageMaker Unified Studio in the Amazon Web Services IAM Identity Center.
54652 54653 54654 54655 54656 54657 54658 54659 54660 54661 54662 54663 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 54652 class UnifiedStudioSettings < Struct.new( :studio_web_portal_access, :domain_account_id, :domain_region, :domain_id, :project_id, :environment_id, :project_s3_path, :single_sign_on_application_arn) SENSITIVE = [] include Aws::Structure end |
#studio_web_portal_access ⇒ String
Sets whether you can access the domain in Amazon SageMaker Studio:
ENABLED
: You can access the domain in Amazon SageMaker Studio. If you
migrate the domain to Amazon SageMaker Unified Studio, you can
access it in both studio interfaces.
DISABLED
: You can’t access the domain in Amazon SageMaker Studio. If you
migrate the domain to Amazon SageMaker Unified Studio, you can
access it only in that studio interface.
To migrate a domain to Amazon SageMaker Unified Studio, you specify the UnifiedStudioSettings data type when you use the UpdateDomain action.
54652 54653 54654 54655 54656 54657 54658 54659 54660 54661 54662 54663 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 54652 class UnifiedStudioSettings < Struct.new( :studio_web_portal_access, :domain_account_id, :domain_region, :domain_id, :project_id, :environment_id, :project_s3_path, :single_sign_on_application_arn) SENSITIVE = [] include Aws::Structure end |