Class: Aws::SageMaker::Types::UpdateEndpointInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::UpdateEndpointInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#deployment_config ⇒ Types::DeploymentConfig
The deployment configuration for an endpoint, which contains the desired deployment strategy and rollback configurations.
-
#endpoint_config_name ⇒ String
The name of the new endpoint configuration.
-
#endpoint_name ⇒ String
The name of the endpoint whose configuration you want to update.
-
#exclude_retained_variant_properties ⇒ Array<Types::VariantProperty>
When you are updating endpoint resources with
RetainAllVariantProperties, whose value is set totrue,ExcludeRetainedVariantPropertiesspecifies the list of type [VariantProperty] to override with the values provided byEndpointConfig. -
#retain_all_variant_properties ⇒ Boolean
When updating endpoint resources, enables or disables the retention of [variant properties], such as the instance count or the variant weight.
-
#retain_deployment_config ⇒ Boolean
Specifies whether to reuse the last deployment configuration.
Instance Attribute Details
#deployment_config ⇒ Types::DeploymentConfig
The deployment configuration for an endpoint, which contains the desired deployment strategy and rollback configurations.
43155 43156 43157 43158 43159 43160 43161 43162 43163 43164 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43155 class UpdateEndpointInput < Struct.new( :endpoint_name, :endpoint_config_name, :retain_all_variant_properties, :exclude_retained_variant_properties, :deployment_config, :retain_deployment_config) SENSITIVE = [] include Aws::Structure end |
#endpoint_config_name ⇒ String
The name of the new endpoint configuration.
43155 43156 43157 43158 43159 43160 43161 43162 43163 43164 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43155 class UpdateEndpointInput < Struct.new( :endpoint_name, :endpoint_config_name, :retain_all_variant_properties, :exclude_retained_variant_properties, :deployment_config, :retain_deployment_config) SENSITIVE = [] include Aws::Structure end |
#endpoint_name ⇒ String
The name of the endpoint whose configuration you want to update.
43155 43156 43157 43158 43159 43160 43161 43162 43163 43164 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43155 class UpdateEndpointInput < Struct.new( :endpoint_name, :endpoint_config_name, :retain_all_variant_properties, :exclude_retained_variant_properties, :deployment_config, :retain_deployment_config) SENSITIVE = [] include Aws::Structure end |
#exclude_retained_variant_properties ⇒ Array<Types::VariantProperty>
When you are updating endpoint resources with RetainAllVariantProperties, whose value is set to true, ExcludeRetainedVariantProperties specifies the list of type
- VariantProperty][1
-
to override with the values provided by
EndpointConfig. If you don’t specify a value for ExcludeRetainedVariantProperties, no variant properties are overridden.
[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_VariantProperty.html
43155 43156 43157 43158 43159 43160 43161 43162 43163 43164 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43155 class UpdateEndpointInput < Struct.new( :endpoint_name, :endpoint_config_name, :retain_all_variant_properties, :exclude_retained_variant_properties, :deployment_config, :retain_deployment_config) SENSITIVE = [] include Aws::Structure end |
#retain_all_variant_properties ⇒ Boolean
When updating endpoint resources, enables or disables the retention of [variant properties], such as the instance count or the variant weight. To retain the variant properties of an endpoint when updating it, set RetainAllVariantProperties to true. To use the variant properties specified in a new EndpointConfig call when updating an endpoint, set RetainAllVariantProperties to false. The default is false.
[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_VariantProperty.html
43155 43156 43157 43158 43159 43160 43161 43162 43163 43164 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43155 class UpdateEndpointInput < Struct.new( :endpoint_name, :endpoint_config_name, :retain_all_variant_properties, :exclude_retained_variant_properties, :deployment_config, :retain_deployment_config) SENSITIVE = [] include Aws::Structure end |
#retain_deployment_config ⇒ Boolean
Specifies whether to reuse the last deployment configuration. The default value is false (the configuration is not reused).
43155 43156 43157 43158 43159 43160 43161 43162 43163 43164 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43155 class UpdateEndpointInput < Struct.new( :endpoint_name, :endpoint_config_name, :retain_all_variant_properties, :exclude_retained_variant_properties, :deployment_config, :retain_deployment_config) SENSITIVE = [] include Aws::Structure end |