Class: Aws::SageMaker::Types::UpdateHubContentReferenceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::UpdateHubContentReferenceRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#hub_content_name ⇒ String
The name of the hub content resource that you want to update.
-
#hub_content_type ⇒ String
The content type of the resource that you want to update.
-
#hub_name ⇒ String
The name of the SageMaker hub that contains the hub content you want to update.
-
#min_version ⇒ String
The minimum hub content version of the referenced model that you want to use.
Instance Attribute Details
#hub_content_name ⇒ String
The name of the hub content resource that you want to update.
57536 57537 57538 57539 57540 57541 57542 57543 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 57536 class UpdateHubContentReferenceRequest < Struct.new( :hub_name, :hub_content_name, :hub_content_type, :min_version) SENSITIVE = [] include Aws::Structure end |
#hub_content_type ⇒ String
The content type of the resource that you want to update. Only
specify a ModelReference resource for this API. To update a
Model or Notebook resource, use the UpdateHubContent API
instead.
57536 57537 57538 57539 57540 57541 57542 57543 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 57536 class UpdateHubContentReferenceRequest < Struct.new( :hub_name, :hub_content_name, :hub_content_type, :min_version) SENSITIVE = [] include Aws::Structure end |
#hub_name ⇒ String
The name of the SageMaker hub that contains the hub content you want to update. You can optionally use the hub ARN instead.
57536 57537 57538 57539 57540 57541 57542 57543 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 57536 class UpdateHubContentReferenceRequest < Struct.new( :hub_name, :hub_content_name, :hub_content_type, :min_version) SENSITIVE = [] include Aws::Structure end |
#min_version ⇒ String
The minimum hub content version of the referenced model that you
want to use. The minimum version must be older than the latest
available version of the referenced model. To support all versions
of a model, set the value to 1.0.0.
57536 57537 57538 57539 57540 57541 57542 57543 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 57536 class UpdateHubContentReferenceRequest < Struct.new( :hub_name, :hub_content_name, :hub_content_type, :min_version) SENSITIVE = [] include Aws::Structure end |