Class: Aws::SageMaker::Types::UpdateInferenceComponentRuntimeConfigInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::UpdateInferenceComponentRuntimeConfigInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#desired_runtime_config ⇒ Types::InferenceComponentRuntimeConfig
Runtime settings for a model that is deployed with an inference component.
-
#inference_component_name ⇒ String
The name of the inference component to update.
Instance Attribute Details
#desired_runtime_config ⇒ Types::InferenceComponentRuntimeConfig
Runtime settings for a model that is deployed with an inference component.
53801 53802 53803 53804 53805 53806 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53801 class UpdateInferenceComponentRuntimeConfigInput < Struct.new( :inference_component_name, :desired_runtime_config) SENSITIVE = [] include Aws::Structure end |
#inference_component_name ⇒ String
The name of the inference component to update.
53801 53802 53803 53804 53805 53806 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53801 class UpdateInferenceComponentRuntimeConfigInput < Struct.new( :inference_component_name, :desired_runtime_config) SENSITIVE = [] include Aws::Structure end |