Class: Aws::SageMaker::Types::UpdateMlflowAppRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_default_statusString

Indicates whether this this MLflow App is the default for the account.

Returns:

  • (String)


57447
57448
57449
57450
57451
57452
57453
57454
57455
57456
57457
# File 'lib/aws-sdk-sagemaker/types.rb', line 57447

class UpdateMlflowAppRequest < Struct.new(
  :arn,
  :name,
  :artifact_store_uri,
  :model_registration_mode,
  :weekly_maintenance_window_start,
  :default_domain_id_list,
  :account_default_status)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The ARN of the MLflow App to update.

Returns:

  • (String)


57447
57448
57449
57450
57451
57452
57453
57454
57455
57456
57457
# File 'lib/aws-sdk-sagemaker/types.rb', line 57447

class UpdateMlflowAppRequest < Struct.new(
  :arn,
  :name,
  :artifact_store_uri,
  :model_registration_mode,
  :weekly_maintenance_window_start,
  :default_domain_id_list,
  :account_default_status)
  SENSITIVE = []
  include Aws::Structure
end

#artifact_store_uriString

The new S3 URI for the general purpose bucket to use as the artifact store for the MLflow App.

Returns:

  • (String)


57447
57448
57449
57450
57451
57452
57453
57454
57455
57456
57457
# File 'lib/aws-sdk-sagemaker/types.rb', line 57447

class UpdateMlflowAppRequest < Struct.new(
  :arn,
  :name,
  :artifact_store_uri,
  :model_registration_mode,
  :weekly_maintenance_window_start,
  :default_domain_id_list,
  :account_default_status)
  SENSITIVE = []
  include Aws::Structure
end

#default_domain_id_listArray<String>

List of SageMaker Domain IDs for which this MLflow App is the default.

Returns:

  • (Array<String>)


57447
57448
57449
57450
57451
57452
57453
57454
57455
57456
57457
# File 'lib/aws-sdk-sagemaker/types.rb', line 57447

class UpdateMlflowAppRequest < Struct.new(
  :arn,
  :name,
  :artifact_store_uri,
  :model_registration_mode,
  :weekly_maintenance_window_start,
  :default_domain_id_list,
  :account_default_status)
  SENSITIVE = []
  include Aws::Structure
end

#model_registration_modeString

Whether to enable or disable automatic registration of new MLflow models to the SageMaker Model Registry. To enable automatic model registration, set this value to AutoModelRegistrationEnabled. To disable automatic model registration, set this value to AutoModelRegistrationDisabled. If not specified, AutomaticModelRegistration defaults to AutoModelRegistrationEnabled

Returns:

  • (String)


57447
57448
57449
57450
57451
57452
57453
57454
57455
57456
57457
# File 'lib/aws-sdk-sagemaker/types.rb', line 57447

class UpdateMlflowAppRequest < Struct.new(
  :arn,
  :name,
  :artifact_store_uri,
  :model_registration_mode,
  :weekly_maintenance_window_start,
  :default_domain_id_list,
  :account_default_status)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the MLflow App to update.

Returns:

  • (String)


57447
57448
57449
57450
57451
57452
57453
57454
57455
57456
57457
# File 'lib/aws-sdk-sagemaker/types.rb', line 57447

class UpdateMlflowAppRequest < Struct.new(
  :arn,
  :name,
  :artifact_store_uri,
  :model_registration_mode,
  :weekly_maintenance_window_start,
  :default_domain_id_list,
  :account_default_status)
  SENSITIVE = []
  include Aws::Structure
end

#weekly_maintenance_window_startString

The new weekly maintenance window start day and time to update. The maintenance window day and time should be in Coordinated Universal Time (UTC) 24-hour standard time. For example: TUE:03:30.

Returns:

  • (String)


57447
57448
57449
57450
57451
57452
57453
57454
57455
57456
57457
# File 'lib/aws-sdk-sagemaker/types.rb', line 57447

class UpdateMlflowAppRequest < Struct.new(
  :arn,
  :name,
  :artifact_store_uri,
  :model_registration_mode,
  :weekly_maintenance_window_start,
  :default_domain_id_list,
  :account_default_status)
  SENSITIVE = []
  include Aws::Structure
end