Class: Aws::SageMaker::Types::UpdateMlflowTrackingServerRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#artifact_store_uri ⇒ String

The new S3 URI for the general purpose bucket to use as the artifact store for the MLflow Tracking Server.



58197
58198
58199
58200
58201
58202
58203
58204
58205
58206
58207
# File 'lib/aws-sdk-sagemaker/types.rb', line 58197

class UpdateMlflowTrackingServerRequest < Struct.new(
  :tracking_server_name,
  :artifact_store_uri,
  :tracking_server_size,
  :automatic_model_registration,
  :weekly_maintenance_window_start,
  :s3_bucket_owner_account_id,
  :s3_bucket_owner_verification)
  SENSITIVE = []
  include Aws::Structure
end

#automatic_model_registration ⇒ Boolean

Whether to enable or disable automatic registration of new MLflow models to the SageMaker Model Registry. To enable automatic model registration, set this value to True. To disable automatic model registration, set this value to False. If not specified, AutomaticModelRegistration defaults to False



58197
58198
58199
58200
58201
58202
58203
58204
58205
58206
58207
# File 'lib/aws-sdk-sagemaker/types.rb', line 58197

class UpdateMlflowTrackingServerRequest < Struct.new(
  :tracking_server_name,
  :artifact_store_uri,
  :tracking_server_size,
  :automatic_model_registration,
  :weekly_maintenance_window_start,
  :s3_bucket_owner_account_id,
  :s3_bucket_owner_verification)
  SENSITIVE = []
  include Aws::Structure
end

#s3_bucket_owner_account_id ⇒ String

The new expected Amazon Web Services account ID that owns the Amazon S3 bucket for artifact storage.



58197
58198
58199
58200
58201
58202
58203
58204
58205
58206
58207
# File 'lib/aws-sdk-sagemaker/types.rb', line 58197

class UpdateMlflowTrackingServerRequest < Struct.new(
  :tracking_server_name,
  :artifact_store_uri,
  :tracking_server_size,
  :automatic_model_registration,
  :weekly_maintenance_window_start,
  :s3_bucket_owner_account_id,
  :s3_bucket_owner_verification)
  SENSITIVE = []
  include Aws::Structure
end

#s3_bucket_owner_verification ⇒ Boolean

Whether to enable or disable Amazon S3 Bucket Owenrship Verifaction whenever the MLflow Tracking Server interacts with Amazon Amazon S3.



58197
58198
58199
58200
58201
58202
58203
58204
58205
58206
58207
# File 'lib/aws-sdk-sagemaker/types.rb', line 58197

class UpdateMlflowTrackingServerRequest < Struct.new(
  :tracking_server_name,
  :artifact_store_uri,
  :tracking_server_size,
  :automatic_model_registration,
  :weekly_maintenance_window_start,
  :s3_bucket_owner_account_id,
  :s3_bucket_owner_verification)
  SENSITIVE = []
  include Aws::Structure
end

#tracking_server_name ⇒ String

The name of the MLflow Tracking Server to update.



58197
58198
58199
58200
58201
58202
58203
58204
58205
58206
58207
# File 'lib/aws-sdk-sagemaker/types.rb', line 58197

class UpdateMlflowTrackingServerRequest < Struct.new(
  :tracking_server_name,
  :artifact_store_uri,
  :tracking_server_size,
  :automatic_model_registration,
  :weekly_maintenance_window_start,
  :s3_bucket_owner_account_id,
  :s3_bucket_owner_verification)
  SENSITIVE = []
  include Aws::Structure
end

#tracking_server_size ⇒ String

The new size for the MLflow Tracking Server.



58197
58198
58199
58200
58201
58202
58203
58204
58205
58206
58207
# File 'lib/aws-sdk-sagemaker/types.rb', line 58197

class UpdateMlflowTrackingServerRequest < Struct.new(
  :tracking_server_name,
  :artifact_store_uri,
  :tracking_server_size,
  :automatic_model_registration,
  :weekly_maintenance_window_start,
  :s3_bucket_owner_account_id,
  :s3_bucket_owner_verification)
  SENSITIVE = []
  include Aws::Structure
end

#weekly_maintenance_window_start ⇒ String

The new weekly maintenance window start day and time to update. The maintenance window day and time should be in Coordinated Universal Time (UTC) 24-hour standard time. For example: TUE:03:30.



58197
58198
58199
58200
58201
58202
58203
58204
58205
58206
58207
# File 'lib/aws-sdk-sagemaker/types.rb', line 58197

class UpdateMlflowTrackingServerRequest < Struct.new(
  :tracking_server_name,
  :artifact_store_uri,
  :tracking_server_size,
  :automatic_model_registration,
  :weekly_maintenance_window_start,
  :s3_bucket_owner_account_id,
  :s3_bucket_owner_verification)
  SENSITIVE = []
  include Aws::Structure
end