Class: Aws::SageMaker::Types::UpdateTrainingJobRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#profiler_configTypes::ProfilerConfigForUpdate

Configuration information for Amazon SageMaker Debugger system monitoring, framework profiling, and storage paths.



55027
55028
55029
55030
55031
55032
55033
55034
55035
# File 'lib/aws-sdk-sagemaker/types.rb', line 55027

class UpdateTrainingJobRequest < Struct.new(
  :training_job_name,
  :profiler_config,
  :profiler_rule_configurations,
  :resource_config,
  :remote_debug_config)
  SENSITIVE = []
  include Aws::Structure
end

#profiler_rule_configurationsArray<Types::ProfilerRuleConfiguration>

Configuration information for Amazon SageMaker Debugger rules for profiling system and framework metrics.



55027
55028
55029
55030
55031
55032
55033
55034
55035
# File 'lib/aws-sdk-sagemaker/types.rb', line 55027

class UpdateTrainingJobRequest < Struct.new(
  :training_job_name,
  :profiler_config,
  :profiler_rule_configurations,
  :resource_config,
  :remote_debug_config)
  SENSITIVE = []
  include Aws::Structure
end

#remote_debug_configTypes::RemoteDebugConfigForUpdate

Configuration for remote debugging while the training job is running. You can update the remote debugging configuration when the SecondaryStatus of the job is Downloading or Training.To learn more about the remote debugging functionality of SageMaker, see [Access a training container through Amazon Web Services Systems Manager (SSM) for remote debugging].

[1]: docs.aws.amazon.com/sagemaker/latest/dg/train-remote-debugging.html



55027
55028
55029
55030
55031
55032
55033
55034
55035
# File 'lib/aws-sdk-sagemaker/types.rb', line 55027

class UpdateTrainingJobRequest < Struct.new(
  :training_job_name,
  :profiler_config,
  :profiler_rule_configurations,
  :resource_config,
  :remote_debug_config)
  SENSITIVE = []
  include Aws::Structure
end

#resource_configTypes::ResourceConfigForUpdate

The training job ResourceConfig to update warm pool retention length.



55027
55028
55029
55030
55031
55032
55033
55034
55035
# File 'lib/aws-sdk-sagemaker/types.rb', line 55027

class UpdateTrainingJobRequest < Struct.new(
  :training_job_name,
  :profiler_config,
  :profiler_rule_configurations,
  :resource_config,
  :remote_debug_config)
  SENSITIVE = []
  include Aws::Structure
end

#training_job_nameString

The name of a training job to update the Debugger profiling configuration.

Returns:

  • (String)


55027
55028
55029
55030
55031
55032
55033
55034
55035
# File 'lib/aws-sdk-sagemaker/types.rb', line 55027

class UpdateTrainingJobRequest < Struct.new(
  :training_job_name,
  :profiler_config,
  :profiler_rule_configurations,
  :resource_config,
  :remote_debug_config)
  SENSITIVE = []
  include Aws::Structure
end