Class: Aws::SageMaker::Types::UpdateWorkforceRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ip_address_typeString

Use this parameter to specify whether you want IPv4 only or dualstack (IPv4 and IPv6) to support your labeling workforce.

Returns:

  • (String)


59266
59267
59268
59269
59270
59271
59272
59273
59274
# File 'lib/aws-sdk-sagemaker/types.rb', line 59266

class UpdateWorkforceRequest < Struct.new(
  :workforce_name,
  :source_ip_config,
  :oidc_config,
  :workforce_vpc_config,
  :ip_address_type)
  SENSITIVE = []
  include Aws::Structure
end

#oidc_configTypes::OidcConfig

Use this parameter to update your OIDC Identity Provider (IdP) configuration for a workforce made using your own IdP.

Returns:



59266
59267
59268
59269
59270
59271
59272
59273
59274
# File 'lib/aws-sdk-sagemaker/types.rb', line 59266

class UpdateWorkforceRequest < Struct.new(
  :workforce_name,
  :source_ip_config,
  :oidc_config,
  :workforce_vpc_config,
  :ip_address_type)
  SENSITIVE = []
  include Aws::Structure
end

#source_ip_configTypes::SourceIpConfig

A list of one to ten worker IP address ranges (CIDRs) that can be used to access tasks assigned to this workforce.

Maximum: Ten CIDR values



59266
59267
59268
59269
59270
59271
59272
59273
59274
# File 'lib/aws-sdk-sagemaker/types.rb', line 59266

class UpdateWorkforceRequest < Struct.new(
  :workforce_name,
  :source_ip_config,
  :oidc_config,
  :workforce_vpc_config,
  :ip_address_type)
  SENSITIVE = []
  include Aws::Structure
end

#workforce_nameString

The name of the private workforce that you want to update. You can find your workforce name by using the ListWorkforces operation.

Returns:

  • (String)


59266
59267
59268
59269
59270
59271
59272
59273
59274
# File 'lib/aws-sdk-sagemaker/types.rb', line 59266

class UpdateWorkforceRequest < Struct.new(
  :workforce_name,
  :source_ip_config,
  :oidc_config,
  :workforce_vpc_config,
  :ip_address_type)
  SENSITIVE = []
  include Aws::Structure
end

#workforce_vpc_configTypes::WorkforceVpcConfigRequest

Use this parameter to update your VPC configuration for a workforce.



59266
59267
59268
59269
59270
59271
59272
59273
59274
# File 'lib/aws-sdk-sagemaker/types.rb', line 59266

class UpdateWorkforceRequest < Struct.new(
  :workforce_name,
  :source_ip_config,
  :oidc_config,
  :workforce_vpc_config,
  :ip_address_type)
  SENSITIVE = []
  include Aws::Structure
end