Class: Aws::SageMaker::Types::UserSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::UserSettings
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
A collection of settings that apply to users in a domain. These settings are specified when the CreateUserProfile API is called, and as DefaultUserSettings when the CreateDomain API is called.
SecurityGroups is aggregated when specified in both calls. For all other settings in UserSettings, the values specified in CreateUserProfile take precedence over those specified in CreateDomain.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_mount_home_efs ⇒ String
Indicates whether auto-mounting of an EFS volume is supported for the user profile.
-
#canvas_app_settings ⇒ Types::CanvasAppSettings
The Canvas app settings.
-
#code_editor_app_settings ⇒ Types::CodeEditorAppSettings
The Code Editor application settings.
-
#custom_file_system_configs ⇒ Array<Types::CustomFileSystemConfig>
The settings for assigning a custom file system to a user profile.
-
#custom_posix_user_config ⇒ Types::CustomPosixUserConfig
Details about the POSIX identity that is used for file system operations.
-
#default_landing_uri ⇒ String
The default experience that the user is directed to when accessing the domain.
-
#execution_role ⇒ String
The execution role for the user.
-
#jupyter_lab_app_settings ⇒ Types::JupyterLabAppSettings
The settings for the JupyterLab application.
-
#jupyter_server_app_settings ⇒ Types::JupyterServerAppSettings
The Jupyter server’s app settings.
-
#kernel_gateway_app_settings ⇒ Types::KernelGatewayAppSettings
The kernel gateway app settings.
-
#r_session_app_settings ⇒ Types::RSessionAppSettings
A collection of settings that configure the
RSessionGatewayapp. -
#r_studio_server_pro_app_settings ⇒ Types::RStudioServerProAppSettings
A collection of settings that configure user interaction with the
RStudioServerProapp. -
#security_groups ⇒ Array<String>
The security groups for the Amazon Virtual Private Cloud (VPC) that the domain uses for communication.
-
#sharing_settings ⇒ Types::SharingSettings
Specifies options for sharing Amazon SageMaker AI Studio notebooks.
-
#space_storage_settings ⇒ Types::DefaultSpaceStorageSettings
The storage settings for a space.
-
#studio_web_portal ⇒ String
Whether the user can access Studio.
-
#studio_web_portal_settings ⇒ Types::StudioWebPortalSettings
Studio settings.
-
#tensor_board_app_settings ⇒ Types::TensorBoardAppSettings
The TensorBoard app settings.
Instance Attribute Details
#auto_mount_home_efs ⇒ String
Indicates whether auto-mounting of an EFS volume is supported for the user profile. The DefaultAsDomain value is only supported for user profiles. Do not use the DefaultAsDomain value when setting this parameter for a domain.
SageMaker applies this setting only to private spaces that the user creates in the domain. SageMaker doesn’t apply this setting to shared spaces.
55553 55554 55555 55556 55557 55558 55559 55560 55561 55562 55563 55564 55565 55566 55567 55568 55569 55570 55571 55572 55573 55574 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55553 class UserSettings < Struct.new( :execution_role, :security_groups, :sharing_settings, :jupyter_server_app_settings, :kernel_gateway_app_settings, :tensor_board_app_settings, :r_studio_server_pro_app_settings, :r_session_app_settings, :canvas_app_settings, :code_editor_app_settings, :jupyter_lab_app_settings, :space_storage_settings, :default_landing_uri, :studio_web_portal, :custom_posix_user_config, :custom_file_system_configs, :studio_web_portal_settings, :auto_mount_home_efs) SENSITIVE = [] include Aws::Structure end |
#canvas_app_settings ⇒ Types::CanvasAppSettings
The Canvas app settings.
SageMaker applies these settings only to private spaces that SageMaker creates for the Canvas app.
55553 55554 55555 55556 55557 55558 55559 55560 55561 55562 55563 55564 55565 55566 55567 55568 55569 55570 55571 55572 55573 55574 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55553 class UserSettings < Struct.new( :execution_role, :security_groups, :sharing_settings, :jupyter_server_app_settings, :kernel_gateway_app_settings, :tensor_board_app_settings, :r_studio_server_pro_app_settings, :r_session_app_settings, :canvas_app_settings, :code_editor_app_settings, :jupyter_lab_app_settings, :space_storage_settings, :default_landing_uri, :studio_web_portal, :custom_posix_user_config, :custom_file_system_configs, :studio_web_portal_settings, :auto_mount_home_efs) SENSITIVE = [] include Aws::Structure end |
#code_editor_app_settings ⇒ Types::CodeEditorAppSettings
The Code Editor application settings.
SageMaker applies these settings only to private spaces that the user creates in the domain. SageMaker doesn’t apply these settings to shared spaces.
55553 55554 55555 55556 55557 55558 55559 55560 55561 55562 55563 55564 55565 55566 55567 55568 55569 55570 55571 55572 55573 55574 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55553 class UserSettings < Struct.new( :execution_role, :security_groups, :sharing_settings, :jupyter_server_app_settings, :kernel_gateway_app_settings, :tensor_board_app_settings, :r_studio_server_pro_app_settings, :r_session_app_settings, :canvas_app_settings, :code_editor_app_settings, :jupyter_lab_app_settings, :space_storage_settings, :default_landing_uri, :studio_web_portal, :custom_posix_user_config, :custom_file_system_configs, :studio_web_portal_settings, :auto_mount_home_efs) SENSITIVE = [] include Aws::Structure end |
#custom_file_system_configs ⇒ Array<Types::CustomFileSystemConfig>
The settings for assigning a custom file system to a user profile. Permitted users can access this file system in Amazon SageMaker AI Studio.
SageMaker applies these settings only to private spaces that the user creates in the domain. SageMaker doesn’t apply these settings to shared spaces.
55553 55554 55555 55556 55557 55558 55559 55560 55561 55562 55563 55564 55565 55566 55567 55568 55569 55570 55571 55572 55573 55574 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55553 class UserSettings < Struct.new( :execution_role, :security_groups, :sharing_settings, :jupyter_server_app_settings, :kernel_gateway_app_settings, :tensor_board_app_settings, :r_studio_server_pro_app_settings, :r_session_app_settings, :canvas_app_settings, :code_editor_app_settings, :jupyter_lab_app_settings, :space_storage_settings, :default_landing_uri, :studio_web_portal, :custom_posix_user_config, :custom_file_system_configs, :studio_web_portal_settings, :auto_mount_home_efs) SENSITIVE = [] include Aws::Structure end |
#custom_posix_user_config ⇒ Types::CustomPosixUserConfig
Details about the POSIX identity that is used for file system operations.
SageMaker applies these settings only to private spaces that the user creates in the domain. SageMaker doesn’t apply these settings to shared spaces.
55553 55554 55555 55556 55557 55558 55559 55560 55561 55562 55563 55564 55565 55566 55567 55568 55569 55570 55571 55572 55573 55574 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55553 class UserSettings < Struct.new( :execution_role, :security_groups, :sharing_settings, :jupyter_server_app_settings, :kernel_gateway_app_settings, :tensor_board_app_settings, :r_studio_server_pro_app_settings, :r_session_app_settings, :canvas_app_settings, :code_editor_app_settings, :jupyter_lab_app_settings, :space_storage_settings, :default_landing_uri, :studio_web_portal, :custom_posix_user_config, :custom_file_system_configs, :studio_web_portal_settings, :auto_mount_home_efs) SENSITIVE = [] include Aws::Structure end |
#default_landing_uri ⇒ String
The default experience that the user is directed to when accessing the domain. The supported values are:
-
studio::: Indicates that Studio is the default experience. This value can only be passed ifStudioWebPortalis set toENABLED. -
app:JupyterServer:: Indicates that Studio Classic is the default experience.
55553 55554 55555 55556 55557 55558 55559 55560 55561 55562 55563 55564 55565 55566 55567 55568 55569 55570 55571 55572 55573 55574 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55553 class UserSettings < Struct.new( :execution_role, :security_groups, :sharing_settings, :jupyter_server_app_settings, :kernel_gateway_app_settings, :tensor_board_app_settings, :r_studio_server_pro_app_settings, :r_session_app_settings, :canvas_app_settings, :code_editor_app_settings, :jupyter_lab_app_settings, :space_storage_settings, :default_landing_uri, :studio_web_portal, :custom_posix_user_config, :custom_file_system_configs, :studio_web_portal_settings, :auto_mount_home_efs) SENSITIVE = [] include Aws::Structure end |
#execution_role ⇒ String
The execution role for the user.
SageMaker applies this setting only to private spaces that the user creates in the domain. SageMaker doesn’t apply this setting to shared spaces.
55553 55554 55555 55556 55557 55558 55559 55560 55561 55562 55563 55564 55565 55566 55567 55568 55569 55570 55571 55572 55573 55574 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55553 class UserSettings < Struct.new( :execution_role, :security_groups, :sharing_settings, :jupyter_server_app_settings, :kernel_gateway_app_settings, :tensor_board_app_settings, :r_studio_server_pro_app_settings, :r_session_app_settings, :canvas_app_settings, :code_editor_app_settings, :jupyter_lab_app_settings, :space_storage_settings, :default_landing_uri, :studio_web_portal, :custom_posix_user_config, :custom_file_system_configs, :studio_web_portal_settings, :auto_mount_home_efs) SENSITIVE = [] include Aws::Structure end |
#jupyter_lab_app_settings ⇒ Types::JupyterLabAppSettings
The settings for the JupyterLab application.
SageMaker applies these settings only to private spaces that the user creates in the domain. SageMaker doesn’t apply these settings to shared spaces.
55553 55554 55555 55556 55557 55558 55559 55560 55561 55562 55563 55564 55565 55566 55567 55568 55569 55570 55571 55572 55573 55574 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55553 class UserSettings < Struct.new( :execution_role, :security_groups, :sharing_settings, :jupyter_server_app_settings, :kernel_gateway_app_settings, :tensor_board_app_settings, :r_studio_server_pro_app_settings, :r_session_app_settings, :canvas_app_settings, :code_editor_app_settings, :jupyter_lab_app_settings, :space_storage_settings, :default_landing_uri, :studio_web_portal, :custom_posix_user_config, :custom_file_system_configs, :studio_web_portal_settings, :auto_mount_home_efs) SENSITIVE = [] include Aws::Structure end |
#jupyter_server_app_settings ⇒ Types::JupyterServerAppSettings
The Jupyter server’s app settings.
55553 55554 55555 55556 55557 55558 55559 55560 55561 55562 55563 55564 55565 55566 55567 55568 55569 55570 55571 55572 55573 55574 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55553 class UserSettings < Struct.new( :execution_role, :security_groups, :sharing_settings, :jupyter_server_app_settings, :kernel_gateway_app_settings, :tensor_board_app_settings, :r_studio_server_pro_app_settings, :r_session_app_settings, :canvas_app_settings, :code_editor_app_settings, :jupyter_lab_app_settings, :space_storage_settings, :default_landing_uri, :studio_web_portal, :custom_posix_user_config, :custom_file_system_configs, :studio_web_portal_settings, :auto_mount_home_efs) SENSITIVE = [] include Aws::Structure end |
#kernel_gateway_app_settings ⇒ Types::KernelGatewayAppSettings
The kernel gateway app settings.
55553 55554 55555 55556 55557 55558 55559 55560 55561 55562 55563 55564 55565 55566 55567 55568 55569 55570 55571 55572 55573 55574 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55553 class UserSettings < Struct.new( :execution_role, :security_groups, :sharing_settings, :jupyter_server_app_settings, :kernel_gateway_app_settings, :tensor_board_app_settings, :r_studio_server_pro_app_settings, :r_session_app_settings, :canvas_app_settings, :code_editor_app_settings, :jupyter_lab_app_settings, :space_storage_settings, :default_landing_uri, :studio_web_portal, :custom_posix_user_config, :custom_file_system_configs, :studio_web_portal_settings, :auto_mount_home_efs) SENSITIVE = [] include Aws::Structure end |
#r_session_app_settings ⇒ Types::RSessionAppSettings
A collection of settings that configure the RSessionGateway app.
55553 55554 55555 55556 55557 55558 55559 55560 55561 55562 55563 55564 55565 55566 55567 55568 55569 55570 55571 55572 55573 55574 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55553 class UserSettings < Struct.new( :execution_role, :security_groups, :sharing_settings, :jupyter_server_app_settings, :kernel_gateway_app_settings, :tensor_board_app_settings, :r_studio_server_pro_app_settings, :r_session_app_settings, :canvas_app_settings, :code_editor_app_settings, :jupyter_lab_app_settings, :space_storage_settings, :default_landing_uri, :studio_web_portal, :custom_posix_user_config, :custom_file_system_configs, :studio_web_portal_settings, :auto_mount_home_efs) SENSITIVE = [] include Aws::Structure end |
#r_studio_server_pro_app_settings ⇒ Types::RStudioServerProAppSettings
A collection of settings that configure user interaction with the RStudioServerPro app.
55553 55554 55555 55556 55557 55558 55559 55560 55561 55562 55563 55564 55565 55566 55567 55568 55569 55570 55571 55572 55573 55574 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55553 class UserSettings < Struct.new( :execution_role, :security_groups, :sharing_settings, :jupyter_server_app_settings, :kernel_gateway_app_settings, :tensor_board_app_settings, :r_studio_server_pro_app_settings, :r_session_app_settings, :canvas_app_settings, :code_editor_app_settings, :jupyter_lab_app_settings, :space_storage_settings, :default_landing_uri, :studio_web_portal, :custom_posix_user_config, :custom_file_system_configs, :studio_web_portal_settings, :auto_mount_home_efs) SENSITIVE = [] include Aws::Structure end |
#security_groups ⇒ Array<String>
The security groups for the Amazon Virtual Private Cloud (VPC) that the domain uses for communication.
Optional when the CreateDomain.AppNetworkAccessType parameter is set to PublicInternetOnly.
Required when the CreateDomain.AppNetworkAccessType parameter is set to VpcOnly, unless specified as part of the DefaultUserSettings for the domain.
Amazon SageMaker AI adds a security group to allow NFS traffic from Amazon SageMaker AI Studio. Therefore, the number of security groups that you can specify is one less than the maximum number shown.
SageMaker applies these settings only to private spaces that the user creates in the domain. SageMaker doesn’t apply these settings to shared spaces.
55553 55554 55555 55556 55557 55558 55559 55560 55561 55562 55563 55564 55565 55566 55567 55568 55569 55570 55571 55572 55573 55574 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55553 class UserSettings < Struct.new( :execution_role, :security_groups, :sharing_settings, :jupyter_server_app_settings, :kernel_gateway_app_settings, :tensor_board_app_settings, :r_studio_server_pro_app_settings, :r_session_app_settings, :canvas_app_settings, :code_editor_app_settings, :jupyter_lab_app_settings, :space_storage_settings, :default_landing_uri, :studio_web_portal, :custom_posix_user_config, :custom_file_system_configs, :studio_web_portal_settings, :auto_mount_home_efs) SENSITIVE = [] include Aws::Structure end |
#sharing_settings ⇒ Types::SharingSettings
Specifies options for sharing Amazon SageMaker AI Studio notebooks.
55553 55554 55555 55556 55557 55558 55559 55560 55561 55562 55563 55564 55565 55566 55567 55568 55569 55570 55571 55572 55573 55574 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55553 class UserSettings < Struct.new( :execution_role, :security_groups, :sharing_settings, :jupyter_server_app_settings, :kernel_gateway_app_settings, :tensor_board_app_settings, :r_studio_server_pro_app_settings, :r_session_app_settings, :canvas_app_settings, :code_editor_app_settings, :jupyter_lab_app_settings, :space_storage_settings, :default_landing_uri, :studio_web_portal, :custom_posix_user_config, :custom_file_system_configs, :studio_web_portal_settings, :auto_mount_home_efs) SENSITIVE = [] include Aws::Structure end |
#space_storage_settings ⇒ Types::DefaultSpaceStorageSettings
The storage settings for a space.
SageMaker applies these settings only to private spaces that the user creates in the domain. SageMaker doesn’t apply these settings to shared spaces.
55553 55554 55555 55556 55557 55558 55559 55560 55561 55562 55563 55564 55565 55566 55567 55568 55569 55570 55571 55572 55573 55574 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55553 class UserSettings < Struct.new( :execution_role, :security_groups, :sharing_settings, :jupyter_server_app_settings, :kernel_gateway_app_settings, :tensor_board_app_settings, :r_studio_server_pro_app_settings, :r_session_app_settings, :canvas_app_settings, :code_editor_app_settings, :jupyter_lab_app_settings, :space_storage_settings, :default_landing_uri, :studio_web_portal, :custom_posix_user_config, :custom_file_system_configs, :studio_web_portal_settings, :auto_mount_home_efs) SENSITIVE = [] include Aws::Structure end |
#studio_web_portal ⇒ String
Whether the user can access Studio. If this value is set to DISABLED, the user cannot access Studio, even if that is the default experience for the domain.
55553 55554 55555 55556 55557 55558 55559 55560 55561 55562 55563 55564 55565 55566 55567 55568 55569 55570 55571 55572 55573 55574 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55553 class UserSettings < Struct.new( :execution_role, :security_groups, :sharing_settings, :jupyter_server_app_settings, :kernel_gateway_app_settings, :tensor_board_app_settings, :r_studio_server_pro_app_settings, :r_session_app_settings, :canvas_app_settings, :code_editor_app_settings, :jupyter_lab_app_settings, :space_storage_settings, :default_landing_uri, :studio_web_portal, :custom_posix_user_config, :custom_file_system_configs, :studio_web_portal_settings, :auto_mount_home_efs) SENSITIVE = [] include Aws::Structure end |
#studio_web_portal_settings ⇒ Types::StudioWebPortalSettings
Studio settings. If these settings are applied on a user level, they take priority over the settings applied on a domain level.
55553 55554 55555 55556 55557 55558 55559 55560 55561 55562 55563 55564 55565 55566 55567 55568 55569 55570 55571 55572 55573 55574 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55553 class UserSettings < Struct.new( :execution_role, :security_groups, :sharing_settings, :jupyter_server_app_settings, :kernel_gateway_app_settings, :tensor_board_app_settings, :r_studio_server_pro_app_settings, :r_session_app_settings, :canvas_app_settings, :code_editor_app_settings, :jupyter_lab_app_settings, :space_storage_settings, :default_landing_uri, :studio_web_portal, :custom_posix_user_config, :custom_file_system_configs, :studio_web_portal_settings, :auto_mount_home_efs) SENSITIVE = [] include Aws::Structure end |
#tensor_board_app_settings ⇒ Types::TensorBoardAppSettings
The TensorBoard app settings.
55553 55554 55555 55556 55557 55558 55559 55560 55561 55562 55563 55564 55565 55566 55567 55568 55569 55570 55571 55572 55573 55574 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55553 class UserSettings < Struct.new( :execution_role, :security_groups, :sharing_settings, :jupyter_server_app_settings, :kernel_gateway_app_settings, :tensor_board_app_settings, :r_studio_server_pro_app_settings, :r_session_app_settings, :canvas_app_settings, :code_editor_app_settings, :jupyter_lab_app_settings, :space_storage_settings, :default_landing_uri, :studio_web_portal, :custom_posix_user_config, :custom_file_system_configs, :studio_web_portal_settings, :auto_mount_home_efs) SENSITIVE = [] include Aws::Structure end |