Class: Aws::SageMaker::Types::VariantProperty
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::VariantProperty
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Specifies a production variant property type for an Endpoint.
If you are updating an endpoint with the RetainAllVariantProperties
option of UpdateEndpointInput set to true, the
VariantProperty objects listed in the
ExcludeRetainedVariantProperties parameter of
UpdateEndpointInput override the existing variant properties of
the endpoint.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#variant_property_type ⇒ String
The type of variant property.
Instance Attribute Details
#variant_property_type ⇒ String
The type of variant property. The supported values are:
-
DesiredInstanceCount: Overrides the existing variant instance counts using theInitialInstanceCountvalues in theProductionVariantsof CreateEndpointConfig. -
DesiredWeight: Overrides the existing variant weights using theInitialVariantWeightvalues in theProductionVariantsof CreateEndpointConfig. -
DataCaptureConfig: (Not currently supported.)
59276 59277 59278 59279 59280 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 59276 class VariantProperty < Struct.new( :variant_property_type) SENSITIVE = [] include Aws::Structure end |