Class: Aws::SageMaker::Types::VpcConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::VpcConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Specifies an Amazon Virtual Private Cloud (VPC) that your SageMaker jobs, hosted models, and compute resources have access to. You can control access to and from your resources by configuring a VPC. For more information, see [Give SageMaker Access to Resources in your Amazon VPC].
[1]: docs.aws.amazon.com/sagemaker/latest/dg/infrastructure-give-access.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#security_group_ids ⇒ Array<String>
The VPC security group IDs, in the form ‘sg-xxxxxxxx`.
-
#subnets ⇒ Array<String>
The ID of the subnets in the VPC to which you want to connect your training job or model.
Instance Attribute Details
#security_group_ids ⇒ Array<String>
The VPC security group IDs, in the form ‘sg-xxxxxxxx`. Specify the security groups for the VPC that is specified in the `Subnets` field.
57880 57881 57882 57883 57884 57885 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 57880 class VpcConfig < Struct.new( :security_group_ids, :subnets) SENSITIVE = [] include Aws::Structure end |
#subnets ⇒ Array<String>
The ID of the subnets in the VPC to which you want to connect your training job or model. For information about the availability of specific instance types, see [Supported Instance Types and Availability Zones].
[1]: docs.aws.amazon.com/sagemaker/latest/dg/instance-types-az.html
57880 57881 57882 57883 57884 57885 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 57880 class VpcConfig < Struct.new( :security_group_ids, :subnets) SENSITIVE = [] include Aws::Structure end |