Class: Aws::SageMaker::Types::Workforce
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::Workforce
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
A single private workforce, which is automatically created when you create your first private work team. You can create one private work force in each Amazon Web Services Region. By default, any workforce-related API operation used in a specific region will apply to the workforce created in that region. To learn how to create a private workforce, see Create a Private Workforce.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cognito_config ⇒ Types::CognitoConfig
The configuration of an Amazon Cognito workforce.
-
#create_date ⇒ Time
The date that the workforce is created.
-
#failure_reason ⇒ String
The reason your workforce failed.
-
#ip_address_type ⇒ String
The IP address type you specify - either
IPv4only ordualstack(IPv4andIPv6) - to support your labeling workforce. -
#last_updated_date ⇒ Time
The most recent date that [UpdateWorkforce][1] was used to successfully add one or more IP address ranges ([CIDRs][2]) to a private workforce's allow list.
-
#oidc_config ⇒ Types::OidcConfigForResponse
The configuration of an OIDC Identity Provider (IdP) private workforce.
-
#source_ip_config ⇒ Types::SourceIpConfig
A list of one to ten IP address ranges ([CIDRs][1]) to be added to the workforce allow list.
-
#status ⇒ String
The status of your workforce.
-
#sub_domain ⇒ String
The subdomain for your OIDC Identity Provider.
-
#workforce_arn ⇒ String
The Amazon Resource Name (ARN) of the private workforce.
-
#workforce_name ⇒ String
The name of the private workforce.
-
#workforce_vpc_config ⇒ Types::WorkforceVpcConfigResponse
The configuration of a VPC workforce.
Instance Attribute Details
#cognito_config ⇒ Types::CognitoConfig
The configuration of an Amazon Cognito workforce. A single Cognito workforce is created using and corresponds to a single Amazon Cognito user pool.
59892 59893 59894 59895 59896 59897 59898 59899 59900 59901 59902 59903 59904 59905 59906 59907 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 59892 class Workforce < Struct.new( :workforce_name, :workforce_arn, :last_updated_date, :source_ip_config, :sub_domain, :cognito_config, :oidc_config, :create_date, :workforce_vpc_config, :status, :failure_reason, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#create_date ⇒ Time
The date that the workforce is created.
59892 59893 59894 59895 59896 59897 59898 59899 59900 59901 59902 59903 59904 59905 59906 59907 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 59892 class Workforce < Struct.new( :workforce_name, :workforce_arn, :last_updated_date, :source_ip_config, :sub_domain, :cognito_config, :oidc_config, :create_date, :workforce_vpc_config, :status, :failure_reason, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
The reason your workforce failed.
59892 59893 59894 59895 59896 59897 59898 59899 59900 59901 59902 59903 59904 59905 59906 59907 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 59892 class Workforce < Struct.new( :workforce_name, :workforce_arn, :last_updated_date, :source_ip_config, :sub_domain, :cognito_config, :oidc_config, :create_date, :workforce_vpc_config, :status, :failure_reason, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#ip_address_type ⇒ String
The IP address type you specify - either IPv4 only or dualstack
(IPv4 and IPv6) - to support your labeling workforce.
59892 59893 59894 59895 59896 59897 59898 59899 59900 59901 59902 59903 59904 59905 59906 59907 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 59892 class Workforce < Struct.new( :workforce_name, :workforce_arn, :last_updated_date, :source_ip_config, :sub_domain, :cognito_config, :oidc_config, :create_date, :workforce_vpc_config, :status, :failure_reason, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#last_updated_date ⇒ Time
The most recent date that UpdateWorkforce was used to successfully add one or more IP address ranges (CIDRs) to a private workforce's allow list.
59892 59893 59894 59895 59896 59897 59898 59899 59900 59901 59902 59903 59904 59905 59906 59907 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 59892 class Workforce < Struct.new( :workforce_name, :workforce_arn, :last_updated_date, :source_ip_config, :sub_domain, :cognito_config, :oidc_config, :create_date, :workforce_vpc_config, :status, :failure_reason, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#oidc_config ⇒ Types::OidcConfigForResponse
The configuration of an OIDC Identity Provider (IdP) private workforce.
59892 59893 59894 59895 59896 59897 59898 59899 59900 59901 59902 59903 59904 59905 59906 59907 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 59892 class Workforce < Struct.new( :workforce_name, :workforce_arn, :last_updated_date, :source_ip_config, :sub_domain, :cognito_config, :oidc_config, :create_date, :workforce_vpc_config, :status, :failure_reason, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#source_ip_config ⇒ Types::SourceIpConfig
A list of one to ten IP address ranges (CIDRs) to be added to the workforce allow list. By default, a workforce isn't restricted to specific IP addresses.
59892 59893 59894 59895 59896 59897 59898 59899 59900 59901 59902 59903 59904 59905 59906 59907 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 59892 class Workforce < Struct.new( :workforce_name, :workforce_arn, :last_updated_date, :source_ip_config, :sub_domain, :cognito_config, :oidc_config, :create_date, :workforce_vpc_config, :status, :failure_reason, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of your workforce.
59892 59893 59894 59895 59896 59897 59898 59899 59900 59901 59902 59903 59904 59905 59906 59907 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 59892 class Workforce < Struct.new( :workforce_name, :workforce_arn, :last_updated_date, :source_ip_config, :sub_domain, :cognito_config, :oidc_config, :create_date, :workforce_vpc_config, :status, :failure_reason, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#sub_domain ⇒ String
The subdomain for your OIDC Identity Provider.
59892 59893 59894 59895 59896 59897 59898 59899 59900 59901 59902 59903 59904 59905 59906 59907 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 59892 class Workforce < Struct.new( :workforce_name, :workforce_arn, :last_updated_date, :source_ip_config, :sub_domain, :cognito_config, :oidc_config, :create_date, :workforce_vpc_config, :status, :failure_reason, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#workforce_arn ⇒ String
The Amazon Resource Name (ARN) of the private workforce.
59892 59893 59894 59895 59896 59897 59898 59899 59900 59901 59902 59903 59904 59905 59906 59907 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 59892 class Workforce < Struct.new( :workforce_name, :workforce_arn, :last_updated_date, :source_ip_config, :sub_domain, :cognito_config, :oidc_config, :create_date, :workforce_vpc_config, :status, :failure_reason, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#workforce_name ⇒ String
The name of the private workforce.
59892 59893 59894 59895 59896 59897 59898 59899 59900 59901 59902 59903 59904 59905 59906 59907 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 59892 class Workforce < Struct.new( :workforce_name, :workforce_arn, :last_updated_date, :source_ip_config, :sub_domain, :cognito_config, :oidc_config, :create_date, :workforce_vpc_config, :status, :failure_reason, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#workforce_vpc_config ⇒ Types::WorkforceVpcConfigResponse
The configuration of a VPC workforce.
59892 59893 59894 59895 59896 59897 59898 59899 59900 59901 59902 59903 59904 59905 59906 59907 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 59892 class Workforce < Struct.new( :workforce_name, :workforce_arn, :last_updated_date, :source_ip_config, :sub_domain, :cognito_config, :oidc_config, :create_date, :workforce_vpc_config, :status, :failure_reason, :ip_address_type) SENSITIVE = [] include Aws::Structure end |