Class: Aws::SageMaker::Types::WorkspaceSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::WorkspaceSettings
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The workspace settings for the SageMaker Canvas application.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#s3_artifact_path ⇒ String
The Amazon S3 bucket used to store artifacts generated by Canvas.
-
#s3_kms_key_id ⇒ String
The Amazon Web Services Key Management Service (KMS) encryption key ID that is used to encrypt artifacts generated by Canvas in the Amazon S3 bucket.
Instance Attribute Details
#s3_artifact_path ⇒ String
The Amazon S3 bucket used to store artifacts generated by Canvas. Updating the Amazon S3 location impacts existing configuration settings, and Canvas users no longer have access to their artifacts. Canvas users must log out and log back in to apply the new location.
55951 55952 55953 55954 55955 55956 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55951 class WorkspaceSettings < Struct.new( :s3_artifact_path, :s3_kms_key_id) SENSITIVE = [] include Aws::Structure end |
#s3_kms_key_id ⇒ String
The Amazon Web Services Key Management Service (KMS) encryption key ID that is used to encrypt artifacts generated by Canvas in the Amazon S3 bucket.
55951 55952 55953 55954 55955 55956 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55951 class WorkspaceSettings < Struct.new( :s3_artifact_path, :s3_kms_key_id) SENSITIVE = [] include Aws::Structure end |