Class: Aws::SageMaker::Waiters::EndpointInService
- Inherits:
-
Object
- Object
- Aws::SageMaker::Waiters::EndpointInService
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-sagemaker/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ EndpointInService
constructor
A new instance of EndpointInService.
-
#wait(params = {}) ⇒ Types::DescribeEndpointOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ EndpointInService
Returns a new instance of EndpointInService.
139 140 |
# File 'lib/aws-sdk-sagemaker/waiters.rb', line 139
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
176 177 178 |
# File 'lib/aws-sdk-sagemaker/waiters.rb', line 176 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeEndpointOutput
Returns a response object which responds to the following methods:
- #endpoint_name => String
- #endpoint_arn => String
- #endpoint_config_name => String
- #production_variants => Array<Types::ProductionVariantSummary>
- #data_capture_config => Types::DataCaptureConfigSummary
- #endpoint_status => String
- #failure_reason => String
- #creation_time => Time
- #last_modified_time => Time
- #last_deployment_config => Types::DeploymentConfig
- #async_inference_config => Types::AsyncInferenceConfig
- #pending_deployment_summary => Types::PendingDeploymentSummary
- #explainer_config => Types::ExplainerConfig
- #shadow_production_variants => Array<Types::ProductionVariantSummary>
- #metrics_config => Types::MetricsConfig
171 |
# File 'lib/aws-sdk-sagemaker/waiters.rb', line 171
def wait: (
|