Class: Aws::SageMaker::Waiters::ImageVersionDeleted
- Inherits:
-
Object
- Object
- Aws::SageMaker::Waiters::ImageVersionDeleted
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-sagemaker/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ImageVersionDeleted
constructor
A new instance of ImageVersionDeleted.
-
#wait(params = {}) ⇒ Types::DescribeImageVersionResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ImageVersionDeleted
Returns a new instance of ImageVersionDeleted.
383 384 |
# File 'lib/aws-sdk-sagemaker/waiters.rb', line 383
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
419 420 421 |
# File 'lib/aws-sdk-sagemaker/waiters.rb', line 419 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeImageVersionResponse
Returns a response object which responds to the following methods:
- #base_image => String
- #container_image => String
- #creation_time => Time
- #failure_reason => String
- #image_arn => String
- #image_version_arn => String
- #image_version_status => String
- #last_modified_time => Time
- #version => Integer
- #vendor_guidance => String
- #job_type => String
- #ml_framework => String
- #programming_lang => String
- #processor => String
- #horovod => Boolean
- #release_notes => String
414 |
# File 'lib/aws-sdk-sagemaker/waiters.rb', line 414
def wait: (
|