Class: Aws::SageMaker::Waiters::NotebookInstanceStopped

Inherits:
Object
  • Object
show all
Defined in:
sig/waiters.rbs,
lib/aws-sdk-sagemaker/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ NotebookInstanceStopped

Returns a new instance of NotebookInstanceStopped.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 60
  • :delay (Integer) — default: 30
  • :before_attempt (Proc)
  • :before_wait (Proc)


518
519
# File 'lib/aws-sdk-sagemaker/waiters.rb', line 518

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



550
551
552
# File 'lib/aws-sdk-sagemaker/waiters.rb', line 550

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeNotebookInstanceOutput

Returns a response object which responds to the following methods:

Options Hash (params):

  • :notebook_instance_name (required, String)

    The name of the notebook instance that you want information about.

Returns:



545
# File 'lib/aws-sdk-sagemaker/waiters.rb', line 545

def wait: (