Class: Aws::SageMaker::Waiters::ProcessingJobCompletedOrStopped

Inherits:
Object
  • Object
show all
Defined in:
sig/waiters.rbs,
lib/aws-sdk-sagemaker/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ ProcessingJobCompletedOrStopped

Returns a new instance of ProcessingJobCompletedOrStopped.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 60
  • :delay (Integer) — default: 60
  • :before_attempt (Proc)
  • :before_wait (Proc)


562
563
# File 'lib/aws-sdk-sagemaker/waiters.rb', line 562

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



605
606
607
# File 'lib/aws-sdk-sagemaker/waiters.rb', line 605

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeProcessingJobResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :processing_job_name (required, String)

    The name of the processing job. The name must be unique within an Amazon Web Services Region in the Amazon Web Services account.

Returns:



600
# File 'lib/aws-sdk-sagemaker/waiters.rb', line 600

def wait: (