Class: Aws::SageMaker::Types::AIAdapterModelPackageEntry
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::AIAdapterModelPackageEntry
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
A LoRA adapter entry identified by a model package ARN.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#adapter_id ⇒ String
A unique identifier for the adapter.
-
#model_package_arn ⇒ String
The Amazon Resource Name (ARN) of the model package that contains the LoRA adapter artifacts.
Instance Attribute Details
#adapter_id ⇒ String
A unique identifier for the adapter. This ID is used as the inference component name when the adapter is deployed. The ID must start and end with an alphanumeric character, can contain hyphens between alphanumeric characters, and can be up to 63 characters long.
30 31 32 33 34 35 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30 class AIAdapterModelPackageEntry < Struct.new( :adapter_id, :model_package_arn) SENSITIVE = [] include Aws::Structure end |
#model_package_arn ⇒ String
The Amazon Resource Name (ARN) of the model package that contains the LoRA adapter artifacts.
30 31 32 33 34 35 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30 class AIAdapterModelPackageEntry < Struct.new( :adapter_id, :model_package_arn) SENSITIVE = [] include Aws::Structure end |