Class: Aws::SageMaker::Types::AIAdapterS3Entry
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::AIAdapterS3Entry
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
A LoRA adapter entry identified by an Amazon S3 URI.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#adapter_id ⇒ String
A unique identifier for the adapter.
-
#s3_uri ⇒ String
The Amazon S3 URI of the directory that contains the LoRA adapter artifacts in PEFT format.
Instance Attribute Details
#adapter_id ⇒ String
A unique identifier for the adapter. This ID is used as the inference component name when the adapter is deployed. The ID must start and end with an alphanumeric character, can contain hyphens between alphanumeric characters, and can be up to 63 characters long.
54 55 56 57 58 59 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 54 class AIAdapterS3Entry < Struct.new( :adapter_id, :s3_uri) SENSITIVE = [] include Aws::Structure end |
#s3_uri ⇒ String
The Amazon S3 URI of the directory that contains the LoRA adapter artifacts in PEFT format.
54 55 56 57 58 59 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 54 class AIAdapterS3Entry < Struct.new( :adapter_id, :s3_uri) SENSITIVE = [] include Aws::Structure end |