Class: Aws::SageMaker::Types::AIBenchmarkJobSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::AIBenchmarkJobSummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Summary information about an AI benchmark job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ai_benchmark_job_arn ⇒ String
The Amazon Resource Name (ARN) of the benchmark job.
-
#ai_benchmark_job_name ⇒ String
The name of the benchmark job.
-
#ai_benchmark_job_status ⇒ String
The status of the benchmark job.
-
#ai_workload_config_name ⇒ String
The name of the AI workload configuration used by the benchmark job.
-
#creation_time ⇒ Time
A timestamp that indicates when the benchmark job was created.
-
#end_time ⇒ Time
A timestamp that indicates when the benchmark job completed.
Instance Attribute Details
#ai_benchmark_job_arn ⇒ String
The Amazon Resource Name (ARN) of the benchmark job.
81 82 83 84 85 86 87 88 89 90 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 81 class AIBenchmarkJobSummary < Struct.new( :ai_benchmark_job_name, :ai_benchmark_job_arn, :ai_benchmark_job_status, :creation_time, :end_time, :ai_workload_config_name) SENSITIVE = [] include Aws::Structure end |
#ai_benchmark_job_name ⇒ String
The name of the benchmark job.
81 82 83 84 85 86 87 88 89 90 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 81 class AIBenchmarkJobSummary < Struct.new( :ai_benchmark_job_name, :ai_benchmark_job_arn, :ai_benchmark_job_status, :creation_time, :end_time, :ai_workload_config_name) SENSITIVE = [] include Aws::Structure end |
#ai_benchmark_job_status ⇒ String
The status of the benchmark job.
81 82 83 84 85 86 87 88 89 90 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 81 class AIBenchmarkJobSummary < Struct.new( :ai_benchmark_job_name, :ai_benchmark_job_arn, :ai_benchmark_job_status, :creation_time, :end_time, :ai_workload_config_name) SENSITIVE = [] include Aws::Structure end |
#ai_workload_config_name ⇒ String
The name of the AI workload configuration used by the benchmark job.
81 82 83 84 85 86 87 88 89 90 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 81 class AIBenchmarkJobSummary < Struct.new( :ai_benchmark_job_name, :ai_benchmark_job_arn, :ai_benchmark_job_status, :creation_time, :end_time, :ai_workload_config_name) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
A timestamp that indicates when the benchmark job was created.
81 82 83 84 85 86 87 88 89 90 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 81 class AIBenchmarkJobSummary < Struct.new( :ai_benchmark_job_name, :ai_benchmark_job_arn, :ai_benchmark_job_status, :creation_time, :end_time, :ai_workload_config_name) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
A timestamp that indicates when the benchmark job completed.
81 82 83 84 85 86 87 88 89 90 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 81 class AIBenchmarkJobSummary < Struct.new( :ai_benchmark_job_name, :ai_benchmark_job_arn, :ai_benchmark_job_status, :creation_time, :end_time, :ai_workload_config_name) SENSITIVE = [] include Aws::Structure end |