Class: Aws::SageMaker::Types::AIBenchmarkTarget
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::AIBenchmarkTarget
- Includes:
- Aws::Structure, Aws::Structure::Union
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Note:
AIBenchmarkTarget is a union - when making an API calls you must set exactly one of the members.
Note:
AIBenchmarkTarget is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of AIBenchmarkTarget corresponding to the set member.
The target for an AI benchmark job. This is a union type — specify one of the members.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#endpoint ⇒ Types::AIBenchmarkEndpoint
The SageMaker endpoint to benchmark.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#endpoint ⇒ Types::AIBenchmarkEndpoint
The SageMaker endpoint to benchmark.
153 154 155 156 157 158 159 160 161 162 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 153 class AIBenchmarkTarget < Struct.new( :endpoint, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Endpoint < AIBenchmarkTarget; end class Unknown < AIBenchmarkTarget; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
153 154 155 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 153 def unknown @unknown end |