Class: Aws::SageMaker::Types::AIDatasetConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::AIDatasetConfig
- Includes:
- Aws::Structure, Aws::Structure::Union
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Note:
AIDatasetConfig is a union - when making an API calls you must set exactly one of the members.
Note:
AIDatasetConfig is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of AIDatasetConfig corresponding to the set member.
The dataset configuration for an AI workload. This is a union type —specify one of the members.
Direct Known Subclasses
Defined Under Namespace
Classes: InputDataConfig, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#input_data_config ⇒ Array<Types::AIWorkloadInputDataConfig>
An array of input data channel configurations for the workload.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#input_data_config ⇒ Array<Types::AIWorkloadInputDataConfig>
An array of input data channel configurations for the workload.
216 217 218 219 220 221 222 223 224 225 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 216 class AIDatasetConfig < Struct.new( :input_data_config, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class InputDataConfig < AIDatasetConfig; end class Unknown < AIDatasetConfig; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
216 217 218 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 216 def unknown @unknown end |