Class: Aws::SageMaker::Types::AIRecommendation

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

An optimization recommendation generated by an AI recommendation job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ai_benchmark_job_arnString

The Amazon Resource Name (ARN) of the benchmark job associated with this recommendation.

Returns:

  • (String)


296
297
298
299
300
301
302
303
304
305
# File 'lib/aws-sdk-sagemaker/types.rb', line 296

class AIRecommendation < Struct.new(
  :recommendation_description,
  :optimization_details,
  :model_details,
  :deployment_configuration,
  :ai_benchmark_job_arn,
  :expected_performance)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_configurationTypes::AIRecommendationDeploymentConfiguration

The deployment configuration for this recommendation, including the container image, instance type, instance count, and environment variables.



296
297
298
299
300
301
302
303
304
305
# File 'lib/aws-sdk-sagemaker/types.rb', line 296

class AIRecommendation < Struct.new(
  :recommendation_description,
  :optimization_details,
  :model_details,
  :deployment_configuration,
  :ai_benchmark_job_arn,
  :expected_performance)
  SENSITIVE = []
  include Aws::Structure
end

#expected_performanceArray<Types::AIRecommendationPerformanceMetric>

The expected performance metrics for this recommendation.



296
297
298
299
300
301
302
303
304
305
# File 'lib/aws-sdk-sagemaker/types.rb', line 296

class AIRecommendation < Struct.new(
  :recommendation_description,
  :optimization_details,
  :model_details,
  :deployment_configuration,
  :ai_benchmark_job_arn,
  :expected_performance)
  SENSITIVE = []
  include Aws::Structure
end

#model_detailsTypes::AIRecommendationModelDetails

Details about the model package associated with this recommendation.



296
297
298
299
300
301
302
303
304
305
# File 'lib/aws-sdk-sagemaker/types.rb', line 296

class AIRecommendation < Struct.new(
  :recommendation_description,
  :optimization_details,
  :model_details,
  :deployment_configuration,
  :ai_benchmark_job_arn,
  :expected_performance)
  SENSITIVE = []
  include Aws::Structure
end

#optimization_detailsArray<Types::AIRecommendationOptimizationDetail>

The optimization techniques applied in this recommendation.



296
297
298
299
300
301
302
303
304
305
# File 'lib/aws-sdk-sagemaker/types.rb', line 296

class AIRecommendation < Struct.new(
  :recommendation_description,
  :optimization_details,
  :model_details,
  :deployment_configuration,
  :ai_benchmark_job_arn,
  :expected_performance)
  SENSITIVE = []
  include Aws::Structure
end

#recommendation_descriptionString

A description of the recommendation.

Returns:

  • (String)


296
297
298
299
300
301
302
303
304
305
# File 'lib/aws-sdk-sagemaker/types.rb', line 296

class AIRecommendation < Struct.new(
  :recommendation_description,
  :optimization_details,
  :model_details,
  :deployment_configuration,
  :ai_benchmark_job_arn,
  :expected_performance)
  SENSITIVE = []
  include Aws::Structure
end