Class: Aws::SageMaker::Types::AIRecommendationJobSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::AIRecommendationJobSummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Summary information about an AI recommendation job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ai_recommendation_job_arn ⇒ String
The Amazon Resource Name (ARN) of the recommendation job.
-
#ai_recommendation_job_name ⇒ String
The name of the recommendation job.
-
#ai_recommendation_job_status ⇒ String
The status of the recommendation job.
-
#creation_time ⇒ Time
A timestamp that indicates when the recommendation job was created.
-
#end_time ⇒ Time
A timestamp that indicates when the recommendation job completed.
Instance Attribute Details
#ai_recommendation_job_arn ⇒ String
The Amazon Resource Name (ARN) of the recommendation job.
463 464 465 466 467 468 469 470 471 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 463 class AIRecommendationJobSummary < Struct.new( :ai_recommendation_job_name, :ai_recommendation_job_arn, :ai_recommendation_job_status, :creation_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#ai_recommendation_job_name ⇒ String
The name of the recommendation job.
463 464 465 466 467 468 469 470 471 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 463 class AIRecommendationJobSummary < Struct.new( :ai_recommendation_job_name, :ai_recommendation_job_arn, :ai_recommendation_job_status, :creation_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#ai_recommendation_job_status ⇒ String
The status of the recommendation job.
463 464 465 466 467 468 469 470 471 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 463 class AIRecommendationJobSummary < Struct.new( :ai_recommendation_job_name, :ai_recommendation_job_arn, :ai_recommendation_job_status, :creation_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
A timestamp that indicates when the recommendation job was created.
463 464 465 466 467 468 469 470 471 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 463 class AIRecommendationJobSummary < Struct.new( :ai_recommendation_job_name, :ai_recommendation_job_arn, :ai_recommendation_job_status, :creation_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
A timestamp that indicates when the recommendation job completed.
463 464 465 466 467 468 469 470 471 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 463 class AIRecommendationJobSummary < Struct.new( :ai_recommendation_job_name, :ai_recommendation_job_arn, :ai_recommendation_job_status, :creation_time, :end_time) SENSITIVE = [] include Aws::Structure end |