Class: Aws::SageMaker::Types::AIRecommendationModelDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::AIRecommendationModelDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Details about the model package in a recommendation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#inference_specification_name ⇒ String
The name of the inference specification within the model package.
-
#instance_details ⇒ Array<Types::AIRecommendationInstanceDetail>
The instance details for this recommendation, including instance type, count, and model copies per instance.
-
#model_package_arn ⇒ String
The Amazon Resource Name (ARN) of the model package.
Instance Attribute Details
#inference_specification_name ⇒ String
The name of the inference specification within the model package.
527 528 529 530 531 532 533 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 527 class AIRecommendationModelDetails < Struct.new( :model_package_arn, :inference_specification_name, :instance_details) SENSITIVE = [] include Aws::Structure end |
#instance_details ⇒ Array<Types::AIRecommendationInstanceDetail>
The instance details for this recommendation, including instance type, count, and model copies per instance.
527 528 529 530 531 532 533 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 527 class AIRecommendationModelDetails < Struct.new( :model_package_arn, :inference_specification_name, :instance_details) SENSITIVE = [] include Aws::Structure end |
#model_package_arn ⇒ String
The Amazon Resource Name (ARN) of the model package.
527 528 529 530 531 532 533 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 527 class AIRecommendationModelDetails < Struct.new( :model_package_arn, :inference_specification_name, :instance_details) SENSITIVE = [] include Aws::Structure end |