Class: Aws::SageMaker::Types::AIRecommendationOutputConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::AIRecommendationOutputConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The output configuration for an AI recommendation job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#mlflow_config ⇒ Types::AIMlflowConfig
The MLflow tracking configuration for the job.
-
#model_package_group_identifier ⇒ String
The name or Amazon Resource Name (ARN) of the model package group where the optimized model is registered as a new model package version.
-
#s3_output_location ⇒ String
The Amazon S3 URI where recommendation results are stored.
Instance Attribute Details
#mlflow_config ⇒ Types::AIMlflowConfig
The MLflow tracking configuration for the job. If you don’t specify this parameter, MLflow tracking is disabled.
574 575 576 577 578 579 580 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 574 class AIRecommendationOutputConfig < Struct.new( :s3_output_location, :model_package_group_identifier, :mlflow_config) SENSITIVE = [] include Aws::Structure end |
#model_package_group_identifier ⇒ String
The name or Amazon Resource Name (ARN) of the model package group where the optimized model is registered as a new model package version.
574 575 576 577 578 579 580 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 574 class AIRecommendationOutputConfig < Struct.new( :s3_output_location, :model_package_group_identifier, :mlflow_config) SENSITIVE = [] include Aws::Structure end |
#s3_output_location ⇒ String
The Amazon S3 URI where recommendation results are stored.
574 575 576 577 578 579 580 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 574 class AIRecommendationOutputConfig < Struct.new( :s3_output_location, :model_package_group_identifier, :mlflow_config) SENSITIVE = [] include Aws::Structure end |