Class: Aws::SageMaker::Types::AIRecommendationOutputConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::AIRecommendationOutputConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The output configuration for an AI recommendation job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#model_package_group_identifier ⇒ String
The name or Amazon Resource Name (ARN) of the model package group where the optimized model is registered as a new model package version.
-
#s3_output_location ⇒ String
The Amazon S3 URI where recommendation results are stored.
Instance Attribute Details
#model_package_group_identifier ⇒ String
The name or Amazon Resource Name (ARN) of the model package group where the optimized model is registered as a new model package version.
532 533 534 535 536 537 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 532 class AIRecommendationOutputConfig < Struct.new( :s3_output_location, :model_package_group_identifier) SENSITIVE = [] include Aws::Structure end |
#s3_output_location ⇒ String
The Amazon S3 URI where recommendation results are stored.
532 533 534 535 536 537 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 532 class AIRecommendationOutputConfig < Struct.new( :s3_output_location, :model_package_group_identifier) SENSITIVE = [] include Aws::Structure end |