Class: Aws::SageMaker::Types::AIRecommendationOutputResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::AIRecommendationOutputResult
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The output configuration for an AI recommendation job, including the S3 location for results and the model package group for deployment.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#model_package_group_identifier ⇒ String
The name or Amazon Resource Name (ARN) of the model package group where deployment-ready model packages are registered.
-
#s3_output_location ⇒ String
The Amazon S3 URI where the recommendation job writes its output results.
Instance Attribute Details
#model_package_group_identifier ⇒ String
The name or Amazon Resource Name (ARN) of the model package group where deployment-ready model packages are registered.
554 555 556 557 558 559 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 554 class AIRecommendationOutputResult < Struct.new( :s3_output_location, :model_package_group_identifier) SENSITIVE = [] include Aws::Structure end |
#s3_output_location ⇒ String
The Amazon S3 URI where the recommendation job writes its output results.
554 555 556 557 558 559 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 554 class AIRecommendationOutputResult < Struct.new( :s3_output_location, :model_package_group_identifier) SENSITIVE = [] include Aws::Structure end |