Class: Aws::SageMaker::Types::AlgorithmValidationProfile

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Defines a training job and a batch transform job that SageMaker runs to validate your algorithm.

The data provided in the validation profile is made available to your buyers on Amazon Web Services Marketplace.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#profile_nameString

The name of the profile for the algorithm. The name must have 1 to 63 characters. Valid characters are a-z, A-Z, 0-9, and - (hyphen).

Returns:

  • (String)


1415
1416
1417
1418
1419
1420
1421
# File 'lib/aws-sdk-sagemaker/types.rb', line 1415

class AlgorithmValidationProfile < Struct.new(
  :profile_name,
  :training_job_definition,
  :transform_job_definition)
  SENSITIVE = []
  include Aws::Structure
end

#training_job_definitionTypes::TrainingJobDefinition

The ‘TrainingJobDefinition` object that describes the training job that SageMaker runs to validate your algorithm.



1415
1416
1417
1418
1419
1420
1421
# File 'lib/aws-sdk-sagemaker/types.rb', line 1415

class AlgorithmValidationProfile < Struct.new(
  :profile_name,
  :training_job_definition,
  :transform_job_definition)
  SENSITIVE = []
  include Aws::Structure
end

#transform_job_definitionTypes::TransformJobDefinition

The ‘TransformJobDefinition` object that describes the transform job that SageMaker runs to validate your algorithm.



1415
1416
1417
1418
1419
1420
1421
# File 'lib/aws-sdk-sagemaker/types.rb', line 1415

class AlgorithmValidationProfile < Struct.new(
  :profile_name,
  :training_job_definition,
  :transform_job_definition)
  SENSITIVE = []
  include Aws::Structure
end