Class: Aws::SageMaker::Types::AsyncInferenceClientConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::AsyncInferenceClientConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Configures the behavior of the client used by SageMaker to interact with the model container during asynchronous inference.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_concurrent_invocations_per_instance ⇒ Integer
The maximum number of concurrent requests sent by the SageMaker client to the model container.
Instance Attribute Details
#max_concurrent_invocations_per_instance ⇒ Integer
The maximum number of concurrent requests sent by the SageMaker client to the model container. If no value is provided, SageMaker chooses an optimal value.
2456 2457 2458 2459 2460 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 2456 class AsyncInferenceClientConfig < Struct.new( :max_concurrent_invocations_per_instance) SENSITIVE = [] include Aws::Structure end |