Class: Aws::SageMaker::Types::AsyncInferenceOutputConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Specifies the configuration for asynchronous inference invocation outputs.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#kms_key_idString

The Amazon Web Services Key Management Service (Amazon Web Services KMS) key that SageMaker uses to encrypt the asynchronous inference output in Amazon S3.



1716
1717
1718
1719
1720
1721
1722
1723
# File 'lib/aws-sdk-sagemaker/types.rb', line 1716

class AsyncInferenceOutputConfig < Struct.new(
  :kms_key_id,
  :s3_output_path,
  :notification_config,
  :s3_failure_path)
  SENSITIVE = []
  include Aws::Structure
end

#notification_configTypes::AsyncInferenceNotificationConfig

Specifies the configuration for notifications of inference results for asynchronous inference.



1716
1717
1718
1719
1720
1721
1722
1723
# File 'lib/aws-sdk-sagemaker/types.rb', line 1716

class AsyncInferenceOutputConfig < Struct.new(
  :kms_key_id,
  :s3_output_path,
  :notification_config,
  :s3_failure_path)
  SENSITIVE = []
  include Aws::Structure
end

#s3_failure_pathString

The Amazon S3 location to upload failure inference responses to.



1716
1717
1718
1719
1720
1721
1722
1723
# File 'lib/aws-sdk-sagemaker/types.rb', line 1716

class AsyncInferenceOutputConfig < Struct.new(
  :kms_key_id,
  :s3_output_path,
  :notification_config,
  :s3_failure_path)
  SENSITIVE = []
  include Aws::Structure
end

#s3_output_pathString

The Amazon S3 location to upload inference responses to.



1716
1717
1718
1719
1720
1721
1722
1723
# File 'lib/aws-sdk-sagemaker/types.rb', line 1716

class AsyncInferenceOutputConfig < Struct.new(
  :kms_key_id,
  :s3_output_path,
  :notification_config,
  :s3_failure_path)
  SENSITIVE = []
  include Aws::Structure
end