Class: Aws::SageMaker::Types::AthenaDatasetDefinition
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::AthenaDatasetDefinition
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Configuration for Athena Dataset Definition input.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog ⇒ String
The name of the data catalog used in Athena query execution.
-
#database ⇒ String
The name of the database used in the Athena query execution.
-
#kms_key_id ⇒ String
The Amazon Web Services Key Management Service (Amazon Web Services KMS) key that Amazon SageMaker uses to encrypt data generated from an Athena query execution.
-
#output_compression ⇒ String
The compression used for Athena query results.
-
#output_format ⇒ String
The data storage format for Athena query results.
-
#output_s3_uri ⇒ String
The location in Amazon S3 where Athena query results are stored.
-
#query_string ⇒ String
The SQL query statements, to be executed.
-
#work_group ⇒ String
The name of the workgroup in which the Athena query is being started.
Instance Attribute Details
#catalog ⇒ String
The name of the data catalog used in Athena query execution.
2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 2590 class AthenaDatasetDefinition < Struct.new( :catalog, :database, :query_string, :work_group, :output_s3_uri, :kms_key_id, :output_format, :output_compression) SENSITIVE = [] include Aws::Structure end |
#database ⇒ String
The name of the database used in the Athena query execution.
2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 2590 class AthenaDatasetDefinition < Struct.new( :catalog, :database, :query_string, :work_group, :output_s3_uri, :kms_key_id, :output_format, :output_compression) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The Amazon Web Services Key Management Service (Amazon Web Services KMS) key that Amazon SageMaker uses to encrypt data generated from an Athena query execution.
2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 2590 class AthenaDatasetDefinition < Struct.new( :catalog, :database, :query_string, :work_group, :output_s3_uri, :kms_key_id, :output_format, :output_compression) SENSITIVE = [] include Aws::Structure end |
#output_compression ⇒ String
The compression used for Athena query results.
2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 2590 class AthenaDatasetDefinition < Struct.new( :catalog, :database, :query_string, :work_group, :output_s3_uri, :kms_key_id, :output_format, :output_compression) SENSITIVE = [] include Aws::Structure end |
#output_format ⇒ String
The data storage format for Athena query results.
2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 2590 class AthenaDatasetDefinition < Struct.new( :catalog, :database, :query_string, :work_group, :output_s3_uri, :kms_key_id, :output_format, :output_compression) SENSITIVE = [] include Aws::Structure end |
#output_s3_uri ⇒ String
The location in Amazon S3 where Athena query results are stored.
2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 2590 class AthenaDatasetDefinition < Struct.new( :catalog, :database, :query_string, :work_group, :output_s3_uri, :kms_key_id, :output_format, :output_compression) SENSITIVE = [] include Aws::Structure end |
#query_string ⇒ String
The SQL query statements, to be executed.
2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 2590 class AthenaDatasetDefinition < Struct.new( :catalog, :database, :query_string, :work_group, :output_s3_uri, :kms_key_id, :output_format, :output_compression) SENSITIVE = [] include Aws::Structure end |
#work_group ⇒ String
The name of the workgroup in which the Athena query is being started.
2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 2590 class AthenaDatasetDefinition < Struct.new( :catalog, :database, :query_string, :work_group, :output_s3_uri, :kms_key_id, :output_format, :output_compression) SENSITIVE = [] include Aws::Structure end |