Class: Aws::SageMaker::Types::AttachClusterNodeNetworkInterfaceResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::AttachClusterNodeNetworkInterfaceResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attachment_id ⇒ String
The unique identifier of the network interface attachment.
-
#cluster_arn ⇒ String
The Amazon Resource Name (ARN) of your SageMaker HyperPod cluster where the network interface attachment operation was performed.
-
#network_interface_id ⇒ String
The unique identifier of the elastic network interface (ENI) that was attached.
-
#node_id ⇒ String
The unique identifier of the cluster node where your network interface was attached.
Instance Attribute Details
#attachment_id ⇒ String
The unique identifier of the network interface attachment. Use this value to reference or detach the network interface later.
2820 2821 2822 2823 2824 2825 2826 2827 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 2820 class AttachClusterNodeNetworkInterfaceResponse < Struct.new( :cluster_arn, :node_id, :network_interface_id, :attachment_id) SENSITIVE = [] include Aws::Structure end |
#cluster_arn ⇒ String
The Amazon Resource Name (ARN) of your SageMaker HyperPod cluster where the network interface attachment operation was performed.
2820 2821 2822 2823 2824 2825 2826 2827 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 2820 class AttachClusterNodeNetworkInterfaceResponse < Struct.new( :cluster_arn, :node_id, :network_interface_id, :attachment_id) SENSITIVE = [] include Aws::Structure end |
#network_interface_id ⇒ String
The unique identifier of the elastic network interface (ENI) that was attached.
2820 2821 2822 2823 2824 2825 2826 2827 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 2820 class AttachClusterNodeNetworkInterfaceResponse < Struct.new( :cluster_arn, :node_id, :network_interface_id, :attachment_id) SENSITIVE = [] include Aws::Structure end |
#node_id ⇒ String
The unique identifier of the cluster node where your network interface was attached.
2820 2821 2822 2823 2824 2825 2826 2827 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 2820 class AttachClusterNodeNetworkInterfaceResponse < Struct.new( :cluster_arn, :node_id, :network_interface_id, :attachment_id) SENSITIVE = [] include Aws::Structure end |