Class: Aws::SageMaker::Types::AutoMLDataSplitConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::AutoMLDataSplitConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
This structure specifies how to split the data into train and validation datasets.
The validation and training datasets must contain the same headers. For jobs created by calling CreateAutoMLJob, the validation dataset must be less than 2 GB in size.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#validation_fraction ⇒ Float
The validation fraction (optional) is a float that specifies the portion of the training dataset to be used for validation.
Instance Attribute Details
#validation_fraction ⇒ Float
The validation fraction (optional) is a float that specifies the portion of the training dataset to be used for validation. The default value is 0.2, and values must be greater than 0 and less than 1. We recommend setting this value to be less than 0.5.
2219 2220 2221 2222 2223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 2219 class AutoMLDataSplitConfig < Struct.new( :validation_fraction) SENSITIVE = [] include Aws::Structure end |