Class: Aws::SageMaker::Types::AutoMLProblemTypeResolvedAttributes
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::AutoMLProblemTypeResolvedAttributes
- Includes:
- Aws::Structure, Aws::Structure::Union
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
AutoMLProblemTypeResolvedAttributes is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of AutoMLProblemTypeResolvedAttributes corresponding to the set member.
Stores resolved attributes specific to the problem type of an AutoML job V2.
Direct Known Subclasses
TabularResolvedAttributes, TextGenerationResolvedAttributes, Unknown
Defined Under Namespace
Classes: TabularResolvedAttributes, TextGenerationResolvedAttributes, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#tabular_resolved_attributes ⇒ Types::TabularResolvedAttributes
The resolved attributes for the tabular problem type.
-
#text_generation_resolved_attributes ⇒ Types::TextGenerationResolvedAttributes
The resolved attributes for the text generation problem type.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#tabular_resolved_attributes ⇒ Types::TabularResolvedAttributes
The resolved attributes for the tabular problem type.
3608 3609 3610 3611 3612 3613 3614 3615 3616 3617 3618 3619 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 3608 class AutoMLProblemTypeResolvedAttributes < Struct.new( :tabular_resolved_attributes, :text_generation_resolved_attributes, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class TabularResolvedAttributes < AutoMLProblemTypeResolvedAttributes; end class TextGenerationResolvedAttributes < AutoMLProblemTypeResolvedAttributes; end class Unknown < AutoMLProblemTypeResolvedAttributes; end end |
#text_generation_resolved_attributes ⇒ Types::TextGenerationResolvedAttributes
The resolved attributes for the text generation problem type.
3608 3609 3610 3611 3612 3613 3614 3615 3616 3617 3618 3619 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 3608 class AutoMLProblemTypeResolvedAttributes < Struct.new( :tabular_resolved_attributes, :text_generation_resolved_attributes, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class TabularResolvedAttributes < AutoMLProblemTypeResolvedAttributes; end class TextGenerationResolvedAttributes < AutoMLProblemTypeResolvedAttributes; end class Unknown < AutoMLProblemTypeResolvedAttributes; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
3608 3609 3610 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 3608 def unknown @unknown end |