Class: Aws::SageMaker::Types::AutoMLProblemTypeResolvedAttributes

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure, Aws::Structure::Union
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Note:

AutoMLProblemTypeResolvedAttributes is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of AutoMLProblemTypeResolvedAttributes corresponding to the set member.

Stores resolved attributes specific to the problem type of an AutoML job V2.

Defined Under Namespace

Classes: TabularResolvedAttributes, TextGenerationResolvedAttributes, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#tabular_resolved_attributesTypes::TabularResolvedAttributes

The resolved attributes for the tabular problem type.



2930
2931
2932
2933
2934
2935
2936
2937
2938
2939
2940
2941
# File 'lib/aws-sdk-sagemaker/types.rb', line 2930

class AutoMLProblemTypeResolvedAttributes < Struct.new(
  :tabular_resolved_attributes,
  :text_generation_resolved_attributes,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class TabularResolvedAttributes < AutoMLProblemTypeResolvedAttributes; end
  class TextGenerationResolvedAttributes < AutoMLProblemTypeResolvedAttributes; end
  class Unknown < AutoMLProblemTypeResolvedAttributes; end
end

#text_generation_resolved_attributesTypes::TextGenerationResolvedAttributes

The resolved attributes for the text generation problem type.



2930
2931
2932
2933
2934
2935
2936
2937
2938
2939
2940
2941
# File 'lib/aws-sdk-sagemaker/types.rb', line 2930

class AutoMLProblemTypeResolvedAttributes < Struct.new(
  :tabular_resolved_attributes,
  :text_generation_resolved_attributes,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class TabularResolvedAttributes < AutoMLProblemTypeResolvedAttributes; end
  class TextGenerationResolvedAttributes < AutoMLProblemTypeResolvedAttributes; end
  class Unknown < AutoMLProblemTypeResolvedAttributes; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



2930
2931
2932
# File 'lib/aws-sdk-sagemaker/types.rb', line 2930

def unknown
  @unknown
end