Class: Aws::SageMaker::Types::AutoParameter
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::AutoParameter
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The name and an example value of the hyperparameter that you want to use in Autotune. If Automatic model tuning (AMT) determines that your hyperparameter is eligible for Autotune, an optimal hyperparameter range is selected for you.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the hyperparameter to optimize using Autotune.
-
#value_hint ⇒ String
An example value of the hyperparameter to optimize using Autotune.
Instance Attribute Details
#name ⇒ String
The name of the hyperparameter to optimize using Autotune.
3752 3753 3754 3755 3756 3757 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 3752 class AutoParameter < Struct.new( :name, :value_hint) SENSITIVE = [] include Aws::Structure end |
#value_hint ⇒ String
An example value of the hyperparameter to optimize using Autotune.
3752 3753 3754 3755 3756 3757 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 3752 class AutoParameter < Struct.new( :name, :value_hint) SENSITIVE = [] include Aws::Structure end |