Class: Aws::SageMaker::Types::BatchAddClusterNodesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::BatchAddClusterNodesResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#failed ⇒ Array<Types::BatchAddClusterNodesError>
A list of errors that occurred during the node addition operation.
-
#successful ⇒ Array<Types::NodeAdditionResult>
A list of ‘NodeLogicalIDs` that were successfully added to the cluster.
Instance Attribute Details
#failed ⇒ Array<Types::BatchAddClusterNodesError>
A list of errors that occurred during the node addition operation. Each entry includes the instance group name, error code, number of failed additions, and an error message.
3959 3960 3961 3962 3963 3964 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 3959 class BatchAddClusterNodesResponse < Struct.new( :successful, :failed) SENSITIVE = [] include Aws::Structure end |
#successful ⇒ Array<Types::NodeAdditionResult>
A list of ‘NodeLogicalIDs` that were successfully added to the cluster. The `NodeLogicalID` is unique per cluster and does not change between instance replacements. Each entry includes a `NodeLogicalId` that can be used to track the node’s provisioning status (with ‘DescribeClusterNode`), the instance group name, and the current status of the node.
3959 3960 3961 3962 3963 3964 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 3959 class BatchAddClusterNodesResponse < Struct.new( :successful, :failed) SENSITIVE = [] include Aws::Structure end |