Class: Aws::SageMaker::Types::BatchDeleteClusterNodesError
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::BatchDeleteClusterNodesError
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Represents an error encountered when deleting a node from a SageMaker HyperPod cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code ⇒ String
The error code associated with the error encountered when deleting a node.
-
#message ⇒ String
A message describing the error encountered when deleting a node.
-
#node_id ⇒ String
The ID of the node that encountered an error during the deletion process.
Instance Attribute Details
#code ⇒ String
The error code associated with the error encountered when deleting a node.
The code provides information about the specific issue encountered, such as the node not being found, the node’s status being invalid for deletion, or the node ID being in use by another process.
4103 4104 4105 4106 4107 4108 4109 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 4103 class BatchDeleteClusterNodesError < Struct.new( :code, :message, :node_id) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
A message describing the error encountered when deleting a node.
4103 4104 4105 4106 4107 4108 4109 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 4103 class BatchDeleteClusterNodesError < Struct.new( :code, :message, :node_id) SENSITIVE = [] include Aws::Structure end |
#node_id ⇒ String
The ID of the node that encountered an error during the deletion process.
4103 4104 4105 4106 4107 4108 4109 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 4103 class BatchDeleteClusterNodesError < Struct.new( :code, :message, :node_id) SENSITIVE = [] include Aws::Structure end |