Class: Aws::SageMaker::Types::BatchRebootClusterNodesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::BatchRebootClusterNodesResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#failed ⇒ Array<Types::BatchRebootClusterNodesError>
A list of errors encountered for EC2 instance IDs that could not be rebooted.
-
#failed_node_logical_ids ⇒ Array<Types::BatchRebootClusterNodeLogicalIdsError>
A list of errors encountered for logical node IDs that could not be rebooted.
-
#successful ⇒ Array<String>
A list of EC2 instance IDs for which the reboot operation was successfully initiated.
-
#successful_node_logical_ids ⇒ Array<String>
A list of logical node IDs for which the reboot operation was successfully initiated.
Instance Attribute Details
#failed ⇒ Array<Types::BatchRebootClusterNodesError>
A list of errors encountered for EC2 instance IDs that could not be rebooted. Each error includes the instance ID, an error code, and a descriptive message.
3712 3713 3714 3715 3716 3717 3718 3719 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 3712 class BatchRebootClusterNodesResponse < Struct.new( :successful, :failed, :failed_node_logical_ids, :successful_node_logical_ids) SENSITIVE = [] include Aws::Structure end |
#failed_node_logical_ids ⇒ Array<Types::BatchRebootClusterNodeLogicalIdsError>
A list of errors encountered for logical node IDs that could not be rebooted. Each error includes the logical node ID, an error code, and a descriptive message. This field is only present when ‘NodeLogicalIds` were provided in the request.
3712 3713 3714 3715 3716 3717 3718 3719 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 3712 class BatchRebootClusterNodesResponse < Struct.new( :successful, :failed, :failed_node_logical_ids, :successful_node_logical_ids) SENSITIVE = [] include Aws::Structure end |
#successful ⇒ Array<String>
A list of EC2 instance IDs for which the reboot operation was successfully initiated.
3712 3713 3714 3715 3716 3717 3718 3719 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 3712 class BatchRebootClusterNodesResponse < Struct.new( :successful, :failed, :failed_node_logical_ids, :successful_node_logical_ids) SENSITIVE = [] include Aws::Structure end |
#successful_node_logical_ids ⇒ Array<String>
A list of logical node IDs for which the reboot operation was successfully initiated. This field is only present when ‘NodeLogicalIds` were provided in the request.
3712 3713 3714 3715 3716 3717 3718 3719 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 3712 class BatchRebootClusterNodesResponse < Struct.new( :successful, :failed, :failed_node_logical_ids, :successful_node_logical_ids) SENSITIVE = [] include Aws::Structure end |