Class: Aws::SageMaker::Types::ChannelSpecification
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ChannelSpecification
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Defines a named input source, called a channel, to be used by an algorithm.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A brief description of the channel.
-
#is_required ⇒ Boolean
Indicates whether the channel is required by the algorithm.
-
#name ⇒ String
The name of the channel.
-
#supported_compression_types ⇒ Array<String>
The allowed compression types, if data compression is used.
-
#supported_content_types ⇒ Array<String>
The supported MIME types for the data.
-
#supported_input_modes ⇒ Array<String>
The allowed input mode, either FILE or PIPE.
Instance Attribute Details
#description ⇒ String
A brief description of the channel.
4796 4797 4798 4799 4800 4801 4802 4803 4804 4805 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 4796 class ChannelSpecification < Struct.new( :name, :description, :is_required, :supported_content_types, :supported_compression_types, :supported_input_modes) SENSITIVE = [] include Aws::Structure end |
#is_required ⇒ Boolean
Indicates whether the channel is required by the algorithm.
4796 4797 4798 4799 4800 4801 4802 4803 4804 4805 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 4796 class ChannelSpecification < Struct.new( :name, :description, :is_required, :supported_content_types, :supported_compression_types, :supported_input_modes) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the channel.
4796 4797 4798 4799 4800 4801 4802 4803 4804 4805 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 4796 class ChannelSpecification < Struct.new( :name, :description, :is_required, :supported_content_types, :supported_compression_types, :supported_input_modes) SENSITIVE = [] include Aws::Structure end |
#supported_compression_types ⇒ Array<String>
The allowed compression types, if data compression is used.
4796 4797 4798 4799 4800 4801 4802 4803 4804 4805 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 4796 class ChannelSpecification < Struct.new( :name, :description, :is_required, :supported_content_types, :supported_compression_types, :supported_input_modes) SENSITIVE = [] include Aws::Structure end |
#supported_content_types ⇒ Array<String>
The supported MIME types for the data.
4796 4797 4798 4799 4800 4801 4802 4803 4804 4805 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 4796 class ChannelSpecification < Struct.new( :name, :description, :is_required, :supported_content_types, :supported_compression_types, :supported_input_modes) SENSITIVE = [] include Aws::Structure end |
#supported_input_modes ⇒ Array<String>
The allowed input mode, either FILE or PIPE.
In FILE mode, Amazon SageMaker copies the data from the input source onto the local Amazon Elastic Block Store (Amazon EBS) volumes before starting your training algorithm. This is the most commonly used input mode.
In PIPE mode, Amazon SageMaker streams input data from the source directly to your algorithm without using the EBS volume.
4796 4797 4798 4799 4800 4801 4802 4803 4804 4805 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 4796 class ChannelSpecification < Struct.new( :name, :description, :is_required, :supported_content_types, :supported_compression_types, :supported_input_modes) SENSITIVE = [] include Aws::Structure end |