Class: Aws::SageMaker::Types::ClusterAutoPatchConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ClusterAutoPatchConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The configuration for automatic patching of the instance group. When configured, the system automatically applies security patch AMI updates to the instance group.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#deployment_config ⇒ Types::DeploymentConfiguration
The deployment configuration for rolling patch updates, including rollback settings and batch sizes.
-
#patch_schedule ⇒ Types::ClusterPatchSchedule
The schedule for automatic patching, including the next patch date.
-
#patching_strategy ⇒ String
The strategy for applying patches to instances in the group.
Instance Attribute Details
#deployment_config ⇒ Types::DeploymentConfiguration
The deployment configuration for rolling patch updates, including rollback settings and batch sizes. Only applicable when using a rolling patching strategy.
5984 5985 5986 5987 5988 5989 5990 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5984 class ClusterAutoPatchConfig < Struct.new( :patching_strategy, :patch_schedule, :deployment_config) SENSITIVE = [] include Aws::Structure end |
#patch_schedule ⇒ Types::ClusterPatchSchedule
The schedule for automatic patching, including the next patch date.
5984 5985 5986 5987 5988 5989 5990 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5984 class ClusterAutoPatchConfig < Struct.new( :patching_strategy, :patch_schedule, :deployment_config) SENSITIVE = [] include Aws::Structure end |
#patching_strategy ⇒ String
The strategy for applying patches to instances in the group.
-
WhenIdle: Cordons all instances and patches each instance as it becomes idle (no running jobs). Each instance is uncordoned immediately after patching and becomes available for new jobs. If instances do not become idle, they remain on the previous AMI version. You can then use UpdateClusterSoftware with the desired ImageReleaseVersion to manually update the remaining instances. -
WhenAllIdle: Cordons all instances and waits for all to become idle before patching. All instances are uncordoned after patching completes. If not all instances become idle, no patching occurs and all instances remain on the previous AMI version.
5984 5985 5986 5987 5988 5989 5990 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5984 class ClusterAutoPatchConfig < Struct.new( :patching_strategy, :patch_schedule, :deployment_config) SENSITIVE = [] include Aws::Structure end |