Class: Aws::SageMaker::Types::ClusterAutoPatchConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The configuration for automatic patching of the instance group. When configured, the system automatically applies security patch AMI updates to the instance group.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#deployment_configTypes::DeploymentConfiguration

The deployment configuration for rolling patch updates, including rollback settings and batch sizes. Only applicable when using a rolling patching strategy.



5972
5973
5974
5975
5976
5977
5978
# File 'lib/aws-sdk-sagemaker/types.rb', line 5972

class ClusterAutoPatchConfig < Struct.new(
  :patching_strategy,
  :patch_schedule,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#patch_scheduleTypes::ClusterPatchSchedule

The schedule for automatic patching, including the next patch date.



5972
5973
5974
5975
5976
5977
5978
# File 'lib/aws-sdk-sagemaker/types.rb', line 5972

class ClusterAutoPatchConfig < Struct.new(
  :patching_strategy,
  :patch_schedule,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#patching_strategyString

The strategy for applying patches to instances in the group.

Returns:

  • (String)


5972
5973
5974
5975
5976
5977
5978
# File 'lib/aws-sdk-sagemaker/types.rb', line 5972

class ClusterAutoPatchConfig < Struct.new(
  :patching_strategy,
  :patch_schedule,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end