Class: Aws::SageMaker::Types::ClusterAutoPatchConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ClusterAutoPatchConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The configuration for automatic patching of the instance group. When configured, the system automatically applies security patch AMI updates to the instance group.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#deployment_config ⇒ Types::DeploymentConfiguration
The deployment configuration for rolling patch updates, including rollback settings and batch sizes.
-
#patch_schedule ⇒ Types::ClusterPatchSchedule
The schedule for automatic patching, including the next patch date.
-
#patching_strategy ⇒ String
The strategy for applying patches to instances in the group.
Instance Attribute Details
#deployment_config ⇒ Types::DeploymentConfiguration
The deployment configuration for rolling patch updates, including rollback settings and batch sizes. Only applicable when using a rolling patching strategy.
5972 5973 5974 5975 5976 5977 5978 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5972 class ClusterAutoPatchConfig < Struct.new( :patching_strategy, :patch_schedule, :deployment_config) SENSITIVE = [] include Aws::Structure end |
#patch_schedule ⇒ Types::ClusterPatchSchedule
The schedule for automatic patching, including the next patch date.
5972 5973 5974 5975 5976 5977 5978 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5972 class ClusterAutoPatchConfig < Struct.new( :patching_strategy, :patch_schedule, :deployment_config) SENSITIVE = [] include Aws::Structure end |
#patching_strategy ⇒ String
The strategy for applying patches to instances in the group.
5972 5973 5974 5975 5976 5977 5978 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5972 class ClusterAutoPatchConfig < Struct.new( :patching_strategy, :patch_schedule, :deployment_config) SENSITIVE = [] include Aws::Structure end |