Class: Aws::SageMaker::Types::ClusterAutoPatchConfigDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ClusterAutoPatchConfigDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The auto-patching configuration details for the instance group, including the patching strategy and schedule.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#current_patch_schedule ⇒ Types::ClusterPatchScheduleDetails
The currently active patch schedule that the system will execute.
-
#deployment_config ⇒ Types::DeploymentConfiguration
The deployment configuration for rolling patch updates.
-
#desired_patch_schedule ⇒ Types::ClusterPatchScheduleDetails
The requested patch schedule.
-
#patching_strategy ⇒ String
The strategy used for applying patches to instances in the group.
Instance Attribute Details
#current_patch_schedule ⇒ Types::ClusterPatchScheduleDetails
The currently active patch schedule that the system will execute.
6026 6027 6028 6029 6030 6031 6032 6033 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6026 class ClusterAutoPatchConfigDetails < Struct.new( :patching_strategy, :current_patch_schedule, :desired_patch_schedule, :deployment_config) SENSITIVE = [] include Aws::Structure end |
#deployment_config ⇒ Types::DeploymentConfiguration
The deployment configuration for rolling patch updates.
6026 6027 6028 6029 6030 6031 6032 6033 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6026 class ClusterAutoPatchConfigDetails < Struct.new( :patching_strategy, :current_patch_schedule, :desired_patch_schedule, :deployment_config) SENSITIVE = [] include Aws::Structure end |
#desired_patch_schedule ⇒ Types::ClusterPatchScheduleDetails
The requested patch schedule. Differs from CurrentPatchSchedule when a reschedule request is pending.
6026 6027 6028 6029 6030 6031 6032 6033 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6026 class ClusterAutoPatchConfigDetails < Struct.new( :patching_strategy, :current_patch_schedule, :desired_patch_schedule, :deployment_config) SENSITIVE = [] include Aws::Structure end |
#patching_strategy ⇒ String
The strategy used for applying patches to instances in the group.
-
WhenIdle: Cordons all instances and patches each instance as it becomes idle (no running jobs). Each instance is uncordoned immediately after patching and becomes available for new jobs. If instances do not become idle, they remain on the previous AMI version. You can then use UpdateClusterSoftware with the desired ImageReleaseVersion to manually update the remaining instances. -
WhenAllIdle: Cordons all instances and waits for all to become idle before patching. All instances are uncordoned after patching completes. If not all instances become idle, no patching occurs and all instances remain on the previous AMI version.
6026 6027 6028 6029 6030 6031 6032 6033 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6026 class ClusterAutoPatchConfigDetails < Struct.new( :patching_strategy, :current_patch_schedule, :desired_patch_schedule, :deployment_config) SENSITIVE = [] include Aws::Structure end |