Class: Aws::SageMaker::Types::ClusterAutoPatchConfigDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The auto-patching configuration details for the instance group, including the patching strategy and schedule.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#current_patch_scheduleTypes::ClusterPatchScheduleDetails

The currently active patch schedule that the system will execute.



6002
6003
6004
6005
6006
6007
6008
6009
# File 'lib/aws-sdk-sagemaker/types.rb', line 6002

class ClusterAutoPatchConfigDetails < Struct.new(
  :patching_strategy,
  :current_patch_schedule,
  :desired_patch_schedule,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_configTypes::DeploymentConfiguration

The deployment configuration for rolling patch updates.



6002
6003
6004
6005
6006
6007
6008
6009
# File 'lib/aws-sdk-sagemaker/types.rb', line 6002

class ClusterAutoPatchConfigDetails < Struct.new(
  :patching_strategy,
  :current_patch_schedule,
  :desired_patch_schedule,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#desired_patch_scheduleTypes::ClusterPatchScheduleDetails

The requested patch schedule. Differs from CurrentPatchSchedule when a reschedule request is pending.



6002
6003
6004
6005
6006
6007
6008
6009
# File 'lib/aws-sdk-sagemaker/types.rb', line 6002

class ClusterAutoPatchConfigDetails < Struct.new(
  :patching_strategy,
  :current_patch_schedule,
  :desired_patch_schedule,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#patching_strategyString

The strategy used for applying patches to instances in the group.

Returns:

  • (String)


6002
6003
6004
6005
6006
6007
6008
6009
# File 'lib/aws-sdk-sagemaker/types.rb', line 6002

class ClusterAutoPatchConfigDetails < Struct.new(
  :patching_strategy,
  :current_patch_schedule,
  :desired_patch_schedule,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end