Class: Aws::SageMaker::Types::ClusterAutoPatchConfigDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ClusterAutoPatchConfigDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The auto-patching configuration details for the instance group, including the patching strategy and schedule.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#current_patch_schedule ⇒ Types::ClusterPatchScheduleDetails
The currently active patch schedule that the system will execute.
-
#deployment_config ⇒ Types::DeploymentConfiguration
The deployment configuration for rolling patch updates.
-
#desired_patch_schedule ⇒ Types::ClusterPatchScheduleDetails
The requested patch schedule.
-
#patching_strategy ⇒ String
The strategy used for applying patches to instances in the group.
Instance Attribute Details
#current_patch_schedule ⇒ Types::ClusterPatchScheduleDetails
The currently active patch schedule that the system will execute.
6002 6003 6004 6005 6006 6007 6008 6009 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6002 class ClusterAutoPatchConfigDetails < Struct.new( :patching_strategy, :current_patch_schedule, :desired_patch_schedule, :deployment_config) SENSITIVE = [] include Aws::Structure end |
#deployment_config ⇒ Types::DeploymentConfiguration
The deployment configuration for rolling patch updates.
6002 6003 6004 6005 6006 6007 6008 6009 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6002 class ClusterAutoPatchConfigDetails < Struct.new( :patching_strategy, :current_patch_schedule, :desired_patch_schedule, :deployment_config) SENSITIVE = [] include Aws::Structure end |
#desired_patch_schedule ⇒ Types::ClusterPatchScheduleDetails
The requested patch schedule. Differs from CurrentPatchSchedule when a reschedule request is pending.
6002 6003 6004 6005 6006 6007 6008 6009 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6002 class ClusterAutoPatchConfigDetails < Struct.new( :patching_strategy, :current_patch_schedule, :desired_patch_schedule, :deployment_config) SENSITIVE = [] include Aws::Structure end |
#patching_strategy ⇒ String
The strategy used for applying patches to instances in the group.
6002 6003 6004 6005 6006 6007 6008 6009 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6002 class ClusterAutoPatchConfigDetails < Struct.new( :patching_strategy, :current_patch_schedule, :desired_patch_schedule, :deployment_config) SENSITIVE = [] include Aws::Structure end |