Class: Aws::SageMaker::Types::ClusterInstanceRequirements

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The instance requirements for a flexible instance group. Use this to specify multiple instance types that the instance group can use. The order of instance types in the list determines the priority for instance provisioning.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_typesArray<String>

The list of instance types that the instance group can use. The order of instance types determines the priority—HyperPod attempts to provision instances using the first instance type in the list and falls back to subsequent types if capacity is unavailable.

Returns:

  • (Array<String>)


5992
5993
5994
5995
5996
# File 'lib/aws-sdk-sagemaker/types.rb', line 5992

class ClusterInstanceRequirements < Struct.new(
  :instance_types)
  SENSITIVE = []
  include Aws::Structure
end