Class: Aws::SageMaker::Types::ClusterInstanceStorageConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ClusterInstanceStorageConfig
- Includes:
- Aws::Structure, Aws::Structure::Union
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
ClusterInstanceStorageConfig is a union - when making an API calls you must set exactly one of the members.
ClusterInstanceStorageConfig is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ClusterInstanceStorageConfig corresponding to the set member.
Defines the configuration for attaching additional storage to the instances in the SageMaker HyperPod cluster instance group. To learn more, see [SageMaker HyperPod release notes: June 20, 2024].
Direct Known Subclasses
Defined Under Namespace
Classes: EbsVolumeConfig, FsxLustreConfig, FsxOpenZfsConfig, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ebs_volume_config ⇒ Types::ClusterEbsVolumeConfig
Defines the configuration for attaching additional Amazon Elastic Block Store (EBS) volumes to the instances in the SageMaker HyperPod cluster instance group.
-
#fsx_lustre_config ⇒ Types::ClusterFsxLustreConfig
Defines the configuration for attaching an Amazon FSx for Lustre file system to the instances in the SageMaker HyperPod cluster instance group.
-
#fsx_open_zfs_config ⇒ Types::ClusterFsxOpenZfsConfig
Defines the configuration for attaching an Amazon FSx for OpenZFS file system to the instances in the SageMaker HyperPod cluster instance group.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#ebs_volume_config ⇒ Types::ClusterEbsVolumeConfig
Defines the configuration for attaching additional Amazon Elastic Block Store (EBS) volumes to the instances in the SageMaker HyperPod cluster instance group. The additional EBS volume is attached to each instance within the SageMaker HyperPod cluster instance group and mounted to ‘/opt/sagemaker`.
6889 6890 6891 6892 6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6889 class ClusterInstanceStorageConfig < Struct.new( :ebs_volume_config, :fsx_lustre_config, :fsx_open_zfs_config, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class EbsVolumeConfig < ClusterInstanceStorageConfig; end class FsxLustreConfig < ClusterInstanceStorageConfig; end class FsxOpenZfsConfig < ClusterInstanceStorageConfig; end class Unknown < ClusterInstanceStorageConfig; end end |
#fsx_lustre_config ⇒ Types::ClusterFsxLustreConfig
Defines the configuration for attaching an Amazon FSx for Lustre file system to the instances in the SageMaker HyperPod cluster instance group.
6889 6890 6891 6892 6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6889 class ClusterInstanceStorageConfig < Struct.new( :ebs_volume_config, :fsx_lustre_config, :fsx_open_zfs_config, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class EbsVolumeConfig < ClusterInstanceStorageConfig; end class FsxLustreConfig < ClusterInstanceStorageConfig; end class FsxOpenZfsConfig < ClusterInstanceStorageConfig; end class Unknown < ClusterInstanceStorageConfig; end end |
#fsx_open_zfs_config ⇒ Types::ClusterFsxOpenZfsConfig
Defines the configuration for attaching an Amazon FSx for OpenZFS file system to the instances in the SageMaker HyperPod cluster instance group.
6889 6890 6891 6892 6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6889 class ClusterInstanceStorageConfig < Struct.new( :ebs_volume_config, :fsx_lustre_config, :fsx_open_zfs_config, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class EbsVolumeConfig < ClusterInstanceStorageConfig; end class FsxLustreConfig < ClusterInstanceStorageConfig; end class FsxOpenZfsConfig < ClusterInstanceStorageConfig; end class Unknown < ClusterInstanceStorageConfig; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
6889 6890 6891 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6889 def unknown @unknown end |