Class: Aws::SageMaker::Types::ClusterInstanceStorageConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure, Aws::Structure::Union
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Note:

ClusterInstanceStorageConfig is a union - when making an API calls you must set exactly one of the members.

Note:

ClusterInstanceStorageConfig is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ClusterInstanceStorageConfig corresponding to the set member.

Defines the configuration for attaching additional storage to the instances in the SageMaker HyperPod cluster instance group. To learn more, see [SageMaker HyperPod release notes: June 20, 2024].

[1]: docs.aws.amazon.com/sagemaker/latest/dg/sagemaker-hyperpod-release-notes.html#sagemaker-hyperpod-release-notes-20240620

Defined Under Namespace

Classes: EbsVolumeConfig, FsxLustreConfig, FsxOpenZfsConfig, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ebs_volume_configTypes::ClusterEbsVolumeConfig

Defines the configuration for attaching additional Amazon Elastic Block Store (EBS) volumes to the instances in the SageMaker HyperPod cluster instance group. The additional EBS volume is attached to each instance within the SageMaker HyperPod cluster instance group and mounted to ‘/opt/sagemaker`.



6748
6749
6750
6751
6752
6753
6754
6755
6756
6757
6758
6759
6760
6761
# File 'lib/aws-sdk-sagemaker/types.rb', line 6748

class ClusterInstanceStorageConfig < Struct.new(
  :ebs_volume_config,
  :fsx_lustre_config,
  :fsx_open_zfs_config,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class EbsVolumeConfig < ClusterInstanceStorageConfig; end
  class FsxLustreConfig < ClusterInstanceStorageConfig; end
  class FsxOpenZfsConfig < ClusterInstanceStorageConfig; end
  class Unknown < ClusterInstanceStorageConfig; end
end

#fsx_lustre_configTypes::ClusterFsxLustreConfig

Defines the configuration for attaching an Amazon FSx for Lustre file system to the instances in the SageMaker HyperPod cluster instance group.



6748
6749
6750
6751
6752
6753
6754
6755
6756
6757
6758
6759
6760
6761
# File 'lib/aws-sdk-sagemaker/types.rb', line 6748

class ClusterInstanceStorageConfig < Struct.new(
  :ebs_volume_config,
  :fsx_lustre_config,
  :fsx_open_zfs_config,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class EbsVolumeConfig < ClusterInstanceStorageConfig; end
  class FsxLustreConfig < ClusterInstanceStorageConfig; end
  class FsxOpenZfsConfig < ClusterInstanceStorageConfig; end
  class Unknown < ClusterInstanceStorageConfig; end
end

#fsx_open_zfs_configTypes::ClusterFsxOpenZfsConfig

Defines the configuration for attaching an Amazon FSx for OpenZFS file system to the instances in the SageMaker HyperPod cluster instance group.



6748
6749
6750
6751
6752
6753
6754
6755
6756
6757
6758
6759
6760
6761
# File 'lib/aws-sdk-sagemaker/types.rb', line 6748

class ClusterInstanceStorageConfig < Struct.new(
  :ebs_volume_config,
  :fsx_lustre_config,
  :fsx_open_zfs_config,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class EbsVolumeConfig < ClusterInstanceStorageConfig; end
  class FsxLustreConfig < ClusterInstanceStorageConfig; end
  class FsxOpenZfsConfig < ClusterInstanceStorageConfig; end
  class Unknown < ClusterInstanceStorageConfig; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



6748
6749
6750
# File 'lib/aws-sdk-sagemaker/types.rb', line 6748

def unknown
  @unknown
end