Class: Aws::SageMaker::Types::ClusterMetadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ClusterMetadata
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Metadata information about a HyperPod cluster showing information about the cluster level operations, such as creating, updating, and deleting.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#eks_role_access_entries ⇒ Array<String>
A list of Amazon EKS IAM role ARNs associated with the cluster.
-
#failure_message ⇒ String
An error message describing why the cluster level operation (such as creating, updating, or deleting) failed.
-
#slr_access_entry ⇒ String
The Service-Linked Role (SLR) associated with the cluster.
Instance Attribute Details
#eks_role_access_entries ⇒ Array<String>
A list of Amazon EKS IAM role ARNs associated with the cluster. This is created by HyperPod on your behalf and only applies for EKS orchestrated clusters.
7245 7246 7247 7248 7249 7250 7251 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7245 class ClusterMetadata < Struct.new( :failure_message, :eks_role_access_entries, :slr_access_entry) SENSITIVE = [] include Aws::Structure end |
#failure_message ⇒ String
An error message describing why the cluster level operation (such as creating, updating, or deleting) failed.
7245 7246 7247 7248 7249 7250 7251 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7245 class ClusterMetadata < Struct.new( :failure_message, :eks_role_access_entries, :slr_access_entry) SENSITIVE = [] include Aws::Structure end |
#slr_access_entry ⇒ String
The Service-Linked Role (SLR) associated with the cluster. This is created by HyperPod on your behalf and only applies for EKS orchestrated clusters.
7245 7246 7247 7248 7249 7250 7251 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7245 class ClusterMetadata < Struct.new( :failure_message, :eks_role_access_entries, :slr_access_entry) SENSITIVE = [] include Aws::Structure end |