Class: Aws::SageMaker::Types::ClusterNetworkInterfaceDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ClusterNetworkInterfaceDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The network interface configuration details for a Amazon SageMaker HyperPod cluster instance group.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#interface_type ⇒ String
The type of network interface for the instance group.
Instance Attribute Details
#interface_type ⇒ String
The type of network interface for the instance group. Valid values are ‘efa` and `efa-only`.
6306 6307 6308 6309 6310 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6306 class ClusterNetworkInterfaceDetails < Struct.new( :interface_type) SENSITIVE = [] include Aws::Structure end |