Class: Aws::SageMaker::Types::ClusterNodeDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Details of an instance (also called a node interchangeably) in a SageMaker HyperPod cluster.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_typeString

The capacity type of the node. Valid values are ‘OnDemand` and `Spot`. When set to `OnDemand`, the node is launched as an On-Demand instance. When set to `Spot`, the node is launched as a Spot instance.

Returns:

  • (String)


7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
7179
7180
7181
7182
7183
7184
7185
7186
7187
7188
7189
7190
7191
7192
7193
# File 'lib/aws-sdk-sagemaker/types.rb', line 7168

class ClusterNodeDetails < Struct.new(
  :instance_group_name,
  :instance_id,
  :node_logical_id,
  :instance_status,
  :instance_type,
  :launch_time,
  :last_software_update_time,
  :life_cycle_config,
  :override_vpc_config,
  :threads_per_core,
  :instance_storage_configs,
  :private_primary_ip,
  :private_primary_ipv_6,
  :private_dns_hostname,
  :placement,
  :current_image_id,
  :desired_image_id,
  :image_version_status,
  :ultra_server_info,
  :kubernetes_config,
  :capacity_type,
  :network_interface)
  SENSITIVE = []
  include Aws::Structure
end

#current_image_idString

The ID of the Amazon Machine Image (AMI) currently in use by the node.

Returns:

  • (String)


7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
7179
7180
7181
7182
7183
7184
7185
7186
7187
7188
7189
7190
7191
7192
7193
# File 'lib/aws-sdk-sagemaker/types.rb', line 7168

class ClusterNodeDetails < Struct.new(
  :instance_group_name,
  :instance_id,
  :node_logical_id,
  :instance_status,
  :instance_type,
  :launch_time,
  :last_software_update_time,
  :life_cycle_config,
  :override_vpc_config,
  :threads_per_core,
  :instance_storage_configs,
  :private_primary_ip,
  :private_primary_ipv_6,
  :private_dns_hostname,
  :placement,
  :current_image_id,
  :desired_image_id,
  :image_version_status,
  :ultra_server_info,
  :kubernetes_config,
  :capacity_type,
  :network_interface)
  SENSITIVE = []
  include Aws::Structure
end

#desired_image_idString

The ID of the Amazon Machine Image (AMI) desired for the node.

Returns:

  • (String)


7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
7179
7180
7181
7182
7183
7184
7185
7186
7187
7188
7189
7190
7191
7192
7193
# File 'lib/aws-sdk-sagemaker/types.rb', line 7168

class ClusterNodeDetails < Struct.new(
  :instance_group_name,
  :instance_id,
  :node_logical_id,
  :instance_status,
  :instance_type,
  :launch_time,
  :last_software_update_time,
  :life_cycle_config,
  :override_vpc_config,
  :threads_per_core,
  :instance_storage_configs,
  :private_primary_ip,
  :private_primary_ipv_6,
  :private_dns_hostname,
  :placement,
  :current_image_id,
  :desired_image_id,
  :image_version_status,
  :ultra_server_info,
  :kubernetes_config,
  :capacity_type,
  :network_interface)
  SENSITIVE = []
  include Aws::Structure
end

#image_version_statusString

The status of the image version for the cluster node.

Returns:

  • (String)


7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
7179
7180
7181
7182
7183
7184
7185
7186
7187
7188
7189
7190
7191
7192
7193
# File 'lib/aws-sdk-sagemaker/types.rb', line 7168

class ClusterNodeDetails < Struct.new(
  :instance_group_name,
  :instance_id,
  :node_logical_id,
  :instance_status,
  :instance_type,
  :launch_time,
  :last_software_update_time,
  :life_cycle_config,
  :override_vpc_config,
  :threads_per_core,
  :instance_storage_configs,
  :private_primary_ip,
  :private_primary_ipv_6,
  :private_dns_hostname,
  :placement,
  :current_image_id,
  :desired_image_id,
  :image_version_status,
  :ultra_server_info,
  :kubernetes_config,
  :capacity_type,
  :network_interface)
  SENSITIVE = []
  include Aws::Structure
end

#instance_group_nameString

The instance group name in which the instance is.

Returns:

  • (String)


7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
7179
7180
7181
7182
7183
7184
7185
7186
7187
7188
7189
7190
7191
7192
7193
# File 'lib/aws-sdk-sagemaker/types.rb', line 7168

class ClusterNodeDetails < Struct.new(
  :instance_group_name,
  :instance_id,
  :node_logical_id,
  :instance_status,
  :instance_type,
  :launch_time,
  :last_software_update_time,
  :life_cycle_config,
  :override_vpc_config,
  :threads_per_core,
  :instance_storage_configs,
  :private_primary_ip,
  :private_primary_ipv_6,
  :private_dns_hostname,
  :placement,
  :current_image_id,
  :desired_image_id,
  :image_version_status,
  :ultra_server_info,
  :kubernetes_config,
  :capacity_type,
  :network_interface)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The ID of the instance.

Returns:

  • (String)


7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
7179
7180
7181
7182
7183
7184
7185
7186
7187
7188
7189
7190
7191
7192
7193
# File 'lib/aws-sdk-sagemaker/types.rb', line 7168

class ClusterNodeDetails < Struct.new(
  :instance_group_name,
  :instance_id,
  :node_logical_id,
  :instance_status,
  :instance_type,
  :launch_time,
  :last_software_update_time,
  :life_cycle_config,
  :override_vpc_config,
  :threads_per_core,
  :instance_storage_configs,
  :private_primary_ip,
  :private_primary_ipv_6,
  :private_dns_hostname,
  :placement,
  :current_image_id,
  :desired_image_id,
  :image_version_status,
  :ultra_server_info,
  :kubernetes_config,
  :capacity_type,
  :network_interface)
  SENSITIVE = []
  include Aws::Structure
end

#instance_statusTypes::ClusterInstanceStatusDetails

The status of the instance.



7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
7179
7180
7181
7182
7183
7184
7185
7186
7187
7188
7189
7190
7191
7192
7193
# File 'lib/aws-sdk-sagemaker/types.rb', line 7168

class ClusterNodeDetails < Struct.new(
  :instance_group_name,
  :instance_id,
  :node_logical_id,
  :instance_status,
  :instance_type,
  :launch_time,
  :last_software_update_time,
  :life_cycle_config,
  :override_vpc_config,
  :threads_per_core,
  :instance_storage_configs,
  :private_primary_ip,
  :private_primary_ipv_6,
  :private_dns_hostname,
  :placement,
  :current_image_id,
  :desired_image_id,
  :image_version_status,
  :ultra_server_info,
  :kubernetes_config,
  :capacity_type,
  :network_interface)
  SENSITIVE = []
  include Aws::Structure
end

#instance_storage_configsArray<Types::ClusterInstanceStorageConfig>

The configurations of additional storage specified to the instance group where the instance (node) is launched.



7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
7179
7180
7181
7182
7183
7184
7185
7186
7187
7188
7189
7190
7191
7192
7193
# File 'lib/aws-sdk-sagemaker/types.rb', line 7168

class ClusterNodeDetails < Struct.new(
  :instance_group_name,
  :instance_id,
  :node_logical_id,
  :instance_status,
  :instance_type,
  :launch_time,
  :last_software_update_time,
  :life_cycle_config,
  :override_vpc_config,
  :threads_per_core,
  :instance_storage_configs,
  :private_primary_ip,
  :private_primary_ipv_6,
  :private_dns_hostname,
  :placement,
  :current_image_id,
  :desired_image_id,
  :image_version_status,
  :ultra_server_info,
  :kubernetes_config,
  :capacity_type,
  :network_interface)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typeString

The type of the instance.

Returns:

  • (String)


7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
7179
7180
7181
7182
7183
7184
7185
7186
7187
7188
7189
7190
7191
7192
7193
# File 'lib/aws-sdk-sagemaker/types.rb', line 7168

class ClusterNodeDetails < Struct.new(
  :instance_group_name,
  :instance_id,
  :node_logical_id,
  :instance_status,
  :instance_type,
  :launch_time,
  :last_software_update_time,
  :life_cycle_config,
  :override_vpc_config,
  :threads_per_core,
  :instance_storage_configs,
  :private_primary_ip,
  :private_primary_ipv_6,
  :private_dns_hostname,
  :placement,
  :current_image_id,
  :desired_image_id,
  :image_version_status,
  :ultra_server_info,
  :kubernetes_config,
  :capacity_type,
  :network_interface)
  SENSITIVE = []
  include Aws::Structure
end

#kubernetes_configTypes::ClusterKubernetesConfigNodeDetails

The Kubernetes configuration applied to this node, showing both the current and desired state of labels and taints. The cluster works to reconcile the actual state with the declared state.



7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
7179
7180
7181
7182
7183
7184
7185
7186
7187
7188
7189
7190
7191
7192
7193
# File 'lib/aws-sdk-sagemaker/types.rb', line 7168

class ClusterNodeDetails < Struct.new(
  :instance_group_name,
  :instance_id,
  :node_logical_id,
  :instance_status,
  :instance_type,
  :launch_time,
  :last_software_update_time,
  :life_cycle_config,
  :override_vpc_config,
  :threads_per_core,
  :instance_storage_configs,
  :private_primary_ip,
  :private_primary_ipv_6,
  :private_dns_hostname,
  :placement,
  :current_image_id,
  :desired_image_id,
  :image_version_status,
  :ultra_server_info,
  :kubernetes_config,
  :capacity_type,
  :network_interface)
  SENSITIVE = []
  include Aws::Structure
end

#last_software_update_timeTime

The time when the cluster was last updated.

Returns:

  • (Time)


7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
7179
7180
7181
7182
7183
7184
7185
7186
7187
7188
7189
7190
7191
7192
7193
# File 'lib/aws-sdk-sagemaker/types.rb', line 7168

class ClusterNodeDetails < Struct.new(
  :instance_group_name,
  :instance_id,
  :node_logical_id,
  :instance_status,
  :instance_type,
  :launch_time,
  :last_software_update_time,
  :life_cycle_config,
  :override_vpc_config,
  :threads_per_core,
  :instance_storage_configs,
  :private_primary_ip,
  :private_primary_ipv_6,
  :private_dns_hostname,
  :placement,
  :current_image_id,
  :desired_image_id,
  :image_version_status,
  :ultra_server_info,
  :kubernetes_config,
  :capacity_type,
  :network_interface)
  SENSITIVE = []
  include Aws::Structure
end

#launch_timeTime

The time when the instance is launched.

Returns:

  • (Time)


7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
7179
7180
7181
7182
7183
7184
7185
7186
7187
7188
7189
7190
7191
7192
7193
# File 'lib/aws-sdk-sagemaker/types.rb', line 7168

class ClusterNodeDetails < Struct.new(
  :instance_group_name,
  :instance_id,
  :node_logical_id,
  :instance_status,
  :instance_type,
  :launch_time,
  :last_software_update_time,
  :life_cycle_config,
  :override_vpc_config,
  :threads_per_core,
  :instance_storage_configs,
  :private_primary_ip,
  :private_primary_ipv_6,
  :private_dns_hostname,
  :placement,
  :current_image_id,
  :desired_image_id,
  :image_version_status,
  :ultra_server_info,
  :kubernetes_config,
  :capacity_type,
  :network_interface)
  SENSITIVE = []
  include Aws::Structure
end

#life_cycle_configTypes::ClusterLifeCycleConfig

The LifeCycle configuration applied to the instance.



7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
7179
7180
7181
7182
7183
7184
7185
7186
7187
7188
7189
7190
7191
7192
7193
# File 'lib/aws-sdk-sagemaker/types.rb', line 7168

class ClusterNodeDetails < Struct.new(
  :instance_group_name,
  :instance_id,
  :node_logical_id,
  :instance_status,
  :instance_type,
  :launch_time,
  :last_software_update_time,
  :life_cycle_config,
  :override_vpc_config,
  :threads_per_core,
  :instance_storage_configs,
  :private_primary_ip,
  :private_primary_ipv_6,
  :private_dns_hostname,
  :placement,
  :current_image_id,
  :desired_image_id,
  :image_version_status,
  :ultra_server_info,
  :kubernetes_config,
  :capacity_type,
  :network_interface)
  SENSITIVE = []
  include Aws::Structure
end

#network_interfaceTypes::ClusterNetworkInterfaceDetails

The network interface configuration for the cluster node.



7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
7179
7180
7181
7182
7183
7184
7185
7186
7187
7188
7189
7190
7191
7192
7193
# File 'lib/aws-sdk-sagemaker/types.rb', line 7168

class ClusterNodeDetails < Struct.new(
  :instance_group_name,
  :instance_id,
  :node_logical_id,
  :instance_status,
  :instance_type,
  :launch_time,
  :last_software_update_time,
  :life_cycle_config,
  :override_vpc_config,
  :threads_per_core,
  :instance_storage_configs,
  :private_primary_ip,
  :private_primary_ipv_6,
  :private_dns_hostname,
  :placement,
  :current_image_id,
  :desired_image_id,
  :image_version_status,
  :ultra_server_info,
  :kubernetes_config,
  :capacity_type,
  :network_interface)
  SENSITIVE = []
  include Aws::Structure
end

#node_logical_idString

A unique identifier for the node that persists throughout its lifecycle, from provisioning request to termination. This identifier can be used to track the node even before it has an assigned ‘InstanceId`.

Returns:

  • (String)


7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
7179
7180
7181
7182
7183
7184
7185
7186
7187
7188
7189
7190
7191
7192
7193
# File 'lib/aws-sdk-sagemaker/types.rb', line 7168

class ClusterNodeDetails < Struct.new(
  :instance_group_name,
  :instance_id,
  :node_logical_id,
  :instance_status,
  :instance_type,
  :launch_time,
  :last_software_update_time,
  :life_cycle_config,
  :override_vpc_config,
  :threads_per_core,
  :instance_storage_configs,
  :private_primary_ip,
  :private_primary_ipv_6,
  :private_dns_hostname,
  :placement,
  :current_image_id,
  :desired_image_id,
  :image_version_status,
  :ultra_server_info,
  :kubernetes_config,
  :capacity_type,
  :network_interface)
  SENSITIVE = []
  include Aws::Structure
end

#override_vpc_configTypes::VpcConfig

The customized Amazon VPC configuration at the instance group level that overrides the default Amazon VPC configuration of the SageMaker HyperPod cluster.

Returns:



7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
7179
7180
7181
7182
7183
7184
7185
7186
7187
7188
7189
7190
7191
7192
7193
# File 'lib/aws-sdk-sagemaker/types.rb', line 7168

class ClusterNodeDetails < Struct.new(
  :instance_group_name,
  :instance_id,
  :node_logical_id,
  :instance_status,
  :instance_type,
  :launch_time,
  :last_software_update_time,
  :life_cycle_config,
  :override_vpc_config,
  :threads_per_core,
  :instance_storage_configs,
  :private_primary_ip,
  :private_primary_ipv_6,
  :private_dns_hostname,
  :placement,
  :current_image_id,
  :desired_image_id,
  :image_version_status,
  :ultra_server_info,
  :kubernetes_config,
  :capacity_type,
  :network_interface)
  SENSITIVE = []
  include Aws::Structure
end

#placementTypes::ClusterInstancePlacement

The placement details of the SageMaker HyperPod cluster node.



7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
7179
7180
7181
7182
7183
7184
7185
7186
7187
7188
7189
7190
7191
7192
7193
# File 'lib/aws-sdk-sagemaker/types.rb', line 7168

class ClusterNodeDetails < Struct.new(
  :instance_group_name,
  :instance_id,
  :node_logical_id,
  :instance_status,
  :instance_type,
  :launch_time,
  :last_software_update_time,
  :life_cycle_config,
  :override_vpc_config,
  :threads_per_core,
  :instance_storage_configs,
  :private_primary_ip,
  :private_primary_ipv_6,
  :private_dns_hostname,
  :placement,
  :current_image_id,
  :desired_image_id,
  :image_version_status,
  :ultra_server_info,
  :kubernetes_config,
  :capacity_type,
  :network_interface)
  SENSITIVE = []
  include Aws::Structure
end

#private_dns_hostnameString

The private DNS hostname of the SageMaker HyperPod cluster node.

Returns:

  • (String)


7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
7179
7180
7181
7182
7183
7184
7185
7186
7187
7188
7189
7190
7191
7192
7193
# File 'lib/aws-sdk-sagemaker/types.rb', line 7168

class ClusterNodeDetails < Struct.new(
  :instance_group_name,
  :instance_id,
  :node_logical_id,
  :instance_status,
  :instance_type,
  :launch_time,
  :last_software_update_time,
  :life_cycle_config,
  :override_vpc_config,
  :threads_per_core,
  :instance_storage_configs,
  :private_primary_ip,
  :private_primary_ipv_6,
  :private_dns_hostname,
  :placement,
  :current_image_id,
  :desired_image_id,
  :image_version_status,
  :ultra_server_info,
  :kubernetes_config,
  :capacity_type,
  :network_interface)
  SENSITIVE = []
  include Aws::Structure
end

#private_primary_ipString

The private primary IP address of the SageMaker HyperPod cluster node.

Returns:

  • (String)


7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
7179
7180
7181
7182
7183
7184
7185
7186
7187
7188
7189
7190
7191
7192
7193
# File 'lib/aws-sdk-sagemaker/types.rb', line 7168

class ClusterNodeDetails < Struct.new(
  :instance_group_name,
  :instance_id,
  :node_logical_id,
  :instance_status,
  :instance_type,
  :launch_time,
  :last_software_update_time,
  :life_cycle_config,
  :override_vpc_config,
  :threads_per_core,
  :instance_storage_configs,
  :private_primary_ip,
  :private_primary_ipv_6,
  :private_dns_hostname,
  :placement,
  :current_image_id,
  :desired_image_id,
  :image_version_status,
  :ultra_server_info,
  :kubernetes_config,
  :capacity_type,
  :network_interface)
  SENSITIVE = []
  include Aws::Structure
end

#private_primary_ipv_6String

The private primary IPv6 address of the SageMaker HyperPod cluster node when configured with an Amazon VPC that supports IPv6 and includes subnets with IPv6 addressing enabled in either the cluster Amazon VPC configuration or the instance group Amazon VPC configuration.

Returns:

  • (String)


7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
7179
7180
7181
7182
7183
7184
7185
7186
7187
7188
7189
7190
7191
7192
7193
# File 'lib/aws-sdk-sagemaker/types.rb', line 7168

class ClusterNodeDetails < Struct.new(
  :instance_group_name,
  :instance_id,
  :node_logical_id,
  :instance_status,
  :instance_type,
  :launch_time,
  :last_software_update_time,
  :life_cycle_config,
  :override_vpc_config,
  :threads_per_core,
  :instance_storage_configs,
  :private_primary_ip,
  :private_primary_ipv_6,
  :private_dns_hostname,
  :placement,
  :current_image_id,
  :desired_image_id,
  :image_version_status,
  :ultra_server_info,
  :kubernetes_config,
  :capacity_type,
  :network_interface)
  SENSITIVE = []
  include Aws::Structure
end

#threads_per_coreInteger

The number of threads per CPU core you specified under ‘CreateCluster`.

Returns:

  • (Integer)


7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
7179
7180
7181
7182
7183
7184
7185
7186
7187
7188
7189
7190
7191
7192
7193
# File 'lib/aws-sdk-sagemaker/types.rb', line 7168

class ClusterNodeDetails < Struct.new(
  :instance_group_name,
  :instance_id,
  :node_logical_id,
  :instance_status,
  :instance_type,
  :launch_time,
  :last_software_update_time,
  :life_cycle_config,
  :override_vpc_config,
  :threads_per_core,
  :instance_storage_configs,
  :private_primary_ip,
  :private_primary_ipv_6,
  :private_dns_hostname,
  :placement,
  :current_image_id,
  :desired_image_id,
  :image_version_status,
  :ultra_server_info,
  :kubernetes_config,
  :capacity_type,
  :network_interface)
  SENSITIVE = []
  include Aws::Structure
end

#ultra_server_infoTypes::UltraServerInfo

Contains information about the UltraServer.



7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
7179
7180
7181
7182
7183
7184
7185
7186
7187
7188
7189
7190
7191
7192
7193
# File 'lib/aws-sdk-sagemaker/types.rb', line 7168

class ClusterNodeDetails < Struct.new(
  :instance_group_name,
  :instance_id,
  :node_logical_id,
  :instance_status,
  :instance_type,
  :launch_time,
  :last_software_update_time,
  :life_cycle_config,
  :override_vpc_config,
  :threads_per_core,
  :instance_storage_configs,
  :private_primary_ip,
  :private_primary_ipv_6,
  :private_dns_hostname,
  :placement,
  :current_image_id,
  :desired_image_id,
  :image_version_status,
  :ultra_server_info,
  :kubernetes_config,
  :capacity_type,
  :network_interface)
  SENSITIVE = []
  include Aws::Structure
end