Class: Aws::SageMaker::Types::ClusterNodeDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ClusterNodeDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Details of an instance (also called a node interchangeably) in a SageMaker HyperPod cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_type ⇒ String
The capacity type of the node.
-
#current_image_id ⇒ String
The ID of the Amazon Machine Image (AMI) currently in use by the node.
-
#desired_image_id ⇒ String
The ID of the Amazon Machine Image (AMI) desired for the node.
-
#instance_group_name ⇒ String
The instance group name in which the instance is.
-
#instance_id ⇒ String
The ID of the instance.
-
#instance_status ⇒ Types::ClusterInstanceStatusDetails
The status of the instance.
-
#instance_storage_configs ⇒ Array<Types::ClusterInstanceStorageConfig>
The configurations of additional storage specified to the instance group where the instance (node) is launched.
-
#instance_type ⇒ String
The type of the instance.
-
#kubernetes_config ⇒ Types::ClusterKubernetesConfigNodeDetails
The Kubernetes configuration applied to this node, showing both the current and desired state of labels and taints.
-
#last_software_update_time ⇒ Time
The time when the cluster was last updated.
-
#launch_time ⇒ Time
The time when the instance is launched.
-
#life_cycle_config ⇒ Types::ClusterLifeCycleConfig
The LifeCycle configuration applied to the instance.
-
#network_interface ⇒ Types::ClusterNetworkInterfaceDetails
The network interface configuration for the cluster node.
-
#node_logical_id ⇒ String
A unique identifier for the node that persists throughout its lifecycle, from provisioning request to termination.
-
#override_vpc_config ⇒ Types::VpcConfig
The customized Amazon VPC configuration at the instance group level that overrides the default Amazon VPC configuration of the SageMaker HyperPod cluster.
-
#placement ⇒ Types::ClusterInstancePlacement
The placement details of the SageMaker HyperPod cluster node.
-
#private_dns_hostname ⇒ String
The private DNS hostname of the SageMaker HyperPod cluster node.
-
#private_primary_ip ⇒ String
The private primary IP address of the SageMaker HyperPod cluster node.
-
#private_primary_ipv_6 ⇒ String
The private primary IPv6 address of the SageMaker HyperPod cluster node when configured with an Amazon VPC that supports IPv6 and includes subnets with IPv6 addressing enabled in either the cluster Amazon VPC configuration or the instance group Amazon VPC configuration.
-
#threads_per_core ⇒ Integer
The number of threads per CPU core you specified under ‘CreateCluster`.
-
#ultra_server_info ⇒ Types::UltraServerInfo
Contains information about the UltraServer.
Instance Attribute Details
#capacity_type ⇒ String
The capacity type of the node. Valid values are ‘OnDemand` and `Spot`. When set to `OnDemand`, the node is launched as an On-Demand instance. When set to `Spot`, the node is launched as a Spot instance.
6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 6440 6441 6442 6443 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6419 class ClusterNodeDetails < Struct.new( :instance_group_name, :instance_id, :node_logical_id, :instance_status, :instance_type, :launch_time, :last_software_update_time, :life_cycle_config, :override_vpc_config, :threads_per_core, :instance_storage_configs, :private_primary_ip, :private_primary_ipv_6, :private_dns_hostname, :placement, :current_image_id, :desired_image_id, :ultra_server_info, :kubernetes_config, :capacity_type, :network_interface) SENSITIVE = [] include Aws::Structure end |
#current_image_id ⇒ String
The ID of the Amazon Machine Image (AMI) currently in use by the node.
6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 6440 6441 6442 6443 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6419 class ClusterNodeDetails < Struct.new( :instance_group_name, :instance_id, :node_logical_id, :instance_status, :instance_type, :launch_time, :last_software_update_time, :life_cycle_config, :override_vpc_config, :threads_per_core, :instance_storage_configs, :private_primary_ip, :private_primary_ipv_6, :private_dns_hostname, :placement, :current_image_id, :desired_image_id, :ultra_server_info, :kubernetes_config, :capacity_type, :network_interface) SENSITIVE = [] include Aws::Structure end |
#desired_image_id ⇒ String
The ID of the Amazon Machine Image (AMI) desired for the node.
6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 6440 6441 6442 6443 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6419 class ClusterNodeDetails < Struct.new( :instance_group_name, :instance_id, :node_logical_id, :instance_status, :instance_type, :launch_time, :last_software_update_time, :life_cycle_config, :override_vpc_config, :threads_per_core, :instance_storage_configs, :private_primary_ip, :private_primary_ipv_6, :private_dns_hostname, :placement, :current_image_id, :desired_image_id, :ultra_server_info, :kubernetes_config, :capacity_type, :network_interface) SENSITIVE = [] include Aws::Structure end |
#instance_group_name ⇒ String
The instance group name in which the instance is.
6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 6440 6441 6442 6443 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6419 class ClusterNodeDetails < Struct.new( :instance_group_name, :instance_id, :node_logical_id, :instance_status, :instance_type, :launch_time, :last_software_update_time, :life_cycle_config, :override_vpc_config, :threads_per_core, :instance_storage_configs, :private_primary_ip, :private_primary_ipv_6, :private_dns_hostname, :placement, :current_image_id, :desired_image_id, :ultra_server_info, :kubernetes_config, :capacity_type, :network_interface) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of the instance.
6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 6440 6441 6442 6443 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6419 class ClusterNodeDetails < Struct.new( :instance_group_name, :instance_id, :node_logical_id, :instance_status, :instance_type, :launch_time, :last_software_update_time, :life_cycle_config, :override_vpc_config, :threads_per_core, :instance_storage_configs, :private_primary_ip, :private_primary_ipv_6, :private_dns_hostname, :placement, :current_image_id, :desired_image_id, :ultra_server_info, :kubernetes_config, :capacity_type, :network_interface) SENSITIVE = [] include Aws::Structure end |
#instance_status ⇒ Types::ClusterInstanceStatusDetails
The status of the instance.
6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 6440 6441 6442 6443 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6419 class ClusterNodeDetails < Struct.new( :instance_group_name, :instance_id, :node_logical_id, :instance_status, :instance_type, :launch_time, :last_software_update_time, :life_cycle_config, :override_vpc_config, :threads_per_core, :instance_storage_configs, :private_primary_ip, :private_primary_ipv_6, :private_dns_hostname, :placement, :current_image_id, :desired_image_id, :ultra_server_info, :kubernetes_config, :capacity_type, :network_interface) SENSITIVE = [] include Aws::Structure end |
#instance_storage_configs ⇒ Array<Types::ClusterInstanceStorageConfig>
The configurations of additional storage specified to the instance group where the instance (node) is launched.
6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 6440 6441 6442 6443 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6419 class ClusterNodeDetails < Struct.new( :instance_group_name, :instance_id, :node_logical_id, :instance_status, :instance_type, :launch_time, :last_software_update_time, :life_cycle_config, :override_vpc_config, :threads_per_core, :instance_storage_configs, :private_primary_ip, :private_primary_ipv_6, :private_dns_hostname, :placement, :current_image_id, :desired_image_id, :ultra_server_info, :kubernetes_config, :capacity_type, :network_interface) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The type of the instance.
6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 6440 6441 6442 6443 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6419 class ClusterNodeDetails < Struct.new( :instance_group_name, :instance_id, :node_logical_id, :instance_status, :instance_type, :launch_time, :last_software_update_time, :life_cycle_config, :override_vpc_config, :threads_per_core, :instance_storage_configs, :private_primary_ip, :private_primary_ipv_6, :private_dns_hostname, :placement, :current_image_id, :desired_image_id, :ultra_server_info, :kubernetes_config, :capacity_type, :network_interface) SENSITIVE = [] include Aws::Structure end |
#kubernetes_config ⇒ Types::ClusterKubernetesConfigNodeDetails
The Kubernetes configuration applied to this node, showing both the current and desired state of labels and taints. The cluster works to reconcile the actual state with the declared state.
6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 6440 6441 6442 6443 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6419 class ClusterNodeDetails < Struct.new( :instance_group_name, :instance_id, :node_logical_id, :instance_status, :instance_type, :launch_time, :last_software_update_time, :life_cycle_config, :override_vpc_config, :threads_per_core, :instance_storage_configs, :private_primary_ip, :private_primary_ipv_6, :private_dns_hostname, :placement, :current_image_id, :desired_image_id, :ultra_server_info, :kubernetes_config, :capacity_type, :network_interface) SENSITIVE = [] include Aws::Structure end |
#last_software_update_time ⇒ Time
The time when the cluster was last updated.
6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 6440 6441 6442 6443 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6419 class ClusterNodeDetails < Struct.new( :instance_group_name, :instance_id, :node_logical_id, :instance_status, :instance_type, :launch_time, :last_software_update_time, :life_cycle_config, :override_vpc_config, :threads_per_core, :instance_storage_configs, :private_primary_ip, :private_primary_ipv_6, :private_dns_hostname, :placement, :current_image_id, :desired_image_id, :ultra_server_info, :kubernetes_config, :capacity_type, :network_interface) SENSITIVE = [] include Aws::Structure end |
#launch_time ⇒ Time
The time when the instance is launched.
6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 6440 6441 6442 6443 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6419 class ClusterNodeDetails < Struct.new( :instance_group_name, :instance_id, :node_logical_id, :instance_status, :instance_type, :launch_time, :last_software_update_time, :life_cycle_config, :override_vpc_config, :threads_per_core, :instance_storage_configs, :private_primary_ip, :private_primary_ipv_6, :private_dns_hostname, :placement, :current_image_id, :desired_image_id, :ultra_server_info, :kubernetes_config, :capacity_type, :network_interface) SENSITIVE = [] include Aws::Structure end |
#life_cycle_config ⇒ Types::ClusterLifeCycleConfig
The LifeCycle configuration applied to the instance.
6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 6440 6441 6442 6443 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6419 class ClusterNodeDetails < Struct.new( :instance_group_name, :instance_id, :node_logical_id, :instance_status, :instance_type, :launch_time, :last_software_update_time, :life_cycle_config, :override_vpc_config, :threads_per_core, :instance_storage_configs, :private_primary_ip, :private_primary_ipv_6, :private_dns_hostname, :placement, :current_image_id, :desired_image_id, :ultra_server_info, :kubernetes_config, :capacity_type, :network_interface) SENSITIVE = [] include Aws::Structure end |
#network_interface ⇒ Types::ClusterNetworkInterfaceDetails
The network interface configuration for the cluster node.
6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 6440 6441 6442 6443 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6419 class ClusterNodeDetails < Struct.new( :instance_group_name, :instance_id, :node_logical_id, :instance_status, :instance_type, :launch_time, :last_software_update_time, :life_cycle_config, :override_vpc_config, :threads_per_core, :instance_storage_configs, :private_primary_ip, :private_primary_ipv_6, :private_dns_hostname, :placement, :current_image_id, :desired_image_id, :ultra_server_info, :kubernetes_config, :capacity_type, :network_interface) SENSITIVE = [] include Aws::Structure end |
#node_logical_id ⇒ String
A unique identifier for the node that persists throughout its lifecycle, from provisioning request to termination. This identifier can be used to track the node even before it has an assigned ‘InstanceId`.
6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 6440 6441 6442 6443 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6419 class ClusterNodeDetails < Struct.new( :instance_group_name, :instance_id, :node_logical_id, :instance_status, :instance_type, :launch_time, :last_software_update_time, :life_cycle_config, :override_vpc_config, :threads_per_core, :instance_storage_configs, :private_primary_ip, :private_primary_ipv_6, :private_dns_hostname, :placement, :current_image_id, :desired_image_id, :ultra_server_info, :kubernetes_config, :capacity_type, :network_interface) SENSITIVE = [] include Aws::Structure end |
#override_vpc_config ⇒ Types::VpcConfig
The customized Amazon VPC configuration at the instance group level that overrides the default Amazon VPC configuration of the SageMaker HyperPod cluster.
6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 6440 6441 6442 6443 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6419 class ClusterNodeDetails < Struct.new( :instance_group_name, :instance_id, :node_logical_id, :instance_status, :instance_type, :launch_time, :last_software_update_time, :life_cycle_config, :override_vpc_config, :threads_per_core, :instance_storage_configs, :private_primary_ip, :private_primary_ipv_6, :private_dns_hostname, :placement, :current_image_id, :desired_image_id, :ultra_server_info, :kubernetes_config, :capacity_type, :network_interface) SENSITIVE = [] include Aws::Structure end |
#placement ⇒ Types::ClusterInstancePlacement
The placement details of the SageMaker HyperPod cluster node.
6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 6440 6441 6442 6443 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6419 class ClusterNodeDetails < Struct.new( :instance_group_name, :instance_id, :node_logical_id, :instance_status, :instance_type, :launch_time, :last_software_update_time, :life_cycle_config, :override_vpc_config, :threads_per_core, :instance_storage_configs, :private_primary_ip, :private_primary_ipv_6, :private_dns_hostname, :placement, :current_image_id, :desired_image_id, :ultra_server_info, :kubernetes_config, :capacity_type, :network_interface) SENSITIVE = [] include Aws::Structure end |
#private_dns_hostname ⇒ String
The private DNS hostname of the SageMaker HyperPod cluster node.
6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 6440 6441 6442 6443 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6419 class ClusterNodeDetails < Struct.new( :instance_group_name, :instance_id, :node_logical_id, :instance_status, :instance_type, :launch_time, :last_software_update_time, :life_cycle_config, :override_vpc_config, :threads_per_core, :instance_storage_configs, :private_primary_ip, :private_primary_ipv_6, :private_dns_hostname, :placement, :current_image_id, :desired_image_id, :ultra_server_info, :kubernetes_config, :capacity_type, :network_interface) SENSITIVE = [] include Aws::Structure end |
#private_primary_ip ⇒ String
The private primary IP address of the SageMaker HyperPod cluster node.
6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 6440 6441 6442 6443 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6419 class ClusterNodeDetails < Struct.new( :instance_group_name, :instance_id, :node_logical_id, :instance_status, :instance_type, :launch_time, :last_software_update_time, :life_cycle_config, :override_vpc_config, :threads_per_core, :instance_storage_configs, :private_primary_ip, :private_primary_ipv_6, :private_dns_hostname, :placement, :current_image_id, :desired_image_id, :ultra_server_info, :kubernetes_config, :capacity_type, :network_interface) SENSITIVE = [] include Aws::Structure end |
#private_primary_ipv_6 ⇒ String
The private primary IPv6 address of the SageMaker HyperPod cluster node when configured with an Amazon VPC that supports IPv6 and includes subnets with IPv6 addressing enabled in either the cluster Amazon VPC configuration or the instance group Amazon VPC configuration.
6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 6440 6441 6442 6443 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6419 class ClusterNodeDetails < Struct.new( :instance_group_name, :instance_id, :node_logical_id, :instance_status, :instance_type, :launch_time, :last_software_update_time, :life_cycle_config, :override_vpc_config, :threads_per_core, :instance_storage_configs, :private_primary_ip, :private_primary_ipv_6, :private_dns_hostname, :placement, :current_image_id, :desired_image_id, :ultra_server_info, :kubernetes_config, :capacity_type, :network_interface) SENSITIVE = [] include Aws::Structure end |
#threads_per_core ⇒ Integer
The number of threads per CPU core you specified under ‘CreateCluster`.
6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 6440 6441 6442 6443 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6419 class ClusterNodeDetails < Struct.new( :instance_group_name, :instance_id, :node_logical_id, :instance_status, :instance_type, :launch_time, :last_software_update_time, :life_cycle_config, :override_vpc_config, :threads_per_core, :instance_storage_configs, :private_primary_ip, :private_primary_ipv_6, :private_dns_hostname, :placement, :current_image_id, :desired_image_id, :ultra_server_info, :kubernetes_config, :capacity_type, :network_interface) SENSITIVE = [] include Aws::Structure end |
#ultra_server_info ⇒ Types::UltraServerInfo
Contains information about the UltraServer.
6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 6440 6441 6442 6443 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6419 class ClusterNodeDetails < Struct.new( :instance_group_name, :instance_id, :node_logical_id, :instance_status, :instance_type, :launch_time, :last_software_update_time, :life_cycle_config, :override_vpc_config, :threads_per_core, :instance_storage_configs, :private_primary_ip, :private_primary_ipv_6, :private_dns_hostname, :placement, :current_image_id, :desired_image_id, :ultra_server_info, :kubernetes_config, :capacity_type, :network_interface) SENSITIVE = [] include Aws::Structure end |