Class: Aws::SageMaker::Types::ClusterNodeSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ClusterNodeSummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Lists a summary of the properties of an instance (also called a node interchangeably) of a SageMaker HyperPod cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#image_version_status ⇒ String
The status of the image version for the cluster node.
-
#instance_group_name ⇒ String
The name of the instance group in which the instance is.
-
#instance_id ⇒ String
The ID of the instance.
-
#instance_status ⇒ Types::ClusterInstanceStatusDetails
The status of the instance.
-
#instance_type ⇒ String
The type of the instance.
-
#last_software_update_time ⇒ Time
The time when SageMaker last updated the software of the instances in the cluster.
-
#launch_time ⇒ Time
The time when the instance is launched.
-
#node_logical_id ⇒ String
A unique identifier for the node that persists throughout its lifecycle, from provisioning request to termination.
-
#private_dns_hostname ⇒ String
The private DNS hostname of the SageMaker HyperPod cluster node.
-
#ultra_server_info ⇒ Types::UltraServerInfo
Contains information about the UltraServer.
Instance Attribute Details
#image_version_status ⇒ String
The status of the image version for the cluster node.
7198 7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 7210 7211 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7198 class ClusterNodeSummary < Struct.new( :instance_group_name, :instance_id, :node_logical_id, :instance_type, :launch_time, :last_software_update_time, :instance_status, :ultra_server_info, :private_dns_hostname, :image_version_status) SENSITIVE = [] include Aws::Structure end |
#instance_group_name ⇒ String
The name of the instance group in which the instance is.
7198 7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 7210 7211 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7198 class ClusterNodeSummary < Struct.new( :instance_group_name, :instance_id, :node_logical_id, :instance_type, :launch_time, :last_software_update_time, :instance_status, :ultra_server_info, :private_dns_hostname, :image_version_status) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of the instance.
7198 7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 7210 7211 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7198 class ClusterNodeSummary < Struct.new( :instance_group_name, :instance_id, :node_logical_id, :instance_type, :launch_time, :last_software_update_time, :instance_status, :ultra_server_info, :private_dns_hostname, :image_version_status) SENSITIVE = [] include Aws::Structure end |
#instance_status ⇒ Types::ClusterInstanceStatusDetails
The status of the instance.
7198 7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 7210 7211 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7198 class ClusterNodeSummary < Struct.new( :instance_group_name, :instance_id, :node_logical_id, :instance_type, :launch_time, :last_software_update_time, :instance_status, :ultra_server_info, :private_dns_hostname, :image_version_status) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The type of the instance.
7198 7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 7210 7211 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7198 class ClusterNodeSummary < Struct.new( :instance_group_name, :instance_id, :node_logical_id, :instance_type, :launch_time, :last_software_update_time, :instance_status, :ultra_server_info, :private_dns_hostname, :image_version_status) SENSITIVE = [] include Aws::Structure end |
#last_software_update_time ⇒ Time
The time when SageMaker last updated the software of the instances in the cluster.
7198 7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 7210 7211 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7198 class ClusterNodeSummary < Struct.new( :instance_group_name, :instance_id, :node_logical_id, :instance_type, :launch_time, :last_software_update_time, :instance_status, :ultra_server_info, :private_dns_hostname, :image_version_status) SENSITIVE = [] include Aws::Structure end |
#launch_time ⇒ Time
The time when the instance is launched.
7198 7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 7210 7211 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7198 class ClusterNodeSummary < Struct.new( :instance_group_name, :instance_id, :node_logical_id, :instance_type, :launch_time, :last_software_update_time, :instance_status, :ultra_server_info, :private_dns_hostname, :image_version_status) SENSITIVE = [] include Aws::Structure end |
#node_logical_id ⇒ String
A unique identifier for the node that persists throughout its lifecycle, from provisioning request to termination. This identifier can be used to track the node even before it has an assigned ‘InstanceId`. This field is only included when `IncludeNodeLogicalIds` is set to `True` in the `ListClusterNodes` request.
7198 7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 7210 7211 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7198 class ClusterNodeSummary < Struct.new( :instance_group_name, :instance_id, :node_logical_id, :instance_type, :launch_time, :last_software_update_time, :instance_status, :ultra_server_info, :private_dns_hostname, :image_version_status) SENSITIVE = [] include Aws::Structure end |
#private_dns_hostname ⇒ String
The private DNS hostname of the SageMaker HyperPod cluster node.
7198 7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 7210 7211 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7198 class ClusterNodeSummary < Struct.new( :instance_group_name, :instance_id, :node_logical_id, :instance_type, :launch_time, :last_software_update_time, :instance_status, :ultra_server_info, :private_dns_hostname, :image_version_status) SENSITIVE = [] include Aws::Structure end |
#ultra_server_info ⇒ Types::UltraServerInfo
Contains information about the UltraServer.
7198 7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 7210 7211 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7198 class ClusterNodeSummary < Struct.new( :instance_group_name, :instance_id, :node_logical_id, :instance_type, :launch_time, :last_software_update_time, :instance_status, :ultra_server_info, :private_dns_hostname, :image_version_status) SENSITIVE = [] include Aws::Structure end |