Class: Aws::SageMaker::Types::ClusterNodeSummary

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Lists a summary of the properties of an instance (also called a node interchangeably) of a SageMaker HyperPod cluster.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#image_version_statusString

The status of the image version for the cluster node.

Returns:

  • (String)


7186
7187
7188
7189
7190
7191
7192
7193
7194
7195
7196
7197
7198
7199
# File 'lib/aws-sdk-sagemaker/types.rb', line 7186

class ClusterNodeSummary < Struct.new(
  :instance_group_name,
  :instance_id,
  :node_logical_id,
  :instance_type,
  :launch_time,
  :last_software_update_time,
  :instance_status,
  :ultra_server_info,
  :private_dns_hostname,
  :image_version_status)
  SENSITIVE = []
  include Aws::Structure
end

#instance_group_nameString

The name of the instance group in which the instance is.

Returns:

  • (String)


7186
7187
7188
7189
7190
7191
7192
7193
7194
7195
7196
7197
7198
7199
# File 'lib/aws-sdk-sagemaker/types.rb', line 7186

class ClusterNodeSummary < Struct.new(
  :instance_group_name,
  :instance_id,
  :node_logical_id,
  :instance_type,
  :launch_time,
  :last_software_update_time,
  :instance_status,
  :ultra_server_info,
  :private_dns_hostname,
  :image_version_status)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The ID of the instance.

Returns:

  • (String)


7186
7187
7188
7189
7190
7191
7192
7193
7194
7195
7196
7197
7198
7199
# File 'lib/aws-sdk-sagemaker/types.rb', line 7186

class ClusterNodeSummary < Struct.new(
  :instance_group_name,
  :instance_id,
  :node_logical_id,
  :instance_type,
  :launch_time,
  :last_software_update_time,
  :instance_status,
  :ultra_server_info,
  :private_dns_hostname,
  :image_version_status)
  SENSITIVE = []
  include Aws::Structure
end

#instance_statusTypes::ClusterInstanceStatusDetails

The status of the instance.



7186
7187
7188
7189
7190
7191
7192
7193
7194
7195
7196
7197
7198
7199
# File 'lib/aws-sdk-sagemaker/types.rb', line 7186

class ClusterNodeSummary < Struct.new(
  :instance_group_name,
  :instance_id,
  :node_logical_id,
  :instance_type,
  :launch_time,
  :last_software_update_time,
  :instance_status,
  :ultra_server_info,
  :private_dns_hostname,
  :image_version_status)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typeString

The type of the instance.

Returns:

  • (String)


7186
7187
7188
7189
7190
7191
7192
7193
7194
7195
7196
7197
7198
7199
# File 'lib/aws-sdk-sagemaker/types.rb', line 7186

class ClusterNodeSummary < Struct.new(
  :instance_group_name,
  :instance_id,
  :node_logical_id,
  :instance_type,
  :launch_time,
  :last_software_update_time,
  :instance_status,
  :ultra_server_info,
  :private_dns_hostname,
  :image_version_status)
  SENSITIVE = []
  include Aws::Structure
end

#last_software_update_timeTime

The time when SageMaker last updated the software of the instances in the cluster.

Returns:

  • (Time)


7186
7187
7188
7189
7190
7191
7192
7193
7194
7195
7196
7197
7198
7199
# File 'lib/aws-sdk-sagemaker/types.rb', line 7186

class ClusterNodeSummary < Struct.new(
  :instance_group_name,
  :instance_id,
  :node_logical_id,
  :instance_type,
  :launch_time,
  :last_software_update_time,
  :instance_status,
  :ultra_server_info,
  :private_dns_hostname,
  :image_version_status)
  SENSITIVE = []
  include Aws::Structure
end

#launch_timeTime

The time when the instance is launched.

Returns:

  • (Time)


7186
7187
7188
7189
7190
7191
7192
7193
7194
7195
7196
7197
7198
7199
# File 'lib/aws-sdk-sagemaker/types.rb', line 7186

class ClusterNodeSummary < Struct.new(
  :instance_group_name,
  :instance_id,
  :node_logical_id,
  :instance_type,
  :launch_time,
  :last_software_update_time,
  :instance_status,
  :ultra_server_info,
  :private_dns_hostname,
  :image_version_status)
  SENSITIVE = []
  include Aws::Structure
end

#node_logical_idString

A unique identifier for the node that persists throughout its lifecycle, from provisioning request to termination. This identifier can be used to track the node even before it has an assigned ‘InstanceId`. This field is only included when `IncludeNodeLogicalIds` is set to `True` in the `ListClusterNodes` request.

Returns:

  • (String)


7186
7187
7188
7189
7190
7191
7192
7193
7194
7195
7196
7197
7198
7199
# File 'lib/aws-sdk-sagemaker/types.rb', line 7186

class ClusterNodeSummary < Struct.new(
  :instance_group_name,
  :instance_id,
  :node_logical_id,
  :instance_type,
  :launch_time,
  :last_software_update_time,
  :instance_status,
  :ultra_server_info,
  :private_dns_hostname,
  :image_version_status)
  SENSITIVE = []
  include Aws::Structure
end

#private_dns_hostnameString

The private DNS hostname of the SageMaker HyperPod cluster node.

Returns:

  • (String)


7186
7187
7188
7189
7190
7191
7192
7193
7194
7195
7196
7197
7198
7199
# File 'lib/aws-sdk-sagemaker/types.rb', line 7186

class ClusterNodeSummary < Struct.new(
  :instance_group_name,
  :instance_id,
  :node_logical_id,
  :instance_type,
  :launch_time,
  :last_software_update_time,
  :instance_status,
  :ultra_server_info,
  :private_dns_hostname,
  :image_version_status)
  SENSITIVE = []
  include Aws::Structure
end

#ultra_server_infoTypes::UltraServerInfo

Contains information about the UltraServer.



7186
7187
7188
7189
7190
7191
7192
7193
7194
7195
7196
7197
7198
7199
# File 'lib/aws-sdk-sagemaker/types.rb', line 7186

class ClusterNodeSummary < Struct.new(
  :instance_group_name,
  :instance_id,
  :node_logical_id,
  :instance_type,
  :launch_time,
  :last_software_update_time,
  :instance_status,
  :ultra_server_info,
  :private_dns_hostname,
  :image_version_status)
  SENSITIVE = []
  include Aws::Structure
end