Class: Aws::SageMaker::Types::ClusterPatchSchedule

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The schedule configuration for automatic patching.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_patch_dateTime

The date and time of the next scheduled automatic patch. The system sets this automatically when a patch is detected. Use this field to reschedule the patch to a different date.

Returns:

  • (Time)


7443
7444
7445
7446
7447
# File 'lib/aws-sdk-sagemaker/types.rb', line 7443

class ClusterPatchSchedule < Struct.new(
  :next_patch_date)
  SENSITIVE = []
  include Aws::Structure
end