Class: Aws::SageMaker::Types::ClusterRestrictedInstanceGroupSpecification

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The specifications of a restricted instance group that you need to define.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#environment_configTypes::EnvironmentConfig

The configuration for the restricted instance groups (RIG) environment.



6767
6768
6769
6770
6771
6772
6773
6774
6775
6776
6777
6778
6779
6780
6781
# File 'lib/aws-sdk-sagemaker/types.rb', line 6767

class ClusterRestrictedInstanceGroupSpecification < Struct.new(
  :instance_count,
  :instance_group_name,
  :instance_type,
  :execution_role,
  :threads_per_core,
  :instance_storage_configs,
  :on_start_deep_health_checks,
  :training_plan_arn,
  :override_vpc_config,
  :scheduled_update_config,
  :environment_config)
  SENSITIVE = []
  include Aws::Structure
end

#execution_roleString

Specifies an IAM execution role to be assumed by the restricted instance group.

Returns:

  • (String)


6767
6768
6769
6770
6771
6772
6773
6774
6775
6776
6777
6778
6779
6780
6781
# File 'lib/aws-sdk-sagemaker/types.rb', line 6767

class ClusterRestrictedInstanceGroupSpecification < Struct.new(
  :instance_count,
  :instance_group_name,
  :instance_type,
  :execution_role,
  :threads_per_core,
  :instance_storage_configs,
  :on_start_deep_health_checks,
  :training_plan_arn,
  :override_vpc_config,
  :scheduled_update_config,
  :environment_config)
  SENSITIVE = []
  include Aws::Structure
end

#instance_countInteger

Specifies the number of instances to add to the restricted instance group of a SageMaker HyperPod cluster.

Returns:

  • (Integer)


6767
6768
6769
6770
6771
6772
6773
6774
6775
6776
6777
6778
6779
6780
6781
# File 'lib/aws-sdk-sagemaker/types.rb', line 6767

class ClusterRestrictedInstanceGroupSpecification < Struct.new(
  :instance_count,
  :instance_group_name,
  :instance_type,
  :execution_role,
  :threads_per_core,
  :instance_storage_configs,
  :on_start_deep_health_checks,
  :training_plan_arn,
  :override_vpc_config,
  :scheduled_update_config,
  :environment_config)
  SENSITIVE = []
  include Aws::Structure
end

#instance_group_nameString

Specifies the name of the restricted instance group.

Returns:

  • (String)


6767
6768
6769
6770
6771
6772
6773
6774
6775
6776
6777
6778
6779
6780
6781
# File 'lib/aws-sdk-sagemaker/types.rb', line 6767

class ClusterRestrictedInstanceGroupSpecification < Struct.new(
  :instance_count,
  :instance_group_name,
  :instance_type,
  :execution_role,
  :threads_per_core,
  :instance_storage_configs,
  :on_start_deep_health_checks,
  :training_plan_arn,
  :override_vpc_config,
  :scheduled_update_config,
  :environment_config)
  SENSITIVE = []
  include Aws::Structure
end

#instance_storage_configsArray<Types::ClusterInstanceStorageConfig>

Specifies the additional storage configurations for the instances in the SageMaker HyperPod cluster restricted instance group.



6767
6768
6769
6770
6771
6772
6773
6774
6775
6776
6777
6778
6779
6780
6781
# File 'lib/aws-sdk-sagemaker/types.rb', line 6767

class ClusterRestrictedInstanceGroupSpecification < Struct.new(
  :instance_count,
  :instance_group_name,
  :instance_type,
  :execution_role,
  :threads_per_core,
  :instance_storage_configs,
  :on_start_deep_health_checks,
  :training_plan_arn,
  :override_vpc_config,
  :scheduled_update_config,
  :environment_config)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typeString

Specifies the instance type of the restricted instance group.

Returns:

  • (String)


6767
6768
6769
6770
6771
6772
6773
6774
6775
6776
6777
6778
6779
6780
6781
# File 'lib/aws-sdk-sagemaker/types.rb', line 6767

class ClusterRestrictedInstanceGroupSpecification < Struct.new(
  :instance_count,
  :instance_group_name,
  :instance_type,
  :execution_role,
  :threads_per_core,
  :instance_storage_configs,
  :on_start_deep_health_checks,
  :training_plan_arn,
  :override_vpc_config,
  :scheduled_update_config,
  :environment_config)
  SENSITIVE = []
  include Aws::Structure
end

#on_start_deep_health_checksArray<String>

A flag indicating whether deep health checks should be performed when the cluster restricted instance group is created or updated.

Returns:

  • (Array<String>)


6767
6768
6769
6770
6771
6772
6773
6774
6775
6776
6777
6778
6779
6780
6781
# File 'lib/aws-sdk-sagemaker/types.rb', line 6767

class ClusterRestrictedInstanceGroupSpecification < Struct.new(
  :instance_count,
  :instance_group_name,
  :instance_type,
  :execution_role,
  :threads_per_core,
  :instance_storage_configs,
  :on_start_deep_health_checks,
  :training_plan_arn,
  :override_vpc_config,
  :scheduled_update_config,
  :environment_config)
  SENSITIVE = []
  include Aws::Structure
end

#override_vpc_configTypes::VpcConfig

Specifies an Amazon Virtual Private Cloud (VPC) that your SageMaker jobs, hosted models, and compute resources have access to. You can control access to and from your resources by configuring a VPC. For more information, see [Give SageMaker Access to Resources in your Amazon VPC].

[1]: docs.aws.amazon.com/sagemaker/latest/dg/infrastructure-give-access.html

Returns:



6767
6768
6769
6770
6771
6772
6773
6774
6775
6776
6777
6778
6779
6780
6781
# File 'lib/aws-sdk-sagemaker/types.rb', line 6767

class ClusterRestrictedInstanceGroupSpecification < Struct.new(
  :instance_count,
  :instance_group_name,
  :instance_type,
  :execution_role,
  :threads_per_core,
  :instance_storage_configs,
  :on_start_deep_health_checks,
  :training_plan_arn,
  :override_vpc_config,
  :scheduled_update_config,
  :environment_config)
  SENSITIVE = []
  include Aws::Structure
end

#scheduled_update_configTypes::ScheduledUpdateConfig

The configuration object of the schedule that SageMaker follows when updating the AMI.



6767
6768
6769
6770
6771
6772
6773
6774
6775
6776
6777
6778
6779
6780
6781
# File 'lib/aws-sdk-sagemaker/types.rb', line 6767

class ClusterRestrictedInstanceGroupSpecification < Struct.new(
  :instance_count,
  :instance_group_name,
  :instance_type,
  :execution_role,
  :threads_per_core,
  :instance_storage_configs,
  :on_start_deep_health_checks,
  :training_plan_arn,
  :override_vpc_config,
  :scheduled_update_config,
  :environment_config)
  SENSITIVE = []
  include Aws::Structure
end

#threads_per_coreInteger

The number you specified to ‘TreadsPerCore` in `CreateCluster` for enabling or disabling multithreading. For instance types that support multithreading, you can specify 1 for disabling multithreading and 2 for enabling multithreading. For more information, see the reference table of [CPU cores and threads per CPU core per instance type] in the *Amazon Elastic Compute Cloud User Guide*.

[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/cpu-options-supported-instances-values.html

Returns:

  • (Integer)


6767
6768
6769
6770
6771
6772
6773
6774
6775
6776
6777
6778
6779
6780
6781
# File 'lib/aws-sdk-sagemaker/types.rb', line 6767

class ClusterRestrictedInstanceGroupSpecification < Struct.new(
  :instance_count,
  :instance_group_name,
  :instance_type,
  :execution_role,
  :threads_per_core,
  :instance_storage_configs,
  :on_start_deep_health_checks,
  :training_plan_arn,
  :override_vpc_config,
  :scheduled_update_config,
  :environment_config)
  SENSITIVE = []
  include Aws::Structure
end

#training_plan_arnString

The Amazon Resource Name (ARN) of the training plan to filter clusters by. For more information about reserving GPU capacity for your SageMaker HyperPod clusters using Amazon SageMaker Training Plan, see ‘ CreateTrainingPlan `.

Returns:

  • (String)


6767
6768
6769
6770
6771
6772
6773
6774
6775
6776
6777
6778
6779
6780
6781
# File 'lib/aws-sdk-sagemaker/types.rb', line 6767

class ClusterRestrictedInstanceGroupSpecification < Struct.new(
  :instance_count,
  :instance_group_name,
  :instance_type,
  :execution_role,
  :threads_per_core,
  :instance_storage_configs,
  :on_start_deep_health_checks,
  :training_plan_arn,
  :override_vpc_config,
  :scheduled_update_config,
  :environment_config)
  SENSITIVE = []
  include Aws::Structure
end