Class: Aws::SageMaker::Types::ClusterSharedEnvironmentConfigDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ClusterSharedEnvironmentConfigDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The shared environment configuration details for the restricted instance groups (RIG).
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#current_f_sx_lustre_config ⇒ Types::FSxLustreConfig
The current Amazon FSx for Lustre file system configuration in the shared environment.
-
#current_f_sx_lustre_deletion_policy ⇒ String
The current deletion policy for the Amazon FSx for Lustre file system in the shared environment.
-
#desired_f_sx_lustre_config ⇒ Types::FSxLustreConfig
The desired Amazon FSx for Lustre file system configuration in the shared environment.
-
#desired_f_sx_lustre_deletion_policy ⇒ String
The desired deletion policy for the Amazon FSx for Lustre file system in the shared environment.
Instance Attribute Details
#current_f_sx_lustre_config ⇒ Types::FSxLustreConfig
The current Amazon FSx for Lustre file system configuration in the shared environment.
7666 7667 7668 7669 7670 7671 7672 7673 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7666 class ClusterSharedEnvironmentConfigDetails < Struct.new( :current_f_sx_lustre_config, :desired_f_sx_lustre_config, :current_f_sx_lustre_deletion_policy, :desired_f_sx_lustre_deletion_policy) SENSITIVE = [] include Aws::Structure end |
#current_f_sx_lustre_deletion_policy ⇒ String
The current deletion policy for the Amazon FSx for Lustre file system in the shared environment.
7666 7667 7668 7669 7670 7671 7672 7673 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7666 class ClusterSharedEnvironmentConfigDetails < Struct.new( :current_f_sx_lustre_config, :desired_f_sx_lustre_config, :current_f_sx_lustre_deletion_policy, :desired_f_sx_lustre_deletion_policy) SENSITIVE = [] include Aws::Structure end |
#desired_f_sx_lustre_config ⇒ Types::FSxLustreConfig
The desired Amazon FSx for Lustre file system configuration in the shared environment.
7666 7667 7668 7669 7670 7671 7672 7673 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7666 class ClusterSharedEnvironmentConfigDetails < Struct.new( :current_f_sx_lustre_config, :desired_f_sx_lustre_config, :current_f_sx_lustre_deletion_policy, :desired_f_sx_lustre_deletion_policy) SENSITIVE = [] include Aws::Structure end |
#desired_f_sx_lustre_deletion_policy ⇒ String
The desired deletion policy for the Amazon FSx for Lustre file system in the shared environment.
7666 7667 7668 7669 7670 7671 7672 7673 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7666 class ClusterSharedEnvironmentConfigDetails < Struct.new( :current_f_sx_lustre_config, :desired_f_sx_lustre_config, :current_f_sx_lustre_deletion_policy, :desired_f_sx_lustre_deletion_policy) SENSITIVE = [] include Aws::Structure end |