Class: Aws::SageMaker::Types::ClusterSummary

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Lists a summary of the properties of a SageMaker HyperPod cluster.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_arnString

The Amazon Resource Name (ARN) of the SageMaker HyperPod cluster.

Returns:

  • (String)


7929
7930
7931
7932
7933
7934
7935
7936
7937
7938
# File 'lib/aws-sdk-sagemaker/types.rb', line 7929

class ClusterSummary < Struct.new(
  :cluster_arn,
  :cluster_name,
  :creation_time,
  :cluster_status,
  :training_plan_arns,
  :image_version_status)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_nameString

The name of the SageMaker HyperPod cluster.

Returns:

  • (String)


7929
7930
7931
7932
7933
7934
7935
7936
7937
7938
# File 'lib/aws-sdk-sagemaker/types.rb', line 7929

class ClusterSummary < Struct.new(
  :cluster_arn,
  :cluster_name,
  :creation_time,
  :cluster_status,
  :training_plan_arns,
  :image_version_status)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_statusString

The status of the SageMaker HyperPod cluster.

Returns:

  • (String)


7929
7930
7931
7932
7933
7934
7935
7936
7937
7938
# File 'lib/aws-sdk-sagemaker/types.rb', line 7929

class ClusterSummary < Struct.new(
  :cluster_arn,
  :cluster_name,
  :creation_time,
  :cluster_status,
  :training_plan_arns,
  :image_version_status)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

The time when the SageMaker HyperPod cluster is created.

Returns:

  • (Time)


7929
7930
7931
7932
7933
7934
7935
7936
7937
7938
# File 'lib/aws-sdk-sagemaker/types.rb', line 7929

class ClusterSummary < Struct.new(
  :cluster_arn,
  :cluster_name,
  :creation_time,
  :cluster_status,
  :training_plan_arns,
  :image_version_status)
  SENSITIVE = []
  include Aws::Structure
end

#image_version_statusString

The aggregate status of the image version across the cluster's instance groups.

Returns:

  • (String)


7929
7930
7931
7932
7933
7934
7935
7936
7937
7938
# File 'lib/aws-sdk-sagemaker/types.rb', line 7929

class ClusterSummary < Struct.new(
  :cluster_arn,
  :cluster_name,
  :creation_time,
  :cluster_status,
  :training_plan_arns,
  :image_version_status)
  SENSITIVE = []
  include Aws::Structure
end

#training_plan_arnsArray<String>

A list of Amazon Resource Names (ARNs) of the training plans associated with this cluster.

For more information about how to reserve GPU capacity for your SageMaker HyperPod clusters using Amazon SageMaker Training Plan, see CreateTrainingPlan.

Returns:

  • (Array<String>)


7929
7930
7931
7932
7933
7934
7935
7936
7937
7938
# File 'lib/aws-sdk-sagemaker/types.rb', line 7929

class ClusterSummary < Struct.new(
  :cluster_arn,
  :cluster_name,
  :creation_time,
  :cluster_status,
  :training_plan_arns,
  :image_version_status)
  SENSITIVE = []
  include Aws::Structure
end