Class: Aws::SageMaker::Types::ClusterSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ClusterSummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Lists a summary of the properties of a SageMaker HyperPod cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster_arn ⇒ String
The Amazon Resource Name (ARN) of the SageMaker HyperPod cluster.
-
#cluster_name ⇒ String
The name of the SageMaker HyperPod cluster.
-
#cluster_status ⇒ String
The status of the SageMaker HyperPod cluster.
-
#creation_time ⇒ Time
The time when the SageMaker HyperPod cluster is created.
-
#image_version_status ⇒ String
The aggregate status of the image version across the cluster's instance groups.
-
#training_plan_arns ⇒ Array<String>
A list of Amazon Resource Names (ARNs) of the training plans associated with this cluster.
Instance Attribute Details
#cluster_arn ⇒ String
The Amazon Resource Name (ARN) of the SageMaker HyperPod cluster.
7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7929 class ClusterSummary < Struct.new( :cluster_arn, :cluster_name, :creation_time, :cluster_status, :training_plan_arns, :image_version_status) SENSITIVE = [] include Aws::Structure end |
#cluster_name ⇒ String
The name of the SageMaker HyperPod cluster.
7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7929 class ClusterSummary < Struct.new( :cluster_arn, :cluster_name, :creation_time, :cluster_status, :training_plan_arns, :image_version_status) SENSITIVE = [] include Aws::Structure end |
#cluster_status ⇒ String
The status of the SageMaker HyperPod cluster.
7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7929 class ClusterSummary < Struct.new( :cluster_arn, :cluster_name, :creation_time, :cluster_status, :training_plan_arns, :image_version_status) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The time when the SageMaker HyperPod cluster is created.
7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7929 class ClusterSummary < Struct.new( :cluster_arn, :cluster_name, :creation_time, :cluster_status, :training_plan_arns, :image_version_status) SENSITIVE = [] include Aws::Structure end |
#image_version_status ⇒ String
The aggregate status of the image version across the cluster's instance groups.
7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7929 class ClusterSummary < Struct.new( :cluster_arn, :cluster_name, :creation_time, :cluster_status, :training_plan_arns, :image_version_status) SENSITIVE = [] include Aws::Structure end |
#training_plan_arns ⇒ Array<String>
A list of Amazon Resource Names (ARNs) of the training plans associated with this cluster.
For more information about how to reserve GPU capacity for your
SageMaker HyperPod clusters using Amazon SageMaker Training Plan,
see CreateTrainingPlan.
7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7929 class ClusterSummary < Struct.new( :cluster_arn, :cluster_name, :creation_time, :cluster_status, :training_plan_arns, :image_version_status) SENSITIVE = [] include Aws::Structure end |