Class: Aws::SageMaker::Types::CodeEditorAppSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CodeEditorAppSettings
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The Code Editor application settings.
For more information about Code Editor, see Get started with Code Editor in Amazon SageMaker.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#app_lifecycle_management ⇒ Types::AppLifecycleManagement
Settings that are used to configure and manage the lifecycle of CodeEditor applications.
-
#built_in_lifecycle_config_arn ⇒ String
The lifecycle configuration that runs before the default lifecycle configuration.
-
#custom_images ⇒ Array<Types::CustomImage>
A list of custom SageMaker images that are configured to run as a Code Editor app.
-
#default_resource_spec ⇒ Types::ResourceSpec
Specifies the ARN's of a SageMaker AI image and SageMaker AI image version, and the instance type that the version runs on.
-
#lifecycle_config_arns ⇒ Array<String>
The Amazon Resource Name (ARN) of the Code Editor application lifecycle configuration.
Instance Attribute Details
#app_lifecycle_management ⇒ Types::AppLifecycleManagement
Settings that are used to configure and manage the lifecycle of CodeEditor applications.
8013 8014 8015 8016 8017 8018 8019 8020 8021 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 8013 class CodeEditorAppSettings < Struct.new( :default_resource_spec, :custom_images, :lifecycle_config_arns, :app_lifecycle_management, :built_in_lifecycle_config_arn) SENSITIVE = [] include Aws::Structure end |
#built_in_lifecycle_config_arn ⇒ String
The lifecycle configuration that runs before the default lifecycle configuration. It can override changes made in the default lifecycle configuration.
8013 8014 8015 8016 8017 8018 8019 8020 8021 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 8013 class CodeEditorAppSettings < Struct.new( :default_resource_spec, :custom_images, :lifecycle_config_arns, :app_lifecycle_management, :built_in_lifecycle_config_arn) SENSITIVE = [] include Aws::Structure end |
#custom_images ⇒ Array<Types::CustomImage>
A list of custom SageMaker images that are configured to run as a Code Editor app.
8013 8014 8015 8016 8017 8018 8019 8020 8021 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 8013 class CodeEditorAppSettings < Struct.new( :default_resource_spec, :custom_images, :lifecycle_config_arns, :app_lifecycle_management, :built_in_lifecycle_config_arn) SENSITIVE = [] include Aws::Structure end |
#default_resource_spec ⇒ Types::ResourceSpec
Specifies the ARN's of a SageMaker AI image and SageMaker AI image version, and the instance type that the version runs on.
SageMakerImageVersionArn and SageMakerImageArn are
passed, SageMakerImageVersionArn is used. Any updates to
SageMakerImageArn will not take effect if
SageMakerImageVersionArn already exists in the ResourceSpec
because SageMakerImageVersionArn always takes precedence. To clear
the value set for SageMakerImageVersionArn, pass None as the
value.
8013 8014 8015 8016 8017 8018 8019 8020 8021 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 8013 class CodeEditorAppSettings < Struct.new( :default_resource_spec, :custom_images, :lifecycle_config_arns, :app_lifecycle_management, :built_in_lifecycle_config_arn) SENSITIVE = [] include Aws::Structure end |
#lifecycle_config_arns ⇒ Array<String>
The Amazon Resource Name (ARN) of the Code Editor application lifecycle configuration.
8013 8014 8015 8016 8017 8018 8019 8020 8021 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 8013 class CodeEditorAppSettings < Struct.new( :default_resource_spec, :custom_images, :lifecycle_config_arns, :app_lifecycle_management, :built_in_lifecycle_config_arn) SENSITIVE = [] include Aws::Structure end |