Class: Aws::SageMaker::Types::CodeRepositorySummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CodeRepositorySummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Specifies summary information about a Git repository.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code_repository_arn ⇒ String
The Amazon Resource Name (ARN) of the Git repository.
-
#code_repository_name ⇒ String
The name of the Git repository.
-
#creation_time ⇒ Time
The date and time that the Git repository was created.
-
#git_config ⇒ Types::GitConfig
Configuration details for the Git repository, including the URL where it is located and the ARN of the Amazon Web Services Secrets Manager secret that contains the credentials used to access the repository.
-
#last_modified_time ⇒ Time
The date and time that the Git repository was last modified.
Instance Attribute Details
#code_repository_arn ⇒ String
The Amazon Resource Name (ARN) of the Git repository.
8213 8214 8215 8216 8217 8218 8219 8220 8221 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 8213 class CodeRepositorySummary < Struct.new( :code_repository_name, :code_repository_arn, :creation_time, :last_modified_time, :git_config) SENSITIVE = [] include Aws::Structure end |
#code_repository_name ⇒ String
The name of the Git repository.
8213 8214 8215 8216 8217 8218 8219 8220 8221 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 8213 class CodeRepositorySummary < Struct.new( :code_repository_name, :code_repository_arn, :creation_time, :last_modified_time, :git_config) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The date and time that the Git repository was created.
8213 8214 8215 8216 8217 8218 8219 8220 8221 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 8213 class CodeRepositorySummary < Struct.new( :code_repository_name, :code_repository_arn, :creation_time, :last_modified_time, :git_config) SENSITIVE = [] include Aws::Structure end |
#git_config ⇒ Types::GitConfig
Configuration details for the Git repository, including the URL where it is located and the ARN of the Amazon Web Services Secrets Manager secret that contains the credentials used to access the repository.
8213 8214 8215 8216 8217 8218 8219 8220 8221 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 8213 class CodeRepositorySummary < Struct.new( :code_repository_name, :code_repository_arn, :creation_time, :last_modified_time, :git_config) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The date and time that the Git repository was last modified.
8213 8214 8215 8216 8217 8218 8219 8220 8221 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 8213 class CodeRepositorySummary < Struct.new( :code_repository_name, :code_repository_arn, :creation_time, :last_modified_time, :git_config) SENSITIVE = [] include Aws::Structure end |