Class: Aws::SageMaker::Types::CognitoConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CognitoConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Use this parameter to configure your Amazon Cognito workforce. A single Cognito workforce is created using and corresponds to a single Amazon Cognito user pool.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_id ⇒ String
The client ID for your Amazon Cognito user pool.
-
#user_pool ⇒ String
A [ user pool][1] is a user directory in Amazon Cognito.
Instance Attribute Details
#client_id ⇒ String
The client ID for your Amazon Cognito user pool.
8127 8128 8129 8130 8131 8132 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 8127 class CognitoConfig < Struct.new( :user_pool, :client_id) SENSITIVE = [] include Aws::Structure end |
#user_pool ⇒ String
A user pool is a user directory in Amazon Cognito. With a user pool, your users can sign in to your web or mobile app through Amazon Cognito. Your users can also sign in through social identity providers like Google, Facebook, Amazon, or Apple, and through SAML identity providers.
8127 8128 8129 8130 8131 8132 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 8127 class CognitoConfig < Struct.new( :user_pool, :client_id) SENSITIVE = [] include Aws::Structure end |