Class: Aws::SageMaker::Types::CognitoConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CognitoConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Use this parameter to configure your Amazon Cognito workforce. A single Cognito workforce is created using and corresponds to a single [ Amazon Cognito user pool].
[1]: docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-identity-pools.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_id ⇒ String
The client ID for your Amazon Cognito user pool.
-
#user_pool ⇒ String
A [ user pool] is a user directory in Amazon Cognito.
Instance Attribute Details
#client_id ⇒ String
The client ID for your Amazon Cognito user pool.
7905 7906 7907 7908 7909 7910 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7905 class CognitoConfig < Struct.new( :user_pool, :client_id) SENSITIVE = [] include Aws::Structure end |
#user_pool ⇒ String
A [ user pool] is a user directory in Amazon Cognito. With a user pool, your users can sign in to your web or mobile app through Amazon Cognito. Your users can also sign in through social identity providers like Google, Facebook, Amazon, or Apple, and through SAML identity providers.
[1]: docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-identity-pools.html
7905 7906 7907 7908 7909 7910 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7905 class CognitoConfig < Struct.new( :user_pool, :client_id) SENSITIVE = [] include Aws::Structure end |