Class: Aws::SageMaker::Types::CollectionConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CollectionConfig
- Includes:
- Aws::Structure, Aws::Structure::Union
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Note:
CollectionConfig is a union - when making an API calls you must set exactly one of the members.
Note:
CollectionConfig is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of CollectionConfig corresponding to the set member.
Configuration for your collection.
Direct Known Subclasses
Defined Under Namespace
Classes: Unknown, VectorConfig
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#unknown ⇒ Object
Returns the value of attribute unknown.
-
#vector_config ⇒ Types::VectorConfig
Configuration for your vector collection type.
Instance Attribute Details
#unknown ⇒ Object
Returns the value of attribute unknown
7855 7856 7857 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7855 def unknown @unknown end |
#vector_config ⇒ Types::VectorConfig
Configuration for your vector collection type.
-
‘Dimension`: The number of elements in your vector.
^
7855 7856 7857 7858 7859 7860 7861 7862 7863 7864 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7855 class CollectionConfig < Struct.new( :vector_config, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class VectorConfig < CollectionConfig; end class Unknown < CollectionConfig; end end |