Class: Aws::SageMaker::Types::ContainerMetricsConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ContainerMetricsConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The configuration for container-level metrics scraping. Use this configuration to specify a custom metrics endpoint path and publishing frequency for container metrics. When ‘EnableDetailedObservability` is set to `True` in `MetricsConfig`, metrics are scraped from the container’s Prometheus endpoint. If this configuration is not provided, the default path ‘/metrics` on port `8080` is used with a default publishing frequency of `60` seconds. For first-party and Deep Learning Containers (DLC), the endpoint path is determined automatically and this configuration is optional.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#metrics_endpoints ⇒ Array<Types::MetricsEndpoint>
A list of metrics endpoints to scrape from the container.
Instance Attribute Details
#metrics_endpoints ⇒ Array<Types::MetricsEndpoint>
A list of metrics endpoints to scrape from the container. Each endpoint specifies the path where the container exposes Prometheus-formatted metrics and the frequency at which to publish them. You can specify a maximum of 1 endpoint.
8525 8526 8527 8528 8529 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 8525 class ContainerMetricsConfig < Struct.new( :metrics_endpoints) SENSITIVE = [] include Aws::Structure end |