Class: Aws::SageMaker::Types::CreateAIBenchmarkJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreateAIBenchmarkJobRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ai_benchmark_job_name ⇒ String
The name of the AI benchmark job.
-
#ai_workload_config_identifier ⇒ String
The name or Amazon Resource Name (ARN) of the AI workload configuration to use for this benchmark job.
-
#benchmark_target ⇒ Types::AIBenchmarkTarget
The target endpoint to benchmark.
-
#network_config ⇒ Types::AIBenchmarkNetworkConfig
The network configuration for the benchmark job, including VPC settings.
-
#output_config ⇒ Types::AIBenchmarkOutputConfig
The output configuration for the benchmark job, including the Amazon S3 location where benchmark results are stored.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that enables Amazon SageMaker AI to perform tasks on your behalf.
-
#tags ⇒ Array<Types::Tag>
The metadata that you apply to Amazon Web Services resources to help you categorize and organize them.
Instance Attribute Details
#ai_benchmark_job_name ⇒ String
The name of the AI benchmark job. The name must be unique within your Amazon Web Services account in the current Amazon Web Services Region.
8652 8653 8654 8655 8656 8657 8658 8659 8660 8661 8662 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 8652 class CreateAIBenchmarkJobRequest < Struct.new( :ai_benchmark_job_name, :benchmark_target, :output_config, :ai_workload_config_identifier, :role_arn, :network_config, :tags) SENSITIVE = [] include Aws::Structure end |
#ai_workload_config_identifier ⇒ String
The name or Amazon Resource Name (ARN) of the AI workload configuration to use for this benchmark job.
8652 8653 8654 8655 8656 8657 8658 8659 8660 8661 8662 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 8652 class CreateAIBenchmarkJobRequest < Struct.new( :ai_benchmark_job_name, :benchmark_target, :output_config, :ai_workload_config_identifier, :role_arn, :network_config, :tags) SENSITIVE = [] include Aws::Structure end |
#benchmark_target ⇒ Types::AIBenchmarkTarget
The target endpoint to benchmark. Specify a SageMaker endpoint by providing its name or Amazon Resource Name (ARN).
8652 8653 8654 8655 8656 8657 8658 8659 8660 8661 8662 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 8652 class CreateAIBenchmarkJobRequest < Struct.new( :ai_benchmark_job_name, :benchmark_target, :output_config, :ai_workload_config_identifier, :role_arn, :network_config, :tags) SENSITIVE = [] include Aws::Structure end |
#network_config ⇒ Types::AIBenchmarkNetworkConfig
The network configuration for the benchmark job, including VPC settings.
8652 8653 8654 8655 8656 8657 8658 8659 8660 8661 8662 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 8652 class CreateAIBenchmarkJobRequest < Struct.new( :ai_benchmark_job_name, :benchmark_target, :output_config, :ai_workload_config_identifier, :role_arn, :network_config, :tags) SENSITIVE = [] include Aws::Structure end |
#output_config ⇒ Types::AIBenchmarkOutputConfig
The output configuration for the benchmark job, including the Amazon S3 location where benchmark results are stored.
8652 8653 8654 8655 8656 8657 8658 8659 8660 8661 8662 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 8652 class CreateAIBenchmarkJobRequest < Struct.new( :ai_benchmark_job_name, :benchmark_target, :output_config, :ai_workload_config_identifier, :role_arn, :network_config, :tags) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that enables Amazon SageMaker AI to perform tasks on your behalf.
8652 8653 8654 8655 8656 8657 8658 8659 8660 8661 8662 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 8652 class CreateAIBenchmarkJobRequest < Struct.new( :ai_benchmark_job_name, :benchmark_target, :output_config, :ai_workload_config_identifier, :role_arn, :network_config, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The metadata that you apply to Amazon Web Services resources to help you categorize and organize them. Each tag consists of a key and a value, both of which you define.
8652 8653 8654 8655 8656 8657 8658 8659 8660 8661 8662 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 8652 class CreateAIBenchmarkJobRequest < Struct.new( :ai_benchmark_job_name, :benchmark_target, :output_config, :ai_workload_config_identifier, :role_arn, :network_config, :tags) SENSITIVE = [] include Aws::Structure end |