Class: Aws::SageMaker::Types::CreateAIBenchmarkJobRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ai_benchmark_job_nameString

The name of the AI benchmark job. The name must be unique within your Amazon Web Services account in the current Amazon Web Services Region.

Returns:

  • (String)


8535
8536
8537
8538
8539
8540
8541
8542
8543
8544
8545
# File 'lib/aws-sdk-sagemaker/types.rb', line 8535

class CreateAIBenchmarkJobRequest < Struct.new(
  :ai_benchmark_job_name,
  :benchmark_target,
  :output_config,
  :ai_workload_config_identifier,
  :role_arn,
  :network_config,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#ai_workload_config_identifierString

The name or Amazon Resource Name (ARN) of the AI workload configuration to use for this benchmark job.

Returns:

  • (String)


8535
8536
8537
8538
8539
8540
8541
8542
8543
8544
8545
# File 'lib/aws-sdk-sagemaker/types.rb', line 8535

class CreateAIBenchmarkJobRequest < Struct.new(
  :ai_benchmark_job_name,
  :benchmark_target,
  :output_config,
  :ai_workload_config_identifier,
  :role_arn,
  :network_config,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#benchmark_targetTypes::AIBenchmarkTarget

The target endpoint to benchmark. Specify a SageMaker endpoint by providing its name or Amazon Resource Name (ARN).



8535
8536
8537
8538
8539
8540
8541
8542
8543
8544
8545
# File 'lib/aws-sdk-sagemaker/types.rb', line 8535

class CreateAIBenchmarkJobRequest < Struct.new(
  :ai_benchmark_job_name,
  :benchmark_target,
  :output_config,
  :ai_workload_config_identifier,
  :role_arn,
  :network_config,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#network_configTypes::AIBenchmarkNetworkConfig

The network configuration for the benchmark job, including VPC settings.



8535
8536
8537
8538
8539
8540
8541
8542
8543
8544
8545
# File 'lib/aws-sdk-sagemaker/types.rb', line 8535

class CreateAIBenchmarkJobRequest < Struct.new(
  :ai_benchmark_job_name,
  :benchmark_target,
  :output_config,
  :ai_workload_config_identifier,
  :role_arn,
  :network_config,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#output_configTypes::AIBenchmarkOutputConfig

The output configuration for the benchmark job, including the Amazon S3 location where benchmark results are stored.



8535
8536
8537
8538
8539
8540
8541
8542
8543
8544
8545
# File 'lib/aws-sdk-sagemaker/types.rb', line 8535

class CreateAIBenchmarkJobRequest < Struct.new(
  :ai_benchmark_job_name,
  :benchmark_target,
  :output_config,
  :ai_workload_config_identifier,
  :role_arn,
  :network_config,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of an IAM role that enables Amazon SageMaker AI to perform tasks on your behalf.

Returns:

  • (String)


8535
8536
8537
8538
8539
8540
8541
8542
8543
8544
8545
# File 'lib/aws-sdk-sagemaker/types.rb', line 8535

class CreateAIBenchmarkJobRequest < Struct.new(
  :ai_benchmark_job_name,
  :benchmark_target,
  :output_config,
  :ai_workload_config_identifier,
  :role_arn,
  :network_config,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The metadata that you apply to Amazon Web Services resources to help you categorize and organize them. Each tag consists of a key and a value, both of which you define.

Returns:



8535
8536
8537
8538
8539
8540
8541
8542
8543
8544
8545
# File 'lib/aws-sdk-sagemaker/types.rb', line 8535

class CreateAIBenchmarkJobRequest < Struct.new(
  :ai_benchmark_job_name,
  :benchmark_target,
  :output_config,
  :ai_workload_config_identifier,
  :role_arn,
  :network_config,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end