Class: Aws::SageMaker::Types::CreateAIRecommendationJobRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ai_recommendation_job_nameString

The name of the AI recommendation job. The name must be unique within your Amazon Web Services account in the current Amazon Web Services Region.

Returns:

  • (String)


8615
8616
8617
8618
8619
8620
8621
8622
8623
8624
8625
8626
8627
8628
# File 'lib/aws-sdk-sagemaker/types.rb', line 8615

class CreateAIRecommendationJobRequest < Struct.new(
  :ai_recommendation_job_name,
  :model_source,
  :output_config,
  :ai_workload_config_identifier,
  :performance_target,
  :role_arn,
  :inference_specification,
  :optimize_model,
  :compute_spec,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#ai_workload_config_identifierString

The name or Amazon Resource Name (ARN) of the AI workload configuration to use for this recommendation job.

Returns:

  • (String)


8615
8616
8617
8618
8619
8620
8621
8622
8623
8624
8625
8626
8627
8628
# File 'lib/aws-sdk-sagemaker/types.rb', line 8615

class CreateAIRecommendationJobRequest < Struct.new(
  :ai_recommendation_job_name,
  :model_source,
  :output_config,
  :ai_workload_config_identifier,
  :performance_target,
  :role_arn,
  :inference_specification,
  :optimize_model,
  :compute_spec,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#compute_specTypes::AIRecommendationComputeSpec

The compute resource specification for the recommendation job. You can specify up to 3 instance types to consider, and optionally provide capacity reservation configuration.



8615
8616
8617
8618
8619
8620
8621
8622
8623
8624
8625
8626
8627
8628
# File 'lib/aws-sdk-sagemaker/types.rb', line 8615

class CreateAIRecommendationJobRequest < Struct.new(
  :ai_recommendation_job_name,
  :model_source,
  :output_config,
  :ai_workload_config_identifier,
  :performance_target,
  :role_arn,
  :inference_specification,
  :optimize_model,
  :compute_spec,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#inference_specificationTypes::AIRecommendationInferenceSpecification

The inference framework configuration. Specify the framework (such as LMI or vLLM) for the recommendation job.



8615
8616
8617
8618
8619
8620
8621
8622
8623
8624
8625
8626
8627
8628
# File 'lib/aws-sdk-sagemaker/types.rb', line 8615

class CreateAIRecommendationJobRequest < Struct.new(
  :ai_recommendation_job_name,
  :model_source,
  :output_config,
  :ai_workload_config_identifier,
  :performance_target,
  :role_arn,
  :inference_specification,
  :optimize_model,
  :compute_spec,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#model_sourceTypes::AIModelSource

The source of the model to optimize. Specify the Amazon S3 location of the model artifacts.



8615
8616
8617
8618
8619
8620
8621
8622
8623
8624
8625
8626
8627
8628
# File 'lib/aws-sdk-sagemaker/types.rb', line 8615

class CreateAIRecommendationJobRequest < Struct.new(
  :ai_recommendation_job_name,
  :model_source,
  :output_config,
  :ai_workload_config_identifier,
  :performance_target,
  :role_arn,
  :inference_specification,
  :optimize_model,
  :compute_spec,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#optimize_modelBoolean

Whether to allow model optimization techniques such as quantization, speculative decoding, and kernel tuning. The default is ‘true`.

Returns:

  • (Boolean)


8615
8616
8617
8618
8619
8620
8621
8622
8623
8624
8625
8626
8627
8628
# File 'lib/aws-sdk-sagemaker/types.rb', line 8615

class CreateAIRecommendationJobRequest < Struct.new(
  :ai_recommendation_job_name,
  :model_source,
  :output_config,
  :ai_workload_config_identifier,
  :performance_target,
  :role_arn,
  :inference_specification,
  :optimize_model,
  :compute_spec,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#output_configTypes::AIRecommendationOutputConfig

The output configuration for the recommendation job, including the Amazon S3 location for results and an optional model package group where the optimized model is registered.



8615
8616
8617
8618
8619
8620
8621
8622
8623
8624
8625
8626
8627
8628
# File 'lib/aws-sdk-sagemaker/types.rb', line 8615

class CreateAIRecommendationJobRequest < Struct.new(
  :ai_recommendation_job_name,
  :model_source,
  :output_config,
  :ai_workload_config_identifier,
  :performance_target,
  :role_arn,
  :inference_specification,
  :optimize_model,
  :compute_spec,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#performance_targetTypes::AIRecommendationPerformanceTarget

The performance targets for the recommendation job. Specify constraints on metrics such as time to first token (‘ttft-ms`), `throughput`, or `cost`.



8615
8616
8617
8618
8619
8620
8621
8622
8623
8624
8625
8626
8627
8628
# File 'lib/aws-sdk-sagemaker/types.rb', line 8615

class CreateAIRecommendationJobRequest < Struct.new(
  :ai_recommendation_job_name,
  :model_source,
  :output_config,
  :ai_workload_config_identifier,
  :performance_target,
  :role_arn,
  :inference_specification,
  :optimize_model,
  :compute_spec,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of an IAM role that enables Amazon SageMaker AI to perform tasks on your behalf.

Returns:

  • (String)


8615
8616
8617
8618
8619
8620
8621
8622
8623
8624
8625
8626
8627
8628
# File 'lib/aws-sdk-sagemaker/types.rb', line 8615

class CreateAIRecommendationJobRequest < Struct.new(
  :ai_recommendation_job_name,
  :model_source,
  :output_config,
  :ai_workload_config_identifier,
  :performance_target,
  :role_arn,
  :inference_specification,
  :optimize_model,
  :compute_spec,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The metadata that you apply to Amazon Web Services resources to help you categorize and organize them.

Returns:



8615
8616
8617
8618
8619
8620
8621
8622
8623
8624
8625
8626
8627
8628
# File 'lib/aws-sdk-sagemaker/types.rb', line 8615

class CreateAIRecommendationJobRequest < Struct.new(
  :ai_recommendation_job_name,
  :model_source,
  :output_config,
  :ai_workload_config_identifier,
  :performance_target,
  :role_arn,
  :inference_specification,
  :optimize_model,
  :compute_spec,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end