Class: Aws::SageMaker::Types::CreateAIRecommendationJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreateAIRecommendationJobRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ai_recommendation_job_name ⇒ String
The name of the AI recommendation job.
-
#ai_workload_config_identifier ⇒ String
The name or Amazon Resource Name (ARN) of the AI workload configuration to use for this recommendation job.
-
#compute_spec ⇒ Types::AIRecommendationComputeSpec
The compute resource specification for the recommendation job.
-
#inference_specification ⇒ Types::AIRecommendationInferenceSpecification
The inference framework configuration.
-
#model_source ⇒ Types::AIModelSource
The source of the model to optimize.
-
#optimize_model ⇒ Boolean
Whether to allow model optimization techniques such as quantization, speculative decoding, and kernel tuning.
-
#output_config ⇒ Types::AIRecommendationOutputConfig
The output configuration for the recommendation job, including the Amazon S3 location for results and an optional model package group where the optimized model is registered.
-
#performance_target ⇒ Types::AIRecommendationPerformanceTarget
The performance targets for the recommendation job.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that enables Amazon SageMaker AI to perform tasks on your behalf.
-
#tags ⇒ Array<Types::Tag>
The metadata that you apply to Amazon Web Services resources to help you categorize and organize them.
Instance Attribute Details
#ai_recommendation_job_name ⇒ String
The name of the AI recommendation job. The name must be unique within your Amazon Web Services account in the current Amazon Web Services Region.
8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 8626 8627 8628 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 8615 class CreateAIRecommendationJobRequest < Struct.new( :ai_recommendation_job_name, :model_source, :output_config, :ai_workload_config_identifier, :performance_target, :role_arn, :inference_specification, :optimize_model, :compute_spec, :tags) SENSITIVE = [] include Aws::Structure end |
#ai_workload_config_identifier ⇒ String
The name or Amazon Resource Name (ARN) of the AI workload configuration to use for this recommendation job.
8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 8626 8627 8628 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 8615 class CreateAIRecommendationJobRequest < Struct.new( :ai_recommendation_job_name, :model_source, :output_config, :ai_workload_config_identifier, :performance_target, :role_arn, :inference_specification, :optimize_model, :compute_spec, :tags) SENSITIVE = [] include Aws::Structure end |
#compute_spec ⇒ Types::AIRecommendationComputeSpec
The compute resource specification for the recommendation job. You can specify up to 3 instance types to consider, and optionally provide capacity reservation configuration.
8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 8626 8627 8628 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 8615 class CreateAIRecommendationJobRequest < Struct.new( :ai_recommendation_job_name, :model_source, :output_config, :ai_workload_config_identifier, :performance_target, :role_arn, :inference_specification, :optimize_model, :compute_spec, :tags) SENSITIVE = [] include Aws::Structure end |
#inference_specification ⇒ Types::AIRecommendationInferenceSpecification
The inference framework configuration. Specify the framework (such as LMI or vLLM) for the recommendation job.
8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 8626 8627 8628 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 8615 class CreateAIRecommendationJobRequest < Struct.new( :ai_recommendation_job_name, :model_source, :output_config, :ai_workload_config_identifier, :performance_target, :role_arn, :inference_specification, :optimize_model, :compute_spec, :tags) SENSITIVE = [] include Aws::Structure end |
#model_source ⇒ Types::AIModelSource
The source of the model to optimize. Specify the Amazon S3 location of the model artifacts.
8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 8626 8627 8628 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 8615 class CreateAIRecommendationJobRequest < Struct.new( :ai_recommendation_job_name, :model_source, :output_config, :ai_workload_config_identifier, :performance_target, :role_arn, :inference_specification, :optimize_model, :compute_spec, :tags) SENSITIVE = [] include Aws::Structure end |
#optimize_model ⇒ Boolean
Whether to allow model optimization techniques such as quantization, speculative decoding, and kernel tuning. The default is ‘true`.
8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 8626 8627 8628 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 8615 class CreateAIRecommendationJobRequest < Struct.new( :ai_recommendation_job_name, :model_source, :output_config, :ai_workload_config_identifier, :performance_target, :role_arn, :inference_specification, :optimize_model, :compute_spec, :tags) SENSITIVE = [] include Aws::Structure end |
#output_config ⇒ Types::AIRecommendationOutputConfig
The output configuration for the recommendation job, including the Amazon S3 location for results and an optional model package group where the optimized model is registered.
8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 8626 8627 8628 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 8615 class CreateAIRecommendationJobRequest < Struct.new( :ai_recommendation_job_name, :model_source, :output_config, :ai_workload_config_identifier, :performance_target, :role_arn, :inference_specification, :optimize_model, :compute_spec, :tags) SENSITIVE = [] include Aws::Structure end |
#performance_target ⇒ Types::AIRecommendationPerformanceTarget
The performance targets for the recommendation job. Specify constraints on metrics such as time to first token (‘ttft-ms`), `throughput`, or `cost`.
8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 8626 8627 8628 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 8615 class CreateAIRecommendationJobRequest < Struct.new( :ai_recommendation_job_name, :model_source, :output_config, :ai_workload_config_identifier, :performance_target, :role_arn, :inference_specification, :optimize_model, :compute_spec, :tags) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that enables Amazon SageMaker AI to perform tasks on your behalf.
8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 8626 8627 8628 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 8615 class CreateAIRecommendationJobRequest < Struct.new( :ai_recommendation_job_name, :model_source, :output_config, :ai_workload_config_identifier, :performance_target, :role_arn, :inference_specification, :optimize_model, :compute_spec, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The metadata that you apply to Amazon Web Services resources to help you categorize and organize them.
8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 8626 8627 8628 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 8615 class CreateAIRecommendationJobRequest < Struct.new( :ai_recommendation_job_name, :model_source, :output_config, :ai_workload_config_identifier, :performance_target, :role_arn, :inference_specification, :optimize_model, :compute_spec, :tags) SENSITIVE = [] include Aws::Structure end |