Class: Aws::SageMaker::Types::CreateAIWorkloadConfigRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreateAIWorkloadConfigRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ai_workload_config_name ⇒ String
The name of the AI workload configuration.
-
#ai_workload_configs ⇒ Types::AIWorkloadConfigs
The benchmark tool configuration and workload specification.
-
#dataset_config ⇒ Types::AIDatasetConfig
The dataset configuration for the workload.
-
#tags ⇒ Array<Types::Tag>
The metadata that you apply to Amazon Web Services resources to help you categorize and organize them.
Instance Attribute Details
#ai_workload_config_name ⇒ String
The name of the AI workload configuration. The name must be unique within your Amazon Web Services account in the current Amazon Web Services Region.
9020 9021 9022 9023 9024 9025 9026 9027 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9020 class CreateAIWorkloadConfigRequest < Struct.new( :ai_workload_config_name, :dataset_config, :ai_workload_configs, :tags) SENSITIVE = [] include Aws::Structure end |
#ai_workload_configs ⇒ Types::AIWorkloadConfigs
The benchmark tool configuration and workload specification. Provide the specification as an inline YAML or JSON string.
9020 9021 9022 9023 9024 9025 9026 9027 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9020 class CreateAIWorkloadConfigRequest < Struct.new( :ai_workload_config_name, :dataset_config, :ai_workload_configs, :tags) SENSITIVE = [] include Aws::Structure end |
#dataset_config ⇒ Types::AIDatasetConfig
The dataset configuration for the workload. Specify input data channels with their data sources for benchmark workloads.
9020 9021 9022 9023 9024 9025 9026 9027 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9020 class CreateAIWorkloadConfigRequest < Struct.new( :ai_workload_config_name, :dataset_config, :ai_workload_configs, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The metadata that you apply to Amazon Web Services resources to help you categorize and organize them. Each tag consists of a key and a value, both of which you define. For more information, see [Tagging Amazon Web Services Resources] in the Amazon Web Services General Reference.
9020 9021 9022 9023 9024 9025 9026 9027 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9020 class CreateAIWorkloadConfigRequest < Struct.new( :ai_workload_config_name, :dataset_config, :ai_workload_configs, :tags) SENSITIVE = [] include Aws::Structure end |