Class: Aws::SageMaker::Types::CreateAIWorkloadConfigRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ai_workload_config_nameString

The name of the AI workload configuration. The name must be unique within your Amazon Web Services account in the current Amazon Web Services Region.

Returns:

  • (String)


8672
8673
8674
8675
8676
8677
8678
8679
# File 'lib/aws-sdk-sagemaker/types.rb', line 8672

class CreateAIWorkloadConfigRequest < Struct.new(
  :ai_workload_config_name,
  :dataset_config,
  :ai_workload_configs,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#ai_workload_configsTypes::AIWorkloadConfigs

The benchmark tool configuration and workload specification. Provide the specification as an inline YAML or JSON string.



8672
8673
8674
8675
8676
8677
8678
8679
# File 'lib/aws-sdk-sagemaker/types.rb', line 8672

class CreateAIWorkloadConfigRequest < Struct.new(
  :ai_workload_config_name,
  :dataset_config,
  :ai_workload_configs,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#dataset_configTypes::AIDatasetConfig

The dataset configuration for the workload. Specify input data channels with their data sources for benchmark workloads.



8672
8673
8674
8675
8676
8677
8678
8679
# File 'lib/aws-sdk-sagemaker/types.rb', line 8672

class CreateAIWorkloadConfigRequest < Struct.new(
  :ai_workload_config_name,
  :dataset_config,
  :ai_workload_configs,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The metadata that you apply to Amazon Web Services resources to help you categorize and organize them. Each tag consists of a key and a value, both of which you define. For more information, see [Tagging Amazon Web Services Resources] in the Amazon Web Services General Reference.

[1]: docs.aws.amazon.com/general/latest/gr/aws_tagging.html

Returns:



8672
8673
8674
8675
8676
8677
8678
8679
# File 'lib/aws-sdk-sagemaker/types.rb', line 8672

class CreateAIWorkloadConfigRequest < Struct.new(
  :ai_workload_config_name,
  :dataset_config,
  :ai_workload_configs,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end