Class: Aws::SageMaker::Types::CreateAppImageConfigRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#app_image_config_nameString

The name of the AppImageConfig. Must be unique to your account.

Returns:

  • (String)


8880
8881
8882
8883
8884
8885
8886
8887
8888
# File 'lib/aws-sdk-sagemaker/types.rb', line 8880

class CreateAppImageConfigRequest < Struct.new(
  :app_image_config_name,
  :tags,
  :kernel_gateway_image_config,
  :jupyter_lab_app_image_config,
  :code_editor_app_image_config)
  SENSITIVE = []
  include Aws::Structure
end

#code_editor_app_image_configTypes::CodeEditorAppImageConfig

The ‘CodeEditorAppImageConfig`. You can only specify one image kernel in the AppImageConfig API. This kernel is shown to users before the image starts. After the image runs, all kernels are visible in Code Editor.



8880
8881
8882
8883
8884
8885
8886
8887
8888
# File 'lib/aws-sdk-sagemaker/types.rb', line 8880

class CreateAppImageConfigRequest < Struct.new(
  :app_image_config_name,
  :tags,
  :kernel_gateway_image_config,
  :jupyter_lab_app_image_config,
  :code_editor_app_image_config)
  SENSITIVE = []
  include Aws::Structure
end

#jupyter_lab_app_image_configTypes::JupyterLabAppImageConfig

The ‘JupyterLabAppImageConfig`. You can only specify one image kernel in the `AppImageConfig` API. This kernel is shown to users before the image starts. After the image runs, all kernels are visible in JupyterLab.



8880
8881
8882
8883
8884
8885
8886
8887
8888
# File 'lib/aws-sdk-sagemaker/types.rb', line 8880

class CreateAppImageConfigRequest < Struct.new(
  :app_image_config_name,
  :tags,
  :kernel_gateway_image_config,
  :jupyter_lab_app_image_config,
  :code_editor_app_image_config)
  SENSITIVE = []
  include Aws::Structure
end

#kernel_gateway_image_configTypes::KernelGatewayImageConfig

The KernelGatewayImageConfig. You can only specify one image kernel in the AppImageConfig API. This kernel will be shown to users before the image starts. Once the image runs, all kernels are visible in JupyterLab.



8880
8881
8882
8883
8884
8885
8886
8887
8888
# File 'lib/aws-sdk-sagemaker/types.rb', line 8880

class CreateAppImageConfigRequest < Struct.new(
  :app_image_config_name,
  :tags,
  :kernel_gateway_image_config,
  :jupyter_lab_app_image_config,
  :code_editor_app_image_config)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

A list of tags to apply to the AppImageConfig.

Returns:



8880
8881
8882
8883
8884
8885
8886
8887
8888
# File 'lib/aws-sdk-sagemaker/types.rb', line 8880

class CreateAppImageConfigRequest < Struct.new(
  :app_image_config_name,
  :tags,
  :kernel_gateway_image_config,
  :jupyter_lab_app_image_config,
  :code_editor_app_image_config)
  SENSITIVE = []
  include Aws::Structure
end