Class: Aws::SageMaker::Types::CreateAppImageConfigRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#app_image_config_nameString

The name of the AppImageConfig. Must be unique to your account.

Returns:



4135
4136
4137
4138
4139
4140
4141
# File 'lib/aws-sdk-sagemaker/types.rb', line 4135

class CreateAppImageConfigRequest < Struct.new(
  :app_image_config_name,
  :tags,
  :kernel_gateway_image_config)
  SENSITIVE = []
  include Aws::Structure
end

#kernel_gateway_image_configTypes::KernelGatewayImageConfig

The KernelGatewayImageConfig. You can only specify one image kernel in the AppImageConfig API. This kernel will be shown to users before the image starts. Once the image runs, all kernels are visible in JupyterLab.

Returns:



4135
4136
4137
4138
4139
4140
4141
# File 'lib/aws-sdk-sagemaker/types.rb', line 4135

class CreateAppImageConfigRequest < Struct.new(
  :app_image_config_name,
  :tags,
  :kernel_gateway_image_config)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

A list of tags to apply to the AppImageConfig.

Returns:



4135
4136
4137
4138
4139
4140
4141
# File 'lib/aws-sdk-sagemaker/types.rb', line 4135

class CreateAppImageConfigRequest < Struct.new(
  :app_image_config_name,
  :tags,
  :kernel_gateway_image_config)
  SENSITIVE = []
  include Aws::Structure
end