Class: Aws::SageMaker::Types::CreateAppImageConfigRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreateAppImageConfigRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#app_image_config_name ⇒ String
The name of the AppImageConfig.
-
#kernel_gateway_image_config ⇒ Types::KernelGatewayImageConfig
The KernelGatewayImageConfig.
-
#tags ⇒ Array<Types::Tag>
A list of tags to apply to the AppImageConfig.
Instance Attribute Details
#app_image_config_name ⇒ String
The name of the AppImageConfig. Must be unique to your account.
4135 4136 4137 4138 4139 4140 4141 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 4135 class CreateAppImageConfigRequest < Struct.new( :app_image_config_name, :tags, :kernel_gateway_image_config) SENSITIVE = [] include Aws::Structure end |
#kernel_gateway_image_config ⇒ Types::KernelGatewayImageConfig
The KernelGatewayImageConfig. You can only specify one image kernel in the AppImageConfig API. This kernel will be shown to users before the image starts. Once the image runs, all kernels are visible in JupyterLab.
4135 4136 4137 4138 4139 4140 4141 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 4135 class CreateAppImageConfigRequest < Struct.new( :app_image_config_name, :tags, :kernel_gateway_image_config) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of tags to apply to the AppImageConfig.
4135 4136 4137 4138 4139 4140 4141 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 4135 class CreateAppImageConfigRequest < Struct.new( :app_image_config_name, :tags, :kernel_gateway_image_config) SENSITIVE = [] include Aws::Structure end |