Class: Aws::SageMaker::Types::CreateAppRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#app_nameString

The name of the app.

Returns:

  • (String)


5808
5809
5810
5811
5812
5813
5814
5815
5816
5817
5818
# File 'lib/aws-sdk-sagemaker/types.rb', line 5808

class CreateAppRequest < Struct.new(
  :domain_id,
  :user_profile_name,
  :space_name,
  :app_type,
  :app_name,
  :tags,
  :resource_spec)
  SENSITIVE = []
  include Aws::Structure
end

#app_typeString

The type of app.

Returns:

  • (String)


5808
5809
5810
5811
5812
5813
5814
5815
5816
5817
5818
# File 'lib/aws-sdk-sagemaker/types.rb', line 5808

class CreateAppRequest < Struct.new(
  :domain_id,
  :user_profile_name,
  :space_name,
  :app_type,
  :app_name,
  :tags,
  :resource_spec)
  SENSITIVE = []
  include Aws::Structure
end

#domain_idString

The domain ID.

Returns:

  • (String)


5808
5809
5810
5811
5812
5813
5814
5815
5816
5817
5818
# File 'lib/aws-sdk-sagemaker/types.rb', line 5808

class CreateAppRequest < Struct.new(
  :domain_id,
  :user_profile_name,
  :space_name,
  :app_type,
  :app_name,
  :tags,
  :resource_spec)
  SENSITIVE = []
  include Aws::Structure
end

#resource_specTypes::ResourceSpec

The instance type and the Amazon Resource Name (ARN) of the SageMaker AI image created on the instance.

<note markdown=“1”> The value of InstanceType passed as part of the ResourceSpec in the CreateApp call overrides the value passed as part of the ResourceSpec configured for the user profile or the domain. If InstanceType is not specified in any of those three ResourceSpec values for a KernelGateway app, the CreateApp call fails with a request validation error.

</note>

Returns:



5808
5809
5810
5811
5812
5813
5814
5815
5816
5817
5818
# File 'lib/aws-sdk-sagemaker/types.rb', line 5808

class CreateAppRequest < Struct.new(
  :domain_id,
  :user_profile_name,
  :space_name,
  :app_type,
  :app_name,
  :tags,
  :resource_spec)
  SENSITIVE = []
  include Aws::Structure
end

#space_nameString

The name of the space. If this value is not set, then UserProfileName must be set.

Returns:

  • (String)


5808
5809
5810
5811
5812
5813
5814
5815
5816
5817
5818
# File 'lib/aws-sdk-sagemaker/types.rb', line 5808

class CreateAppRequest < Struct.new(
  :domain_id,
  :user_profile_name,
  :space_name,
  :app_type,
  :app_name,
  :tags,
  :resource_spec)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Each tag consists of a key and an optional value. Tag keys must be unique per resource.

Returns:



5808
5809
5810
5811
5812
5813
5814
5815
5816
5817
5818
# File 'lib/aws-sdk-sagemaker/types.rb', line 5808

class CreateAppRequest < Struct.new(
  :domain_id,
  :user_profile_name,
  :space_name,
  :app_type,
  :app_name,
  :tags,
  :resource_spec)
  SENSITIVE = []
  include Aws::Structure
end

#user_profile_nameString

The user profile name. If this value is not set, then SpaceName must be set.

Returns:

  • (String)


5808
5809
5810
5811
5812
5813
5814
5815
5816
5817
5818
# File 'lib/aws-sdk-sagemaker/types.rb', line 5808

class CreateAppRequest < Struct.new(
  :domain_id,
  :user_profile_name,
  :space_name,
  :app_type,
  :app_name,
  :tags,
  :resource_spec)
  SENSITIVE = []
  include Aws::Structure
end