Class: Aws::SageMaker::Types::CreateAppRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#app_nameString

The name of the app.

Returns:



4198
4199
4200
4201
4202
4203
4204
4205
4206
4207
4208
# File 'lib/aws-sdk-sagemaker/types.rb', line 4198

class CreateAppRequest < Struct.new(
  :domain_id,
  :user_profile_name,
  :app_type,
  :app_name,
  :tags,
  :resource_spec,
  :space_name)
  SENSITIVE = []
  include Aws::Structure
end

#app_typeString

The type of app.

Returns:



4198
4199
4200
4201
4202
4203
4204
4205
4206
4207
4208
# File 'lib/aws-sdk-sagemaker/types.rb', line 4198

class CreateAppRequest < Struct.new(
  :domain_id,
  :user_profile_name,
  :app_type,
  :app_name,
  :tags,
  :resource_spec,
  :space_name)
  SENSITIVE = []
  include Aws::Structure
end

#domain_idString

The domain ID.

Returns:



4198
4199
4200
4201
4202
4203
4204
4205
4206
4207
4208
# File 'lib/aws-sdk-sagemaker/types.rb', line 4198

class CreateAppRequest < Struct.new(
  :domain_id,
  :user_profile_name,
  :app_type,
  :app_name,
  :tags,
  :resource_spec,
  :space_name)
  SENSITIVE = []
  include Aws::Structure
end

#resource_specTypes::ResourceSpec

The instance type and the Amazon Resource Name (ARN) of the SageMaker image created on the instance.

<note markdown=“1”> The value of InstanceType passed as part of the ResourceSpec in the CreateApp call overrides the value passed as part of the ResourceSpec configured for the user profile or the domain. If InstanceType is not specified in any of those three ResourceSpec values for a KernelGateway app, the CreateApp call fails with a request validation error.

</note>

Returns:



4198
4199
4200
4201
4202
4203
4204
4205
4206
4207
4208
# File 'lib/aws-sdk-sagemaker/types.rb', line 4198

class CreateAppRequest < Struct.new(
  :domain_id,
  :user_profile_name,
  :app_type,
  :app_name,
  :tags,
  :resource_spec,
  :space_name)
  SENSITIVE = []
  include Aws::Structure
end

#space_nameString

The name of the space. If this value is not set, then UserProfileName must be set.

Returns:



4198
4199
4200
4201
4202
4203
4204
4205
4206
4207
4208
# File 'lib/aws-sdk-sagemaker/types.rb', line 4198

class CreateAppRequest < Struct.new(
  :domain_id,
  :user_profile_name,
  :app_type,
  :app_name,
  :tags,
  :resource_spec,
  :space_name)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Each tag consists of a key and an optional value. Tag keys must be unique per resource.

Returns:



4198
4199
4200
4201
4202
4203
4204
4205
4206
4207
4208
# File 'lib/aws-sdk-sagemaker/types.rb', line 4198

class CreateAppRequest < Struct.new(
  :domain_id,
  :user_profile_name,
  :app_type,
  :app_name,
  :tags,
  :resource_spec,
  :space_name)
  SENSITIVE = []
  include Aws::Structure
end

#user_profile_nameString

The user profile name. If this value is not set, then SpaceName must be set.

Returns:



4198
4199
4200
4201
4202
4203
4204
4205
4206
4207
4208
# File 'lib/aws-sdk-sagemaker/types.rb', line 4198

class CreateAppRequest < Struct.new(
  :domain_id,
  :user_profile_name,
  :app_type,
  :app_name,
  :tags,
  :resource_spec,
  :space_name)
  SENSITIVE = []
  include Aws::Structure
end