Class: Aws::SageMaker::Types::CreateAutoMLJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreateAutoMLJobRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_ml_job_config ⇒ Types::AutoMLJobConfig
A collection of settings used to configure an AutoML job.
-
#auto_ml_job_name ⇒ String
Identifies an Autopilot job.
-
#auto_ml_job_objective ⇒ Types::AutoMLJobObjective
Specifies a metric to minimize or maximize as the objective of a job.
-
#generate_candidate_definitions_only ⇒ Boolean
Generates possible candidates without training the models.
-
#input_data_config ⇒ Array<Types::AutoMLChannel>
An array of channel objects that describes the input data and its location.
-
#model_deploy_config ⇒ Types::ModelDeployConfig
Specifies how to generate the endpoint name for an automatic one-click Autopilot model deployment.
-
#output_data_config ⇒ Types::AutoMLOutputDataConfig
Provides information about encryption and the Amazon S3 output path needed to store artifacts from an AutoML job.
-
#problem_type ⇒ String
Defines the type of supervised learning problem available for the candidates.
-
#role_arn ⇒ String
The ARN of the role that is used to access the data.
-
#tags ⇒ Array<Types::Tag>
An array of key-value pairs.
Instance Attribute Details
#auto_ml_job_config ⇒ Types::AutoMLJobConfig
A collection of settings used to configure an AutoML job.
9132 9133 9134 9135 9136 9137 9138 9139 9140 9141 9142 9143 9144 9145 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9132 class CreateAutoMLJobRequest < Struct.new( :auto_ml_job_name, :input_data_config, :output_data_config, :problem_type, :auto_ml_job_objective, :auto_ml_job_config, :role_arn, :generate_candidate_definitions_only, :tags, :model_deploy_config) SENSITIVE = [] include Aws::Structure end |
#auto_ml_job_name ⇒ String
Identifies an Autopilot job. The name must be unique to your account and is case insensitive.
9132 9133 9134 9135 9136 9137 9138 9139 9140 9141 9142 9143 9144 9145 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9132 class CreateAutoMLJobRequest < Struct.new( :auto_ml_job_name, :input_data_config, :output_data_config, :problem_type, :auto_ml_job_objective, :auto_ml_job_config, :role_arn, :generate_candidate_definitions_only, :tags, :model_deploy_config) SENSITIVE = [] include Aws::Structure end |
#auto_ml_job_objective ⇒ Types::AutoMLJobObjective
Specifies a metric to minimize or maximize as the objective of a job. If not specified, the default objective metric depends on the problem type. See [AutoMLJobObjective] for the default values.
[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_AutoMLJobObjective.html
9132 9133 9134 9135 9136 9137 9138 9139 9140 9141 9142 9143 9144 9145 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9132 class CreateAutoMLJobRequest < Struct.new( :auto_ml_job_name, :input_data_config, :output_data_config, :problem_type, :auto_ml_job_objective, :auto_ml_job_config, :role_arn, :generate_candidate_definitions_only, :tags, :model_deploy_config) SENSITIVE = [] include Aws::Structure end |
#generate_candidate_definitions_only ⇒ Boolean
Generates possible candidates without training the models. A candidate is a combination of data preprocessors, algorithms, and algorithm parameter settings.
9132 9133 9134 9135 9136 9137 9138 9139 9140 9141 9142 9143 9144 9145 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9132 class CreateAutoMLJobRequest < Struct.new( :auto_ml_job_name, :input_data_config, :output_data_config, :problem_type, :auto_ml_job_objective, :auto_ml_job_config, :role_arn, :generate_candidate_definitions_only, :tags, :model_deploy_config) SENSITIVE = [] include Aws::Structure end |
#input_data_config ⇒ Array<Types::AutoMLChannel>
An array of channel objects that describes the input data and its location. Each channel is a named input source. Similar to ‘InputDataConfig` supported by [HyperParameterTrainingJobDefinition]. Format(s) supported: CSV, Parquet. A minimum of 500 rows is required for the training dataset. There is not a minimum number of rows required for the validation dataset.
[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_HyperParameterTrainingJobDefinition.html
9132 9133 9134 9135 9136 9137 9138 9139 9140 9141 9142 9143 9144 9145 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9132 class CreateAutoMLJobRequest < Struct.new( :auto_ml_job_name, :input_data_config, :output_data_config, :problem_type, :auto_ml_job_objective, :auto_ml_job_config, :role_arn, :generate_candidate_definitions_only, :tags, :model_deploy_config) SENSITIVE = [] include Aws::Structure end |
#model_deploy_config ⇒ Types::ModelDeployConfig
Specifies how to generate the endpoint name for an automatic one-click Autopilot model deployment.
9132 9133 9134 9135 9136 9137 9138 9139 9140 9141 9142 9143 9144 9145 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9132 class CreateAutoMLJobRequest < Struct.new( :auto_ml_job_name, :input_data_config, :output_data_config, :problem_type, :auto_ml_job_objective, :auto_ml_job_config, :role_arn, :generate_candidate_definitions_only, :tags, :model_deploy_config) SENSITIVE = [] include Aws::Structure end |
#output_data_config ⇒ Types::AutoMLOutputDataConfig
Provides information about encryption and the Amazon S3 output path needed to store artifacts from an AutoML job. Format(s) supported: CSV.
9132 9133 9134 9135 9136 9137 9138 9139 9140 9141 9142 9143 9144 9145 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9132 class CreateAutoMLJobRequest < Struct.new( :auto_ml_job_name, :input_data_config, :output_data_config, :problem_type, :auto_ml_job_objective, :auto_ml_job_config, :role_arn, :generate_candidate_definitions_only, :tags, :model_deploy_config) SENSITIVE = [] include Aws::Structure end |
#problem_type ⇒ String
Defines the type of supervised learning problem available for the candidates. For more information, see [ SageMaker Autopilot problem types].
9132 9133 9134 9135 9136 9137 9138 9139 9140 9141 9142 9143 9144 9145 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9132 class CreateAutoMLJobRequest < Struct.new( :auto_ml_job_name, :input_data_config, :output_data_config, :problem_type, :auto_ml_job_objective, :auto_ml_job_config, :role_arn, :generate_candidate_definitions_only, :tags, :model_deploy_config) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The ARN of the role that is used to access the data.
9132 9133 9134 9135 9136 9137 9138 9139 9140 9141 9142 9143 9144 9145 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9132 class CreateAutoMLJobRequest < Struct.new( :auto_ml_job_name, :input_data_config, :output_data_config, :problem_type, :auto_ml_job_objective, :auto_ml_job_config, :role_arn, :generate_candidate_definitions_only, :tags, :model_deploy_config) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
An array of key-value pairs. You can use tags to categorize your Amazon Web Services resources in different ways, for example, by purpose, owner, or environment. For more information, see [Tagging Amazon Web ServicesResources]. Tag keys must be unique per resource.
9132 9133 9134 9135 9136 9137 9138 9139 9140 9141 9142 9143 9144 9145 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9132 class CreateAutoMLJobRequest < Struct.new( :auto_ml_job_name, :input_data_config, :output_data_config, :problem_type, :auto_ml_job_objective, :auto_ml_job_config, :role_arn, :generate_candidate_definitions_only, :tags, :model_deploy_config) SENSITIVE = [] include Aws::Structure end |