Class: Aws::SageMaker::Types::CreateAutoMLJobRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_ml_job_configTypes::AutoMLJobConfig

A collection of settings used to configure an AutoML job.



4334
4335
4336
4337
4338
4339
4340
4341
4342
4343
4344
4345
4346
4347
# File 'lib/aws-sdk-sagemaker/types.rb', line 4334

class CreateAutoMLJobRequest < Struct.new(
  :auto_ml_job_name,
  :input_data_config,
  :output_data_config,
  :problem_type,
  :auto_ml_job_objective,
  :auto_ml_job_config,
  :role_arn,
  :generate_candidate_definitions_only,
  :tags,
  :model_deploy_config)
  SENSITIVE = []
  include Aws::Structure
end

#auto_ml_job_nameString

Identifies an Autopilot job. The name must be unique to your account and is case-insensitive.

Returns:

  • (String)


4334
4335
4336
4337
4338
4339
4340
4341
4342
4343
4344
4345
4346
4347
# File 'lib/aws-sdk-sagemaker/types.rb', line 4334

class CreateAutoMLJobRequest < Struct.new(
  :auto_ml_job_name,
  :input_data_config,
  :output_data_config,
  :problem_type,
  :auto_ml_job_objective,
  :auto_ml_job_config,
  :role_arn,
  :generate_candidate_definitions_only,
  :tags,
  :model_deploy_config)
  SENSITIVE = []
  include Aws::Structure
end

#auto_ml_job_objectiveTypes::AutoMLJobObjective

Defines the objective metric used to measure the predictive quality of an AutoML job. You provide an AutoMLJobObjective$MetricName and Autopilot infers whether to minimize or maximize it.



4334
4335
4336
4337
4338
4339
4340
4341
4342
4343
4344
4345
4346
4347
# File 'lib/aws-sdk-sagemaker/types.rb', line 4334

class CreateAutoMLJobRequest < Struct.new(
  :auto_ml_job_name,
  :input_data_config,
  :output_data_config,
  :problem_type,
  :auto_ml_job_objective,
  :auto_ml_job_config,
  :role_arn,
  :generate_candidate_definitions_only,
  :tags,
  :model_deploy_config)
  SENSITIVE = []
  include Aws::Structure
end

#generate_candidate_definitions_onlyBoolean

Generates possible candidates without training the models. A candidate is a combination of data preprocessors, algorithms, and algorithm parameter settings.

Returns:

  • (Boolean)


4334
4335
4336
4337
4338
4339
4340
4341
4342
4343
4344
4345
4346
4347
# File 'lib/aws-sdk-sagemaker/types.rb', line 4334

class CreateAutoMLJobRequest < Struct.new(
  :auto_ml_job_name,
  :input_data_config,
  :output_data_config,
  :problem_type,
  :auto_ml_job_objective,
  :auto_ml_job_config,
  :role_arn,
  :generate_candidate_definitions_only,
  :tags,
  :model_deploy_config)
  SENSITIVE = []
  include Aws::Structure
end

#input_data_configArray<Types::AutoMLChannel>

An array of channel objects that describes the input data and its location. Each channel is a named input source. Similar to InputDataConfig supported by . Format(s) supported: CSV, Parquet. A minimum of 500 rows is required for the training dataset. There is not a minimum number of rows required for the validation dataset.

Returns:



4334
4335
4336
4337
4338
4339
4340
4341
4342
4343
4344
4345
4346
4347
# File 'lib/aws-sdk-sagemaker/types.rb', line 4334

class CreateAutoMLJobRequest < Struct.new(
  :auto_ml_job_name,
  :input_data_config,
  :output_data_config,
  :problem_type,
  :auto_ml_job_objective,
  :auto_ml_job_config,
  :role_arn,
  :generate_candidate_definitions_only,
  :tags,
  :model_deploy_config)
  SENSITIVE = []
  include Aws::Structure
end

#model_deploy_configTypes::ModelDeployConfig

Specifies how to generate the endpoint name for an automatic one-click Autopilot model deployment.



4334
4335
4336
4337
4338
4339
4340
4341
4342
4343
4344
4345
4346
4347
# File 'lib/aws-sdk-sagemaker/types.rb', line 4334

class CreateAutoMLJobRequest < Struct.new(
  :auto_ml_job_name,
  :input_data_config,
  :output_data_config,
  :problem_type,
  :auto_ml_job_objective,
  :auto_ml_job_config,
  :role_arn,
  :generate_candidate_definitions_only,
  :tags,
  :model_deploy_config)
  SENSITIVE = []
  include Aws::Structure
end

#output_data_configTypes::AutoMLOutputDataConfig

Provides information about encryption and the Amazon S3 output path needed to store artifacts from an AutoML job. Format(s) supported: CSV.



4334
4335
4336
4337
4338
4339
4340
4341
4342
4343
4344
4345
4346
4347
# File 'lib/aws-sdk-sagemaker/types.rb', line 4334

class CreateAutoMLJobRequest < Struct.new(
  :auto_ml_job_name,
  :input_data_config,
  :output_data_config,
  :problem_type,
  :auto_ml_job_objective,
  :auto_ml_job_config,
  :role_arn,
  :generate_candidate_definitions_only,
  :tags,
  :model_deploy_config)
  SENSITIVE = []
  include Aws::Structure
end

#problem_typeString

Defines the type of supervised learning available for the candidates. For more information, see [ Amazon SageMaker Autopilot problem types and algorithm support].

[1]: docs.aws.amazon.com/sagemaker/latest/dg/autopilot-automate-model-development-problem-types.html

Returns:

  • (String)


4334
4335
4336
4337
4338
4339
4340
4341
4342
4343
4344
4345
4346
4347
# File 'lib/aws-sdk-sagemaker/types.rb', line 4334

class CreateAutoMLJobRequest < Struct.new(
  :auto_ml_job_name,
  :input_data_config,
  :output_data_config,
  :problem_type,
  :auto_ml_job_objective,
  :auto_ml_job_config,
  :role_arn,
  :generate_candidate_definitions_only,
  :tags,
  :model_deploy_config)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The ARN of the role that is used to access the data.

Returns:

  • (String)


4334
4335
4336
4337
4338
4339
4340
4341
4342
4343
4344
4345
4346
4347
# File 'lib/aws-sdk-sagemaker/types.rb', line 4334

class CreateAutoMLJobRequest < Struct.new(
  :auto_ml_job_name,
  :input_data_config,
  :output_data_config,
  :problem_type,
  :auto_ml_job_objective,
  :auto_ml_job_config,
  :role_arn,
  :generate_candidate_definitions_only,
  :tags,
  :model_deploy_config)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Each tag consists of a key and an optional value. Tag keys must be unique per resource.

Returns:



4334
4335
4336
4337
4338
4339
4340
4341
4342
4343
4344
4345
4346
4347
# File 'lib/aws-sdk-sagemaker/types.rb', line 4334

class CreateAutoMLJobRequest < Struct.new(
  :auto_ml_job_name,
  :input_data_config,
  :output_data_config,
  :problem_type,
  :auto_ml_job_objective,
  :auto_ml_job_config,
  :role_arn,
  :generate_candidate_definitions_only,
  :tags,
  :model_deploy_config)
  SENSITIVE = []
  include Aws::Structure
end