Class: Aws::SageMaker::Types::CreateCodeRepositoryInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#code_repository_nameString

The name of the Git repository. The name must have 1 to 63 characters. Valid characters are a-z, A-Z, 0-9, and - (hyphen).

Returns:

  • (String)


9854
9855
9856
9857
9858
9859
9860
# File 'lib/aws-sdk-sagemaker/types.rb', line 9854

class CreateCodeRepositoryInput < Struct.new(
  :code_repository_name,
  :git_config,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#git_configTypes::GitConfig

Specifies details about the repository, including the URL where the repository is located, the default branch, and credentials to use to access the repository.

Returns:



9854
9855
9856
9857
9858
9859
9860
# File 'lib/aws-sdk-sagemaker/types.rb', line 9854

class CreateCodeRepositoryInput < Struct.new(
  :code_repository_name,
  :git_config,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

An array of key-value pairs. You can use tags to categorize your Amazon Web Services resources in different ways, for example, by purpose, owner, or environment. For more information, see Tagging Amazon Web Services Resources.

Returns:



9854
9855
9856
9857
9858
9859
9860
# File 'lib/aws-sdk-sagemaker/types.rb', line 9854

class CreateCodeRepositoryInput < Struct.new(
  :code_repository_name,
  :git_config,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end