Class: Aws::SageMaker::Types::CreateCodeRepositoryInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreateCodeRepositoryInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code_repository_name ⇒ String
The name of the Git repository.
-
#git_config ⇒ Types::GitConfig
Specifies details about the repository, including the URL where the repository is located, the default branch, and credentials to use to access the repository.
-
#tags ⇒ Array<Types::Tag>
An array of key-value pairs.
Instance Attribute Details
#code_repository_name ⇒ String
The name of the Git repository. The name must have 1 to 63 characters. Valid characters are a-z, A-Z, 0-9, and - (hyphen).
8624 8625 8626 8627 8628 8629 8630 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 8624 class CreateCodeRepositoryInput < Struct.new( :code_repository_name, :git_config, :tags) SENSITIVE = [] include Aws::Structure end |
#git_config ⇒ Types::GitConfig
Specifies details about the repository, including the URL where the repository is located, the default branch, and credentials to use to access the repository.
8624 8625 8626 8627 8628 8629 8630 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 8624 class CreateCodeRepositoryInput < Struct.new( :code_repository_name, :git_config, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
An array of key-value pairs. You can use tags to categorize your Amazon Web Services resources in different ways, for example, by purpose, owner, or environment. For more information, see [Tagging Amazon Web Services Resources].
8624 8625 8626 8627 8628 8629 8630 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 8624 class CreateCodeRepositoryInput < Struct.new( :code_repository_name, :git_config, :tags) SENSITIVE = [] include Aws::Structure end |