Class: Aws::SageMaker::Types::CreateCompilationJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreateCompilationJobRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compilation_job_name ⇒ String
A name for the model compilation job.
-
#input_config ⇒ Types::InputConfig
Provides information about the location of input model artifacts, the name and shape of the expected data inputs, and the framework in which the model was trained.
-
#model_package_version_arn ⇒ String
The Amazon Resource Name (ARN) of a versioned model package.
-
#output_config ⇒ Types::OutputConfig
Provides information about the output location for the compiled model and the target device the model runs on.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that enables Amazon SageMaker to perform tasks on your behalf.
-
#stopping_condition ⇒ Types::StoppingCondition
Specifies a limit to how long a model compilation job can run.
-
#tags ⇒ Array<Types::Tag>
An array of key-value pairs.
-
#vpc_config ⇒ Types::NeoVpcConfig
A VpcConfig object that specifies the VPC that you want your compilation job to connect to.
Instance Attribute Details
#compilation_job_name ⇒ String
A name for the model compilation job. The name must be unique within the Amazon Web Services Region and within your Amazon Web Services account.
4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 4483 class CreateCompilationJobRequest < Struct.new( :compilation_job_name, :role_arn, :model_package_version_arn, :input_config, :output_config, :vpc_config, :stopping_condition, :tags) SENSITIVE = [] include Aws::Structure end |
#input_config ⇒ Types::InputConfig
Provides information about the location of input model artifacts, the name and shape of the expected data inputs, and the framework in which the model was trained.
4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 4483 class CreateCompilationJobRequest < Struct.new( :compilation_job_name, :role_arn, :model_package_version_arn, :input_config, :output_config, :vpc_config, :stopping_condition, :tags) SENSITIVE = [] include Aws::Structure end |
#model_package_version_arn ⇒ String
The Amazon Resource Name (ARN) of a versioned model package. Provide either a ModelPackageVersionArn or an InputConfig object in the request syntax. The presence of both objects in the CreateCompilationJob request will return an exception.
4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 4483 class CreateCompilationJobRequest < Struct.new( :compilation_job_name, :role_arn, :model_package_version_arn, :input_config, :output_config, :vpc_config, :stopping_condition, :tags) SENSITIVE = [] include Aws::Structure end |
#output_config ⇒ Types::OutputConfig
Provides information about the output location for the compiled model and the target device the model runs on.
4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 4483 class CreateCompilationJobRequest < Struct.new( :compilation_job_name, :role_arn, :model_package_version_arn, :input_config, :output_config, :vpc_config, :stopping_condition, :tags) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that enables Amazon SageMaker to perform tasks on your behalf.
During model compilation, Amazon SageMaker needs your permission to:
-
Read input data from an S3 bucket
-
Write model artifacts to an S3 bucket
-
Write logs to Amazon CloudWatch Logs
-
Publish metrics to Amazon CloudWatch
You grant permissions for all of these tasks to an IAM role. To pass this role to Amazon SageMaker, the caller of this API must have the iam:PassRole permission. For more information, see [Amazon SageMaker Roles.]
[1]: docs.aws.amazon.com/sagemaker/latest/dg/sagemaker-roles.html
4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 4483 class CreateCompilationJobRequest < Struct.new( :compilation_job_name, :role_arn, :model_package_version_arn, :input_config, :output_config, :vpc_config, :stopping_condition, :tags) SENSITIVE = [] include Aws::Structure end |
#stopping_condition ⇒ Types::StoppingCondition
Specifies a limit to how long a model compilation job can run. When the job reaches the time limit, Amazon SageMaker ends the compilation job. Use this API to cap model training costs.
4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 4483 class CreateCompilationJobRequest < Struct.new( :compilation_job_name, :role_arn, :model_package_version_arn, :input_config, :output_config, :vpc_config, :stopping_condition, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
An array of key-value pairs. You can use tags to categorize your Amazon Web Services resources in different ways, for example, by purpose, owner, or environment. For more information, see [Tagging Amazon Web Services Resources].
4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 4483 class CreateCompilationJobRequest < Struct.new( :compilation_job_name, :role_arn, :model_package_version_arn, :input_config, :output_config, :vpc_config, :stopping_condition, :tags) SENSITIVE = [] include Aws::Structure end |
#vpc_config ⇒ Types::NeoVpcConfig
A VpcConfig object that specifies the VPC that you want your compilation job to connect to. Control access to your models by configuring the VPC. For more information, see [Protect Compilation Jobs by Using an Amazon Virtual Private Cloud].
4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 4483 class CreateCompilationJobRequest < Struct.new( :compilation_job_name, :role_arn, :model_package_version_arn, :input_config, :output_config, :vpc_config, :stopping_condition, :tags) SENSITIVE = [] include Aws::Structure end |