Class: Aws::SageMaker::Types::CreateDomainRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreateDomainRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#app_network_access_type ⇒ String
Specifies the VPC used for non-EFS traffic.
-
#app_security_group_management ⇒ String
The entity that creates and manages the required security groups for inter-app communication in
VPCOnlymode. -
#auth_mode ⇒ String
The mode of authentication that members use to access the domain.
-
#default_space_settings ⇒ Types::DefaultSpaceSettings
The default settings for shared spaces that users create in the domain.
-
#default_user_settings ⇒ Types::UserSettings
The default settings to use to create a user profile when
UserSettingsisn’t specified in the call to theCreateUserProfileAPI. -
#domain_name ⇒ String
A name for the domain.
-
#domain_settings ⇒ Types::DomainSettings
A collection of
Domainsettings. -
#home_efs_file_system_kms_key_id ⇒ String
Use
KmsKeyId. -
#kms_key_id ⇒ String
SageMaker AI uses Amazon Web Services KMS to encrypt EFS and EBS volumes attached to the domain with an Amazon Web Services managed key by default.
-
#subnet_ids ⇒ Array<String>
The VPC subnets that the domain uses for communication.
-
#tag_propagation ⇒ String
Indicates whether custom tag propagation is supported for the domain.
-
#tags ⇒ Array<Types::Tag>
Tags to associated with the Domain.
-
#vpc_id ⇒ String
The ID of the Amazon Virtual Private Cloud (VPC) that the domain uses for communication.
Instance Attribute Details
#app_network_access_type ⇒ String
Specifies the VPC used for non-EFS traffic. The default value is PublicInternetOnly.
-
PublicInternetOnly- Non-EFS traffic is through a VPC managed by Amazon SageMaker AI, which allows direct internet access -
VpcOnly- All traffic is through the specified VPC and subnets
6724 6725 6726 6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 6740 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6724 class CreateDomainRequest < Struct.new( :domain_name, :auth_mode, :default_user_settings, :domain_settings, :subnet_ids, :vpc_id, :tags, :app_network_access_type, :home_efs_file_system_kms_key_id, :kms_key_id, :app_security_group_management, :tag_propagation, :default_space_settings) SENSITIVE = [] include Aws::Structure end |
#app_security_group_management ⇒ String
The entity that creates and manages the required security groups for inter-app communication in VPCOnly mode. Required when CreateDomain.AppNetworkAccessType is VPCOnly and DomainSettings.RStudioServerProDomainSettings.DomainExecutionRoleArn is provided. If setting up the domain for use with RStudio, this value must be set to Service.
6724 6725 6726 6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 6740 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6724 class CreateDomainRequest < Struct.new( :domain_name, :auth_mode, :default_user_settings, :domain_settings, :subnet_ids, :vpc_id, :tags, :app_network_access_type, :home_efs_file_system_kms_key_id, :kms_key_id, :app_security_group_management, :tag_propagation, :default_space_settings) SENSITIVE = [] include Aws::Structure end |
#auth_mode ⇒ String
The mode of authentication that members use to access the domain.
6724 6725 6726 6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 6740 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6724 class CreateDomainRequest < Struct.new( :domain_name, :auth_mode, :default_user_settings, :domain_settings, :subnet_ids, :vpc_id, :tags, :app_network_access_type, :home_efs_file_system_kms_key_id, :kms_key_id, :app_security_group_management, :tag_propagation, :default_space_settings) SENSITIVE = [] include Aws::Structure end |
#default_space_settings ⇒ Types::DefaultSpaceSettings
The default settings for shared spaces that users create in the domain.
6724 6725 6726 6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 6740 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6724 class CreateDomainRequest < Struct.new( :domain_name, :auth_mode, :default_user_settings, :domain_settings, :subnet_ids, :vpc_id, :tags, :app_network_access_type, :home_efs_file_system_kms_key_id, :kms_key_id, :app_security_group_management, :tag_propagation, :default_space_settings) SENSITIVE = [] include Aws::Structure end |
#default_user_settings ⇒ Types::UserSettings
The default settings to use to create a user profile when UserSettings isn’t specified in the call to the CreateUserProfile API.
SecurityGroups is aggregated when specified in both calls. For all other settings in UserSettings, the values specified in CreateUserProfile take precedence over those specified in CreateDomain.
6724 6725 6726 6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 6740 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6724 class CreateDomainRequest < Struct.new( :domain_name, :auth_mode, :default_user_settings, :domain_settings, :subnet_ids, :vpc_id, :tags, :app_network_access_type, :home_efs_file_system_kms_key_id, :kms_key_id, :app_security_group_management, :tag_propagation, :default_space_settings) SENSITIVE = [] include Aws::Structure end |
#domain_name ⇒ String
A name for the domain.
6724 6725 6726 6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 6740 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6724 class CreateDomainRequest < Struct.new( :domain_name, :auth_mode, :default_user_settings, :domain_settings, :subnet_ids, :vpc_id, :tags, :app_network_access_type, :home_efs_file_system_kms_key_id, :kms_key_id, :app_security_group_management, :tag_propagation, :default_space_settings) SENSITIVE = [] include Aws::Structure end |
#domain_settings ⇒ Types::DomainSettings
A collection of Domain settings.
6724 6725 6726 6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 6740 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6724 class CreateDomainRequest < Struct.new( :domain_name, :auth_mode, :default_user_settings, :domain_settings, :subnet_ids, :vpc_id, :tags, :app_network_access_type, :home_efs_file_system_kms_key_id, :kms_key_id, :app_security_group_management, :tag_propagation, :default_space_settings) SENSITIVE = [] include Aws::Structure end |
#home_efs_file_system_kms_key_id ⇒ String
Use KmsKeyId.
6724 6725 6726 6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 6740 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6724 class CreateDomainRequest < Struct.new( :domain_name, :auth_mode, :default_user_settings, :domain_settings, :subnet_ids, :vpc_id, :tags, :app_network_access_type, :home_efs_file_system_kms_key_id, :kms_key_id, :app_security_group_management, :tag_propagation, :default_space_settings) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
SageMaker AI uses Amazon Web Services KMS to encrypt EFS and EBS volumes attached to the domain with an Amazon Web Services managed key by default. For more control, specify a customer managed key.
6724 6725 6726 6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 6740 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6724 class CreateDomainRequest < Struct.new( :domain_name, :auth_mode, :default_user_settings, :domain_settings, :subnet_ids, :vpc_id, :tags, :app_network_access_type, :home_efs_file_system_kms_key_id, :kms_key_id, :app_security_group_management, :tag_propagation, :default_space_settings) SENSITIVE = [] include Aws::Structure end |
#subnet_ids ⇒ Array<String>
The VPC subnets that the domain uses for communication.
6724 6725 6726 6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 6740 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6724 class CreateDomainRequest < Struct.new( :domain_name, :auth_mode, :default_user_settings, :domain_settings, :subnet_ids, :vpc_id, :tags, :app_network_access_type, :home_efs_file_system_kms_key_id, :kms_key_id, :app_security_group_management, :tag_propagation, :default_space_settings) SENSITIVE = [] include Aws::Structure end |
#tag_propagation ⇒ String
Indicates whether custom tag propagation is supported for the domain. Defaults to DISABLED.
6724 6725 6726 6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 6740 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6724 class CreateDomainRequest < Struct.new( :domain_name, :auth_mode, :default_user_settings, :domain_settings, :subnet_ids, :vpc_id, :tags, :app_network_access_type, :home_efs_file_system_kms_key_id, :kms_key_id, :app_security_group_management, :tag_propagation, :default_space_settings) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Tags to associated with the Domain. Each tag consists of a key and an optional value. Tag keys must be unique per resource. Tags are searchable using the Search API.
Tags that you specify for the Domain are also added to all Apps that the Domain launches.
6724 6725 6726 6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 6740 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6724 class CreateDomainRequest < Struct.new( :domain_name, :auth_mode, :default_user_settings, :domain_settings, :subnet_ids, :vpc_id, :tags, :app_network_access_type, :home_efs_file_system_kms_key_id, :kms_key_id, :app_security_group_management, :tag_propagation, :default_space_settings) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the Amazon Virtual Private Cloud (VPC) that the domain uses for communication.
6724 6725 6726 6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 6740 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6724 class CreateDomainRequest < Struct.new( :domain_name, :auth_mode, :default_user_settings, :domain_settings, :subnet_ids, :vpc_id, :tags, :app_network_access_type, :home_efs_file_system_kms_key_id, :kms_key_id, :app_security_group_management, :tag_propagation, :default_space_settings) SENSITIVE = [] include Aws::Structure end |