Class: Aws::SageMaker::Types::CreateDomainRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#app_network_access_typeString

Specifies the VPC used for non-EFS traffic. The default value is PublicInternetOnly.

  • PublicInternetOnly - Non-EFS traffic is through a VPC managed by Amazon SageMaker, which allows direct internet access

  • VpcOnly - All Studio traffic is through the specified VPC and subnets

Returns:



4763
4764
4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
4777
4778
# File 'lib/aws-sdk-sagemaker/types.rb', line 4763

class CreateDomainRequest < Struct.new(
  :domain_name,
  :auth_mode,
  :default_user_settings,
  :subnet_ids,
  :vpc_id,
  :tags,
  :app_network_access_type,
  :home_efs_file_system_kms_key_id,
  :kms_key_id,
  :app_security_group_management,
  :domain_settings,
  :default_space_settings)
  SENSITIVE = []
  include Aws::Structure
end

#app_security_group_managementString

The entity that creates and manages the required security groups for inter-app communication in VPCOnly mode. Required when CreateDomain.AppNetworkAccessType is VPCOnly and DomainSettings.RStudioServerProDomainSettings.DomainExecutionRoleArn is provided.

Returns:



4763
4764
4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
4777
4778
# File 'lib/aws-sdk-sagemaker/types.rb', line 4763

class CreateDomainRequest < Struct.new(
  :domain_name,
  :auth_mode,
  :default_user_settings,
  :subnet_ids,
  :vpc_id,
  :tags,
  :app_network_access_type,
  :home_efs_file_system_kms_key_id,
  :kms_key_id,
  :app_security_group_management,
  :domain_settings,
  :default_space_settings)
  SENSITIVE = []
  include Aws::Structure
end

#auth_modeString

The mode of authentication that members use to access the domain.

Returns:



4763
4764
4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
4777
4778
# File 'lib/aws-sdk-sagemaker/types.rb', line 4763

class CreateDomainRequest < Struct.new(
  :domain_name,
  :auth_mode,
  :default_user_settings,
  :subnet_ids,
  :vpc_id,
  :tags,
  :app_network_access_type,
  :home_efs_file_system_kms_key_id,
  :kms_key_id,
  :app_security_group_management,
  :domain_settings,
  :default_space_settings)
  SENSITIVE = []
  include Aws::Structure
end

#default_space_settingsTypes::DefaultSpaceSettings

The default settings used to create a space.

Returns:



4763
4764
4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
4777
4778
# File 'lib/aws-sdk-sagemaker/types.rb', line 4763

class CreateDomainRequest < Struct.new(
  :domain_name,
  :auth_mode,
  :default_user_settings,
  :subnet_ids,
  :vpc_id,
  :tags,
  :app_network_access_type,
  :home_efs_file_system_kms_key_id,
  :kms_key_id,
  :app_security_group_management,
  :domain_settings,
  :default_space_settings)
  SENSITIVE = []
  include Aws::Structure
end

#default_user_settingsTypes::UserSettings

The default settings to use to create a user profile when UserSettings isn’t specified in the call to the CreateUserProfile API.

SecurityGroups is aggregated when specified in both calls. For all other settings in UserSettings, the values specified in CreateUserProfile take precedence over those specified in CreateDomain.

Returns:



4763
4764
4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
4777
4778
# File 'lib/aws-sdk-sagemaker/types.rb', line 4763

class CreateDomainRequest < Struct.new(
  :domain_name,
  :auth_mode,
  :default_user_settings,
  :subnet_ids,
  :vpc_id,
  :tags,
  :app_network_access_type,
  :home_efs_file_system_kms_key_id,
  :kms_key_id,
  :app_security_group_management,
  :domain_settings,
  :default_space_settings)
  SENSITIVE = []
  include Aws::Structure
end

#domain_nameString

A name for the domain.

Returns:



4763
4764
4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
4777
4778
# File 'lib/aws-sdk-sagemaker/types.rb', line 4763

class CreateDomainRequest < Struct.new(
  :domain_name,
  :auth_mode,
  :default_user_settings,
  :subnet_ids,
  :vpc_id,
  :tags,
  :app_network_access_type,
  :home_efs_file_system_kms_key_id,
  :kms_key_id,
  :app_security_group_management,
  :domain_settings,
  :default_space_settings)
  SENSITIVE = []
  include Aws::Structure
end

#domain_settingsTypes::DomainSettings

A collection of Domain settings.

Returns:



4763
4764
4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
4777
4778
# File 'lib/aws-sdk-sagemaker/types.rb', line 4763

class CreateDomainRequest < Struct.new(
  :domain_name,
  :auth_mode,
  :default_user_settings,
  :subnet_ids,
  :vpc_id,
  :tags,
  :app_network_access_type,
  :home_efs_file_system_kms_key_id,
  :kms_key_id,
  :app_security_group_management,
  :domain_settings,
  :default_space_settings)
  SENSITIVE = []
  include Aws::Structure
end

#home_efs_file_system_kms_key_idString

Use KmsKeyId.

Returns:



4763
4764
4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
4777
4778
# File 'lib/aws-sdk-sagemaker/types.rb', line 4763

class CreateDomainRequest < Struct.new(
  :domain_name,
  :auth_mode,
  :default_user_settings,
  :subnet_ids,
  :vpc_id,
  :tags,
  :app_network_access_type,
  :home_efs_file_system_kms_key_id,
  :kms_key_id,
  :app_security_group_management,
  :domain_settings,
  :default_space_settings)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

SageMaker uses Amazon Web Services KMS to encrypt the EFS volume attached to the domain with an Amazon Web Services managed key by default. For more control, specify a customer managed key.

Returns:



4763
4764
4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
4777
4778
# File 'lib/aws-sdk-sagemaker/types.rb', line 4763

class CreateDomainRequest < Struct.new(
  :domain_name,
  :auth_mode,
  :default_user_settings,
  :subnet_ids,
  :vpc_id,
  :tags,
  :app_network_access_type,
  :home_efs_file_system_kms_key_id,
  :kms_key_id,
  :app_security_group_management,
  :domain_settings,
  :default_space_settings)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idsArray<String>

The VPC subnets that Studio uses for communication.

Returns:



4763
4764
4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
4777
4778
# File 'lib/aws-sdk-sagemaker/types.rb', line 4763

class CreateDomainRequest < Struct.new(
  :domain_name,
  :auth_mode,
  :default_user_settings,
  :subnet_ids,
  :vpc_id,
  :tags,
  :app_network_access_type,
  :home_efs_file_system_kms_key_id,
  :kms_key_id,
  :app_security_group_management,
  :domain_settings,
  :default_space_settings)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Tags to associated with the Domain. Each tag consists of a key and an optional value. Tag keys must be unique per resource. Tags are searchable using the Search API.

Tags that you specify for the Domain are also added to all Apps that the Domain launches.

Returns:



4763
4764
4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
4777
4778
# File 'lib/aws-sdk-sagemaker/types.rb', line 4763

class CreateDomainRequest < Struct.new(
  :domain_name,
  :auth_mode,
  :default_user_settings,
  :subnet_ids,
  :vpc_id,
  :tags,
  :app_network_access_type,
  :home_efs_file_system_kms_key_id,
  :kms_key_id,
  :app_security_group_management,
  :domain_settings,
  :default_space_settings)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the Amazon Virtual Private Cloud (VPC) that Studio uses for communication.

Returns:



4763
4764
4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
4777
4778
# File 'lib/aws-sdk-sagemaker/types.rb', line 4763

class CreateDomainRequest < Struct.new(
  :domain_name,
  :auth_mode,
  :default_user_settings,
  :subnet_ids,
  :vpc_id,
  :tags,
  :app_network_access_type,
  :home_efs_file_system_kms_key_id,
  :kms_key_id,
  :app_security_group_management,
  :domain_settings,
  :default_space_settings)
  SENSITIVE = []
  include Aws::Structure
end