Class: Aws::SageMaker::Types::CreateEdgePackagingJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreateEdgePackagingJobRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compilation_job_name ⇒ String
The name of the SageMaker Neo compilation job that will be used to locate model artifacts for packaging.
-
#edge_packaging_job_name ⇒ String
The name of the edge packaging job.
-
#model_name ⇒ String
The name of the model.
-
#model_version ⇒ String
The version of the model.
-
#output_config ⇒ Types::EdgeOutputConfig
Provides information about the output location for the packaged model.
-
#resource_key ⇒ String
The Amazon Web Services KMS key to use when encrypting the EBS volume the edge packaging job runs on.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that enables Amazon SageMaker to download and upload the model, and to contact SageMaker Neo.
-
#tags ⇒ Array<Types::Tag>
Creates tags for the packaging job.
Instance Attribute Details
#compilation_job_name ⇒ String
The name of the SageMaker Neo compilation job that will be used to locate model artifacts for packaging.
4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 4909 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 4898 class CreateEdgePackagingJobRequest < Struct.new( :edge_packaging_job_name, :compilation_job_name, :model_name, :model_version, :role_arn, :output_config, :resource_key, :tags) SENSITIVE = [] include Aws::Structure end |
#edge_packaging_job_name ⇒ String
The name of the edge packaging job.
4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 4909 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 4898 class CreateEdgePackagingJobRequest < Struct.new( :edge_packaging_job_name, :compilation_job_name, :model_name, :model_version, :role_arn, :output_config, :resource_key, :tags) SENSITIVE = [] include Aws::Structure end |
#model_name ⇒ String
The name of the model.
4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 4909 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 4898 class CreateEdgePackagingJobRequest < Struct.new( :edge_packaging_job_name, :compilation_job_name, :model_name, :model_version, :role_arn, :output_config, :resource_key, :tags) SENSITIVE = [] include Aws::Structure end |
#model_version ⇒ String
The version of the model.
4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 4909 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 4898 class CreateEdgePackagingJobRequest < Struct.new( :edge_packaging_job_name, :compilation_job_name, :model_name, :model_version, :role_arn, :output_config, :resource_key, :tags) SENSITIVE = [] include Aws::Structure end |
#output_config ⇒ Types::EdgeOutputConfig
Provides information about the output location for the packaged model.
4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 4909 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 4898 class CreateEdgePackagingJobRequest < Struct.new( :edge_packaging_job_name, :compilation_job_name, :model_name, :model_version, :role_arn, :output_config, :resource_key, :tags) SENSITIVE = [] include Aws::Structure end |
#resource_key ⇒ String
The Amazon Web Services KMS key to use when encrypting the EBS volume the edge packaging job runs on.
4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 4909 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 4898 class CreateEdgePackagingJobRequest < Struct.new( :edge_packaging_job_name, :compilation_job_name, :model_name, :model_version, :role_arn, :output_config, :resource_key, :tags) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that enables Amazon SageMaker to download and upload the model, and to contact SageMaker Neo.
4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 4909 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 4898 class CreateEdgePackagingJobRequest < Struct.new( :edge_packaging_job_name, :compilation_job_name, :model_name, :model_version, :role_arn, :output_config, :resource_key, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Creates tags for the packaging job.
4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 4909 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 4898 class CreateEdgePackagingJobRequest < Struct.new( :edge_packaging_job_name, :compilation_job_name, :model_name, :model_version, :role_arn, :output_config, :resource_key, :tags) SENSITIVE = [] include Aws::Structure end |