Class: Aws::SageMaker::Types::CreateEdgePackagingJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreateEdgePackagingJobRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compilation_job_name ⇒ String
The name of the SageMaker Neo compilation job that will be used to locate model artifacts for packaging.
-
#edge_packaging_job_name ⇒ String
The name of the edge packaging job.
-
#model_name ⇒ String
The name of the model.
-
#model_version ⇒ String
The version of the model.
-
#output_config ⇒ Types::EdgeOutputConfig
Provides information about the output location for the packaged model.
-
#resource_key ⇒ String
The Amazon Web Services KMS key to use when encrypting the EBS volume the edge packaging job runs on.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that enables Amazon SageMaker to download and upload the model, and to contact SageMaker Neo.
-
#tags ⇒ Array<Types::Tag>
Creates tags for the packaging job.
Instance Attribute Details
#compilation_job_name ⇒ String
The name of the SageMaker Neo compilation job that will be used to locate model artifacts for packaging.
9042 9043 9044 9045 9046 9047 9048 9049 9050 9051 9052 9053 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9042 class CreateEdgePackagingJobRequest < Struct.new( :edge_packaging_job_name, :compilation_job_name, :model_name, :model_version, :role_arn, :output_config, :resource_key, :tags) SENSITIVE = [] include Aws::Structure end |
#edge_packaging_job_name ⇒ String
The name of the edge packaging job.
9042 9043 9044 9045 9046 9047 9048 9049 9050 9051 9052 9053 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9042 class CreateEdgePackagingJobRequest < Struct.new( :edge_packaging_job_name, :compilation_job_name, :model_name, :model_version, :role_arn, :output_config, :resource_key, :tags) SENSITIVE = [] include Aws::Structure end |
#model_name ⇒ String
The name of the model.
9042 9043 9044 9045 9046 9047 9048 9049 9050 9051 9052 9053 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9042 class CreateEdgePackagingJobRequest < Struct.new( :edge_packaging_job_name, :compilation_job_name, :model_name, :model_version, :role_arn, :output_config, :resource_key, :tags) SENSITIVE = [] include Aws::Structure end |
#model_version ⇒ String
The version of the model.
9042 9043 9044 9045 9046 9047 9048 9049 9050 9051 9052 9053 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9042 class CreateEdgePackagingJobRequest < Struct.new( :edge_packaging_job_name, :compilation_job_name, :model_name, :model_version, :role_arn, :output_config, :resource_key, :tags) SENSITIVE = [] include Aws::Structure end |
#output_config ⇒ Types::EdgeOutputConfig
Provides information about the output location for the packaged model.
9042 9043 9044 9045 9046 9047 9048 9049 9050 9051 9052 9053 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9042 class CreateEdgePackagingJobRequest < Struct.new( :edge_packaging_job_name, :compilation_job_name, :model_name, :model_version, :role_arn, :output_config, :resource_key, :tags) SENSITIVE = [] include Aws::Structure end |
#resource_key ⇒ String
The Amazon Web Services KMS key to use when encrypting the EBS volume the edge packaging job runs on.
9042 9043 9044 9045 9046 9047 9048 9049 9050 9051 9052 9053 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9042 class CreateEdgePackagingJobRequest < Struct.new( :edge_packaging_job_name, :compilation_job_name, :model_name, :model_version, :role_arn, :output_config, :resource_key, :tags) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that enables Amazon SageMaker to download and upload the model, and to contact SageMaker Neo.
9042 9043 9044 9045 9046 9047 9048 9049 9050 9051 9052 9053 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9042 class CreateEdgePackagingJobRequest < Struct.new( :edge_packaging_job_name, :compilation_job_name, :model_name, :model_version, :role_arn, :output_config, :resource_key, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Creates tags for the packaging job.
9042 9043 9044 9045 9046 9047 9048 9049 9050 9051 9052 9053 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9042 class CreateEdgePackagingJobRequest < Struct.new( :edge_packaging_job_name, :compilation_job_name, :model_name, :model_version, :role_arn, :output_config, :resource_key, :tags) SENSITIVE = [] include Aws::Structure end |