Class: Aws::SageMaker::Types::CreateEndpointInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#deployment_configTypes::DeploymentConfig

The deployment configuration for an endpoint, which contains the desired deployment strategy and rollback configurations.



10678
10679
10680
10681
10682
10683
10684
10685
# File 'lib/aws-sdk-sagemaker/types.rb', line 10678

class CreateEndpointInput < Struct.new(
  :endpoint_name,
  :endpoint_config_name,
  :deployment_config,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_config_nameString

The name of an endpoint configuration. For more information, see CreateEndpointConfig.

Returns:

  • (String)


10678
10679
10680
10681
10682
10683
10684
10685
# File 'lib/aws-sdk-sagemaker/types.rb', line 10678

class CreateEndpointInput < Struct.new(
  :endpoint_name,
  :endpoint_config_name,
  :deployment_config,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_nameString

The name of the endpoint.The name must be unique within an Amazon Web Services Region in your Amazon Web Services account. The name is case-insensitive in CreateEndpoint, but the case is preserved and must be matched in InvokeEndpoint.

Returns:

  • (String)


10678
10679
10680
10681
10682
10683
10684
10685
# File 'lib/aws-sdk-sagemaker/types.rb', line 10678

class CreateEndpointInput < Struct.new(
  :endpoint_name,
  :endpoint_config_name,
  :deployment_config,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

An array of key-value pairs. You can use tags to categorize your Amazon Web Services resources in different ways, for example, by purpose, owner, or environment. For more information, see Tagging Amazon Web Services Resources.

Returns:



10678
10679
10680
10681
10682
10683
10684
10685
# File 'lib/aws-sdk-sagemaker/types.rb', line 10678

class CreateEndpointInput < Struct.new(
  :endpoint_name,
  :endpoint_config_name,
  :deployment_config,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end