Class: Aws::SageMaker::Types::CreateExperimentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreateExperimentRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the experiment.
-
#display_name ⇒ String
The name of the experiment as displayed.
-
#experiment_name ⇒ String
The name of the experiment.
-
#tags ⇒ Array<Types::Tag>
A list of tags to associate with the experiment.
Instance Attribute Details
#description ⇒ String
The description of the experiment.
10749 10750 10751 10752 10753 10754 10755 10756 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10749 class CreateExperimentRequest < Struct.new( :experiment_name, :display_name, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The name of the experiment as displayed. The name doesn't need to
be unique. If you don't specify DisplayName, the value in
ExperimentName is displayed.
10749 10750 10751 10752 10753 10754 10755 10756 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10749 class CreateExperimentRequest < Struct.new( :experiment_name, :display_name, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#experiment_name ⇒ String
The name of the experiment. The name must be unique in your Amazon Web Services account and is not case-sensitive.
10749 10750 10751 10752 10753 10754 10755 10756 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10749 class CreateExperimentRequest < Struct.new( :experiment_name, :display_name, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of tags to associate with the experiment. You can use Search API to search on the tags.
10749 10750 10751 10752 10753 10754 10755 10756 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10749 class CreateExperimentRequest < Struct.new( :experiment_name, :display_name, :description, :tags) SENSITIVE = [] include Aws::Structure end |