Class: Aws::SageMaker::Types::CreateExperimentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreateExperimentRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the experiment.
-
#display_name ⇒ String
The name of the experiment as displayed.
-
#experiment_name ⇒ String
The name of the experiment.
-
#tags ⇒ Array<Types::Tag>
A list of tags to associate with the experiment.
Instance Attribute Details
#description ⇒ String
The description of the experiment.
7109 7110 7111 7112 7113 7114 7115 7116 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7109 class CreateExperimentRequest < Struct.new( :experiment_name, :display_name, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The name of the experiment as displayed. The name doesn’t need to be unique. If you don’t specify DisplayName, the value in ExperimentName is displayed.
7109 7110 7111 7112 7113 7114 7115 7116 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7109 class CreateExperimentRequest < Struct.new( :experiment_name, :display_name, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#experiment_name ⇒ String
The name of the experiment. The name must be unique in your Amazon Web Services account and is not case-sensitive.
7109 7110 7111 7112 7113 7114 7115 7116 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7109 class CreateExperimentRequest < Struct.new( :experiment_name, :display_name, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of tags to associate with the experiment. You can use
- Search][1
-
API to search on the tags.
[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_Search.html
7109 7110 7111 7112 7113 7114 7115 7116 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7109 class CreateExperimentRequest < Struct.new( :experiment_name, :display_name, :description, :tags) SENSITIVE = [] include Aws::Structure end |