Class: Aws::SageMaker::Types::CreateFlowDefinitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreateFlowDefinitionRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#flow_definition_name ⇒ String
The name of your flow definition.
-
#human_loop_activation_config ⇒ Types::HumanLoopActivationConfig
An object containing information about the events that trigger a human workflow.
-
#human_loop_config ⇒ Types::HumanLoopConfig
An object containing information about the tasks the human reviewers will perform.
-
#human_loop_request_source ⇒ Types::HumanLoopRequestSource
Container for configuring the source of human task requests.
-
#output_config ⇒ Types::FlowDefinitionOutputConfig
An object containing information about where the human review results will be uploaded.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the role needed to call other services on your behalf.
-
#tags ⇒ Array<Types::Tag>
An array of key-value pairs that contain metadata to help you categorize and organize a flow definition.
Instance Attribute Details
#flow_definition_name ⇒ String
The name of your flow definition.
10631 10632 10633 10634 10635 10636 10637 10638 10639 10640 10641 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10631 class CreateFlowDefinitionRequest < Struct.new( :flow_definition_name, :human_loop_request_source, :human_loop_activation_config, :human_loop_config, :output_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#human_loop_activation_config ⇒ Types::HumanLoopActivationConfig
An object containing information about the events that trigger a human workflow.
10631 10632 10633 10634 10635 10636 10637 10638 10639 10640 10641 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10631 class CreateFlowDefinitionRequest < Struct.new( :flow_definition_name, :human_loop_request_source, :human_loop_activation_config, :human_loop_config, :output_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#human_loop_config ⇒ Types::HumanLoopConfig
An object containing information about the tasks the human reviewers will perform.
10631 10632 10633 10634 10635 10636 10637 10638 10639 10640 10641 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10631 class CreateFlowDefinitionRequest < Struct.new( :flow_definition_name, :human_loop_request_source, :human_loop_activation_config, :human_loop_config, :output_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#human_loop_request_source ⇒ Types::HumanLoopRequestSource
Container for configuring the source of human task requests. Use to specify if Amazon Rekognition or Amazon Textract is used as an integration source.
10631 10632 10633 10634 10635 10636 10637 10638 10639 10640 10641 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10631 class CreateFlowDefinitionRequest < Struct.new( :flow_definition_name, :human_loop_request_source, :human_loop_activation_config, :human_loop_config, :output_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#output_config ⇒ Types::FlowDefinitionOutputConfig
An object containing information about where the human review results will be uploaded.
10631 10632 10633 10634 10635 10636 10637 10638 10639 10640 10641 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10631 class CreateFlowDefinitionRequest < Struct.new( :flow_definition_name, :human_loop_request_source, :human_loop_activation_config, :human_loop_config, :output_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the role needed to call other services on your behalf. For example, ‘arn:aws:iam::1234567890:role/service-role/AmazonSageMaker-ExecutionRole-20180111T151298`.
10631 10632 10633 10634 10635 10636 10637 10638 10639 10640 10641 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10631 class CreateFlowDefinitionRequest < Struct.new( :flow_definition_name, :human_loop_request_source, :human_loop_activation_config, :human_loop_config, :output_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
An array of key-value pairs that contain metadata to help you categorize and organize a flow definition. Each tag consists of a key and a value, both of which you define.
10631 10632 10633 10634 10635 10636 10637 10638 10639 10640 10641 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10631 class CreateFlowDefinitionRequest < Struct.new( :flow_definition_name, :human_loop_request_source, :human_loop_activation_config, :human_loop_config, :output_config, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |