Class: Aws::SageMaker::Types::CreateFlowDefinitionRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#flow_definition_nameString

The name of your flow definition.

Returns:



5310
5311
5312
5313
5314
5315
5316
5317
5318
5319
5320
# File 'lib/aws-sdk-sagemaker/types.rb', line 5310

class CreateFlowDefinitionRequest < Struct.new(
  :flow_definition_name,
  :human_loop_request_source,
  :human_loop_activation_config,
  :human_loop_config,
  :output_config,
  :role_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#human_loop_activation_configTypes::HumanLoopActivationConfig

An object containing information about the events that trigger a human workflow.

Returns:



5310
5311
5312
5313
5314
5315
5316
5317
5318
5319
5320
# File 'lib/aws-sdk-sagemaker/types.rb', line 5310

class CreateFlowDefinitionRequest < Struct.new(
  :flow_definition_name,
  :human_loop_request_source,
  :human_loop_activation_config,
  :human_loop_config,
  :output_config,
  :role_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#human_loop_configTypes::HumanLoopConfig

An object containing information about the tasks the human reviewers will perform.

Returns:



5310
5311
5312
5313
5314
5315
5316
5317
5318
5319
5320
# File 'lib/aws-sdk-sagemaker/types.rb', line 5310

class CreateFlowDefinitionRequest < Struct.new(
  :flow_definition_name,
  :human_loop_request_source,
  :human_loop_activation_config,
  :human_loop_config,
  :output_config,
  :role_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#human_loop_request_sourceTypes::HumanLoopRequestSource

Container for configuring the source of human task requests. Use to specify if Amazon Rekognition or Amazon Textract is used as an integration source.

Returns:



5310
5311
5312
5313
5314
5315
5316
5317
5318
5319
5320
# File 'lib/aws-sdk-sagemaker/types.rb', line 5310

class CreateFlowDefinitionRequest < Struct.new(
  :flow_definition_name,
  :human_loop_request_source,
  :human_loop_activation_config,
  :human_loop_config,
  :output_config,
  :role_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#output_configTypes::FlowDefinitionOutputConfig

An object containing information about where the human review results will be uploaded.

Returns:



5310
5311
5312
5313
5314
5315
5316
5317
5318
5319
5320
# File 'lib/aws-sdk-sagemaker/types.rb', line 5310

class CreateFlowDefinitionRequest < Struct.new(
  :flow_definition_name,
  :human_loop_request_source,
  :human_loop_activation_config,
  :human_loop_config,
  :output_config,
  :role_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of the role needed to call other services on your behalf. For example, arn:aws:iam::1234567890:role/service-role/AmazonSageMaker-ExecutionRole-20180111T151298.

Returns:



5310
5311
5312
5313
5314
5315
5316
5317
5318
5319
5320
# File 'lib/aws-sdk-sagemaker/types.rb', line 5310

class CreateFlowDefinitionRequest < Struct.new(
  :flow_definition_name,
  :human_loop_request_source,
  :human_loop_activation_config,
  :human_loop_config,
  :output_config,
  :role_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

An array of key-value pairs that contain metadata to help you categorize and organize a flow definition. Each tag consists of a key and a value, both of which you define.

Returns:



5310
5311
5312
5313
5314
5315
5316
5317
5318
5319
5320
# File 'lib/aws-sdk-sagemaker/types.rb', line 5310

class CreateFlowDefinitionRequest < Struct.new(
  :flow_definition_name,
  :human_loop_request_source,
  :human_loop_activation_config,
  :human_loop_config,
  :output_config,
  :role_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end