Class: Aws::SageMaker::Types::CreateImageVersionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreateImageVersionRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aliases ⇒ Array<String>
A list of aliases created with the image version.
-
#base_image ⇒ String
The registry path of the container image to use as the starting point for this version.
-
#client_token ⇒ String
A unique ID.
-
#horovod ⇒ Boolean
Indicates Horovod compatibility.
-
#image_name ⇒ String
The
ImageNameof theImageto create a version of. -
#job_type ⇒ String
Indicates SageMaker job type compatibility.
-
#ml_framework ⇒ String
The machine learning framework vended in the image version.
-
#processor ⇒ String
Indicates CPU or GPU compatibility.
-
#programming_lang ⇒ String
The supported programming language and its version.
-
#release_notes ⇒ String
The maintainer description of the image version.
-
#vendor_guidance ⇒ String
The stability of the image version, specified by the maintainer.
Instance Attribute Details
#aliases ⇒ Array<String>
A list of aliases created with the image version.
5643 5644 5645 5646 5647 5648 5649 5650 5651 5652 5653 5654 5655 5656 5657 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5643 class CreateImageVersionRequest < Struct.new( :base_image, :client_token, :image_name, :aliases, :vendor_guidance, :job_type, :ml_framework, :programming_lang, :processor, :horovod, :release_notes) SENSITIVE = [] include Aws::Structure end |
#base_image ⇒ String
The registry path of the container image to use as the starting point for this version. The path is an Amazon Elastic Container Registry (ECR) URI in the following format:
‘<acct-id>.dkr.ecr.<region>.amazonaws.com/<repo-name or [@digest]>`
5643 5644 5645 5646 5647 5648 5649 5650 5651 5652 5653 5654 5655 5656 5657 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5643 class CreateImageVersionRequest < Struct.new( :base_image, :client_token, :image_name, :aliases, :vendor_guidance, :job_type, :ml_framework, :programming_lang, :processor, :horovod, :release_notes) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique ID. If not specified, the Amazon Web Services CLI and Amazon Web Services SDKs, such as the SDK for Python (Boto3), add a unique value to the call.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
5643 5644 5645 5646 5647 5648 5649 5650 5651 5652 5653 5654 5655 5656 5657 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5643 class CreateImageVersionRequest < Struct.new( :base_image, :client_token, :image_name, :aliases, :vendor_guidance, :job_type, :ml_framework, :programming_lang, :processor, :horovod, :release_notes) SENSITIVE = [] include Aws::Structure end |
#horovod ⇒ Boolean
Indicates Horovod compatibility.
5643 5644 5645 5646 5647 5648 5649 5650 5651 5652 5653 5654 5655 5656 5657 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5643 class CreateImageVersionRequest < Struct.new( :base_image, :client_token, :image_name, :aliases, :vendor_guidance, :job_type, :ml_framework, :programming_lang, :processor, :horovod, :release_notes) SENSITIVE = [] include Aws::Structure end |
#image_name ⇒ String
The ImageName of the Image to create a version of.
5643 5644 5645 5646 5647 5648 5649 5650 5651 5652 5653 5654 5655 5656 5657 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5643 class CreateImageVersionRequest < Struct.new( :base_image, :client_token, :image_name, :aliases, :vendor_guidance, :job_type, :ml_framework, :programming_lang, :processor, :horovod, :release_notes) SENSITIVE = [] include Aws::Structure end |
#job_type ⇒ String
Indicates SageMaker job type compatibility.
-
TRAINING: The image version is compatible with SageMaker training jobs. -
INFERENCE: The image version is compatible with SageMaker inference jobs. -
NOTEBOOK_KERNEL: The image version is compatible with SageMaker notebook kernels.
5643 5644 5645 5646 5647 5648 5649 5650 5651 5652 5653 5654 5655 5656 5657 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5643 class CreateImageVersionRequest < Struct.new( :base_image, :client_token, :image_name, :aliases, :vendor_guidance, :job_type, :ml_framework, :programming_lang, :processor, :horovod, :release_notes) SENSITIVE = [] include Aws::Structure end |
#ml_framework ⇒ String
The machine learning framework vended in the image version.
5643 5644 5645 5646 5647 5648 5649 5650 5651 5652 5653 5654 5655 5656 5657 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5643 class CreateImageVersionRequest < Struct.new( :base_image, :client_token, :image_name, :aliases, :vendor_guidance, :job_type, :ml_framework, :programming_lang, :processor, :horovod, :release_notes) SENSITIVE = [] include Aws::Structure end |
#processor ⇒ String
Indicates CPU or GPU compatibility.
-
CPU: The image version is compatible with CPU. -
GPU: The image version is compatible with GPU.
5643 5644 5645 5646 5647 5648 5649 5650 5651 5652 5653 5654 5655 5656 5657 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5643 class CreateImageVersionRequest < Struct.new( :base_image, :client_token, :image_name, :aliases, :vendor_guidance, :job_type, :ml_framework, :programming_lang, :processor, :horovod, :release_notes) SENSITIVE = [] include Aws::Structure end |
#programming_lang ⇒ String
The supported programming language and its version.
5643 5644 5645 5646 5647 5648 5649 5650 5651 5652 5653 5654 5655 5656 5657 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5643 class CreateImageVersionRequest < Struct.new( :base_image, :client_token, :image_name, :aliases, :vendor_guidance, :job_type, :ml_framework, :programming_lang, :processor, :horovod, :release_notes) SENSITIVE = [] include Aws::Structure end |
#release_notes ⇒ String
The maintainer description of the image version.
5643 5644 5645 5646 5647 5648 5649 5650 5651 5652 5653 5654 5655 5656 5657 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5643 class CreateImageVersionRequest < Struct.new( :base_image, :client_token, :image_name, :aliases, :vendor_guidance, :job_type, :ml_framework, :programming_lang, :processor, :horovod, :release_notes) SENSITIVE = [] include Aws::Structure end |
#vendor_guidance ⇒ String
The stability of the image version, specified by the maintainer.
-
NOT_PROVIDED: The maintainers did not provide a status for image version stability. -
STABLE: The image version is stable. -
TO_BE_ARCHIVED: The image version is set to be archived. Custom image versions that are set to be archived are automatically archived after three months. -
ARCHIVED: The image version is archived. Archived image versions are not searchable and are no longer actively supported.
5643 5644 5645 5646 5647 5648 5649 5650 5651 5652 5653 5654 5655 5656 5657 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 5643 class CreateImageVersionRequest < Struct.new( :base_image, :client_token, :image_name, :aliases, :vendor_guidance, :job_type, :ml_framework, :programming_lang, :processor, :horovod, :release_notes) SENSITIVE = [] include Aws::Structure end |