Class: Aws::SageMaker::Types::CreateImageVersionRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aliasesArray<String>

A list of aliases created with the image version.



10036
10037
10038
10039
10040
10041
10042
10043
10044
10045
10046
10047
10048
10049
10050
# File 'lib/aws-sdk-sagemaker/types.rb', line 10036

class CreateImageVersionRequest < Struct.new(
  :base_image,
  :client_token,
  :image_name,
  :aliases,
  :vendor_guidance,
  :job_type,
  :ml_framework,
  :programming_lang,
  :processor,
  :horovod,
  :release_notes)
  SENSITIVE = []
  include Aws::Structure
end

#base_imageString

The registry path of the container image to use as the starting point for this version. The path is an Amazon ECR URI in the following format:

‘<acct-id>.dkr.ecr.<region>.amazonaws.com/<repo-name or [@digest]>`



10036
10037
10038
10039
10040
10041
10042
10043
10044
10045
10046
10047
10048
10049
10050
# File 'lib/aws-sdk-sagemaker/types.rb', line 10036

class CreateImageVersionRequest < Struct.new(
  :base_image,
  :client_token,
  :image_name,
  :aliases,
  :vendor_guidance,
  :job_type,
  :ml_framework,
  :programming_lang,
  :processor,
  :horovod,
  :release_notes)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique ID. If not specified, the Amazon Web Services CLI and Amazon Web Services SDKs, such as the SDK for Python (Boto3), add a unique value to the call.

**A suitable default value is auto-generated.** You should normally not need to pass this option.



10036
10037
10038
10039
10040
10041
10042
10043
10044
10045
10046
10047
10048
10049
10050
# File 'lib/aws-sdk-sagemaker/types.rb', line 10036

class CreateImageVersionRequest < Struct.new(
  :base_image,
  :client_token,
  :image_name,
  :aliases,
  :vendor_guidance,
  :job_type,
  :ml_framework,
  :programming_lang,
  :processor,
  :horovod,
  :release_notes)
  SENSITIVE = []
  include Aws::Structure
end

#horovodBoolean

Indicates Horovod compatibility.



10036
10037
10038
10039
10040
10041
10042
10043
10044
10045
10046
10047
10048
10049
10050
# File 'lib/aws-sdk-sagemaker/types.rb', line 10036

class CreateImageVersionRequest < Struct.new(
  :base_image,
  :client_token,
  :image_name,
  :aliases,
  :vendor_guidance,
  :job_type,
  :ml_framework,
  :programming_lang,
  :processor,
  :horovod,
  :release_notes)
  SENSITIVE = []
  include Aws::Structure
end

#image_nameString

The ImageName of the Image to create a version of.



10036
10037
10038
10039
10040
10041
10042
10043
10044
10045
10046
10047
10048
10049
10050
# File 'lib/aws-sdk-sagemaker/types.rb', line 10036

class CreateImageVersionRequest < Struct.new(
  :base_image,
  :client_token,
  :image_name,
  :aliases,
  :vendor_guidance,
  :job_type,
  :ml_framework,
  :programming_lang,
  :processor,
  :horovod,
  :release_notes)
  SENSITIVE = []
  include Aws::Structure
end

#job_typeString

Indicates SageMaker AI job type compatibility.

  • TRAINING: The image version is compatible with SageMaker AI training jobs.

  • INFERENCE: The image version is compatible with SageMaker AI inference jobs.

  • NOTEBOOK_KERNEL: The image version is compatible with SageMaker AI notebook kernels.



10036
10037
10038
10039
10040
10041
10042
10043
10044
10045
10046
10047
10048
10049
10050
# File 'lib/aws-sdk-sagemaker/types.rb', line 10036

class CreateImageVersionRequest < Struct.new(
  :base_image,
  :client_token,
  :image_name,
  :aliases,
  :vendor_guidance,
  :job_type,
  :ml_framework,
  :programming_lang,
  :processor,
  :horovod,
  :release_notes)
  SENSITIVE = []
  include Aws::Structure
end

#ml_frameworkString

The machine learning framework vended in the image version.



10036
10037
10038
10039
10040
10041
10042
10043
10044
10045
10046
10047
10048
10049
10050
# File 'lib/aws-sdk-sagemaker/types.rb', line 10036

class CreateImageVersionRequest < Struct.new(
  :base_image,
  :client_token,
  :image_name,
  :aliases,
  :vendor_guidance,
  :job_type,
  :ml_framework,
  :programming_lang,
  :processor,
  :horovod,
  :release_notes)
  SENSITIVE = []
  include Aws::Structure
end

#processorString

Indicates CPU or GPU compatibility.

  • CPU: The image version is compatible with CPU.

  • GPU: The image version is compatible with GPU.



10036
10037
10038
10039
10040
10041
10042
10043
10044
10045
10046
10047
10048
10049
10050
# File 'lib/aws-sdk-sagemaker/types.rb', line 10036

class CreateImageVersionRequest < Struct.new(
  :base_image,
  :client_token,
  :image_name,
  :aliases,
  :vendor_guidance,
  :job_type,
  :ml_framework,
  :programming_lang,
  :processor,
  :horovod,
  :release_notes)
  SENSITIVE = []
  include Aws::Structure
end

#programming_langString

The supported programming language and its version.



10036
10037
10038
10039
10040
10041
10042
10043
10044
10045
10046
10047
10048
10049
10050
# File 'lib/aws-sdk-sagemaker/types.rb', line 10036

class CreateImageVersionRequest < Struct.new(
  :base_image,
  :client_token,
  :image_name,
  :aliases,
  :vendor_guidance,
  :job_type,
  :ml_framework,
  :programming_lang,
  :processor,
  :horovod,
  :release_notes)
  SENSITIVE = []
  include Aws::Structure
end

#release_notesString

The maintainer description of the image version.



10036
10037
10038
10039
10040
10041
10042
10043
10044
10045
10046
10047
10048
10049
10050
# File 'lib/aws-sdk-sagemaker/types.rb', line 10036

class CreateImageVersionRequest < Struct.new(
  :base_image,
  :client_token,
  :image_name,
  :aliases,
  :vendor_guidance,
  :job_type,
  :ml_framework,
  :programming_lang,
  :processor,
  :horovod,
  :release_notes)
  SENSITIVE = []
  include Aws::Structure
end

#vendor_guidanceString

The stability of the image version, specified by the maintainer.

  • NOT_PROVIDED: The maintainers did not provide a status for image version stability.

  • STABLE: The image version is stable.

  • TO_BE_ARCHIVED: The image version is set to be archived. Custom image versions that are set to be archived are automatically archived after three months.

  • ARCHIVED: The image version is archived. Archived image versions are not searchable and are no longer actively supported.



10036
10037
10038
10039
10040
10041
10042
10043
10044
10045
10046
10047
10048
10049
10050
# File 'lib/aws-sdk-sagemaker/types.rb', line 10036

class CreateImageVersionRequest < Struct.new(
  :base_image,
  :client_token,
  :image_name,
  :aliases,
  :vendor_guidance,
  :job_type,
  :ml_framework,
  :programming_lang,
  :processor,
  :horovod,
  :release_notes)
  SENSITIVE = []
  include Aws::Structure
end