Class: Aws::SageMaker::Types::CreateJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreateJobRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_category ⇒ String
The category of the job.
-
#job_config_document ⇒ String
The JSON configuration document for the job.
-
#job_config_schema_version ⇒ String
The version of the configuration schema to use for the job configuration document.
-
#job_name ⇒ String
The name of the job.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that Amazon SageMaker assumes to perform the job.
-
#tags ⇒ Array<Types::Tag>
An array of key-value pairs to apply to the job as tags.
Instance Attribute Details
#job_category ⇒ String
The category of the job. The category determines the type of workload that the job runs.
11848 11849 11850 11851 11852 11853 11854 11855 11856 11857 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 11848 class CreateJobRequest < Struct.new( :job_name, :role_arn, :job_category, :job_config_schema_version, :job_config_document, :tags) SENSITIVE = [] include Aws::Structure end |
#job_config_document ⇒ String
The JSON configuration document for the job. The document must
conform to the schema specified by JobConfigSchemaVersion. Use
DescribeJobSchemaVersion to retrieve the schema for validation.
11848 11849 11850 11851 11852 11853 11854 11855 11856 11857 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 11848 class CreateJobRequest < Struct.new( :job_name, :role_arn, :job_category, :job_config_schema_version, :job_config_document, :tags) SENSITIVE = [] include Aws::Structure end |
#job_config_schema_version ⇒ String
The version of the configuration schema to use for the job
configuration document. Use ListJobSchemaVersions to get available
schema versions for a job category.
11848 11849 11850 11851 11852 11853 11854 11855 11856 11857 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 11848 class CreateJobRequest < Struct.new( :job_name, :role_arn, :job_category, :job_config_schema_version, :job_config_document, :tags) SENSITIVE = [] include Aws::Structure end |
#job_name ⇒ String
The name of the job. The name must be unique within your account and Amazon Web Services Region.
11848 11849 11850 11851 11852 11853 11854 11855 11856 11857 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 11848 class CreateJobRequest < Struct.new( :job_name, :role_arn, :job_category, :job_config_schema_version, :job_config_document, :tags) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that Amazon SageMaker assumes to perform the job. The role must have the necessary permissions to access the resources required by the job configuration.
11848 11849 11850 11851 11852 11853 11854 11855 11856 11857 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 11848 class CreateJobRequest < Struct.new( :job_name, :role_arn, :job_category, :job_config_schema_version, :job_config_document, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
An array of key-value pairs to apply to the job as tags. For more information, see Tagging Amazon Web Services Resources.
11848 11849 11850 11851 11852 11853 11854 11855 11856 11857 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 11848 class CreateJobRequest < Struct.new( :job_name, :role_arn, :job_category, :job_config_schema_version, :job_config_document, :tags) SENSITIVE = [] include Aws::Structure end |