Class: Aws::SageMaker::Types::CreateJobRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#job_categoryString

The category of the job. The category determines the type of workload that the job runs.

Returns:

  • (String)


11642
11643
11644
11645
11646
11647
11648
11649
11650
11651
# File 'lib/aws-sdk-sagemaker/types.rb', line 11642

class CreateJobRequest < Struct.new(
  :job_name,
  :role_arn,
  :job_category,
  :job_config_schema_version,
  :job_config_document,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#job_config_documentString

The JSON configuration document for the job. The document must conform to the schema specified by ‘JobConfigSchemaVersion`. Use `DescribeJobSchemaVersion` to retrieve the schema for validation.

Returns:

  • (String)


11642
11643
11644
11645
11646
11647
11648
11649
11650
11651
# File 'lib/aws-sdk-sagemaker/types.rb', line 11642

class CreateJobRequest < Struct.new(
  :job_name,
  :role_arn,
  :job_category,
  :job_config_schema_version,
  :job_config_document,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#job_config_schema_versionString

The version of the configuration schema to use for the job configuration document. Use ‘ListJobSchemaVersions` to get available schema versions for a job category.

Returns:

  • (String)


11642
11643
11644
11645
11646
11647
11648
11649
11650
11651
# File 'lib/aws-sdk-sagemaker/types.rb', line 11642

class CreateJobRequest < Struct.new(
  :job_name,
  :role_arn,
  :job_category,
  :job_config_schema_version,
  :job_config_document,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#job_nameString

The name of the job. The name must be unique within your account and Amazon Web Services Region.

Returns:

  • (String)


11642
11643
11644
11645
11646
11647
11648
11649
11650
11651
# File 'lib/aws-sdk-sagemaker/types.rb', line 11642

class CreateJobRequest < Struct.new(
  :job_name,
  :role_arn,
  :job_category,
  :job_config_schema_version,
  :job_config_document,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of the IAM role that Amazon SageMaker assumes to perform the job. The role must have the necessary permissions to access the resources required by the job configuration.

Returns:

  • (String)


11642
11643
11644
11645
11646
11647
11648
11649
11650
11651
# File 'lib/aws-sdk-sagemaker/types.rb', line 11642

class CreateJobRequest < Struct.new(
  :job_name,
  :role_arn,
  :job_category,
  :job_config_schema_version,
  :job_config_document,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

An array of key-value pairs to apply to the job as tags. For more information, see [Tagging Amazon Web Services Resources].

[1]: docs.aws.amazon.com/general/latest/gr/aws_tagging.html

Returns:



11642
11643
11644
11645
11646
11647
11648
11649
11650
11651
# File 'lib/aws-sdk-sagemaker/types.rb', line 11642

class CreateJobRequest < Struct.new(
  :job_name,
  :role_arn,
  :job_category,
  :job_config_schema_version,
  :job_config_document,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end