Class: Aws::SageMaker::Types::CreateMlflowAppRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreateMlflowAppRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_default_status ⇒ String
Indicates whether this MLflow app is the default for the entire account.
-
#artifact_store_uri ⇒ String
The S3 URI for a general purpose bucket to use as the MLflow App artifact store.
-
#default_domain_id_list ⇒ Array<String>
List of SageMaker domain IDs for which this MLflow App is used as the default.
-
#kms_key_id ⇒ String
The ID of the Amazon Web Services KMS key used to encrypt the data at rest associated with the MLflow App.
-
#model_registration_mode ⇒ String
Whether to enable or disable automatic registration of new MLflow models to the SageMaker Model Registry.
-
#name ⇒ String
A string identifying the MLflow app name.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) for an IAM role in your account that the MLflow App uses to access the artifact store in Amazon S3.
-
#tags ⇒ Array<Types::Tag>
Tags consisting of key-value pairs used to manage metadata for the MLflow App.
-
#weekly_maintenance_window_start ⇒ String
The day and time of the week in Coordinated Universal Time (UTC) 24-hour standard time that weekly maintenance updates are scheduled.
Instance Attribute Details
#account_default_status ⇒ String
Indicates whether this MLflow app is the default for the entire account.
12264 12265 12266 12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12264 class CreateMlflowAppRequest < Struct.new( :name, :artifact_store_uri, :role_arn, :kms_key_id, :model_registration_mode, :weekly_maintenance_window_start, :account_default_status, :default_domain_id_list, :tags) SENSITIVE = [] include Aws::Structure end |
#artifact_store_uri ⇒ String
The S3 URI for a general purpose bucket to use as the MLflow App artifact store.
12264 12265 12266 12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12264 class CreateMlflowAppRequest < Struct.new( :name, :artifact_store_uri, :role_arn, :kms_key_id, :model_registration_mode, :weekly_maintenance_window_start, :account_default_status, :default_domain_id_list, :tags) SENSITIVE = [] include Aws::Structure end |
#default_domain_id_list ⇒ Array<String>
List of SageMaker domain IDs for which this MLflow App is used as the default.
12264 12265 12266 12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12264 class CreateMlflowAppRequest < Struct.new( :name, :artifact_store_uri, :role_arn, :kms_key_id, :model_registration_mode, :weekly_maintenance_window_start, :account_default_status, :default_domain_id_list, :tags) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The ID of the Amazon Web Services KMS key used to encrypt the data at rest associated with the MLflow App. If you don't specify a value, the MLflow App is not encrypted with a customer-managed key.
12264 12265 12266 12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12264 class CreateMlflowAppRequest < Struct.new( :name, :artifact_store_uri, :role_arn, :kms_key_id, :model_registration_mode, :weekly_maintenance_window_start, :account_default_status, :default_domain_id_list, :tags) SENSITIVE = [] include Aws::Structure end |
#model_registration_mode ⇒ String
Whether to enable or disable automatic registration of new MLflow
models to the SageMaker Model Registry. To enable automatic model
registration, set this value to AutoModelRegistrationEnabled. To
disable automatic model registration, set this value to
AutoModelRegistrationDisabled. If not specified,
AutomaticModelRegistration defaults to
AutoModelRegistrationDisabled.
12264 12265 12266 12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12264 class CreateMlflowAppRequest < Struct.new( :name, :artifact_store_uri, :role_arn, :kms_key_id, :model_registration_mode, :weekly_maintenance_window_start, :account_default_status, :default_domain_id_list, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A string identifying the MLflow app name. This string is not part of the tracking server ARN.
12264 12265 12266 12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12264 class CreateMlflowAppRequest < Struct.new( :name, :artifact_store_uri, :role_arn, :kms_key_id, :model_registration_mode, :weekly_maintenance_window_start, :account_default_status, :default_domain_id_list, :tags) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) for an IAM role in your account that
the MLflow App uses to access the artifact store in Amazon S3. The
role should have the AmazonS3FullAccess permission.
12264 12265 12266 12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12264 class CreateMlflowAppRequest < Struct.new( :name, :artifact_store_uri, :role_arn, :kms_key_id, :model_registration_mode, :weekly_maintenance_window_start, :account_default_status, :default_domain_id_list, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Tags consisting of key-value pairs used to manage metadata for the MLflow App.
12264 12265 12266 12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12264 class CreateMlflowAppRequest < Struct.new( :name, :artifact_store_uri, :role_arn, :kms_key_id, :model_registration_mode, :weekly_maintenance_window_start, :account_default_status, :default_domain_id_list, :tags) SENSITIVE = [] include Aws::Structure end |
#weekly_maintenance_window_start ⇒ String
The day and time of the week in Coordinated Universal Time (UTC) 24-hour standard time that weekly maintenance updates are scheduled. For example: TUE:03:30.
12264 12265 12266 12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12264 class CreateMlflowAppRequest < Struct.new( :name, :artifact_store_uri, :role_arn, :kms_key_id, :model_registration_mode, :weekly_maintenance_window_start, :account_default_status, :default_domain_id_list, :tags) SENSITIVE = [] include Aws::Structure end |