Class: Aws::SageMaker::Types::CreateMlflowAppRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreateMlflowAppRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_default_status ⇒ String
Indicates whether this MLflow app is the default for the entire account.
-
#artifact_store_uri ⇒ String
The S3 URI for a general purpose bucket to use as the MLflow App artifact store.
-
#default_domain_id_list ⇒ Array<String>
List of SageMaker domain IDs for which this MLflow App is used as the default.
-
#model_registration_mode ⇒ String
Whether to enable or disable automatic registration of new MLflow models to the SageMaker Model Registry.
-
#name ⇒ String
A string identifying the MLflow app name.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) for an IAM role in your account that the MLflow App uses to access the artifact store in Amazon S3.
-
#tags ⇒ Array<Types::Tag>
Tags consisting of key-value pairs used to manage metadata for the MLflow App.
-
#weekly_maintenance_window_start ⇒ String
The day and time of the week in Coordinated Universal Time (UTC) 24-hour standard time that weekly maintenance updates are scheduled.
Instance Attribute Details
#account_default_status ⇒ String
Indicates whether this MLflow app is the default for the entire account.
12130 12131 12132 12133 12134 12135 12136 12137 12138 12139 12140 12141 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12130 class CreateMlflowAppRequest < Struct.new( :name, :artifact_store_uri, :role_arn, :model_registration_mode, :weekly_maintenance_window_start, :account_default_status, :default_domain_id_list, :tags) SENSITIVE = [] include Aws::Structure end |
#artifact_store_uri ⇒ String
The S3 URI for a general purpose bucket to use as the MLflow App artifact store.
12130 12131 12132 12133 12134 12135 12136 12137 12138 12139 12140 12141 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12130 class CreateMlflowAppRequest < Struct.new( :name, :artifact_store_uri, :role_arn, :model_registration_mode, :weekly_maintenance_window_start, :account_default_status, :default_domain_id_list, :tags) SENSITIVE = [] include Aws::Structure end |
#default_domain_id_list ⇒ Array<String>
List of SageMaker domain IDs for which this MLflow App is used as the default.
12130 12131 12132 12133 12134 12135 12136 12137 12138 12139 12140 12141 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12130 class CreateMlflowAppRequest < Struct.new( :name, :artifact_store_uri, :role_arn, :model_registration_mode, :weekly_maintenance_window_start, :account_default_status, :default_domain_id_list, :tags) SENSITIVE = [] include Aws::Structure end |
#model_registration_mode ⇒ String
Whether to enable or disable automatic registration of new MLflow
models to the SageMaker Model Registry. To enable automatic model
registration, set this value to AutoModelRegistrationEnabled. To
disable automatic model registration, set this value to
AutoModelRegistrationDisabled. If not specified,
AutomaticModelRegistration defaults to
AutoModelRegistrationDisabled.
12130 12131 12132 12133 12134 12135 12136 12137 12138 12139 12140 12141 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12130 class CreateMlflowAppRequest < Struct.new( :name, :artifact_store_uri, :role_arn, :model_registration_mode, :weekly_maintenance_window_start, :account_default_status, :default_domain_id_list, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A string identifying the MLflow app name. This string is not part of the tracking server ARN.
12130 12131 12132 12133 12134 12135 12136 12137 12138 12139 12140 12141 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12130 class CreateMlflowAppRequest < Struct.new( :name, :artifact_store_uri, :role_arn, :model_registration_mode, :weekly_maintenance_window_start, :account_default_status, :default_domain_id_list, :tags) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) for an IAM role in your account that
the MLflow App uses to access the artifact store in Amazon S3. The
role should have the AmazonS3FullAccess permission.
12130 12131 12132 12133 12134 12135 12136 12137 12138 12139 12140 12141 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12130 class CreateMlflowAppRequest < Struct.new( :name, :artifact_store_uri, :role_arn, :model_registration_mode, :weekly_maintenance_window_start, :account_default_status, :default_domain_id_list, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Tags consisting of key-value pairs used to manage metadata for the MLflow App.
12130 12131 12132 12133 12134 12135 12136 12137 12138 12139 12140 12141 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12130 class CreateMlflowAppRequest < Struct.new( :name, :artifact_store_uri, :role_arn, :model_registration_mode, :weekly_maintenance_window_start, :account_default_status, :default_domain_id_list, :tags) SENSITIVE = [] include Aws::Structure end |
#weekly_maintenance_window_start ⇒ String
The day and time of the week in Coordinated Universal Time (UTC) 24-hour standard time that weekly maintenance updates are scheduled. For example: TUE:03:30.
12130 12131 12132 12133 12134 12135 12136 12137 12138 12139 12140 12141 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12130 class CreateMlflowAppRequest < Struct.new( :name, :artifact_store_uri, :role_arn, :model_registration_mode, :weekly_maintenance_window_start, :account_default_status, :default_domain_id_list, :tags) SENSITIVE = [] include Aws::Structure end |