Class: Aws::SageMaker::Types::CreateMlflowTrackingServerRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreateMlflowTrackingServerRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#artifact_store_uri ⇒ String
The S3 URI for a general purpose bucket to use as the MLflow Tracking Server artifact store.
-
#automatic_model_registration ⇒ Boolean
Whether to enable or disable automatic registration of new MLflow models to the SageMaker Model Registry.
-
#mlflow_version ⇒ String
The version of MLflow that the tracking server uses.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) for an IAM role in your account that the MLflow Tracking Server uses to access the artifact store in Amazon S3.
-
#s3_bucket_owner_account_id ⇒ String
Expected Amazon Web Services account ID that owns the Amazon S3 bucket for artifact storage.
-
#s3_bucket_owner_verification ⇒ Boolean
Enable Amazon S3 Ownership checks when interacting with Amazon S3 buckets from a SageMaker Managed MLflow Tracking Server.
-
#tags ⇒ Array<Types::Tag>
Tags consisting of key-value pairs used to manage metadata for the tracking server.
-
#tracking_server_name ⇒ String
A unique string identifying the tracking server name.
-
#tracking_server_size ⇒ String
The size of the tracking server you want to create.
-
#weekly_maintenance_window_start ⇒ String
The day and time of the week in Coordinated Universal Time (UTC) 24-hour standard time that weekly maintenance updates are scheduled.
Instance Attribute Details
#artifact_store_uri ⇒ String
The S3 URI for a general purpose bucket to use as the MLflow Tracking Server artifact store.
10898 10899 10900 10901 10902 10903 10904 10905 10906 10907 10908 10909 10910 10911 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10898 class CreateMlflowTrackingServerRequest < Struct.new( :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :automatic_model_registration, :weekly_maintenance_window_start, :tags, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#automatic_model_registration ⇒ Boolean
Whether to enable or disable automatic registration of new MLflow models to the SageMaker Model Registry. To enable automatic model registration, set this value to ‘True`. To disable automatic model registration, set this value to `False`. If not specified, `AutomaticModelRegistration` defaults to `False`.
10898 10899 10900 10901 10902 10903 10904 10905 10906 10907 10908 10909 10910 10911 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10898 class CreateMlflowTrackingServerRequest < Struct.new( :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :automatic_model_registration, :weekly_maintenance_window_start, :tags, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#mlflow_version ⇒ String
The version of MLflow that the tracking server uses. To see which MLflow versions are available to use, see [How it works].
[1]: docs.aws.amazon.com/sagemaker/latest/dg/mlflow.html#mlflow-create-tracking-server-how-it-works
10898 10899 10900 10901 10902 10903 10904 10905 10906 10907 10908 10909 10910 10911 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10898 class CreateMlflowTrackingServerRequest < Struct.new( :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :automatic_model_registration, :weekly_maintenance_window_start, :tags, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) for an IAM role in your account that the MLflow Tracking Server uses to access the artifact store in Amazon S3. The role should have ‘AmazonS3FullAccess` permissions. For more information on IAM permissions for tracking server creation, see [Set up IAM permissions for MLflow].
[1]: docs.aws.amazon.com/sagemaker/latest/dg/mlflow-create-tracking-server-iam.html
10898 10899 10900 10901 10902 10903 10904 10905 10906 10907 10908 10909 10910 10911 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10898 class CreateMlflowTrackingServerRequest < Struct.new( :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :automatic_model_registration, :weekly_maintenance_window_start, :tags, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#s3_bucket_owner_account_id ⇒ String
Expected Amazon Web Services account ID that owns the Amazon S3 bucket for artifact storage. Defaults to caller’s account ID if not provided.
10898 10899 10900 10901 10902 10903 10904 10905 10906 10907 10908 10909 10910 10911 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10898 class CreateMlflowTrackingServerRequest < Struct.new( :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :automatic_model_registration, :weekly_maintenance_window_start, :tags, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#s3_bucket_owner_verification ⇒ Boolean
Enable Amazon S3 Ownership checks when interacting with Amazon S3 buckets from a SageMaker Managed MLflow Tracking Server. Defaults to ‘True` if not provided.
10898 10899 10900 10901 10902 10903 10904 10905 10906 10907 10908 10909 10910 10911 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10898 class CreateMlflowTrackingServerRequest < Struct.new( :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :automatic_model_registration, :weekly_maintenance_window_start, :tags, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Tags consisting of key-value pairs used to manage metadata for the tracking server.
10898 10899 10900 10901 10902 10903 10904 10905 10906 10907 10908 10909 10910 10911 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10898 class CreateMlflowTrackingServerRequest < Struct.new( :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :automatic_model_registration, :weekly_maintenance_window_start, :tags, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#tracking_server_name ⇒ String
A unique string identifying the tracking server name. This string is part of the tracking server ARN.
10898 10899 10900 10901 10902 10903 10904 10905 10906 10907 10908 10909 10910 10911 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10898 class CreateMlflowTrackingServerRequest < Struct.new( :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :automatic_model_registration, :weekly_maintenance_window_start, :tags, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#tracking_server_size ⇒ String
The size of the tracking server you want to create. You can choose between ‘“Small”`, `“Medium”`, and `“Large”`. The default MLflow Tracking Server configuration size is `“Small”`. You can choose a size depending on the projected use of the tracking server such as the volume of data logged, number of users, and frequency of use.
We recommend using a small tracking server for teams of up to 25 users, a medium tracking server for teams of up to 50 users, and a large tracking server for teams of up to 100 users.
10898 10899 10900 10901 10902 10903 10904 10905 10906 10907 10908 10909 10910 10911 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10898 class CreateMlflowTrackingServerRequest < Struct.new( :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :automatic_model_registration, :weekly_maintenance_window_start, :tags, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#weekly_maintenance_window_start ⇒ String
The day and time of the week in Coordinated Universal Time (UTC) 24-hour standard time that weekly maintenance updates are scheduled. For example: TUE:03:30.
10898 10899 10900 10901 10902 10903 10904 10905 10906 10907 10908 10909 10910 10911 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10898 class CreateMlflowTrackingServerRequest < Struct.new( :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :automatic_model_registration, :weekly_maintenance_window_start, :tags, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |