Class: Aws::SageMaker::Types::CreateModelBiasJobDefinitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreateModelBiasJobDefinitionRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_definition_name ⇒ String
The name of the bias job definition.
-
#job_resources ⇒ Types::MonitoringResources
Identifies the resources to deploy for a monitoring job.
-
#model_bias_app_specification ⇒ Types::ModelBiasAppSpecification
Configures the model bias job to run a specified Docker container image.
-
#model_bias_baseline_config ⇒ Types::ModelBiasBaselineConfig
The baseline configuration for a model bias job.
-
#model_bias_job_input ⇒ Types::ModelBiasJobInput
Inputs for the model bias job.
-
#model_bias_job_output_config ⇒ Types::MonitoringOutputConfig
The output configuration for monitoring jobs.
-
#network_config ⇒ Types::MonitoringNetworkConfig
Networking options for a model bias job.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker can assume to perform tasks on your behalf.
-
#stopping_condition ⇒ Types::MonitoringStoppingCondition
A time limit for how long the monitoring job is allowed to run before stopping.
-
#tags ⇒ Array<Types::Tag>
(Optional) An array of key-value pairs.
Instance Attribute Details
#job_definition_name ⇒ String
The name of the bias job definition. The name must be unique within an Amazon Web Services Region in the Amazon Web Services account.
6165 6166 6167 6168 6169 6170 6171 6172 6173 6174 6175 6176 6177 6178 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6165 class CreateModelBiasJobDefinitionRequest < Struct.new( :job_definition_name, :model_bias_baseline_config, :model_bias_app_specification, :model_bias_job_input, :model_bias_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition, :tags) SENSITIVE = [] include Aws::Structure end |
#job_resources ⇒ Types::MonitoringResources
Identifies the resources to deploy for a monitoring job.
6165 6166 6167 6168 6169 6170 6171 6172 6173 6174 6175 6176 6177 6178 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6165 class CreateModelBiasJobDefinitionRequest < Struct.new( :job_definition_name, :model_bias_baseline_config, :model_bias_app_specification, :model_bias_job_input, :model_bias_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition, :tags) SENSITIVE = [] include Aws::Structure end |
#model_bias_app_specification ⇒ Types::ModelBiasAppSpecification
Configures the model bias job to run a specified Docker container image.
6165 6166 6167 6168 6169 6170 6171 6172 6173 6174 6175 6176 6177 6178 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6165 class CreateModelBiasJobDefinitionRequest < Struct.new( :job_definition_name, :model_bias_baseline_config, :model_bias_app_specification, :model_bias_job_input, :model_bias_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition, :tags) SENSITIVE = [] include Aws::Structure end |
#model_bias_baseline_config ⇒ Types::ModelBiasBaselineConfig
The baseline configuration for a model bias job.
6165 6166 6167 6168 6169 6170 6171 6172 6173 6174 6175 6176 6177 6178 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6165 class CreateModelBiasJobDefinitionRequest < Struct.new( :job_definition_name, :model_bias_baseline_config, :model_bias_app_specification, :model_bias_job_input, :model_bias_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition, :tags) SENSITIVE = [] include Aws::Structure end |
#model_bias_job_input ⇒ Types::ModelBiasJobInput
Inputs for the model bias job.
6165 6166 6167 6168 6169 6170 6171 6172 6173 6174 6175 6176 6177 6178 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6165 class CreateModelBiasJobDefinitionRequest < Struct.new( :job_definition_name, :model_bias_baseline_config, :model_bias_app_specification, :model_bias_job_input, :model_bias_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition, :tags) SENSITIVE = [] include Aws::Structure end |
#model_bias_job_output_config ⇒ Types::MonitoringOutputConfig
The output configuration for monitoring jobs.
6165 6166 6167 6168 6169 6170 6171 6172 6173 6174 6175 6176 6177 6178 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6165 class CreateModelBiasJobDefinitionRequest < Struct.new( :job_definition_name, :model_bias_baseline_config, :model_bias_app_specification, :model_bias_job_input, :model_bias_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition, :tags) SENSITIVE = [] include Aws::Structure end |
#network_config ⇒ Types::MonitoringNetworkConfig
Networking options for a model bias job.
6165 6166 6167 6168 6169 6170 6171 6172 6173 6174 6175 6176 6177 6178 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6165 class CreateModelBiasJobDefinitionRequest < Struct.new( :job_definition_name, :model_bias_baseline_config, :model_bias_app_specification, :model_bias_job_input, :model_bias_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition, :tags) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker can assume to perform tasks on your behalf.
6165 6166 6167 6168 6169 6170 6171 6172 6173 6174 6175 6176 6177 6178 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6165 class CreateModelBiasJobDefinitionRequest < Struct.new( :job_definition_name, :model_bias_baseline_config, :model_bias_app_specification, :model_bias_job_input, :model_bias_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition, :tags) SENSITIVE = [] include Aws::Structure end |
#stopping_condition ⇒ Types::MonitoringStoppingCondition
A time limit for how long the monitoring job is allowed to run before stopping.
6165 6166 6167 6168 6169 6170 6171 6172 6173 6174 6175 6176 6177 6178 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6165 class CreateModelBiasJobDefinitionRequest < Struct.new( :job_definition_name, :model_bias_baseline_config, :model_bias_app_specification, :model_bias_job_input, :model_bias_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
(Optional) An array of key-value pairs. For more information, see
- Using Cost Allocation Tags][1
-
in the *Amazon Web Services Billing
and Cost Management User Guide*.
[1]: docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html#allocation-whatURL
6165 6166 6167 6168 6169 6170 6171 6172 6173 6174 6175 6176 6177 6178 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 6165 class CreateModelBiasJobDefinitionRequest < Struct.new( :job_definition_name, :model_bias_baseline_config, :model_bias_app_specification, :model_bias_job_input, :model_bias_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition, :tags) SENSITIVE = [] include Aws::Structure end |