Class: Aws::SageMaker::Types::CreateModelQualityJobDefinitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreateModelQualityJobDefinitionRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_definition_name ⇒ String
The name of the monitoring job definition.
-
#job_resources ⇒ Types::MonitoringResources
Identifies the resources to deploy for a monitoring job.
-
#model_quality_app_specification ⇒ Types::ModelQualityAppSpecification
The container that runs the monitoring job.
-
#model_quality_baseline_config ⇒ Types::ModelQualityBaselineConfig
Specifies the constraints and baselines for the monitoring job.
-
#model_quality_job_input ⇒ Types::ModelQualityJobInput
A list of the inputs that are monitored.
-
#model_quality_job_output_config ⇒ Types::MonitoringOutputConfig
The output configuration for monitoring jobs.
-
#network_config ⇒ Types::MonitoringNetworkConfig
Specifies the network configuration for the monitoring job.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker AI can assume to perform tasks on your behalf.
-
#stopping_condition ⇒ Types::MonitoringStoppingCondition
A time limit for how long the monitoring job is allowed to run before stopping.
-
#tags ⇒ Array<Types::Tag>
(Optional) An array of key-value pairs.
Instance Attribute Details
#job_definition_name ⇒ String
The name of the monitoring job definition.
12478 12479 12480 12481 12482 12483 12484 12485 12486 12487 12488 12489 12490 12491 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12478 class CreateModelQualityJobDefinitionRequest < Struct.new( :job_definition_name, :model_quality_baseline_config, :model_quality_app_specification, :model_quality_job_input, :model_quality_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition, :tags) SENSITIVE = [] include Aws::Structure end |
#job_resources ⇒ Types::MonitoringResources
Identifies the resources to deploy for a monitoring job.
12478 12479 12480 12481 12482 12483 12484 12485 12486 12487 12488 12489 12490 12491 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12478 class CreateModelQualityJobDefinitionRequest < Struct.new( :job_definition_name, :model_quality_baseline_config, :model_quality_app_specification, :model_quality_job_input, :model_quality_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition, :tags) SENSITIVE = [] include Aws::Structure end |
#model_quality_app_specification ⇒ Types::ModelQualityAppSpecification
The container that runs the monitoring job.
12478 12479 12480 12481 12482 12483 12484 12485 12486 12487 12488 12489 12490 12491 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12478 class CreateModelQualityJobDefinitionRequest < Struct.new( :job_definition_name, :model_quality_baseline_config, :model_quality_app_specification, :model_quality_job_input, :model_quality_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition, :tags) SENSITIVE = [] include Aws::Structure end |
#model_quality_baseline_config ⇒ Types::ModelQualityBaselineConfig
Specifies the constraints and baselines for the monitoring job.
12478 12479 12480 12481 12482 12483 12484 12485 12486 12487 12488 12489 12490 12491 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12478 class CreateModelQualityJobDefinitionRequest < Struct.new( :job_definition_name, :model_quality_baseline_config, :model_quality_app_specification, :model_quality_job_input, :model_quality_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition, :tags) SENSITIVE = [] include Aws::Structure end |
#model_quality_job_input ⇒ Types::ModelQualityJobInput
A list of the inputs that are monitored. Currently endpoints are supported.
12478 12479 12480 12481 12482 12483 12484 12485 12486 12487 12488 12489 12490 12491 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12478 class CreateModelQualityJobDefinitionRequest < Struct.new( :job_definition_name, :model_quality_baseline_config, :model_quality_app_specification, :model_quality_job_input, :model_quality_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition, :tags) SENSITIVE = [] include Aws::Structure end |
#model_quality_job_output_config ⇒ Types::MonitoringOutputConfig
The output configuration for monitoring jobs.
12478 12479 12480 12481 12482 12483 12484 12485 12486 12487 12488 12489 12490 12491 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12478 class CreateModelQualityJobDefinitionRequest < Struct.new( :job_definition_name, :model_quality_baseline_config, :model_quality_app_specification, :model_quality_job_input, :model_quality_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition, :tags) SENSITIVE = [] include Aws::Structure end |
#network_config ⇒ Types::MonitoringNetworkConfig
Specifies the network configuration for the monitoring job.
12478 12479 12480 12481 12482 12483 12484 12485 12486 12487 12488 12489 12490 12491 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12478 class CreateModelQualityJobDefinitionRequest < Struct.new( :job_definition_name, :model_quality_baseline_config, :model_quality_app_specification, :model_quality_job_input, :model_quality_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition, :tags) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker AI can assume to perform tasks on your behalf.
12478 12479 12480 12481 12482 12483 12484 12485 12486 12487 12488 12489 12490 12491 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12478 class CreateModelQualityJobDefinitionRequest < Struct.new( :job_definition_name, :model_quality_baseline_config, :model_quality_app_specification, :model_quality_job_input, :model_quality_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition, :tags) SENSITIVE = [] include Aws::Structure end |
#stopping_condition ⇒ Types::MonitoringStoppingCondition
A time limit for how long the monitoring job is allowed to run before stopping.
12478 12479 12480 12481 12482 12483 12484 12485 12486 12487 12488 12489 12490 12491 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12478 class CreateModelQualityJobDefinitionRequest < Struct.new( :job_definition_name, :model_quality_baseline_config, :model_quality_app_specification, :model_quality_job_input, :model_quality_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
(Optional) An array of key-value pairs. For more information, see [ Using Cost Allocation Tags] in the *Amazon Web Services Billing and Cost Management User Guide*.
[1]: docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html#allocation-whatURL
12478 12479 12480 12481 12482 12483 12484 12485 12486 12487 12488 12489 12490 12491 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12478 class CreateModelQualityJobDefinitionRequest < Struct.new( :job_definition_name, :model_quality_baseline_config, :model_quality_app_specification, :model_quality_job_input, :model_quality_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition, :tags) SENSITIVE = [] include Aws::Structure end |