Class: Aws::SageMaker::Types::CreateMonitoringScheduleRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreateMonitoringScheduleRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#monitoring_schedule_config ⇒ Types::MonitoringScheduleConfig
The configuration object that specifies the monitoring schedule and defines the monitoring job.
-
#monitoring_schedule_name ⇒ String
The name of the monitoring schedule.
-
#tags ⇒ Array<Types::Tag>
(Optional) An array of key-value pairs.
Instance Attribute Details
#monitoring_schedule_config ⇒ Types::MonitoringScheduleConfig
The configuration object that specifies the monitoring schedule and defines the monitoring job.
12533 12534 12535 12536 12537 12538 12539 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12533 class CreateMonitoringScheduleRequest < Struct.new( :monitoring_schedule_name, :monitoring_schedule_config, :tags) SENSITIVE = [] include Aws::Structure end |
#monitoring_schedule_name ⇒ String
The name of the monitoring schedule. The name must be unique within an Amazon Web Services Region within an Amazon Web Services account.
12533 12534 12535 12536 12537 12538 12539 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12533 class CreateMonitoringScheduleRequest < Struct.new( :monitoring_schedule_name, :monitoring_schedule_config, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
(Optional) An array of key-value pairs. For more information, see [Using Cost Allocation Tags]( docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html#allocation-whatURL) in the *Amazon Web Services Billing and Cost Management User Guide*.
12533 12534 12535 12536 12537 12538 12539 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12533 class CreateMonitoringScheduleRequest < Struct.new( :monitoring_schedule_name, :monitoring_schedule_config, :tags) SENSITIVE = [] include Aws::Structure end |