Class: Aws::SageMaker::Types::CreateNotebookInstanceLifecycleConfigInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreateNotebookInstanceLifecycleConfigInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#notebook_instance_lifecycle_config_name ⇒ String
The name of the lifecycle configuration.
-
#on_create ⇒ Array<Types::NotebookInstanceLifecycleHook>
A shell script that runs only once, when you create a notebook instance.
-
#on_start ⇒ Array<Types::NotebookInstanceLifecycleHook>
A shell script that runs every time you start a notebook instance, including when you create the notebook instance.
-
#tags ⇒ Array<Types::Tag>
An array of key-value pairs.
Instance Attribute Details
#notebook_instance_lifecycle_config_name ⇒ String
The name of the lifecycle configuration.
13353 13354 13355 13356 13357 13358 13359 13360 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13353 class CreateNotebookInstanceLifecycleConfigInput < Struct.new( :notebook_instance_lifecycle_config_name, :on_create, :on_start, :tags) SENSITIVE = [] include Aws::Structure end |
#on_create ⇒ Array<Types::NotebookInstanceLifecycleHook>
A shell script that runs only once, when you create a notebook instance. The shell script must be a base64-encoded string.
13353 13354 13355 13356 13357 13358 13359 13360 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13353 class CreateNotebookInstanceLifecycleConfigInput < Struct.new( :notebook_instance_lifecycle_config_name, :on_create, :on_start, :tags) SENSITIVE = [] include Aws::Structure end |
#on_start ⇒ Array<Types::NotebookInstanceLifecycleHook>
A shell script that runs every time you start a notebook instance, including when you create the notebook instance. The shell script must be a base64-encoded string.
13353 13354 13355 13356 13357 13358 13359 13360 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13353 class CreateNotebookInstanceLifecycleConfigInput < Struct.new( :notebook_instance_lifecycle_config_name, :on_create, :on_start, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
An array of key-value pairs. You can use tags to categorize your Amazon Web Services resources in different ways, for example, by purpose, owner, or environment. For more information, see Tagging Amazon Web Services Resources.
13353 13354 13355 13356 13357 13358 13359 13360 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13353 class CreateNotebookInstanceLifecycleConfigInput < Struct.new( :notebook_instance_lifecycle_config_name, :on_create, :on_start, :tags) SENSITIVE = [] include Aws::Structure end |