Class: Aws::SageMaker::Types::CreateNotebookInstanceLifecycleConfigInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#notebook_instance_lifecycle_config_nameString

The name of the lifecycle configuration.

Returns:

  • (String)


13223
13224
13225
13226
13227
13228
13229
13230
# File 'lib/aws-sdk-sagemaker/types.rb', line 13223

class CreateNotebookInstanceLifecycleConfigInput < Struct.new(
  :notebook_instance_lifecycle_config_name,
  :on_create,
  :on_start,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#on_createArray<Types::NotebookInstanceLifecycleHook>

A shell script that runs only once, when you create a notebook instance. The shell script must be a base64-encoded string.



13223
13224
13225
13226
13227
13228
13229
13230
# File 'lib/aws-sdk-sagemaker/types.rb', line 13223

class CreateNotebookInstanceLifecycleConfigInput < Struct.new(
  :notebook_instance_lifecycle_config_name,
  :on_create,
  :on_start,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#on_startArray<Types::NotebookInstanceLifecycleHook>

A shell script that runs every time you start a notebook instance, including when you create the notebook instance. The shell script must be a base64-encoded string.



13223
13224
13225
13226
13227
13228
13229
13230
# File 'lib/aws-sdk-sagemaker/types.rb', line 13223

class CreateNotebookInstanceLifecycleConfigInput < Struct.new(
  :notebook_instance_lifecycle_config_name,
  :on_create,
  :on_start,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

An array of key-value pairs. You can use tags to categorize your Amazon Web Services resources in different ways, for example, by purpose, owner, or environment. For more information, see Tagging Amazon Web Services Resources.

Returns:



13223
13224
13225
13226
13227
13228
13229
13230
# File 'lib/aws-sdk-sagemaker/types.rb', line 13223

class CreateNotebookInstanceLifecycleConfigInput < Struct.new(
  :notebook_instance_lifecycle_config_name,
  :on_create,
  :on_start,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end