Class: Aws::SageMaker::Types::CreateNotebookInstanceLifecycleConfigInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreateNotebookInstanceLifecycleConfigInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#notebook_instance_lifecycle_config_name ⇒ String
The name of the lifecycle configuration.
-
#on_create ⇒ Array<Types::NotebookInstanceLifecycleHook>
A shell script that runs only once, when you create a notebook instance.
-
#on_start ⇒ Array<Types::NotebookInstanceLifecycleHook>
A shell script that runs every time you start a notebook instance, including when you create the notebook instance.
-
#tags ⇒ Array<Types::Tag>
An array of key-value pairs.
Instance Attribute Details
#notebook_instance_lifecycle_config_name ⇒ String
The name of the lifecycle configuration.
13223 13224 13225 13226 13227 13228 13229 13230 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13223 class CreateNotebookInstanceLifecycleConfigInput < Struct.new( :notebook_instance_lifecycle_config_name, :on_create, :on_start, :tags) SENSITIVE = [] include Aws::Structure end |
#on_create ⇒ Array<Types::NotebookInstanceLifecycleHook>
A shell script that runs only once, when you create a notebook instance. The shell script must be a base64-encoded string.
13223 13224 13225 13226 13227 13228 13229 13230 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13223 class CreateNotebookInstanceLifecycleConfigInput < Struct.new( :notebook_instance_lifecycle_config_name, :on_create, :on_start, :tags) SENSITIVE = [] include Aws::Structure end |
#on_start ⇒ Array<Types::NotebookInstanceLifecycleHook>
A shell script that runs every time you start a notebook instance, including when you create the notebook instance. The shell script must be a base64-encoded string.
13223 13224 13225 13226 13227 13228 13229 13230 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13223 class CreateNotebookInstanceLifecycleConfigInput < Struct.new( :notebook_instance_lifecycle_config_name, :on_create, :on_start, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
An array of key-value pairs. You can use tags to categorize your Amazon Web Services resources in different ways, for example, by purpose, owner, or environment. For more information, see Tagging Amazon Web Services Resources.
13223 13224 13225 13226 13227 13228 13229 13230 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13223 class CreateNotebookInstanceLifecycleConfigInput < Struct.new( :notebook_instance_lifecycle_config_name, :on_create, :on_start, :tags) SENSITIVE = [] include Aws::Structure end |