Class: Aws::SageMaker::Types::CreatePartnerAppRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreatePartnerAppRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_config ⇒ Types::PartnerAppConfig
Configuration settings for the SageMaker Partner AI App.
-
#auth_type ⇒ String
The authorization type that users use to access the SageMaker Partner AI App.
-
#client_token ⇒ String
A unique token that guarantees that the call to this API is idempotent.
-
#enable_auto_minor_version_upgrade ⇒ Boolean
When set to ‘TRUE`, the SageMaker Partner AI App is automatically upgraded to the latest minor version during the next scheduled maintenance window, if one is available.
-
#enable_iam_session_based_identity ⇒ Boolean
When set to ‘TRUE`, the SageMaker Partner AI App sets the Amazon Web Services IAM session name or the authenticated IAM user as the identity of the SageMaker Partner AI App user.
-
#execution_role_arn ⇒ String
The ARN of the IAM role that the partner application uses.
-
#kms_key_id ⇒ String
SageMaker Partner AI Apps uses Amazon Web Services KMS to encrypt data at rest using an Amazon Web Services managed key by default.
-
#maintenance_config ⇒ Types::PartnerAppMaintenanceConfig
Maintenance configuration settings for the SageMaker Partner AI App.
-
#name ⇒ String
The name to give the SageMaker Partner AI App.
-
#tags ⇒ Array<Types::Tag>
Each tag consists of a key and an optional value.
-
#tier ⇒ String
Indicates the instance type and size of the cluster attached to the SageMaker Partner AI App.
-
#type ⇒ String
The type of SageMaker Partner AI App to create.
Instance Attribute Details
#application_config ⇒ Types::PartnerAppConfig
Configuration settings for the SageMaker Partner AI App.
13072 13073 13074 13075 13076 13077 13078 13079 13080 13081 13082 13083 13084 13085 13086 13087 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13072 class CreatePartnerAppRequest < Struct.new( :name, :type, :execution_role_arn, :kms_key_id, :maintenance_config, :tier, :application_config, :auth_type, :enable_iam_session_based_identity, :enable_auto_minor_version_upgrade, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#auth_type ⇒ String
The authorization type that users use to access the SageMaker Partner AI App.
13072 13073 13074 13075 13076 13077 13078 13079 13080 13081 13082 13083 13084 13085 13086 13087 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13072 class CreatePartnerAppRequest < Struct.new( :name, :type, :execution_role_arn, :kms_key_id, :maintenance_config, :tier, :application_config, :auth_type, :enable_iam_session_based_identity, :enable_auto_minor_version_upgrade, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique token that guarantees that the call to this API is idempotent.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
13072 13073 13074 13075 13076 13077 13078 13079 13080 13081 13082 13083 13084 13085 13086 13087 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13072 class CreatePartnerAppRequest < Struct.new( :name, :type, :execution_role_arn, :kms_key_id, :maintenance_config, :tier, :application_config, :auth_type, :enable_iam_session_based_identity, :enable_auto_minor_version_upgrade, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#enable_auto_minor_version_upgrade ⇒ Boolean
When set to ‘TRUE`, the SageMaker Partner AI App is automatically upgraded to the latest minor version during the next scheduled maintenance window, if one is available. Default is `FALSE`.
13072 13073 13074 13075 13076 13077 13078 13079 13080 13081 13082 13083 13084 13085 13086 13087 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13072 class CreatePartnerAppRequest < Struct.new( :name, :type, :execution_role_arn, :kms_key_id, :maintenance_config, :tier, :application_config, :auth_type, :enable_iam_session_based_identity, :enable_auto_minor_version_upgrade, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#enable_iam_session_based_identity ⇒ Boolean
When set to ‘TRUE`, the SageMaker Partner AI App sets the Amazon Web Services IAM session name or the authenticated IAM user as the identity of the SageMaker Partner AI App user.
13072 13073 13074 13075 13076 13077 13078 13079 13080 13081 13082 13083 13084 13085 13086 13087 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13072 class CreatePartnerAppRequest < Struct.new( :name, :type, :execution_role_arn, :kms_key_id, :maintenance_config, :tier, :application_config, :auth_type, :enable_iam_session_based_identity, :enable_auto_minor_version_upgrade, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#execution_role_arn ⇒ String
The ARN of the IAM role that the partner application uses.
13072 13073 13074 13075 13076 13077 13078 13079 13080 13081 13082 13083 13084 13085 13086 13087 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13072 class CreatePartnerAppRequest < Struct.new( :name, :type, :execution_role_arn, :kms_key_id, :maintenance_config, :tier, :application_config, :auth_type, :enable_iam_session_based_identity, :enable_auto_minor_version_upgrade, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
SageMaker Partner AI Apps uses Amazon Web Services KMS to encrypt data at rest using an Amazon Web Services managed key by default. For more control, specify a customer managed key.
13072 13073 13074 13075 13076 13077 13078 13079 13080 13081 13082 13083 13084 13085 13086 13087 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13072 class CreatePartnerAppRequest < Struct.new( :name, :type, :execution_role_arn, :kms_key_id, :maintenance_config, :tier, :application_config, :auth_type, :enable_iam_session_based_identity, :enable_auto_minor_version_upgrade, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#maintenance_config ⇒ Types::PartnerAppMaintenanceConfig
Maintenance configuration settings for the SageMaker Partner AI App.
13072 13073 13074 13075 13076 13077 13078 13079 13080 13081 13082 13083 13084 13085 13086 13087 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13072 class CreatePartnerAppRequest < Struct.new( :name, :type, :execution_role_arn, :kms_key_id, :maintenance_config, :tier, :application_config, :auth_type, :enable_iam_session_based_identity, :enable_auto_minor_version_upgrade, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name to give the SageMaker Partner AI App.
13072 13073 13074 13075 13076 13077 13078 13079 13080 13081 13082 13083 13084 13085 13086 13087 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13072 class CreatePartnerAppRequest < Struct.new( :name, :type, :execution_role_arn, :kms_key_id, :maintenance_config, :tier, :application_config, :auth_type, :enable_iam_session_based_identity, :enable_auto_minor_version_upgrade, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Each tag consists of a key and an optional value. Tag keys must be unique per resource.
13072 13073 13074 13075 13076 13077 13078 13079 13080 13081 13082 13083 13084 13085 13086 13087 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13072 class CreatePartnerAppRequest < Struct.new( :name, :type, :execution_role_arn, :kms_key_id, :maintenance_config, :tier, :application_config, :auth_type, :enable_iam_session_based_identity, :enable_auto_minor_version_upgrade, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#tier ⇒ String
Indicates the instance type and size of the cluster attached to the SageMaker Partner AI App.
13072 13073 13074 13075 13076 13077 13078 13079 13080 13081 13082 13083 13084 13085 13086 13087 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13072 class CreatePartnerAppRequest < Struct.new( :name, :type, :execution_role_arn, :kms_key_id, :maintenance_config, :tier, :application_config, :auth_type, :enable_iam_session_based_identity, :enable_auto_minor_version_upgrade, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of SageMaker Partner AI App to create. Must be one of the following: ‘lakera-guard`, `comet`, `deepchecks-llm-evaluation`, or `fiddler`.
13072 13073 13074 13075 13076 13077 13078 13079 13080 13081 13082 13083 13084 13085 13086 13087 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13072 class CreatePartnerAppRequest < Struct.new( :name, :type, :execution_role_arn, :kms_key_id, :maintenance_config, :tier, :application_config, :auth_type, :enable_iam_session_based_identity, :enable_auto_minor_version_upgrade, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |