Class: Aws::SageMaker::Types::CreatePartnerAppRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_configTypes::PartnerAppConfig

Configuration settings for the SageMaker Partner AI App.



9571
9572
9573
9574
9575
9576
9577
9578
9579
9580
9581
9582
9583
9584
# File 'lib/aws-sdk-sagemaker/types.rb', line 9571

class CreatePartnerAppRequest < Struct.new(
  :name,
  :type,
  :execution_role_arn,
  :maintenance_config,
  :tier,
  :application_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#auth_typeString

The authorization type that users use to access the SageMaker Partner AI App.

Returns:

  • (String)


9571
9572
9573
9574
9575
9576
9577
9578
9579
9580
9581
9582
9583
9584
# File 'lib/aws-sdk-sagemaker/types.rb', line 9571

class CreatePartnerAppRequest < Struct.new(
  :name,
  :type,
  :execution_role_arn,
  :maintenance_config,
  :tier,
  :application_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique token that guarantees that the call to this API is idempotent.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


9571
9572
9573
9574
9575
9576
9577
9578
9579
9580
9581
9582
9583
9584
# File 'lib/aws-sdk-sagemaker/types.rb', line 9571

class CreatePartnerAppRequest < Struct.new(
  :name,
  :type,
  :execution_role_arn,
  :maintenance_config,
  :tier,
  :application_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#enable_iam_session_based_identityBoolean

When set to TRUE, the SageMaker Partner AI App sets the Amazon Web Services IAM session name or the authenticated IAM user as the identity of the SageMaker Partner AI App user.

Returns:

  • (Boolean)


9571
9572
9573
9574
9575
9576
9577
9578
9579
9580
9581
9582
9583
9584
# File 'lib/aws-sdk-sagemaker/types.rb', line 9571

class CreatePartnerAppRequest < Struct.new(
  :name,
  :type,
  :execution_role_arn,
  :maintenance_config,
  :tier,
  :application_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#execution_role_arnString

The ARN of the IAM role that the partner application uses.

Returns:

  • (String)


9571
9572
9573
9574
9575
9576
9577
9578
9579
9580
9581
9582
9583
9584
# File 'lib/aws-sdk-sagemaker/types.rb', line 9571

class CreatePartnerAppRequest < Struct.new(
  :name,
  :type,
  :execution_role_arn,
  :maintenance_config,
  :tier,
  :application_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#maintenance_configTypes::PartnerAppMaintenanceConfig

Maintenance configuration settings for the SageMaker Partner AI App.



9571
9572
9573
9574
9575
9576
9577
9578
9579
9580
9581
9582
9583
9584
# File 'lib/aws-sdk-sagemaker/types.rb', line 9571

class CreatePartnerAppRequest < Struct.new(
  :name,
  :type,
  :execution_role_arn,
  :maintenance_config,
  :tier,
  :application_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name to give the SageMaker Partner AI App.

Returns:

  • (String)


9571
9572
9573
9574
9575
9576
9577
9578
9579
9580
9581
9582
9583
9584
# File 'lib/aws-sdk-sagemaker/types.rb', line 9571

class CreatePartnerAppRequest < Struct.new(
  :name,
  :type,
  :execution_role_arn,
  :maintenance_config,
  :tier,
  :application_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Each tag consists of a key and an optional value. Tag keys must be unique per resource.

Returns:



9571
9572
9573
9574
9575
9576
9577
9578
9579
9580
9581
9582
9583
9584
# File 'lib/aws-sdk-sagemaker/types.rb', line 9571

class CreatePartnerAppRequest < Struct.new(
  :name,
  :type,
  :execution_role_arn,
  :maintenance_config,
  :tier,
  :application_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tierString

Indicates the instance type and size of the cluster attached to the SageMaker Partner AI App.

Returns:

  • (String)


9571
9572
9573
9574
9575
9576
9577
9578
9579
9580
9581
9582
9583
9584
# File 'lib/aws-sdk-sagemaker/types.rb', line 9571

class CreatePartnerAppRequest < Struct.new(
  :name,
  :type,
  :execution_role_arn,
  :maintenance_config,
  :tier,
  :application_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of SageMaker Partner AI App to create. Must be one of the following: lakera-guard, comet, deepchecks-llm-evaluation, or fiddler.

Returns:

  • (String)


9571
9572
9573
9574
9575
9576
9577
9578
9579
9580
9581
9582
9583
9584
# File 'lib/aws-sdk-sagemaker/types.rb', line 9571

class CreatePartnerAppRequest < Struct.new(
  :name,
  :type,
  :execution_role_arn,
  :maintenance_config,
  :tier,
  :application_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end