Class: Aws::SageMaker::Types::CreatePipelineRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreatePipelineRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_request_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the operation.
-
#parallelism_configuration ⇒ Types::ParallelismConfiguration
This is the configuration that controls the parallelism of the pipeline.
-
#pipeline_definition ⇒ String
The [JSON pipeline definition] of the pipeline.
-
#pipeline_definition_s3_location ⇒ Types::PipelineDefinitionS3Location
The location of the pipeline definition stored in Amazon S3.
-
#pipeline_description ⇒ String
A description of the pipeline.
-
#pipeline_display_name ⇒ String
The display name of the pipeline.
-
#pipeline_name ⇒ String
The name of the pipeline.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the role used by the pipeline to access and create resources.
-
#tags ⇒ Array<Types::Tag>
A list of tags to apply to the created pipeline.
Instance Attribute Details
#client_request_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the operation. An idempotent operation completes no more than one time.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
13153 13154 13155 13156 13157 13158 13159 13160 13161 13162 13163 13164 13165 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13153 class CreatePipelineRequest < Struct.new( :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_definition_s3_location, :pipeline_description, :client_request_token, :role_arn, :tags, :parallelism_configuration) SENSITIVE = [] include Aws::Structure end |
#parallelism_configuration ⇒ Types::ParallelismConfiguration
This is the configuration that controls the parallelism of the pipeline. If specified, it applies to all runs of this pipeline by default.
13153 13154 13155 13156 13157 13158 13159 13160 13161 13162 13163 13164 13165 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13153 class CreatePipelineRequest < Struct.new( :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_definition_s3_location, :pipeline_description, :client_request_token, :role_arn, :tags, :parallelism_configuration) SENSITIVE = [] include Aws::Structure end |
#pipeline_definition ⇒ String
The [JSON pipeline definition] of the pipeline.
[1]: aws-sagemaker-mlops.github.io/sagemaker-model-building-pipeline-definition-JSON-schema/
13153 13154 13155 13156 13157 13158 13159 13160 13161 13162 13163 13164 13165 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13153 class CreatePipelineRequest < Struct.new( :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_definition_s3_location, :pipeline_description, :client_request_token, :role_arn, :tags, :parallelism_configuration) SENSITIVE = [] include Aws::Structure end |
#pipeline_definition_s3_location ⇒ Types::PipelineDefinitionS3Location
The location of the pipeline definition stored in Amazon S3. If specified, SageMaker will retrieve the pipeline definition from this location.
13153 13154 13155 13156 13157 13158 13159 13160 13161 13162 13163 13164 13165 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13153 class CreatePipelineRequest < Struct.new( :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_definition_s3_location, :pipeline_description, :client_request_token, :role_arn, :tags, :parallelism_configuration) SENSITIVE = [] include Aws::Structure end |
#pipeline_description ⇒ String
A description of the pipeline.
13153 13154 13155 13156 13157 13158 13159 13160 13161 13162 13163 13164 13165 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13153 class CreatePipelineRequest < Struct.new( :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_definition_s3_location, :pipeline_description, :client_request_token, :role_arn, :tags, :parallelism_configuration) SENSITIVE = [] include Aws::Structure end |
#pipeline_display_name ⇒ String
The display name of the pipeline.
13153 13154 13155 13156 13157 13158 13159 13160 13161 13162 13163 13164 13165 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13153 class CreatePipelineRequest < Struct.new( :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_definition_s3_location, :pipeline_description, :client_request_token, :role_arn, :tags, :parallelism_configuration) SENSITIVE = [] include Aws::Structure end |
#pipeline_name ⇒ String
The name of the pipeline.
13153 13154 13155 13156 13157 13158 13159 13160 13161 13162 13163 13164 13165 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13153 class CreatePipelineRequest < Struct.new( :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_definition_s3_location, :pipeline_description, :client_request_token, :role_arn, :tags, :parallelism_configuration) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the role used by the pipeline to access and create resources.
13153 13154 13155 13156 13157 13158 13159 13160 13161 13162 13163 13164 13165 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13153 class CreatePipelineRequest < Struct.new( :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_definition_s3_location, :pipeline_description, :client_request_token, :role_arn, :tags, :parallelism_configuration) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of tags to apply to the created pipeline.
13153 13154 13155 13156 13157 13158 13159 13160 13161 13162 13163 13164 13165 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13153 class CreatePipelineRequest < Struct.new( :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_definition_s3_location, :pipeline_description, :client_request_token, :role_arn, :tags, :parallelism_configuration) SENSITIVE = [] include Aws::Structure end |