Class: Aws::SageMaker::Types::CreatePresignedDomainUrlRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreatePresignedDomainUrlRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_id ⇒ String
The domain ID.
-
#expires_in_seconds ⇒ Integer
The number of seconds until the pre-signed URL expires.
-
#landing_uri ⇒ String
The landing page that the user is directed to when accessing the presigned URL.
-
#session_expiration_duration_in_seconds ⇒ Integer
The session expiration duration in seconds.
-
#space_name ⇒ String
The name of the space.
-
#user_profile_name ⇒ String
The name of the UserProfile to sign-in as.
Instance Attribute Details
#domain_id ⇒ String
The domain ID.
13386 13387 13388 13389 13390 13391 13392 13393 13394 13395 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13386 class CreatePresignedDomainUrlRequest < Struct.new( :domain_id, :user_profile_name, :session_expiration_duration_in_seconds, :expires_in_seconds, :space_name, :landing_uri) SENSITIVE = [] include Aws::Structure end |
#expires_in_seconds ⇒ Integer
The number of seconds until the pre-signed URL expires. This value defaults to 300.
13386 13387 13388 13389 13390 13391 13392 13393 13394 13395 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13386 class CreatePresignedDomainUrlRequest < Struct.new( :domain_id, :user_profile_name, :session_expiration_duration_in_seconds, :expires_in_seconds, :space_name, :landing_uri) SENSITIVE = [] include Aws::Structure end |
#landing_uri ⇒ String
The landing page that the user is directed to when accessing the presigned URL. Using this value, users can access Studio or Studio Classic, even if it is not the default experience for the domain. The supported values are:
-
‘studio::relative/path`: Directs users to the relative path in Studio.
-
‘app:JupyterServer:relative/path`: Directs users to the relative path in the Studio Classic application.
-
‘app:JupyterLab:relative/path`: Directs users to the relative path in the JupyterLab application.
-
‘app:RStudioServerPro:relative/path`: Directs users to the relative path in the RStudio application.
-
‘app:CodeEditor:relative/path`: Directs users to the relative path in the Code Editor, based on Code-OSS, Visual Studio Code - Open Source application.
-
‘app:Canvas:relative/path`: Directs users to the relative path in the Canvas application.
13386 13387 13388 13389 13390 13391 13392 13393 13394 13395 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13386 class CreatePresignedDomainUrlRequest < Struct.new( :domain_id, :user_profile_name, :session_expiration_duration_in_seconds, :expires_in_seconds, :space_name, :landing_uri) SENSITIVE = [] include Aws::Structure end |
#session_expiration_duration_in_seconds ⇒ Integer
The session expiration duration in seconds. This value defaults to 43200.
13386 13387 13388 13389 13390 13391 13392 13393 13394 13395 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13386 class CreatePresignedDomainUrlRequest < Struct.new( :domain_id, :user_profile_name, :session_expiration_duration_in_seconds, :expires_in_seconds, :space_name, :landing_uri) SENSITIVE = [] include Aws::Structure end |
#space_name ⇒ String
The name of the space.
13386 13387 13388 13389 13390 13391 13392 13393 13394 13395 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13386 class CreatePresignedDomainUrlRequest < Struct.new( :domain_id, :user_profile_name, :session_expiration_duration_in_seconds, :expires_in_seconds, :space_name, :landing_uri) SENSITIVE = [] include Aws::Structure end |
#user_profile_name ⇒ String
The name of the UserProfile to sign-in as.
13386 13387 13388 13389 13390 13391 13392 13393 13394 13395 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13386 class CreatePresignedDomainUrlRequest < Struct.new( :domain_id, :user_profile_name, :session_expiration_duration_in_seconds, :expires_in_seconds, :space_name, :landing_uri) SENSITIVE = [] include Aws::Structure end |