Class: Aws::SageMaker::Types::CreatePresignedDomainUrlRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#domain_idString

The domain ID.

Returns:

  • (String)


13221
13222
13223
13224
13225
13226
13227
13228
13229
13230
# File 'lib/aws-sdk-sagemaker/types.rb', line 13221

class CreatePresignedDomainUrlRequest < Struct.new(
  :domain_id,
  :user_profile_name,
  :session_expiration_duration_in_seconds,
  :expires_in_seconds,
  :space_name,
  :landing_uri)
  SENSITIVE = []
  include Aws::Structure
end

#expires_in_secondsInteger

The number of seconds until the pre-signed URL expires. This value defaults to 300.

Returns:

  • (Integer)


13221
13222
13223
13224
13225
13226
13227
13228
13229
13230
# File 'lib/aws-sdk-sagemaker/types.rb', line 13221

class CreatePresignedDomainUrlRequest < Struct.new(
  :domain_id,
  :user_profile_name,
  :session_expiration_duration_in_seconds,
  :expires_in_seconds,
  :space_name,
  :landing_uri)
  SENSITIVE = []
  include Aws::Structure
end

#landing_uriString

The landing page that the user is directed to when accessing the presigned URL. Using this value, users can access Studio or Studio Classic, even if it is not the default experience for the domain. The supported values are:

  • ‘studio::relative/path`: Directs users to the relative path in Studio.

  • ‘app:JupyterServer:relative/path`: Directs users to the relative path in the Studio Classic application.

  • ‘app:JupyterLab:relative/path`: Directs users to the relative path in the JupyterLab application.

  • ‘app:RStudioServerPro:relative/path`: Directs users to the relative path in the RStudio application.

  • ‘app:CodeEditor:relative/path`: Directs users to the relative path in the Code Editor, based on Code-OSS, Visual Studio Code - Open Source application.

  • ‘app:Canvas:relative/path`: Directs users to the relative path in the Canvas application.

Returns:

  • (String)


13221
13222
13223
13224
13225
13226
13227
13228
13229
13230
# File 'lib/aws-sdk-sagemaker/types.rb', line 13221

class CreatePresignedDomainUrlRequest < Struct.new(
  :domain_id,
  :user_profile_name,
  :session_expiration_duration_in_seconds,
  :expires_in_seconds,
  :space_name,
  :landing_uri)
  SENSITIVE = []
  include Aws::Structure
end

#session_expiration_duration_in_secondsInteger

The session expiration duration in seconds. This value defaults to 43200.

Returns:

  • (Integer)


13221
13222
13223
13224
13225
13226
13227
13228
13229
13230
# File 'lib/aws-sdk-sagemaker/types.rb', line 13221

class CreatePresignedDomainUrlRequest < Struct.new(
  :domain_id,
  :user_profile_name,
  :session_expiration_duration_in_seconds,
  :expires_in_seconds,
  :space_name,
  :landing_uri)
  SENSITIVE = []
  include Aws::Structure
end

#space_nameString

The name of the space.

Returns:

  • (String)


13221
13222
13223
13224
13225
13226
13227
13228
13229
13230
# File 'lib/aws-sdk-sagemaker/types.rb', line 13221

class CreatePresignedDomainUrlRequest < Struct.new(
  :domain_id,
  :user_profile_name,
  :session_expiration_duration_in_seconds,
  :expires_in_seconds,
  :space_name,
  :landing_uri)
  SENSITIVE = []
  include Aws::Structure
end

#user_profile_nameString

The name of the UserProfile to sign-in as.

Returns:

  • (String)


13221
13222
13223
13224
13225
13226
13227
13228
13229
13230
# File 'lib/aws-sdk-sagemaker/types.rb', line 13221

class CreatePresignedDomainUrlRequest < Struct.new(
  :domain_id,
  :user_profile_name,
  :session_expiration_duration_in_seconds,
  :expires_in_seconds,
  :space_name,
  :landing_uri)
  SENSITIVE = []
  include Aws::Structure
end