Class: Aws::SageMaker::Types::CreateProcessingJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreateProcessingJobRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#app_specification ⇒ Types::AppSpecification
Configures the processing job to run a specified Docker container image.
-
#environment ⇒ Hash<String,String>
The environment variables to set in the Docker container.
-
#experiment_config ⇒ Types::ExperimentConfig
Associates a SageMaker job as a trial component with an experiment and trial.
-
#network_config ⇒ Types::NetworkConfig
Networking options for a processing job, such as whether to allow inbound and outbound network calls to and from processing containers, and the VPC subnets and security groups to use for VPC-enabled processing jobs.
-
#processing_inputs ⇒ Array<Types::ProcessingInput>
An array of inputs configuring the data to download into the processing container.
-
#processing_job_name ⇒ String
The name of the processing job.
-
#processing_output_config ⇒ Types::ProcessingOutputConfig
Output configuration for the processing job.
-
#processing_resources ⇒ Types::ProcessingResources
Identifies the resources, ML compute instances, and ML storage volumes to deploy for a processing job.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker can assume to perform tasks on your behalf.
-
#stopping_condition ⇒ Types::ProcessingStoppingCondition
The time limit for how long the processing job is allowed to run.
-
#tags ⇒ Array<Types::Tag>
(Optional) An array of key-value pairs.
Instance Attribute Details
#app_specification ⇒ Types::AppSpecification
Configures the processing job to run a specified Docker container image.
14021 14022 14023 14024 14025 14026 14027 14028 14029 14030 14031 14032 14033 14034 14035 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14021 class CreateProcessingJobRequest < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :tags, :experiment_config) SENSITIVE = [] include Aws::Structure end |
#environment ⇒ Hash<String,String>
The environment variables to set in the Docker container. Up to 100 key and values entries in the map are supported.
Do not include any security-sensitive information including account access IDs, secrets, or tokens in any environment fields. As part of the shared responsibility model, you are responsible for any potential exposure, unauthorized access, or compromise of your sensitive data if caused by security-sensitive information included in the request environment variable or plain text fields.
14021 14022 14023 14024 14025 14026 14027 14028 14029 14030 14031 14032 14033 14034 14035 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14021 class CreateProcessingJobRequest < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :tags, :experiment_config) SENSITIVE = [] include Aws::Structure end |
#experiment_config ⇒ Types::ExperimentConfig
Associates a SageMaker job as a trial component with an experiment and trial. Specified when you call the following APIs:
14021 14022 14023 14024 14025 14026 14027 14028 14029 14030 14031 14032 14033 14034 14035 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14021 class CreateProcessingJobRequest < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :tags, :experiment_config) SENSITIVE = [] include Aws::Structure end |
#network_config ⇒ Types::NetworkConfig
Networking options for a processing job, such as whether to allow inbound and outbound network calls to and from processing containers, and the VPC subnets and security groups to use for VPC-enabled processing jobs.
14021 14022 14023 14024 14025 14026 14027 14028 14029 14030 14031 14032 14033 14034 14035 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14021 class CreateProcessingJobRequest < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :tags, :experiment_config) SENSITIVE = [] include Aws::Structure end |
#processing_inputs ⇒ Array<Types::ProcessingInput>
An array of inputs configuring the data to download into the processing container.
14021 14022 14023 14024 14025 14026 14027 14028 14029 14030 14031 14032 14033 14034 14035 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14021 class CreateProcessingJobRequest < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :tags, :experiment_config) SENSITIVE = [] include Aws::Structure end |
#processing_job_name ⇒ String
The name of the processing job. The name must be unique within an Amazon Web Services Region in the Amazon Web Services account.
14021 14022 14023 14024 14025 14026 14027 14028 14029 14030 14031 14032 14033 14034 14035 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14021 class CreateProcessingJobRequest < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :tags, :experiment_config) SENSITIVE = [] include Aws::Structure end |
#processing_output_config ⇒ Types::ProcessingOutputConfig
Output configuration for the processing job.
14021 14022 14023 14024 14025 14026 14027 14028 14029 14030 14031 14032 14033 14034 14035 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14021 class CreateProcessingJobRequest < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :tags, :experiment_config) SENSITIVE = [] include Aws::Structure end |
#processing_resources ⇒ Types::ProcessingResources
Identifies the resources, ML compute instances, and ML storage volumes to deploy for a processing job. In distributed training, you specify more than one instance.
14021 14022 14023 14024 14025 14026 14027 14028 14029 14030 14031 14032 14033 14034 14035 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14021 class CreateProcessingJobRequest < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :tags, :experiment_config) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker can assume to perform tasks on your behalf.
14021 14022 14023 14024 14025 14026 14027 14028 14029 14030 14031 14032 14033 14034 14035 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14021 class CreateProcessingJobRequest < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :tags, :experiment_config) SENSITIVE = [] include Aws::Structure end |
#stopping_condition ⇒ Types::ProcessingStoppingCondition
The time limit for how long the processing job is allowed to run.
14021 14022 14023 14024 14025 14026 14027 14028 14029 14030 14031 14032 14033 14034 14035 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14021 class CreateProcessingJobRequest < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :tags, :experiment_config) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
(Optional) An array of key-value pairs. For more information, see Using Cost Allocation Tags in the Amazon Web Services Billing and Cost Management User Guide.
Do not include any security-sensitive information including account access IDs, secrets, or tokens in any tags. As part of the shared responsibility model, you are responsible for any potential exposure, unauthorized access, or compromise of your sensitive data if caused by security-sensitive information included in the request tag variable or plain text fields.
14021 14022 14023 14024 14025 14026 14027 14028 14029 14030 14031 14032 14033 14034 14035 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14021 class CreateProcessingJobRequest < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :tags, :experiment_config) SENSITIVE = [] include Aws::Structure end |