Class: Aws::SageMaker::Types::CreateProcessingJobRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#app_specificationTypes::AppSpecification

Configures the processing job to run a specified Docker container image.



13598
13599
13600
13601
13602
13603
13604
13605
13606
13607
13608
13609
13610
13611
13612
# File 'lib/aws-sdk-sagemaker/types.rb', line 13598

class CreateProcessingJobRequest < Struct.new(
  :processing_inputs,
  :processing_output_config,
  :processing_job_name,
  :processing_resources,
  :stopping_condition,
  :app_specification,
  :environment,
  :network_config,
  :role_arn,
  :tags,
  :experiment_config)
  SENSITIVE = []
  include Aws::Structure
end

#environmentHash<String,String>

The environment variables to set in the Docker container. Up to 100 key and values entries in the map are supported.

Do not include any security-sensitive information including account access IDs, secrets, or tokens in any environment fields. As part of the shared responsibility model, you are responsible for any potential exposure, unauthorized access, or compromise of your sensitive data if caused by security-sensitive information included in the request environment variable or plain text fields.

Returns:

  • (Hash<String,String>)


13598
13599
13600
13601
13602
13603
13604
13605
13606
13607
13608
13609
13610
13611
13612
# File 'lib/aws-sdk-sagemaker/types.rb', line 13598

class CreateProcessingJobRequest < Struct.new(
  :processing_inputs,
  :processing_output_config,
  :processing_job_name,
  :processing_resources,
  :stopping_condition,
  :app_specification,
  :environment,
  :network_config,
  :role_arn,
  :tags,
  :experiment_config)
  SENSITIVE = []
  include Aws::Structure
end

#experiment_configTypes::ExperimentConfig

Associates a SageMaker job as a trial component with an experiment and trial. Specified when you call the following APIs:

  • CreateProcessingJob][1
  • CreateTrainingJob][2
  • CreateTransformJob][3

[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateProcessingJob.html [2]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateTrainingJob.html [3]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateTransformJob.html



13598
13599
13600
13601
13602
13603
13604
13605
13606
13607
13608
13609
13610
13611
13612
# File 'lib/aws-sdk-sagemaker/types.rb', line 13598

class CreateProcessingJobRequest < Struct.new(
  :processing_inputs,
  :processing_output_config,
  :processing_job_name,
  :processing_resources,
  :stopping_condition,
  :app_specification,
  :environment,
  :network_config,
  :role_arn,
  :tags,
  :experiment_config)
  SENSITIVE = []
  include Aws::Structure
end

#network_configTypes::NetworkConfig

Networking options for a processing job, such as whether to allow inbound and outbound network calls to and from processing containers, and the VPC subnets and security groups to use for VPC-enabled processing jobs.



13598
13599
13600
13601
13602
13603
13604
13605
13606
13607
13608
13609
13610
13611
13612
# File 'lib/aws-sdk-sagemaker/types.rb', line 13598

class CreateProcessingJobRequest < Struct.new(
  :processing_inputs,
  :processing_output_config,
  :processing_job_name,
  :processing_resources,
  :stopping_condition,
  :app_specification,
  :environment,
  :network_config,
  :role_arn,
  :tags,
  :experiment_config)
  SENSITIVE = []
  include Aws::Structure
end

#processing_inputsArray<Types::ProcessingInput>

An array of inputs configuring the data to download into the processing container.

Returns:



13598
13599
13600
13601
13602
13603
13604
13605
13606
13607
13608
13609
13610
13611
13612
# File 'lib/aws-sdk-sagemaker/types.rb', line 13598

class CreateProcessingJobRequest < Struct.new(
  :processing_inputs,
  :processing_output_config,
  :processing_job_name,
  :processing_resources,
  :stopping_condition,
  :app_specification,
  :environment,
  :network_config,
  :role_arn,
  :tags,
  :experiment_config)
  SENSITIVE = []
  include Aws::Structure
end

#processing_job_nameString

The name of the processing job. The name must be unique within an Amazon Web Services Region in the Amazon Web Services account.

Returns:

  • (String)


13598
13599
13600
13601
13602
13603
13604
13605
13606
13607
13608
13609
13610
13611
13612
# File 'lib/aws-sdk-sagemaker/types.rb', line 13598

class CreateProcessingJobRequest < Struct.new(
  :processing_inputs,
  :processing_output_config,
  :processing_job_name,
  :processing_resources,
  :stopping_condition,
  :app_specification,
  :environment,
  :network_config,
  :role_arn,
  :tags,
  :experiment_config)
  SENSITIVE = []
  include Aws::Structure
end

#processing_output_configTypes::ProcessingOutputConfig

Output configuration for the processing job.



13598
13599
13600
13601
13602
13603
13604
13605
13606
13607
13608
13609
13610
13611
13612
# File 'lib/aws-sdk-sagemaker/types.rb', line 13598

class CreateProcessingJobRequest < Struct.new(
  :processing_inputs,
  :processing_output_config,
  :processing_job_name,
  :processing_resources,
  :stopping_condition,
  :app_specification,
  :environment,
  :network_config,
  :role_arn,
  :tags,
  :experiment_config)
  SENSITIVE = []
  include Aws::Structure
end

#processing_resourcesTypes::ProcessingResources

Identifies the resources, ML compute instances, and ML storage volumes to deploy for a processing job. In distributed training, you specify more than one instance.



13598
13599
13600
13601
13602
13603
13604
13605
13606
13607
13608
13609
13610
13611
13612
# File 'lib/aws-sdk-sagemaker/types.rb', line 13598

class CreateProcessingJobRequest < Struct.new(
  :processing_inputs,
  :processing_output_config,
  :processing_job_name,
  :processing_resources,
  :stopping_condition,
  :app_specification,
  :environment,
  :network_config,
  :role_arn,
  :tags,
  :experiment_config)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker can assume to perform tasks on your behalf.

Returns:

  • (String)


13598
13599
13600
13601
13602
13603
13604
13605
13606
13607
13608
13609
13610
13611
13612
# File 'lib/aws-sdk-sagemaker/types.rb', line 13598

class CreateProcessingJobRequest < Struct.new(
  :processing_inputs,
  :processing_output_config,
  :processing_job_name,
  :processing_resources,
  :stopping_condition,
  :app_specification,
  :environment,
  :network_config,
  :role_arn,
  :tags,
  :experiment_config)
  SENSITIVE = []
  include Aws::Structure
end

#stopping_conditionTypes::ProcessingStoppingCondition

The time limit for how long the processing job is allowed to run.



13598
13599
13600
13601
13602
13603
13604
13605
13606
13607
13608
13609
13610
13611
13612
# File 'lib/aws-sdk-sagemaker/types.rb', line 13598

class CreateProcessingJobRequest < Struct.new(
  :processing_inputs,
  :processing_output_config,
  :processing_job_name,
  :processing_resources,
  :stopping_condition,
  :app_specification,
  :environment,
  :network_config,
  :role_arn,
  :tags,
  :experiment_config)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

(Optional) An array of key-value pairs. For more information, see

Using Cost Allocation Tags][1

in the *Amazon Web Services Billing

and Cost Management User Guide*.

Do not include any security-sensitive information including account access IDs, secrets, or tokens in any tags. As part of the shared responsibility model, you are responsible for any potential exposure, unauthorized access, or compromise of your sensitive data if caused by security-sensitive information included in the request tag variable or plain text fields.

[1]: docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html#allocation-whatURL

Returns:



13598
13599
13600
13601
13602
13603
13604
13605
13606
13607
13608
13609
13610
13611
13612
# File 'lib/aws-sdk-sagemaker/types.rb', line 13598

class CreateProcessingJobRequest < Struct.new(
  :processing_inputs,
  :processing_output_config,
  :processing_job_name,
  :processing_resources,
  :stopping_condition,
  :app_specification,
  :environment,
  :network_config,
  :role_arn,
  :tags,
  :experiment_config)
  SENSITIVE = []
  include Aws::Structure
end