Class: Aws::SageMaker::Types::CreateTrialComponentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreateTrialComponentRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#display_name ⇒ String
The name of the component as displayed.
-
#end_time ⇒ Time
When the component ended.
-
#input_artifacts ⇒ Hash<String,Types::TrialComponentArtifact>
The input artifacts for the component.
-
#metadata_properties ⇒ Types::MetadataProperties
Metadata properties of the tracking entity, trial, or trial component.
-
#output_artifacts ⇒ Hash<String,Types::TrialComponentArtifact>
The output artifacts for the component.
-
#parameters ⇒ Hash<String,Types::TrialComponentParameterValue>
The hyperparameters for the component.
-
#start_time ⇒ Time
When the component started.
-
#status ⇒ Types::TrialComponentStatus
The status of the component.
-
#tags ⇒ Array<Types::Tag>
A list of tags to associate with the component.
-
#trial_component_name ⇒ String
The name of the component.
Instance Attribute Details
#display_name ⇒ String
The name of the component as displayed. The name doesn't need to be
unique. If DisplayName isn't specified, TrialComponentName is
displayed.
14813 14814 14815 14816 14817 14818 14819 14820 14821 14822 14823 14824 14825 14826 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14813 class CreateTrialComponentRequest < Struct.new( :trial_component_name, :display_name, :status, :start_time, :end_time, :parameters, :input_artifacts, :output_artifacts, :metadata_properties, :tags) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
When the component ended.
14813 14814 14815 14816 14817 14818 14819 14820 14821 14822 14823 14824 14825 14826 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14813 class CreateTrialComponentRequest < Struct.new( :trial_component_name, :display_name, :status, :start_time, :end_time, :parameters, :input_artifacts, :output_artifacts, :metadata_properties, :tags) SENSITIVE = [] include Aws::Structure end |
#input_artifacts ⇒ Hash<String,Types::TrialComponentArtifact>
The input artifacts for the component. Examples of input artifacts are datasets, algorithms, hyperparameters, source code, and instance types.
14813 14814 14815 14816 14817 14818 14819 14820 14821 14822 14823 14824 14825 14826 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14813 class CreateTrialComponentRequest < Struct.new( :trial_component_name, :display_name, :status, :start_time, :end_time, :parameters, :input_artifacts, :output_artifacts, :metadata_properties, :tags) SENSITIVE = [] include Aws::Structure end |
#metadata_properties ⇒ Types::MetadataProperties
Metadata properties of the tracking entity, trial, or trial component.
14813 14814 14815 14816 14817 14818 14819 14820 14821 14822 14823 14824 14825 14826 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14813 class CreateTrialComponentRequest < Struct.new( :trial_component_name, :display_name, :status, :start_time, :end_time, :parameters, :input_artifacts, :output_artifacts, :metadata_properties, :tags) SENSITIVE = [] include Aws::Structure end |
#output_artifacts ⇒ Hash<String,Types::TrialComponentArtifact>
The output artifacts for the component. Examples of output artifacts are metrics, snapshots, logs, and images.
14813 14814 14815 14816 14817 14818 14819 14820 14821 14822 14823 14824 14825 14826 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14813 class CreateTrialComponentRequest < Struct.new( :trial_component_name, :display_name, :status, :start_time, :end_time, :parameters, :input_artifacts, :output_artifacts, :metadata_properties, :tags) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Hash<String,Types::TrialComponentParameterValue>
The hyperparameters for the component.
14813 14814 14815 14816 14817 14818 14819 14820 14821 14822 14823 14824 14825 14826 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14813 class CreateTrialComponentRequest < Struct.new( :trial_component_name, :display_name, :status, :start_time, :end_time, :parameters, :input_artifacts, :output_artifacts, :metadata_properties, :tags) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
When the component started.
14813 14814 14815 14816 14817 14818 14819 14820 14821 14822 14823 14824 14825 14826 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14813 class CreateTrialComponentRequest < Struct.new( :trial_component_name, :display_name, :status, :start_time, :end_time, :parameters, :input_artifacts, :output_artifacts, :metadata_properties, :tags) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::TrialComponentStatus
The status of the component. States include:
-
InProgress
-
Completed
-
Failed
14813 14814 14815 14816 14817 14818 14819 14820 14821 14822 14823 14824 14825 14826 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14813 class CreateTrialComponentRequest < Struct.new( :trial_component_name, :display_name, :status, :start_time, :end_time, :parameters, :input_artifacts, :output_artifacts, :metadata_properties, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of tags to associate with the component. You can use Search API to search on the tags.
14813 14814 14815 14816 14817 14818 14819 14820 14821 14822 14823 14824 14825 14826 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14813 class CreateTrialComponentRequest < Struct.new( :trial_component_name, :display_name, :status, :start_time, :end_time, :parameters, :input_artifacts, :output_artifacts, :metadata_properties, :tags) SENSITIVE = [] include Aws::Structure end |
#trial_component_name ⇒ String
The name of the component. The name must be unique in your Amazon Web Services account and is not case-sensitive.
14813 14814 14815 14816 14817 14818 14819 14820 14821 14822 14823 14824 14825 14826 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14813 class CreateTrialComponentRequest < Struct.new( :trial_component_name, :display_name, :status, :start_time, :end_time, :parameters, :input_artifacts, :output_artifacts, :metadata_properties, :tags) SENSITIVE = [] include Aws::Structure end |