Class: Aws::SageMaker::Types::CreateTrialRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreateTrialRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#display_name ⇒ String
The name of the trial as displayed.
-
#experiment_name ⇒ String
The name of the experiment to associate the trial with.
-
#metadata_properties ⇒ Types::MetadataProperties
Metadata properties of the tracking entity, trial, or trial component.
-
#tags ⇒ Array<Types::Tag>
A list of tags to associate with the trial.
-
#trial_name ⇒ String
The name of the trial.
Instance Attribute Details
#display_name ⇒ String
The name of the trial as displayed. The name doesn’t need to be unique. If DisplayName isn’t specified, TrialName is displayed.
7950 7951 7952 7953 7954 7955 7956 7957 7958 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7950 class CreateTrialRequest < Struct.new( :trial_name, :display_name, :experiment_name, :metadata_properties, :tags) SENSITIVE = [] include Aws::Structure end |
#experiment_name ⇒ String
The name of the experiment to associate the trial with.
7950 7951 7952 7953 7954 7955 7956 7957 7958 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7950 class CreateTrialRequest < Struct.new( :trial_name, :display_name, :experiment_name, :metadata_properties, :tags) SENSITIVE = [] include Aws::Structure end |
#metadata_properties ⇒ Types::MetadataProperties
Metadata properties of the tracking entity, trial, or trial component.
7950 7951 7952 7953 7954 7955 7956 7957 7958 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7950 class CreateTrialRequest < Struct.new( :trial_name, :display_name, :experiment_name, :metadata_properties, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of tags to associate with the trial. You can use Search API to search on the tags.
7950 7951 7952 7953 7954 7955 7956 7957 7958 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7950 class CreateTrialRequest < Struct.new( :trial_name, :display_name, :experiment_name, :metadata_properties, :tags) SENSITIVE = [] include Aws::Structure end |
#trial_name ⇒ String
The name of the trial. The name must be unique in your Amazon Web Services account and is not case-sensitive.
7950 7951 7952 7953 7954 7955 7956 7957 7958 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 7950 class CreateTrialRequest < Struct.new( :trial_name, :display_name, :experiment_name, :metadata_properties, :tags) SENSITIVE = [] include Aws::Structure end |