Class: Aws::SageMaker::Types::CreateUserProfileRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#domain_idString

The ID of the associated Domain.

Returns:

  • (String)


14464
14465
14466
14467
14468
14469
14470
14471
14472
14473
# File 'lib/aws-sdk-sagemaker/types.rb', line 14464

class CreateUserProfileRequest < Struct.new(
  :domain_id,
  :user_profile_name,
  :single_sign_on_user_identifier,
  :single_sign_on_user_value,
  :tags,
  :user_settings)
  SENSITIVE = []
  include Aws::Structure
end

#single_sign_on_user_identifierString

A specifier for the type of value specified in SingleSignOnUserValue. Currently, the only supported value is “UserName”. If the Domain’s AuthMode is IAM Identity Center, this field is required. If the Domain’s AuthMode is not IAM Identity Center, this field cannot be specified.

Returns:

  • (String)


14464
14465
14466
14467
14468
14469
14470
14471
14472
14473
# File 'lib/aws-sdk-sagemaker/types.rb', line 14464

class CreateUserProfileRequest < Struct.new(
  :domain_id,
  :user_profile_name,
  :single_sign_on_user_identifier,
  :single_sign_on_user_value,
  :tags,
  :user_settings)
  SENSITIVE = []
  include Aws::Structure
end

#single_sign_on_user_valueString

The username of the associated Amazon Web Services Single Sign-On User for this UserProfile. If the Domain’s AuthMode is IAM Identity Center, this field is required, and must match a valid username of a user in your directory. If the Domain’s AuthMode is not IAM Identity Center, this field cannot be specified.

Returns:

  • (String)


14464
14465
14466
14467
14468
14469
14470
14471
14472
14473
# File 'lib/aws-sdk-sagemaker/types.rb', line 14464

class CreateUserProfileRequest < Struct.new(
  :domain_id,
  :user_profile_name,
  :single_sign_on_user_identifier,
  :single_sign_on_user_value,
  :tags,
  :user_settings)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Each tag consists of a key and an optional value. Tag keys must be unique per resource.

Tags that you specify for the User Profile are also added to all Apps that the User Profile launches.

Returns:



14464
14465
14466
14467
14468
14469
14470
14471
14472
14473
# File 'lib/aws-sdk-sagemaker/types.rb', line 14464

class CreateUserProfileRequest < Struct.new(
  :domain_id,
  :user_profile_name,
  :single_sign_on_user_identifier,
  :single_sign_on_user_value,
  :tags,
  :user_settings)
  SENSITIVE = []
  include Aws::Structure
end

#user_profile_nameString

A name for the UserProfile. This value is not case sensitive.

Returns:

  • (String)


14464
14465
14466
14467
14468
14469
14470
14471
14472
14473
# File 'lib/aws-sdk-sagemaker/types.rb', line 14464

class CreateUserProfileRequest < Struct.new(
  :domain_id,
  :user_profile_name,
  :single_sign_on_user_identifier,
  :single_sign_on_user_value,
  :tags,
  :user_settings)
  SENSITIVE = []
  include Aws::Structure
end

#user_settingsTypes::UserSettings

A collection of settings.

Returns:



14464
14465
14466
14467
14468
14469
14470
14471
14472
14473
# File 'lib/aws-sdk-sagemaker/types.rb', line 14464

class CreateUserProfileRequest < Struct.new(
  :domain_id,
  :user_profile_name,
  :single_sign_on_user_identifier,
  :single_sign_on_user_value,
  :tags,
  :user_settings)
  SENSITIVE = []
  include Aws::Structure
end