Class: Aws::SageMaker::Types::CreateWorkforceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CreateWorkforceRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cognito_config ⇒ Types::CognitoConfig
Use this parameter to configure an Amazon Cognito private workforce.
-
#ip_address_type ⇒ String
Use this parameter to specify whether you want
IPv4only ordualstack(IPv4andIPv6) to support your labeling workforce. -
#oidc_config ⇒ Types::OidcConfig
Use this parameter to configure a private workforce using your own OIDC Identity Provider.
-
#source_ip_config ⇒ Types::SourceIpConfig
A list of IP address ranges ([CIDRs]).
-
#tags ⇒ Array<Types::Tag>
An array of key-value pairs that contain metadata to help you categorize and organize our workforce.
-
#workforce_name ⇒ String
The name of the private workforce.
-
#workforce_vpc_config ⇒ Types::WorkforceVpcConfigRequest
Use this parameter to configure a workforce using VPC.
Instance Attribute Details
#cognito_config ⇒ Types::CognitoConfig
Use this parameter to configure an Amazon Cognito private workforce. A single Cognito workforce is created using and corresponds to a single [ Amazon Cognito user pool].
Do not use OidcConfig if you specify values for CognitoConfig.
[1]: docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-identity-pools.html
13332 13333 13334 13335 13336 13337 13338 13339 13340 13341 13342 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13332 class CreateWorkforceRequest < Struct.new( :cognito_config, :oidc_config, :source_ip_config, :workforce_name, :tags, :workforce_vpc_config, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#ip_address_type ⇒ String
Use this parameter to specify whether you want IPv4 only or dualstack (IPv4 and IPv6) to support your labeling workforce.
13332 13333 13334 13335 13336 13337 13338 13339 13340 13341 13342 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13332 class CreateWorkforceRequest < Struct.new( :cognito_config, :oidc_config, :source_ip_config, :workforce_name, :tags, :workforce_vpc_config, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#oidc_config ⇒ Types::OidcConfig
Use this parameter to configure a private workforce using your own OIDC Identity Provider.
Do not use CognitoConfig if you specify values for OidcConfig.
13332 13333 13334 13335 13336 13337 13338 13339 13340 13341 13342 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13332 class CreateWorkforceRequest < Struct.new( :cognito_config, :oidc_config, :source_ip_config, :workforce_name, :tags, :workforce_vpc_config, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#source_ip_config ⇒ Types::SourceIpConfig
A list of IP address ranges ([CIDRs]). Used to create an allow list of IP addresses for a private workforce. Workers will only be able to log in to their worker portal from an IP address within this range. By default, a workforce isn’t restricted to specific IP addresses.
[1]: docs.aws.amazon.com/vpc/latest/userguide/VPC_Subnets.html
13332 13333 13334 13335 13336 13337 13338 13339 13340 13341 13342 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13332 class CreateWorkforceRequest < Struct.new( :cognito_config, :oidc_config, :source_ip_config, :workforce_name, :tags, :workforce_vpc_config, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
An array of key-value pairs that contain metadata to help you categorize and organize our workforce. Each tag consists of a key and a value, both of which you define.
13332 13333 13334 13335 13336 13337 13338 13339 13340 13341 13342 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13332 class CreateWorkforceRequest < Struct.new( :cognito_config, :oidc_config, :source_ip_config, :workforce_name, :tags, :workforce_vpc_config, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#workforce_name ⇒ String
The name of the private workforce.
13332 13333 13334 13335 13336 13337 13338 13339 13340 13341 13342 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13332 class CreateWorkforceRequest < Struct.new( :cognito_config, :oidc_config, :source_ip_config, :workforce_name, :tags, :workforce_vpc_config, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#workforce_vpc_config ⇒ Types::WorkforceVpcConfigRequest
Use this parameter to configure a workforce using VPC.
13332 13333 13334 13335 13336 13337 13338 13339 13340 13341 13342 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13332 class CreateWorkforceRequest < Struct.new( :cognito_config, :oidc_config, :source_ip_config, :workforce_name, :tags, :workforce_vpc_config, :ip_address_type) SENSITIVE = [] include Aws::Structure end |