Class: Aws::SageMaker::Types::CustomFileSystemConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::CustomFileSystemConfig
- Includes:
- Aws::Structure, Aws::Structure::Union
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
CustomFileSystemConfig is a union - when making an API calls you must set exactly one of the members.
CustomFileSystemConfig is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of CustomFileSystemConfig corresponding to the set member.
The settings for assigning a custom file system to a user profile or space for an Amazon SageMaker AI Domain. Permitted users can access this file system in Amazon SageMaker AI Studio.
Direct Known Subclasses
EfsFileSystemConfig, FSxLustreFileSystemConfig, S3FileSystemConfig, Unknown
Defined Under Namespace
Classes: EfsFileSystemConfig, FSxLustreFileSystemConfig, S3FileSystemConfig, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#efs_file_system_config ⇒ Types::EFSFileSystemConfig
The settings for a custom Amazon EFS file system.
-
#f_sx_lustre_file_system_config ⇒ Types::FSxLustreFileSystemConfig
The settings for a custom Amazon FSx for Lustre file system.
-
#s3_file_system_config ⇒ Types::S3FileSystemConfig
Configuration settings for a custom Amazon S3 file system.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#efs_file_system_config ⇒ Types::EFSFileSystemConfig
The settings for a custom Amazon EFS file system.
14777 14778 14779 14780 14781 14782 14783 14784 14785 14786 14787 14788 14789 14790 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14777 class CustomFileSystemConfig < Struct.new( :efs_file_system_config, :f_sx_lustre_file_system_config, :s3_file_system_config, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class EfsFileSystemConfig < CustomFileSystemConfig; end class FSxLustreFileSystemConfig < CustomFileSystemConfig; end class S3FileSystemConfig < CustomFileSystemConfig; end class Unknown < CustomFileSystemConfig; end end |
#f_sx_lustre_file_system_config ⇒ Types::FSxLustreFileSystemConfig
The settings for a custom Amazon FSx for Lustre file system.
14777 14778 14779 14780 14781 14782 14783 14784 14785 14786 14787 14788 14789 14790 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14777 class CustomFileSystemConfig < Struct.new( :efs_file_system_config, :f_sx_lustre_file_system_config, :s3_file_system_config, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class EfsFileSystemConfig < CustomFileSystemConfig; end class FSxLustreFileSystemConfig < CustomFileSystemConfig; end class S3FileSystemConfig < CustomFileSystemConfig; end class Unknown < CustomFileSystemConfig; end end |
#s3_file_system_config ⇒ Types::S3FileSystemConfig
Configuration settings for a custom Amazon S3 file system.
14777 14778 14779 14780 14781 14782 14783 14784 14785 14786 14787 14788 14789 14790 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14777 class CustomFileSystemConfig < Struct.new( :efs_file_system_config, :f_sx_lustre_file_system_config, :s3_file_system_config, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class EfsFileSystemConfig < CustomFileSystemConfig; end class FSxLustreFileSystemConfig < CustomFileSystemConfig; end class S3FileSystemConfig < CustomFileSystemConfig; end class Unknown < CustomFileSystemConfig; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
14777 14778 14779 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14777 def unknown @unknown end |