Class: Aws::SageMaker::Types::DataQualityBaselineConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Configuration for monitoring constraints and monitoring statistics. These baseline resources are compared against the results of the current job from the series of jobs scheduled to collect data periodically.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#baselining_job_nameString

The name of the job that performs baselining for the data quality monitoring job.

Returns:

  • (String)


15174
15175
15176
15177
15178
15179
15180
# File 'lib/aws-sdk-sagemaker/types.rb', line 15174

class DataQualityBaselineConfig < Struct.new(
  :baselining_job_name,
  :constraints_resource,
  :statistics_resource)
  SENSITIVE = []
  include Aws::Structure
end

#constraints_resourceTypes::MonitoringConstraintsResource

The constraints resource for a monitoring job.



15174
15175
15176
15177
15178
15179
15180
# File 'lib/aws-sdk-sagemaker/types.rb', line 15174

class DataQualityBaselineConfig < Struct.new(
  :baselining_job_name,
  :constraints_resource,
  :statistics_resource)
  SENSITIVE = []
  include Aws::Structure
end

#statistics_resourceTypes::MonitoringStatisticsResource

The statistics resource for a monitoring job.



15174
15175
15176
15177
15178
15179
15180
# File 'lib/aws-sdk-sagemaker/types.rb', line 15174

class DataQualityBaselineConfig < Struct.new(
  :baselining_job_name,
  :constraints_resource,
  :statistics_resource)
  SENSITIVE = []
  include Aws::Structure
end