Class: Aws::SageMaker::Types::DataQualityBaselineConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DataQualityBaselineConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Configuration for monitoring constraints and monitoring statistics. These baseline resources are compared against the results of the current job from the series of jobs scheduled to collect data periodically.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#baselining_job_name ⇒ String
The name of the job that performs baselining for the data quality monitoring job.
-
#constraints_resource ⇒ Types::MonitoringConstraintsResource
The constraints resource for a monitoring job.
-
#statistics_resource ⇒ Types::MonitoringStatisticsResource
The statistics resource for a monitoring job.
Instance Attribute Details
#baselining_job_name ⇒ String
The name of the job that performs baselining for the data quality monitoring job.
14916 14917 14918 14919 14920 14921 14922 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14916 class DataQualityBaselineConfig < Struct.new( :baselining_job_name, :constraints_resource, :statistics_resource) SENSITIVE = [] include Aws::Structure end |
#constraints_resource ⇒ Types::MonitoringConstraintsResource
The constraints resource for a monitoring job.
14916 14917 14918 14919 14920 14921 14922 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14916 class DataQualityBaselineConfig < Struct.new( :baselining_job_name, :constraints_resource, :statistics_resource) SENSITIVE = [] include Aws::Structure end |
#statistics_resource ⇒ Types::MonitoringStatisticsResource
The statistics resource for a monitoring job.
14916 14917 14918 14919 14920 14921 14922 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14916 class DataQualityBaselineConfig < Struct.new( :baselining_job_name, :constraints_resource, :statistics_resource) SENSITIVE = [] include Aws::Structure end |