Class: Aws::SageMaker::Types::DebugHookConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DebugHookConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Configuration information for the Amazon SageMaker Debugger hook
parameters, metric and tensor collections, and storage paths. To learn
more about how to configure the DebugHookConfig parameter, see Use
the SageMaker and Debugger Configuration API Operations to Create,
Update, and Debug Your Training Job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#collection_configurations ⇒ Array<Types::CollectionConfiguration>
Configuration information for Amazon SageMaker Debugger tensor collections.
-
#hook_parameters ⇒ Hash<String,String>
Configuration information for the Amazon SageMaker Debugger hook parameters.
-
#local_path ⇒ String
Path to local storage location for metrics and tensors.
-
#s3_output_path ⇒ String
Path to Amazon S3 storage location for metrics and tensors.
Instance Attribute Details
#collection_configurations ⇒ Array<Types::CollectionConfiguration>
Configuration information for Amazon SageMaker Debugger tensor
collections. To learn more about how to configure the
CollectionConfiguration parameter, see Use the SageMaker and
Debugger Configuration API Operations to Create, Update, and Debug
Your Training Job.
15682 15683 15684 15685 15686 15687 15688 15689 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 15682 class DebugHookConfig < Struct.new( :local_path, :s3_output_path, :hook_parameters, :collection_configurations) SENSITIVE = [] include Aws::Structure end |
#hook_parameters ⇒ Hash<String,String>
Configuration information for the Amazon SageMaker Debugger hook parameters.
15682 15683 15684 15685 15686 15687 15688 15689 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 15682 class DebugHookConfig < Struct.new( :local_path, :s3_output_path, :hook_parameters, :collection_configurations) SENSITIVE = [] include Aws::Structure end |
#local_path ⇒ String
Path to local storage location for metrics and tensors. Defaults to
/opt/ml/output/tensors/.
15682 15683 15684 15685 15686 15687 15688 15689 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 15682 class DebugHookConfig < Struct.new( :local_path, :s3_output_path, :hook_parameters, :collection_configurations) SENSITIVE = [] include Aws::Structure end |
#s3_output_path ⇒ String
Path to Amazon S3 storage location for metrics and tensors.
15682 15683 15684 15685 15686 15687 15688 15689 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 15682 class DebugHookConfig < Struct.new( :local_path, :s3_output_path, :hook_parameters, :collection_configurations) SENSITIVE = [] include Aws::Structure end |