Class: Aws::SageMaker::Types::DebugRuleConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Configuration information for SageMaker Debugger rules for debugging. To learn more about how to configure the DebugRuleConfiguration parameter, see Use the SageMaker and Debugger Configuration API Operations to Create, Update, and Debug Your Training Job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_typeString

The instance type to deploy a custom rule for debugging a training job.

Returns:

  • (String)


15586
15587
15588
15589
15590
15591
15592
15593
15594
15595
15596
# File 'lib/aws-sdk-sagemaker/types.rb', line 15586

class DebugRuleConfiguration < Struct.new(
  :rule_configuration_name,
  :local_path,
  :s3_output_path,
  :rule_evaluator_image,
  :instance_type,
  :volume_size_in_gb,
  :rule_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#local_pathString

Path to local storage location for output of rules. Defaults to /opt/ml/processing/output/rule/.

Returns:

  • (String)


15586
15587
15588
15589
15590
15591
15592
15593
15594
15595
15596
# File 'lib/aws-sdk-sagemaker/types.rb', line 15586

class DebugRuleConfiguration < Struct.new(
  :rule_configuration_name,
  :local_path,
  :s3_output_path,
  :rule_evaluator_image,
  :instance_type,
  :volume_size_in_gb,
  :rule_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#rule_configuration_nameString

The name of the rule configuration. It must be unique relative to other rule configuration names.

Returns:

  • (String)


15586
15587
15588
15589
15590
15591
15592
15593
15594
15595
15596
# File 'lib/aws-sdk-sagemaker/types.rb', line 15586

class DebugRuleConfiguration < Struct.new(
  :rule_configuration_name,
  :local_path,
  :s3_output_path,
  :rule_evaluator_image,
  :instance_type,
  :volume_size_in_gb,
  :rule_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#rule_evaluator_imageString

The Amazon Elastic Container (ECR) Image for the managed rule evaluation.

Returns:

  • (String)


15586
15587
15588
15589
15590
15591
15592
15593
15594
15595
15596
# File 'lib/aws-sdk-sagemaker/types.rb', line 15586

class DebugRuleConfiguration < Struct.new(
  :rule_configuration_name,
  :local_path,
  :s3_output_path,
  :rule_evaluator_image,
  :instance_type,
  :volume_size_in_gb,
  :rule_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#rule_parametersHash<String,String>

Runtime configuration for rule container.

Returns:

  • (Hash<String,String>)


15586
15587
15588
15589
15590
15591
15592
15593
15594
15595
15596
# File 'lib/aws-sdk-sagemaker/types.rb', line 15586

class DebugRuleConfiguration < Struct.new(
  :rule_configuration_name,
  :local_path,
  :s3_output_path,
  :rule_evaluator_image,
  :instance_type,
  :volume_size_in_gb,
  :rule_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#s3_output_pathString

Path to Amazon S3 storage location for rules.

Returns:

  • (String)


15586
15587
15588
15589
15590
15591
15592
15593
15594
15595
15596
# File 'lib/aws-sdk-sagemaker/types.rb', line 15586

class DebugRuleConfiguration < Struct.new(
  :rule_configuration_name,
  :local_path,
  :s3_output_path,
  :rule_evaluator_image,
  :instance_type,
  :volume_size_in_gb,
  :rule_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#volume_size_in_gbInteger

The size, in GB, of the ML storage volume attached to the processing instance.

Returns:

  • (Integer)


15586
15587
15588
15589
15590
15591
15592
15593
15594
15595
15596
# File 'lib/aws-sdk-sagemaker/types.rb', line 15586

class DebugRuleConfiguration < Struct.new(
  :rule_configuration_name,
  :local_path,
  :s3_output_path,
  :rule_evaluator_image,
  :instance_type,
  :volume_size_in_gb,
  :rule_parameters)
  SENSITIVE = []
  include Aws::Structure
end