Class: Aws::SageMaker::Types::DefaultSpaceSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DefaultSpaceSettings
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The default settings for shared spaces that users create in the domain.
SageMaker applies these settings only to shared spaces. It doesn’t apply them to private spaces.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#custom_file_system_configs ⇒ Array<Types::CustomFileSystemConfig>
The settings for assigning a custom file system to a domain.
-
#custom_posix_user_config ⇒ Types::CustomPosixUserConfig
Details about the POSIX identity that is used for file system operations.
-
#execution_role ⇒ String
The ARN of the execution role for the space.
-
#jupyter_lab_app_settings ⇒ Types::JupyterLabAppSettings
The settings for the JupyterLab application.
-
#jupyter_server_app_settings ⇒ Types::JupyterServerAppSettings
The JupyterServer app settings.
-
#kernel_gateway_app_settings ⇒ Types::KernelGatewayAppSettings
The KernelGateway app settings.
-
#security_groups ⇒ Array<String>
The security group IDs for the Amazon VPC that the space uses for communication.
-
#space_storage_settings ⇒ Types::DefaultSpaceStorageSettings
The default storage settings for a space.
Instance Attribute Details
#custom_file_system_configs ⇒ Array<Types::CustomFileSystemConfig>
The settings for assigning a custom file system to a domain. Permitted users can access this file system in Amazon SageMaker AI Studio.
15229 15230 15231 15232 15233 15234 15235 15236 15237 15238 15239 15240 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 15229 class DefaultSpaceSettings < Struct.new( :execution_role, :security_groups, :jupyter_server_app_settings, :kernel_gateway_app_settings, :jupyter_lab_app_settings, :space_storage_settings, :custom_posix_user_config, :custom_file_system_configs) SENSITIVE = [] include Aws::Structure end |
#custom_posix_user_config ⇒ Types::CustomPosixUserConfig
Details about the POSIX identity that is used for file system operations.
15229 15230 15231 15232 15233 15234 15235 15236 15237 15238 15239 15240 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 15229 class DefaultSpaceSettings < Struct.new( :execution_role, :security_groups, :jupyter_server_app_settings, :kernel_gateway_app_settings, :jupyter_lab_app_settings, :space_storage_settings, :custom_posix_user_config, :custom_file_system_configs) SENSITIVE = [] include Aws::Structure end |
#execution_role ⇒ String
The ARN of the execution role for the space.
15229 15230 15231 15232 15233 15234 15235 15236 15237 15238 15239 15240 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 15229 class DefaultSpaceSettings < Struct.new( :execution_role, :security_groups, :jupyter_server_app_settings, :kernel_gateway_app_settings, :jupyter_lab_app_settings, :space_storage_settings, :custom_posix_user_config, :custom_file_system_configs) SENSITIVE = [] include Aws::Structure end |
#jupyter_lab_app_settings ⇒ Types::JupyterLabAppSettings
The settings for the JupyterLab application.
15229 15230 15231 15232 15233 15234 15235 15236 15237 15238 15239 15240 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 15229 class DefaultSpaceSettings < Struct.new( :execution_role, :security_groups, :jupyter_server_app_settings, :kernel_gateway_app_settings, :jupyter_lab_app_settings, :space_storage_settings, :custom_posix_user_config, :custom_file_system_configs) SENSITIVE = [] include Aws::Structure end |
#jupyter_server_app_settings ⇒ Types::JupyterServerAppSettings
The JupyterServer app settings.
15229 15230 15231 15232 15233 15234 15235 15236 15237 15238 15239 15240 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 15229 class DefaultSpaceSettings < Struct.new( :execution_role, :security_groups, :jupyter_server_app_settings, :kernel_gateway_app_settings, :jupyter_lab_app_settings, :space_storage_settings, :custom_posix_user_config, :custom_file_system_configs) SENSITIVE = [] include Aws::Structure end |
#kernel_gateway_app_settings ⇒ Types::KernelGatewayAppSettings
The KernelGateway app settings.
15229 15230 15231 15232 15233 15234 15235 15236 15237 15238 15239 15240 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 15229 class DefaultSpaceSettings < Struct.new( :execution_role, :security_groups, :jupyter_server_app_settings, :kernel_gateway_app_settings, :jupyter_lab_app_settings, :space_storage_settings, :custom_posix_user_config, :custom_file_system_configs) SENSITIVE = [] include Aws::Structure end |
#security_groups ⇒ Array<String>
The security group IDs for the Amazon VPC that the space uses for communication.
15229 15230 15231 15232 15233 15234 15235 15236 15237 15238 15239 15240 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 15229 class DefaultSpaceSettings < Struct.new( :execution_role, :security_groups, :jupyter_server_app_settings, :kernel_gateway_app_settings, :jupyter_lab_app_settings, :space_storage_settings, :custom_posix_user_config, :custom_file_system_configs) SENSITIVE = [] include Aws::Structure end |
#space_storage_settings ⇒ Types::DefaultSpaceStorageSettings
The default storage settings for a space.
15229 15230 15231 15232 15233 15234 15235 15236 15237 15238 15239 15240 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 15229 class DefaultSpaceSettings < Struct.new( :execution_role, :security_groups, :jupyter_server_app_settings, :kernel_gateway_app_settings, :jupyter_lab_app_settings, :space_storage_settings, :custom_posix_user_config, :custom_file_system_configs) SENSITIVE = [] include Aws::Structure end |