Class: Aws::SageMaker::Types::DeleteDomainRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#domain_idString

The domain ID.

Returns:

  • (String)


16049
16050
16051
16052
16053
16054
# File 'lib/aws-sdk-sagemaker/types.rb', line 16049

class DeleteDomainRequest < Struct.new(
  :domain_id,
  :retention_policy)
  SENSITIVE = []
  include Aws::Structure
end

#retention_policyTypes::RetentionPolicy

The retention policy for this domain, which specifies whether resources will be retained after the Domain is deleted. By default, all resources are retained (not automatically deleted).



16049
16050
16051
16052
16053
16054
# File 'lib/aws-sdk-sagemaker/types.rb', line 16049

class DeleteDomainRequest < Struct.new(
  :domain_id,
  :retention_policy)
  SENSITIVE = []
  include Aws::Structure
end