Class: Aws::SageMaker::Types::DeleteDomainRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DeleteDomainRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_id ⇒ String
The domain ID.
-
#retention_policy ⇒ Types::RetentionPolicy
The retention policy for this domain, which specifies whether resources will be retained after the Domain is deleted.
Instance Attribute Details
#domain_id ⇒ String
The domain ID.
15758 15759 15760 15761 15762 15763 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 15758 class DeleteDomainRequest < Struct.new( :domain_id, :retention_policy) SENSITIVE = [] include Aws::Structure end |
#retention_policy ⇒ Types::RetentionPolicy
The retention policy for this domain, which specifies whether resources will be retained after the Domain is deleted. By default, all resources are retained (not automatically deleted).
15758 15759 15760 15761 15762 15763 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 15758 class DeleteDomainRequest < Struct.new( :domain_id, :retention_policy) SENSITIVE = [] include Aws::Structure end |