Class: Aws::SageMaker::Types::DeleteFeatureGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DeleteFeatureGroupRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#feature_group_name ⇒ String
The name of the
FeatureGroupyou want to delete.
Instance Attribute Details
#feature_group_name ⇒ String
The name of the FeatureGroup you want to delete. The name must be unique within an Amazon Web Services Region in an Amazon Web Services account.
9050 9051 9052 9053 9054 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 9050 class DeleteFeatureGroupRequest < Struct.new( :feature_group_name) SENSITIVE = [] include Aws::Structure end |