Method: Aws::SageMaker::Types::DeletePipelineRequest#client_request_token
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
#client_request_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the operation. An idempotent operation completes no more than one time.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
14994 14995 14996 14997 14998 14999 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 14994 class DeletePipelineRequest < Struct.new( :pipeline_name, :client_request_token) SENSITIVE = [] include Aws::Structure end |