Class: Aws::SageMaker::Types::DeploymentConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The deployment configuration for an endpoint, which contains the desired deployment strategy and rollback configurations.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_rollback_configurationTypes::AutoRollbackConfig

Automatic rollback configuration for handling endpoint deployment failures and recovery.



16650
16651
16652
16653
16654
16655
16656
# File 'lib/aws-sdk-sagemaker/types.rb', line 16650

class DeploymentConfig < Struct.new(
  :blue_green_update_policy,
  :rolling_update_policy,
  :auto_rollback_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#blue_green_update_policyTypes::BlueGreenUpdatePolicy

Update policy for a blue/green deployment. If this update policy is specified, SageMaker creates a new fleet during the deployment while maintaining the old fleet. SageMaker flips traffic to the new fleet according to the specified traffic routing configuration. Only one update policy should be used in the deployment configuration. If no update policy is specified, SageMaker uses a blue/green deployment strategy with all at once traffic shifting by default.



16650
16651
16652
16653
16654
16655
16656
# File 'lib/aws-sdk-sagemaker/types.rb', line 16650

class DeploymentConfig < Struct.new(
  :blue_green_update_policy,
  :rolling_update_policy,
  :auto_rollback_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#rolling_update_policyTypes::RollingUpdatePolicy

Specifies a rolling deployment strategy for updating a SageMaker endpoint.



16650
16651
16652
16653
16654
16655
16656
# File 'lib/aws-sdk-sagemaker/types.rb', line 16650

class DeploymentConfig < Struct.new(
  :blue_green_update_policy,
  :rolling_update_policy,
  :auto_rollback_configuration)
  SENSITIVE = []
  include Aws::Structure
end