Class: Aws::SageMaker::Types::DescribeAIBenchmarkJobResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeAIBenchmarkJobResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ai_benchmark_job_arn ⇒ String
The Amazon Resource Name (ARN) of the AI benchmark job.
-
#ai_benchmark_job_name ⇒ String
The name of the AI benchmark job.
-
#ai_benchmark_job_status ⇒ String
The status of the AI benchmark job.
-
#ai_workload_config_identifier ⇒ String
The name or Amazon Resource Name (ARN) of the AI workload configuration used for this benchmark job.
-
#benchmark_target ⇒ Types::AIBenchmarkTarget
The target endpoint that was benchmarked.
-
#creation_time ⇒ Time
A timestamp that indicates when the benchmark job was created.
-
#end_time ⇒ Time
A timestamp that indicates when the benchmark job completed.
-
#failure_reason ⇒ String
If the benchmark job failed, the reason it failed.
-
#network_config ⇒ Types::AIBenchmarkNetworkConfig
The network configuration for the benchmark job.
-
#output_config ⇒ Types::AIBenchmarkOutputResult
The output configuration for the benchmark job, including the Amazon S3 output location and CloudWatch log information.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role used by the benchmark job.
-
#start_time ⇒ Time
A timestamp that indicates when the benchmark job started running.
-
#tags ⇒ Array<Types::Tag>
The tags associated with the benchmark job.
Instance Attribute Details
#ai_benchmark_job_arn ⇒ String
The Amazon Resource Name (ARN) of the AI benchmark job.
17298 17299 17300 17301 17302 17303 17304 17305 17306 17307 17308 17309 17310 17311 17312 17313 17314 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17298 class DescribeAIBenchmarkJobResponse < Struct.new( :ai_benchmark_job_name, :ai_benchmark_job_arn, :ai_benchmark_job_status, :failure_reason, :benchmark_target, :output_config, :ai_workload_config_identifier, :role_arn, :network_config, :creation_time, :start_time, :end_time, :tags) SENSITIVE = [] include Aws::Structure end |
#ai_benchmark_job_name ⇒ String
The name of the AI benchmark job.
17298 17299 17300 17301 17302 17303 17304 17305 17306 17307 17308 17309 17310 17311 17312 17313 17314 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17298 class DescribeAIBenchmarkJobResponse < Struct.new( :ai_benchmark_job_name, :ai_benchmark_job_arn, :ai_benchmark_job_status, :failure_reason, :benchmark_target, :output_config, :ai_workload_config_identifier, :role_arn, :network_config, :creation_time, :start_time, :end_time, :tags) SENSITIVE = [] include Aws::Structure end |
#ai_benchmark_job_status ⇒ String
The status of the AI benchmark job.
17298 17299 17300 17301 17302 17303 17304 17305 17306 17307 17308 17309 17310 17311 17312 17313 17314 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17298 class DescribeAIBenchmarkJobResponse < Struct.new( :ai_benchmark_job_name, :ai_benchmark_job_arn, :ai_benchmark_job_status, :failure_reason, :benchmark_target, :output_config, :ai_workload_config_identifier, :role_arn, :network_config, :creation_time, :start_time, :end_time, :tags) SENSITIVE = [] include Aws::Structure end |
#ai_workload_config_identifier ⇒ String
The name or Amazon Resource Name (ARN) of the AI workload configuration used for this benchmark job.
17298 17299 17300 17301 17302 17303 17304 17305 17306 17307 17308 17309 17310 17311 17312 17313 17314 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17298 class DescribeAIBenchmarkJobResponse < Struct.new( :ai_benchmark_job_name, :ai_benchmark_job_arn, :ai_benchmark_job_status, :failure_reason, :benchmark_target, :output_config, :ai_workload_config_identifier, :role_arn, :network_config, :creation_time, :start_time, :end_time, :tags) SENSITIVE = [] include Aws::Structure end |
#benchmark_target ⇒ Types::AIBenchmarkTarget
The target endpoint that was benchmarked.
17298 17299 17300 17301 17302 17303 17304 17305 17306 17307 17308 17309 17310 17311 17312 17313 17314 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17298 class DescribeAIBenchmarkJobResponse < Struct.new( :ai_benchmark_job_name, :ai_benchmark_job_arn, :ai_benchmark_job_status, :failure_reason, :benchmark_target, :output_config, :ai_workload_config_identifier, :role_arn, :network_config, :creation_time, :start_time, :end_time, :tags) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
A timestamp that indicates when the benchmark job was created.
17298 17299 17300 17301 17302 17303 17304 17305 17306 17307 17308 17309 17310 17311 17312 17313 17314 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17298 class DescribeAIBenchmarkJobResponse < Struct.new( :ai_benchmark_job_name, :ai_benchmark_job_arn, :ai_benchmark_job_status, :failure_reason, :benchmark_target, :output_config, :ai_workload_config_identifier, :role_arn, :network_config, :creation_time, :start_time, :end_time, :tags) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
A timestamp that indicates when the benchmark job completed.
17298 17299 17300 17301 17302 17303 17304 17305 17306 17307 17308 17309 17310 17311 17312 17313 17314 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17298 class DescribeAIBenchmarkJobResponse < Struct.new( :ai_benchmark_job_name, :ai_benchmark_job_arn, :ai_benchmark_job_status, :failure_reason, :benchmark_target, :output_config, :ai_workload_config_identifier, :role_arn, :network_config, :creation_time, :start_time, :end_time, :tags) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
If the benchmark job failed, the reason it failed.
17298 17299 17300 17301 17302 17303 17304 17305 17306 17307 17308 17309 17310 17311 17312 17313 17314 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17298 class DescribeAIBenchmarkJobResponse < Struct.new( :ai_benchmark_job_name, :ai_benchmark_job_arn, :ai_benchmark_job_status, :failure_reason, :benchmark_target, :output_config, :ai_workload_config_identifier, :role_arn, :network_config, :creation_time, :start_time, :end_time, :tags) SENSITIVE = [] include Aws::Structure end |
#network_config ⇒ Types::AIBenchmarkNetworkConfig
The network configuration for the benchmark job.
17298 17299 17300 17301 17302 17303 17304 17305 17306 17307 17308 17309 17310 17311 17312 17313 17314 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17298 class DescribeAIBenchmarkJobResponse < Struct.new( :ai_benchmark_job_name, :ai_benchmark_job_arn, :ai_benchmark_job_status, :failure_reason, :benchmark_target, :output_config, :ai_workload_config_identifier, :role_arn, :network_config, :creation_time, :start_time, :end_time, :tags) SENSITIVE = [] include Aws::Structure end |
#output_config ⇒ Types::AIBenchmarkOutputResult
The output configuration for the benchmark job, including the Amazon S3 output location and CloudWatch log information.
17298 17299 17300 17301 17302 17303 17304 17305 17306 17307 17308 17309 17310 17311 17312 17313 17314 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17298 class DescribeAIBenchmarkJobResponse < Struct.new( :ai_benchmark_job_name, :ai_benchmark_job_arn, :ai_benchmark_job_status, :failure_reason, :benchmark_target, :output_config, :ai_workload_config_identifier, :role_arn, :network_config, :creation_time, :start_time, :end_time, :tags) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role used by the benchmark job.
17298 17299 17300 17301 17302 17303 17304 17305 17306 17307 17308 17309 17310 17311 17312 17313 17314 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17298 class DescribeAIBenchmarkJobResponse < Struct.new( :ai_benchmark_job_name, :ai_benchmark_job_arn, :ai_benchmark_job_status, :failure_reason, :benchmark_target, :output_config, :ai_workload_config_identifier, :role_arn, :network_config, :creation_time, :start_time, :end_time, :tags) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
A timestamp that indicates when the benchmark job started running.
17298 17299 17300 17301 17302 17303 17304 17305 17306 17307 17308 17309 17310 17311 17312 17313 17314 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17298 class DescribeAIBenchmarkJobResponse < Struct.new( :ai_benchmark_job_name, :ai_benchmark_job_arn, :ai_benchmark_job_status, :failure_reason, :benchmark_target, :output_config, :ai_workload_config_identifier, :role_arn, :network_config, :creation_time, :start_time, :end_time, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags associated with the benchmark job.
17298 17299 17300 17301 17302 17303 17304 17305 17306 17307 17308 17309 17310 17311 17312 17313 17314 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17298 class DescribeAIBenchmarkJobResponse < Struct.new( :ai_benchmark_job_name, :ai_benchmark_job_arn, :ai_benchmark_job_status, :failure_reason, :benchmark_target, :output_config, :ai_workload_config_identifier, :role_arn, :network_config, :creation_time, :start_time, :end_time, :tags) SENSITIVE = [] include Aws::Structure end |