Class: Aws::SageMaker::Types::DescribeAIBenchmarkJobResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ai_benchmark_job_arnString

The Amazon Resource Name (ARN) of the AI benchmark job.

Returns:

  • (String)


16791
16792
16793
16794
16795
16796
16797
16798
16799
16800
16801
16802
16803
16804
16805
16806
16807
# File 'lib/aws-sdk-sagemaker/types.rb', line 16791

class DescribeAIBenchmarkJobResponse < Struct.new(
  :ai_benchmark_job_name,
  :ai_benchmark_job_arn,
  :ai_benchmark_job_status,
  :failure_reason,
  :benchmark_target,
  :output_config,
  :ai_workload_config_identifier,
  :role_arn,
  :network_config,
  :creation_time,
  :start_time,
  :end_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#ai_benchmark_job_nameString

The name of the AI benchmark job.

Returns:

  • (String)


16791
16792
16793
16794
16795
16796
16797
16798
16799
16800
16801
16802
16803
16804
16805
16806
16807
# File 'lib/aws-sdk-sagemaker/types.rb', line 16791

class DescribeAIBenchmarkJobResponse < Struct.new(
  :ai_benchmark_job_name,
  :ai_benchmark_job_arn,
  :ai_benchmark_job_status,
  :failure_reason,
  :benchmark_target,
  :output_config,
  :ai_workload_config_identifier,
  :role_arn,
  :network_config,
  :creation_time,
  :start_time,
  :end_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#ai_benchmark_job_statusString

The status of the AI benchmark job.

Returns:

  • (String)


16791
16792
16793
16794
16795
16796
16797
16798
16799
16800
16801
16802
16803
16804
16805
16806
16807
# File 'lib/aws-sdk-sagemaker/types.rb', line 16791

class DescribeAIBenchmarkJobResponse < Struct.new(
  :ai_benchmark_job_name,
  :ai_benchmark_job_arn,
  :ai_benchmark_job_status,
  :failure_reason,
  :benchmark_target,
  :output_config,
  :ai_workload_config_identifier,
  :role_arn,
  :network_config,
  :creation_time,
  :start_time,
  :end_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#ai_workload_config_identifierString

The name or Amazon Resource Name (ARN) of the AI workload configuration used for this benchmark job.

Returns:

  • (String)


16791
16792
16793
16794
16795
16796
16797
16798
16799
16800
16801
16802
16803
16804
16805
16806
16807
# File 'lib/aws-sdk-sagemaker/types.rb', line 16791

class DescribeAIBenchmarkJobResponse < Struct.new(
  :ai_benchmark_job_name,
  :ai_benchmark_job_arn,
  :ai_benchmark_job_status,
  :failure_reason,
  :benchmark_target,
  :output_config,
  :ai_workload_config_identifier,
  :role_arn,
  :network_config,
  :creation_time,
  :start_time,
  :end_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#benchmark_targetTypes::AIBenchmarkTarget

The target endpoint that was benchmarked.



16791
16792
16793
16794
16795
16796
16797
16798
16799
16800
16801
16802
16803
16804
16805
16806
16807
# File 'lib/aws-sdk-sagemaker/types.rb', line 16791

class DescribeAIBenchmarkJobResponse < Struct.new(
  :ai_benchmark_job_name,
  :ai_benchmark_job_arn,
  :ai_benchmark_job_status,
  :failure_reason,
  :benchmark_target,
  :output_config,
  :ai_workload_config_identifier,
  :role_arn,
  :network_config,
  :creation_time,
  :start_time,
  :end_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

A timestamp that indicates when the benchmark job was created.

Returns:

  • (Time)


16791
16792
16793
16794
16795
16796
16797
16798
16799
16800
16801
16802
16803
16804
16805
16806
16807
# File 'lib/aws-sdk-sagemaker/types.rb', line 16791

class DescribeAIBenchmarkJobResponse < Struct.new(
  :ai_benchmark_job_name,
  :ai_benchmark_job_arn,
  :ai_benchmark_job_status,
  :failure_reason,
  :benchmark_target,
  :output_config,
  :ai_workload_config_identifier,
  :role_arn,
  :network_config,
  :creation_time,
  :start_time,
  :end_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

A timestamp that indicates when the benchmark job completed.

Returns:

  • (Time)


16791
16792
16793
16794
16795
16796
16797
16798
16799
16800
16801
16802
16803
16804
16805
16806
16807
# File 'lib/aws-sdk-sagemaker/types.rb', line 16791

class DescribeAIBenchmarkJobResponse < Struct.new(
  :ai_benchmark_job_name,
  :ai_benchmark_job_arn,
  :ai_benchmark_job_status,
  :failure_reason,
  :benchmark_target,
  :output_config,
  :ai_workload_config_identifier,
  :role_arn,
  :network_config,
  :creation_time,
  :start_time,
  :end_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

If the benchmark job failed, the reason it failed.

Returns:

  • (String)


16791
16792
16793
16794
16795
16796
16797
16798
16799
16800
16801
16802
16803
16804
16805
16806
16807
# File 'lib/aws-sdk-sagemaker/types.rb', line 16791

class DescribeAIBenchmarkJobResponse < Struct.new(
  :ai_benchmark_job_name,
  :ai_benchmark_job_arn,
  :ai_benchmark_job_status,
  :failure_reason,
  :benchmark_target,
  :output_config,
  :ai_workload_config_identifier,
  :role_arn,
  :network_config,
  :creation_time,
  :start_time,
  :end_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#network_configTypes::AIBenchmarkNetworkConfig

The network configuration for the benchmark job.



16791
16792
16793
16794
16795
16796
16797
16798
16799
16800
16801
16802
16803
16804
16805
16806
16807
# File 'lib/aws-sdk-sagemaker/types.rb', line 16791

class DescribeAIBenchmarkJobResponse < Struct.new(
  :ai_benchmark_job_name,
  :ai_benchmark_job_arn,
  :ai_benchmark_job_status,
  :failure_reason,
  :benchmark_target,
  :output_config,
  :ai_workload_config_identifier,
  :role_arn,
  :network_config,
  :creation_time,
  :start_time,
  :end_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#output_configTypes::AIBenchmarkOutputResult

The output configuration for the benchmark job, including the Amazon S3 output location and CloudWatch log information.



16791
16792
16793
16794
16795
16796
16797
16798
16799
16800
16801
16802
16803
16804
16805
16806
16807
# File 'lib/aws-sdk-sagemaker/types.rb', line 16791

class DescribeAIBenchmarkJobResponse < Struct.new(
  :ai_benchmark_job_name,
  :ai_benchmark_job_arn,
  :ai_benchmark_job_status,
  :failure_reason,
  :benchmark_target,
  :output_config,
  :ai_workload_config_identifier,
  :role_arn,
  :network_config,
  :creation_time,
  :start_time,
  :end_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of the IAM role used by the benchmark job.

Returns:

  • (String)


16791
16792
16793
16794
16795
16796
16797
16798
16799
16800
16801
16802
16803
16804
16805
16806
16807
# File 'lib/aws-sdk-sagemaker/types.rb', line 16791

class DescribeAIBenchmarkJobResponse < Struct.new(
  :ai_benchmark_job_name,
  :ai_benchmark_job_arn,
  :ai_benchmark_job_status,
  :failure_reason,
  :benchmark_target,
  :output_config,
  :ai_workload_config_identifier,
  :role_arn,
  :network_config,
  :creation_time,
  :start_time,
  :end_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

A timestamp that indicates when the benchmark job started running.

Returns:

  • (Time)


16791
16792
16793
16794
16795
16796
16797
16798
16799
16800
16801
16802
16803
16804
16805
16806
16807
# File 'lib/aws-sdk-sagemaker/types.rb', line 16791

class DescribeAIBenchmarkJobResponse < Struct.new(
  :ai_benchmark_job_name,
  :ai_benchmark_job_arn,
  :ai_benchmark_job_status,
  :failure_reason,
  :benchmark_target,
  :output_config,
  :ai_workload_config_identifier,
  :role_arn,
  :network_config,
  :creation_time,
  :start_time,
  :end_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The tags associated with the benchmark job.

Returns:



16791
16792
16793
16794
16795
16796
16797
16798
16799
16800
16801
16802
16803
16804
16805
16806
16807
# File 'lib/aws-sdk-sagemaker/types.rb', line 16791

class DescribeAIBenchmarkJobResponse < Struct.new(
  :ai_benchmark_job_name,
  :ai_benchmark_job_arn,
  :ai_benchmark_job_status,
  :failure_reason,
  :benchmark_target,
  :output_config,
  :ai_workload_config_identifier,
  :role_arn,
  :network_config,
  :creation_time,
  :start_time,
  :end_time,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end