Class: Aws::SageMaker::Types::DescribeAIRecommendationJobResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeAIRecommendationJobResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ai_recommendation_job_arn ⇒ String
The Amazon Resource Name (ARN) of the AI recommendation job.
-
#ai_recommendation_job_name ⇒ String
The name of the AI recommendation job.
-
#ai_recommendation_job_status ⇒ String
The status of the AI recommendation job.
-
#ai_workload_config_identifier ⇒ String
The name or Amazon Resource Name (ARN) of the AI workload configuration used for this recommendation job.
-
#compute_spec ⇒ Types::AIRecommendationComputeSpec
The compute resource specification for the recommendation job.
-
#creation_time ⇒ Time
A timestamp that indicates when the recommendation job was created.
-
#end_time ⇒ Time
A timestamp that indicates when the recommendation job completed.
-
#failure_reason ⇒ String
If the recommendation job failed, the reason it failed.
-
#inference_specification ⇒ Types::AIRecommendationInferenceSpecification
The inference framework configuration.
-
#model_source ⇒ Types::AIModelSource
The source of the model that was analyzed.
-
#optimize_model ⇒ Boolean
Whether model optimization techniques were allowed.
-
#output_config ⇒ Types::AIRecommendationOutputResult
The output configuration for the recommendation job.
-
#performance_target ⇒ Types::AIRecommendationPerformanceTarget
The performance targets specified for the recommendation job.
-
#recommendations ⇒ Array<Types::AIRecommendation>
The list of optimization recommendations generated by the job.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role used by the recommendation job.
-
#start_time ⇒ Time
A timestamp that indicates when the recommendation job started running.
-
#tags ⇒ Array<Types::Tag>
The tags associated with the recommendation job.
Instance Attribute Details
#ai_recommendation_job_arn ⇒ String
The Amazon Resource Name (ARN) of the AI recommendation job.
17061 17062 17063 17064 17065 17066 17067 17068 17069 17070 17071 17072 17073 17074 17075 17076 17077 17078 17079 17080 17081 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17061 class DescribeAIRecommendationJobResponse < Struct.new( :ai_recommendation_job_name, :ai_recommendation_job_arn, :ai_recommendation_job_status, :failure_reason, :model_source, :output_config, :inference_specification, :ai_workload_config_identifier, :optimize_model, :performance_target, :recommendations, :role_arn, :compute_spec, :creation_time, :start_time, :end_time, :tags) SENSITIVE = [] include Aws::Structure end |
#ai_recommendation_job_name ⇒ String
The name of the AI recommendation job.
17061 17062 17063 17064 17065 17066 17067 17068 17069 17070 17071 17072 17073 17074 17075 17076 17077 17078 17079 17080 17081 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17061 class DescribeAIRecommendationJobResponse < Struct.new( :ai_recommendation_job_name, :ai_recommendation_job_arn, :ai_recommendation_job_status, :failure_reason, :model_source, :output_config, :inference_specification, :ai_workload_config_identifier, :optimize_model, :performance_target, :recommendations, :role_arn, :compute_spec, :creation_time, :start_time, :end_time, :tags) SENSITIVE = [] include Aws::Structure end |
#ai_recommendation_job_status ⇒ String
The status of the AI recommendation job.
17061 17062 17063 17064 17065 17066 17067 17068 17069 17070 17071 17072 17073 17074 17075 17076 17077 17078 17079 17080 17081 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17061 class DescribeAIRecommendationJobResponse < Struct.new( :ai_recommendation_job_name, :ai_recommendation_job_arn, :ai_recommendation_job_status, :failure_reason, :model_source, :output_config, :inference_specification, :ai_workload_config_identifier, :optimize_model, :performance_target, :recommendations, :role_arn, :compute_spec, :creation_time, :start_time, :end_time, :tags) SENSITIVE = [] include Aws::Structure end |
#ai_workload_config_identifier ⇒ String
The name or Amazon Resource Name (ARN) of the AI workload configuration used for this recommendation job.
17061 17062 17063 17064 17065 17066 17067 17068 17069 17070 17071 17072 17073 17074 17075 17076 17077 17078 17079 17080 17081 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17061 class DescribeAIRecommendationJobResponse < Struct.new( :ai_recommendation_job_name, :ai_recommendation_job_arn, :ai_recommendation_job_status, :failure_reason, :model_source, :output_config, :inference_specification, :ai_workload_config_identifier, :optimize_model, :performance_target, :recommendations, :role_arn, :compute_spec, :creation_time, :start_time, :end_time, :tags) SENSITIVE = [] include Aws::Structure end |
#compute_spec ⇒ Types::AIRecommendationComputeSpec
The compute resource specification for the recommendation job.
17061 17062 17063 17064 17065 17066 17067 17068 17069 17070 17071 17072 17073 17074 17075 17076 17077 17078 17079 17080 17081 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17061 class DescribeAIRecommendationJobResponse < Struct.new( :ai_recommendation_job_name, :ai_recommendation_job_arn, :ai_recommendation_job_status, :failure_reason, :model_source, :output_config, :inference_specification, :ai_workload_config_identifier, :optimize_model, :performance_target, :recommendations, :role_arn, :compute_spec, :creation_time, :start_time, :end_time, :tags) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
A timestamp that indicates when the recommendation job was created.
17061 17062 17063 17064 17065 17066 17067 17068 17069 17070 17071 17072 17073 17074 17075 17076 17077 17078 17079 17080 17081 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17061 class DescribeAIRecommendationJobResponse < Struct.new( :ai_recommendation_job_name, :ai_recommendation_job_arn, :ai_recommendation_job_status, :failure_reason, :model_source, :output_config, :inference_specification, :ai_workload_config_identifier, :optimize_model, :performance_target, :recommendations, :role_arn, :compute_spec, :creation_time, :start_time, :end_time, :tags) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
A timestamp that indicates when the recommendation job completed.
17061 17062 17063 17064 17065 17066 17067 17068 17069 17070 17071 17072 17073 17074 17075 17076 17077 17078 17079 17080 17081 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17061 class DescribeAIRecommendationJobResponse < Struct.new( :ai_recommendation_job_name, :ai_recommendation_job_arn, :ai_recommendation_job_status, :failure_reason, :model_source, :output_config, :inference_specification, :ai_workload_config_identifier, :optimize_model, :performance_target, :recommendations, :role_arn, :compute_spec, :creation_time, :start_time, :end_time, :tags) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
If the recommendation job failed, the reason it failed.
17061 17062 17063 17064 17065 17066 17067 17068 17069 17070 17071 17072 17073 17074 17075 17076 17077 17078 17079 17080 17081 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17061 class DescribeAIRecommendationJobResponse < Struct.new( :ai_recommendation_job_name, :ai_recommendation_job_arn, :ai_recommendation_job_status, :failure_reason, :model_source, :output_config, :inference_specification, :ai_workload_config_identifier, :optimize_model, :performance_target, :recommendations, :role_arn, :compute_spec, :creation_time, :start_time, :end_time, :tags) SENSITIVE = [] include Aws::Structure end |
#inference_specification ⇒ Types::AIRecommendationInferenceSpecification
The inference framework configuration.
17061 17062 17063 17064 17065 17066 17067 17068 17069 17070 17071 17072 17073 17074 17075 17076 17077 17078 17079 17080 17081 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17061 class DescribeAIRecommendationJobResponse < Struct.new( :ai_recommendation_job_name, :ai_recommendation_job_arn, :ai_recommendation_job_status, :failure_reason, :model_source, :output_config, :inference_specification, :ai_workload_config_identifier, :optimize_model, :performance_target, :recommendations, :role_arn, :compute_spec, :creation_time, :start_time, :end_time, :tags) SENSITIVE = [] include Aws::Structure end |
#model_source ⇒ Types::AIModelSource
The source of the model that was analyzed.
17061 17062 17063 17064 17065 17066 17067 17068 17069 17070 17071 17072 17073 17074 17075 17076 17077 17078 17079 17080 17081 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17061 class DescribeAIRecommendationJobResponse < Struct.new( :ai_recommendation_job_name, :ai_recommendation_job_arn, :ai_recommendation_job_status, :failure_reason, :model_source, :output_config, :inference_specification, :ai_workload_config_identifier, :optimize_model, :performance_target, :recommendations, :role_arn, :compute_spec, :creation_time, :start_time, :end_time, :tags) SENSITIVE = [] include Aws::Structure end |
#optimize_model ⇒ Boolean
Whether model optimization techniques were allowed.
17061 17062 17063 17064 17065 17066 17067 17068 17069 17070 17071 17072 17073 17074 17075 17076 17077 17078 17079 17080 17081 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17061 class DescribeAIRecommendationJobResponse < Struct.new( :ai_recommendation_job_name, :ai_recommendation_job_arn, :ai_recommendation_job_status, :failure_reason, :model_source, :output_config, :inference_specification, :ai_workload_config_identifier, :optimize_model, :performance_target, :recommendations, :role_arn, :compute_spec, :creation_time, :start_time, :end_time, :tags) SENSITIVE = [] include Aws::Structure end |
#output_config ⇒ Types::AIRecommendationOutputResult
The output configuration for the recommendation job.
17061 17062 17063 17064 17065 17066 17067 17068 17069 17070 17071 17072 17073 17074 17075 17076 17077 17078 17079 17080 17081 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17061 class DescribeAIRecommendationJobResponse < Struct.new( :ai_recommendation_job_name, :ai_recommendation_job_arn, :ai_recommendation_job_status, :failure_reason, :model_source, :output_config, :inference_specification, :ai_workload_config_identifier, :optimize_model, :performance_target, :recommendations, :role_arn, :compute_spec, :creation_time, :start_time, :end_time, :tags) SENSITIVE = [] include Aws::Structure end |
#performance_target ⇒ Types::AIRecommendationPerformanceTarget
The performance targets specified for the recommendation job.
17061 17062 17063 17064 17065 17066 17067 17068 17069 17070 17071 17072 17073 17074 17075 17076 17077 17078 17079 17080 17081 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17061 class DescribeAIRecommendationJobResponse < Struct.new( :ai_recommendation_job_name, :ai_recommendation_job_arn, :ai_recommendation_job_status, :failure_reason, :model_source, :output_config, :inference_specification, :ai_workload_config_identifier, :optimize_model, :performance_target, :recommendations, :role_arn, :compute_spec, :creation_time, :start_time, :end_time, :tags) SENSITIVE = [] include Aws::Structure end |
#recommendations ⇒ Array<Types::AIRecommendation>
The list of optimization recommendations generated by the job. Each recommendation includes optimization details, deployment configuration, expected performance metrics, and the associated benchmark job ARN.
17061 17062 17063 17064 17065 17066 17067 17068 17069 17070 17071 17072 17073 17074 17075 17076 17077 17078 17079 17080 17081 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17061 class DescribeAIRecommendationJobResponse < Struct.new( :ai_recommendation_job_name, :ai_recommendation_job_arn, :ai_recommendation_job_status, :failure_reason, :model_source, :output_config, :inference_specification, :ai_workload_config_identifier, :optimize_model, :performance_target, :recommendations, :role_arn, :compute_spec, :creation_time, :start_time, :end_time, :tags) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role used by the recommendation job.
17061 17062 17063 17064 17065 17066 17067 17068 17069 17070 17071 17072 17073 17074 17075 17076 17077 17078 17079 17080 17081 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17061 class DescribeAIRecommendationJobResponse < Struct.new( :ai_recommendation_job_name, :ai_recommendation_job_arn, :ai_recommendation_job_status, :failure_reason, :model_source, :output_config, :inference_specification, :ai_workload_config_identifier, :optimize_model, :performance_target, :recommendations, :role_arn, :compute_spec, :creation_time, :start_time, :end_time, :tags) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
A timestamp that indicates when the recommendation job started running.
17061 17062 17063 17064 17065 17066 17067 17068 17069 17070 17071 17072 17073 17074 17075 17076 17077 17078 17079 17080 17081 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17061 class DescribeAIRecommendationJobResponse < Struct.new( :ai_recommendation_job_name, :ai_recommendation_job_arn, :ai_recommendation_job_status, :failure_reason, :model_source, :output_config, :inference_specification, :ai_workload_config_identifier, :optimize_model, :performance_target, :recommendations, :role_arn, :compute_spec, :creation_time, :start_time, :end_time, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags associated with the recommendation job.
17061 17062 17063 17064 17065 17066 17067 17068 17069 17070 17071 17072 17073 17074 17075 17076 17077 17078 17079 17080 17081 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17061 class DescribeAIRecommendationJobResponse < Struct.new( :ai_recommendation_job_name, :ai_recommendation_job_arn, :ai_recommendation_job_status, :failure_reason, :model_source, :output_config, :inference_specification, :ai_workload_config_identifier, :optimize_model, :performance_target, :recommendations, :role_arn, :compute_spec, :creation_time, :start_time, :end_time, :tags) SENSITIVE = [] include Aws::Structure end |