Class: Aws::SageMaker::Types::DescribeAlgorithmOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeAlgorithmOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#algorithm_arn ⇒ String
The Amazon Resource Name (ARN) of the algorithm.
-
#algorithm_description ⇒ String
A brief summary about the algorithm.
-
#algorithm_name ⇒ String
The name of the algorithm being described.
-
#algorithm_status ⇒ String
The current status of the algorithm.
-
#algorithm_status_details ⇒ Types::AlgorithmStatusDetails
Details about the current status of the algorithm.
-
#certify_for_marketplace ⇒ Boolean
Whether the algorithm is certified to be listed in Amazon Web Services Marketplace.
-
#creation_time ⇒ Time
A timestamp specifying when the algorithm was created.
-
#inference_specification ⇒ Types::InferenceSpecification
Details about inference jobs that the algorithm runs.
-
#product_id ⇒ String
The product identifier of the algorithm.
-
#training_specification ⇒ Types::TrainingSpecification
Details about training jobs run by this algorithm.
-
#validation_specification ⇒ Types::AlgorithmValidationSpecification
Details about configurations for one or more training jobs that SageMaker runs to test the algorithm.
Instance Attribute Details
#algorithm_arn ⇒ String
The Amazon Resource Name (ARN) of the algorithm.
17454 17455 17456 17457 17458 17459 17460 17461 17462 17463 17464 17465 17466 17467 17468 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17454 class DescribeAlgorithmOutput < Struct.new( :algorithm_name, :algorithm_arn, :algorithm_description, :creation_time, :training_specification, :inference_specification, :validation_specification, :algorithm_status, :algorithm_status_details, :product_id, :certify_for_marketplace) SENSITIVE = [] include Aws::Structure end |
#algorithm_description ⇒ String
A brief summary about the algorithm.
17454 17455 17456 17457 17458 17459 17460 17461 17462 17463 17464 17465 17466 17467 17468 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17454 class DescribeAlgorithmOutput < Struct.new( :algorithm_name, :algorithm_arn, :algorithm_description, :creation_time, :training_specification, :inference_specification, :validation_specification, :algorithm_status, :algorithm_status_details, :product_id, :certify_for_marketplace) SENSITIVE = [] include Aws::Structure end |
#algorithm_name ⇒ String
The name of the algorithm being described.
17454 17455 17456 17457 17458 17459 17460 17461 17462 17463 17464 17465 17466 17467 17468 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17454 class DescribeAlgorithmOutput < Struct.new( :algorithm_name, :algorithm_arn, :algorithm_description, :creation_time, :training_specification, :inference_specification, :validation_specification, :algorithm_status, :algorithm_status_details, :product_id, :certify_for_marketplace) SENSITIVE = [] include Aws::Structure end |
#algorithm_status ⇒ String
The current status of the algorithm.
17454 17455 17456 17457 17458 17459 17460 17461 17462 17463 17464 17465 17466 17467 17468 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17454 class DescribeAlgorithmOutput < Struct.new( :algorithm_name, :algorithm_arn, :algorithm_description, :creation_time, :training_specification, :inference_specification, :validation_specification, :algorithm_status, :algorithm_status_details, :product_id, :certify_for_marketplace) SENSITIVE = [] include Aws::Structure end |
#algorithm_status_details ⇒ Types::AlgorithmStatusDetails
Details about the current status of the algorithm.
17454 17455 17456 17457 17458 17459 17460 17461 17462 17463 17464 17465 17466 17467 17468 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17454 class DescribeAlgorithmOutput < Struct.new( :algorithm_name, :algorithm_arn, :algorithm_description, :creation_time, :training_specification, :inference_specification, :validation_specification, :algorithm_status, :algorithm_status_details, :product_id, :certify_for_marketplace) SENSITIVE = [] include Aws::Structure end |
#certify_for_marketplace ⇒ Boolean
Whether the algorithm is certified to be listed in Amazon Web Services Marketplace.
17454 17455 17456 17457 17458 17459 17460 17461 17462 17463 17464 17465 17466 17467 17468 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17454 class DescribeAlgorithmOutput < Struct.new( :algorithm_name, :algorithm_arn, :algorithm_description, :creation_time, :training_specification, :inference_specification, :validation_specification, :algorithm_status, :algorithm_status_details, :product_id, :certify_for_marketplace) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
A timestamp specifying when the algorithm was created.
17454 17455 17456 17457 17458 17459 17460 17461 17462 17463 17464 17465 17466 17467 17468 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17454 class DescribeAlgorithmOutput < Struct.new( :algorithm_name, :algorithm_arn, :algorithm_description, :creation_time, :training_specification, :inference_specification, :validation_specification, :algorithm_status, :algorithm_status_details, :product_id, :certify_for_marketplace) SENSITIVE = [] include Aws::Structure end |
#inference_specification ⇒ Types::InferenceSpecification
Details about inference jobs that the algorithm runs.
17454 17455 17456 17457 17458 17459 17460 17461 17462 17463 17464 17465 17466 17467 17468 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17454 class DescribeAlgorithmOutput < Struct.new( :algorithm_name, :algorithm_arn, :algorithm_description, :creation_time, :training_specification, :inference_specification, :validation_specification, :algorithm_status, :algorithm_status_details, :product_id, :certify_for_marketplace) SENSITIVE = [] include Aws::Structure end |
#product_id ⇒ String
The product identifier of the algorithm.
17454 17455 17456 17457 17458 17459 17460 17461 17462 17463 17464 17465 17466 17467 17468 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17454 class DescribeAlgorithmOutput < Struct.new( :algorithm_name, :algorithm_arn, :algorithm_description, :creation_time, :training_specification, :inference_specification, :validation_specification, :algorithm_status, :algorithm_status_details, :product_id, :certify_for_marketplace) SENSITIVE = [] include Aws::Structure end |
#training_specification ⇒ Types::TrainingSpecification
Details about training jobs run by this algorithm.
17454 17455 17456 17457 17458 17459 17460 17461 17462 17463 17464 17465 17466 17467 17468 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17454 class DescribeAlgorithmOutput < Struct.new( :algorithm_name, :algorithm_arn, :algorithm_description, :creation_time, :training_specification, :inference_specification, :validation_specification, :algorithm_status, :algorithm_status_details, :product_id, :certify_for_marketplace) SENSITIVE = [] include Aws::Structure end |
#validation_specification ⇒ Types::AlgorithmValidationSpecification
Details about configurations for one or more training jobs that SageMaker runs to test the algorithm.
17454 17455 17456 17457 17458 17459 17460 17461 17462 17463 17464 17465 17466 17467 17468 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17454 class DescribeAlgorithmOutput < Struct.new( :algorithm_name, :algorithm_arn, :algorithm_description, :creation_time, :training_specification, :inference_specification, :validation_specification, :algorithm_status, :algorithm_status_details, :product_id, :certify_for_marketplace) SENSITIVE = [] include Aws::Structure end |