Class: Aws::SageMaker::Types::DescribeAlgorithmOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#algorithm_arnString

The Amazon Resource Name (ARN) of the algorithm.

Returns:

  • (String)


15575
15576
15577
15578
15579
15580
15581
15582
15583
15584
15585
15586
15587
15588
15589
# File 'lib/aws-sdk-sagemaker/types.rb', line 15575

class DescribeAlgorithmOutput < Struct.new(
  :algorithm_name,
  :algorithm_arn,
  :algorithm_description,
  :creation_time,
  :training_specification,
  :inference_specification,
  :validation_specification,
  :algorithm_status,
  :algorithm_status_details,
  :product_id,
  :certify_for_marketplace)
  SENSITIVE = []
  include Aws::Structure
end

#algorithm_descriptionString

A brief summary about the algorithm.

Returns:

  • (String)


15575
15576
15577
15578
15579
15580
15581
15582
15583
15584
15585
15586
15587
15588
15589
# File 'lib/aws-sdk-sagemaker/types.rb', line 15575

class DescribeAlgorithmOutput < Struct.new(
  :algorithm_name,
  :algorithm_arn,
  :algorithm_description,
  :creation_time,
  :training_specification,
  :inference_specification,
  :validation_specification,
  :algorithm_status,
  :algorithm_status_details,
  :product_id,
  :certify_for_marketplace)
  SENSITIVE = []
  include Aws::Structure
end

#algorithm_nameString

The name of the algorithm being described.

Returns:

  • (String)


15575
15576
15577
15578
15579
15580
15581
15582
15583
15584
15585
15586
15587
15588
15589
# File 'lib/aws-sdk-sagemaker/types.rb', line 15575

class DescribeAlgorithmOutput < Struct.new(
  :algorithm_name,
  :algorithm_arn,
  :algorithm_description,
  :creation_time,
  :training_specification,
  :inference_specification,
  :validation_specification,
  :algorithm_status,
  :algorithm_status_details,
  :product_id,
  :certify_for_marketplace)
  SENSITIVE = []
  include Aws::Structure
end

#algorithm_statusString

The current status of the algorithm.

Returns:

  • (String)


15575
15576
15577
15578
15579
15580
15581
15582
15583
15584
15585
15586
15587
15588
15589
# File 'lib/aws-sdk-sagemaker/types.rb', line 15575

class DescribeAlgorithmOutput < Struct.new(
  :algorithm_name,
  :algorithm_arn,
  :algorithm_description,
  :creation_time,
  :training_specification,
  :inference_specification,
  :validation_specification,
  :algorithm_status,
  :algorithm_status_details,
  :product_id,
  :certify_for_marketplace)
  SENSITIVE = []
  include Aws::Structure
end

#algorithm_status_detailsTypes::AlgorithmStatusDetails

Details about the current status of the algorithm.



15575
15576
15577
15578
15579
15580
15581
15582
15583
15584
15585
15586
15587
15588
15589
# File 'lib/aws-sdk-sagemaker/types.rb', line 15575

class DescribeAlgorithmOutput < Struct.new(
  :algorithm_name,
  :algorithm_arn,
  :algorithm_description,
  :creation_time,
  :training_specification,
  :inference_specification,
  :validation_specification,
  :algorithm_status,
  :algorithm_status_details,
  :product_id,
  :certify_for_marketplace)
  SENSITIVE = []
  include Aws::Structure
end

#certify_for_marketplaceBoolean

Whether the algorithm is certified to be listed in Amazon Web Services Marketplace.

Returns:

  • (Boolean)


15575
15576
15577
15578
15579
15580
15581
15582
15583
15584
15585
15586
15587
15588
15589
# File 'lib/aws-sdk-sagemaker/types.rb', line 15575

class DescribeAlgorithmOutput < Struct.new(
  :algorithm_name,
  :algorithm_arn,
  :algorithm_description,
  :creation_time,
  :training_specification,
  :inference_specification,
  :validation_specification,
  :algorithm_status,
  :algorithm_status_details,
  :product_id,
  :certify_for_marketplace)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

A timestamp specifying when the algorithm was created.

Returns:

  • (Time)


15575
15576
15577
15578
15579
15580
15581
15582
15583
15584
15585
15586
15587
15588
15589
# File 'lib/aws-sdk-sagemaker/types.rb', line 15575

class DescribeAlgorithmOutput < Struct.new(
  :algorithm_name,
  :algorithm_arn,
  :algorithm_description,
  :creation_time,
  :training_specification,
  :inference_specification,
  :validation_specification,
  :algorithm_status,
  :algorithm_status_details,
  :product_id,
  :certify_for_marketplace)
  SENSITIVE = []
  include Aws::Structure
end

#inference_specificationTypes::InferenceSpecification

Details about inference jobs that the algorithm runs.



15575
15576
15577
15578
15579
15580
15581
15582
15583
15584
15585
15586
15587
15588
15589
# File 'lib/aws-sdk-sagemaker/types.rb', line 15575

class DescribeAlgorithmOutput < Struct.new(
  :algorithm_name,
  :algorithm_arn,
  :algorithm_description,
  :creation_time,
  :training_specification,
  :inference_specification,
  :validation_specification,
  :algorithm_status,
  :algorithm_status_details,
  :product_id,
  :certify_for_marketplace)
  SENSITIVE = []
  include Aws::Structure
end

#product_idString

The product identifier of the algorithm.

Returns:

  • (String)


15575
15576
15577
15578
15579
15580
15581
15582
15583
15584
15585
15586
15587
15588
15589
# File 'lib/aws-sdk-sagemaker/types.rb', line 15575

class DescribeAlgorithmOutput < Struct.new(
  :algorithm_name,
  :algorithm_arn,
  :algorithm_description,
  :creation_time,
  :training_specification,
  :inference_specification,
  :validation_specification,
  :algorithm_status,
  :algorithm_status_details,
  :product_id,
  :certify_for_marketplace)
  SENSITIVE = []
  include Aws::Structure
end

#training_specificationTypes::TrainingSpecification

Details about training jobs run by this algorithm.



15575
15576
15577
15578
15579
15580
15581
15582
15583
15584
15585
15586
15587
15588
15589
# File 'lib/aws-sdk-sagemaker/types.rb', line 15575

class DescribeAlgorithmOutput < Struct.new(
  :algorithm_name,
  :algorithm_arn,
  :algorithm_description,
  :creation_time,
  :training_specification,
  :inference_specification,
  :validation_specification,
  :algorithm_status,
  :algorithm_status_details,
  :product_id,
  :certify_for_marketplace)
  SENSITIVE = []
  include Aws::Structure
end

#validation_specificationTypes::AlgorithmValidationSpecification

Details about configurations for one or more training jobs that SageMaker runs to test the algorithm.



15575
15576
15577
15578
15579
15580
15581
15582
15583
15584
15585
15586
15587
15588
15589
# File 'lib/aws-sdk-sagemaker/types.rb', line 15575

class DescribeAlgorithmOutput < Struct.new(
  :algorithm_name,
  :algorithm_arn,
  :algorithm_description,
  :creation_time,
  :training_specification,
  :inference_specification,
  :validation_specification,
  :algorithm_status,
  :algorithm_status_details,
  :product_id,
  :certify_for_marketplace)
  SENSITIVE = []
  include Aws::Structure
end