Class: Aws::SageMaker::Types::DescribeAppResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeAppResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#app_arn ⇒ String
The Amazon Resource Name (ARN) of the app.
-
#app_name ⇒ String
The name of the app.
-
#app_type ⇒ String
The type of app.
-
#built_in_lifecycle_config_arn ⇒ String
The lifecycle configuration that runs before the default lifecycle configuration.
-
#creation_time ⇒ Time
The creation time of the application.
-
#domain_id ⇒ String
The domain ID.
-
#effective_trusted_identity_propagation_status ⇒ String
The effective status of Trusted Identity Propagation (TIP) for this application.
-
#failure_reason ⇒ String
The failure reason.
-
#last_health_check_timestamp ⇒ Time
The timestamp of the last health check.
-
#last_user_activity_timestamp ⇒ Time
The timestamp of the last user’s activity.
-
#recovery_mode ⇒ Boolean
Indicates whether the application is launched in recovery mode.
-
#resource_spec ⇒ Types::ResourceSpec
The instance type and the Amazon Resource Name (ARN) of the SageMaker AI image created on the instance.
-
#space_name ⇒ String
The name of the space.
-
#status ⇒ String
The status.
-
#user_profile_name ⇒ String
The user profile name.
Instance Attribute Details
#app_arn ⇒ String
The Amazon Resource Name (ARN) of the app.
15773 15774 15775 15776 15777 15778 15779 15780 15781 15782 15783 15784 15785 15786 15787 15788 15789 15790 15791 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 15773 class DescribeAppResponse < Struct.new( :app_arn, :app_type, :app_name, :domain_id, :user_profile_name, :space_name, :status, :effective_trusted_identity_propagation_status, :recovery_mode, :last_health_check_timestamp, :last_user_activity_timestamp, :creation_time, :failure_reason, :resource_spec, :built_in_lifecycle_config_arn) SENSITIVE = [] include Aws::Structure end |
#app_name ⇒ String
The name of the app.
15773 15774 15775 15776 15777 15778 15779 15780 15781 15782 15783 15784 15785 15786 15787 15788 15789 15790 15791 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 15773 class DescribeAppResponse < Struct.new( :app_arn, :app_type, :app_name, :domain_id, :user_profile_name, :space_name, :status, :effective_trusted_identity_propagation_status, :recovery_mode, :last_health_check_timestamp, :last_user_activity_timestamp, :creation_time, :failure_reason, :resource_spec, :built_in_lifecycle_config_arn) SENSITIVE = [] include Aws::Structure end |
#app_type ⇒ String
The type of app.
15773 15774 15775 15776 15777 15778 15779 15780 15781 15782 15783 15784 15785 15786 15787 15788 15789 15790 15791 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 15773 class DescribeAppResponse < Struct.new( :app_arn, :app_type, :app_name, :domain_id, :user_profile_name, :space_name, :status, :effective_trusted_identity_propagation_status, :recovery_mode, :last_health_check_timestamp, :last_user_activity_timestamp, :creation_time, :failure_reason, :resource_spec, :built_in_lifecycle_config_arn) SENSITIVE = [] include Aws::Structure end |
#built_in_lifecycle_config_arn ⇒ String
The lifecycle configuration that runs before the default lifecycle configuration
15773 15774 15775 15776 15777 15778 15779 15780 15781 15782 15783 15784 15785 15786 15787 15788 15789 15790 15791 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 15773 class DescribeAppResponse < Struct.new( :app_arn, :app_type, :app_name, :domain_id, :user_profile_name, :space_name, :status, :effective_trusted_identity_propagation_status, :recovery_mode, :last_health_check_timestamp, :last_user_activity_timestamp, :creation_time, :failure_reason, :resource_spec, :built_in_lifecycle_config_arn) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The creation time of the application.
<note markdown=“1”> After an application has been shut down for 24 hours, SageMaker AI deletes all metadata for the application. To be considered an update and retain application metadata, applications must be restarted within 24 hours after the previous application has been shut down. After this time window, creation of an application is considered a new application rather than an update of the previous application.
</note>
15773 15774 15775 15776 15777 15778 15779 15780 15781 15782 15783 15784 15785 15786 15787 15788 15789 15790 15791 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 15773 class DescribeAppResponse < Struct.new( :app_arn, :app_type, :app_name, :domain_id, :user_profile_name, :space_name, :status, :effective_trusted_identity_propagation_status, :recovery_mode, :last_health_check_timestamp, :last_user_activity_timestamp, :creation_time, :failure_reason, :resource_spec, :built_in_lifecycle_config_arn) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
The domain ID.
15773 15774 15775 15776 15777 15778 15779 15780 15781 15782 15783 15784 15785 15786 15787 15788 15789 15790 15791 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 15773 class DescribeAppResponse < Struct.new( :app_arn, :app_type, :app_name, :domain_id, :user_profile_name, :space_name, :status, :effective_trusted_identity_propagation_status, :recovery_mode, :last_health_check_timestamp, :last_user_activity_timestamp, :creation_time, :failure_reason, :resource_spec, :built_in_lifecycle_config_arn) SENSITIVE = [] include Aws::Structure end |
#effective_trusted_identity_propagation_status ⇒ String
The effective status of Trusted Identity Propagation (TIP) for this application. When enabled, user identities from IAM Identity Center are being propagated through the application to TIP enabled Amazon Web Services services. When disabled, standard IAM role-based access is used.
15773 15774 15775 15776 15777 15778 15779 15780 15781 15782 15783 15784 15785 15786 15787 15788 15789 15790 15791 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 15773 class DescribeAppResponse < Struct.new( :app_arn, :app_type, :app_name, :domain_id, :user_profile_name, :space_name, :status, :effective_trusted_identity_propagation_status, :recovery_mode, :last_health_check_timestamp, :last_user_activity_timestamp, :creation_time, :failure_reason, :resource_spec, :built_in_lifecycle_config_arn) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
The failure reason.
15773 15774 15775 15776 15777 15778 15779 15780 15781 15782 15783 15784 15785 15786 15787 15788 15789 15790 15791 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 15773 class DescribeAppResponse < Struct.new( :app_arn, :app_type, :app_name, :domain_id, :user_profile_name, :space_name, :status, :effective_trusted_identity_propagation_status, :recovery_mode, :last_health_check_timestamp, :last_user_activity_timestamp, :creation_time, :failure_reason, :resource_spec, :built_in_lifecycle_config_arn) SENSITIVE = [] include Aws::Structure end |
#last_health_check_timestamp ⇒ Time
The timestamp of the last health check.
15773 15774 15775 15776 15777 15778 15779 15780 15781 15782 15783 15784 15785 15786 15787 15788 15789 15790 15791 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 15773 class DescribeAppResponse < Struct.new( :app_arn, :app_type, :app_name, :domain_id, :user_profile_name, :space_name, :status, :effective_trusted_identity_propagation_status, :recovery_mode, :last_health_check_timestamp, :last_user_activity_timestamp, :creation_time, :failure_reason, :resource_spec, :built_in_lifecycle_config_arn) SENSITIVE = [] include Aws::Structure end |
#last_user_activity_timestamp ⇒ Time
The timestamp of the last user’s activity. LastUserActivityTimestamp is also updated when SageMaker AI performs health checks without user activity. As a result, this value is set to the same value as LastHealthCheckTimestamp.
15773 15774 15775 15776 15777 15778 15779 15780 15781 15782 15783 15784 15785 15786 15787 15788 15789 15790 15791 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 15773 class DescribeAppResponse < Struct.new( :app_arn, :app_type, :app_name, :domain_id, :user_profile_name, :space_name, :status, :effective_trusted_identity_propagation_status, :recovery_mode, :last_health_check_timestamp, :last_user_activity_timestamp, :creation_time, :failure_reason, :resource_spec, :built_in_lifecycle_config_arn) SENSITIVE = [] include Aws::Structure end |
#recovery_mode ⇒ Boolean
Indicates whether the application is launched in recovery mode.
15773 15774 15775 15776 15777 15778 15779 15780 15781 15782 15783 15784 15785 15786 15787 15788 15789 15790 15791 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 15773 class DescribeAppResponse < Struct.new( :app_arn, :app_type, :app_name, :domain_id, :user_profile_name, :space_name, :status, :effective_trusted_identity_propagation_status, :recovery_mode, :last_health_check_timestamp, :last_user_activity_timestamp, :creation_time, :failure_reason, :resource_spec, :built_in_lifecycle_config_arn) SENSITIVE = [] include Aws::Structure end |
#resource_spec ⇒ Types::ResourceSpec
The instance type and the Amazon Resource Name (ARN) of the SageMaker AI image created on the instance.
15773 15774 15775 15776 15777 15778 15779 15780 15781 15782 15783 15784 15785 15786 15787 15788 15789 15790 15791 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 15773 class DescribeAppResponse < Struct.new( :app_arn, :app_type, :app_name, :domain_id, :user_profile_name, :space_name, :status, :effective_trusted_identity_propagation_status, :recovery_mode, :last_health_check_timestamp, :last_user_activity_timestamp, :creation_time, :failure_reason, :resource_spec, :built_in_lifecycle_config_arn) SENSITIVE = [] include Aws::Structure end |
#space_name ⇒ String
The name of the space. If this value is not set, then UserProfileName must be set.
15773 15774 15775 15776 15777 15778 15779 15780 15781 15782 15783 15784 15785 15786 15787 15788 15789 15790 15791 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 15773 class DescribeAppResponse < Struct.new( :app_arn, :app_type, :app_name, :domain_id, :user_profile_name, :space_name, :status, :effective_trusted_identity_propagation_status, :recovery_mode, :last_health_check_timestamp, :last_user_activity_timestamp, :creation_time, :failure_reason, :resource_spec, :built_in_lifecycle_config_arn) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status.
15773 15774 15775 15776 15777 15778 15779 15780 15781 15782 15783 15784 15785 15786 15787 15788 15789 15790 15791 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 15773 class DescribeAppResponse < Struct.new( :app_arn, :app_type, :app_name, :domain_id, :user_profile_name, :space_name, :status, :effective_trusted_identity_propagation_status, :recovery_mode, :last_health_check_timestamp, :last_user_activity_timestamp, :creation_time, :failure_reason, :resource_spec, :built_in_lifecycle_config_arn) SENSITIVE = [] include Aws::Structure end |
#user_profile_name ⇒ String
The user profile name.
15773 15774 15775 15776 15777 15778 15779 15780 15781 15782 15783 15784 15785 15786 15787 15788 15789 15790 15791 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 15773 class DescribeAppResponse < Struct.new( :app_arn, :app_type, :app_name, :domain_id, :user_profile_name, :space_name, :status, :effective_trusted_identity_propagation_status, :recovery_mode, :last_health_check_timestamp, :last_user_activity_timestamp, :creation_time, :failure_reason, :resource_spec, :built_in_lifecycle_config_arn) SENSITIVE = [] include Aws::Structure end |