Class: Aws::SageMaker::Types::DescribeAutoMLJobResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_ml_job_arnString

Returns the ARN of the AutoML job.

Returns:

  • (String)


17358
17359
17360
17361
17362
17363
17364
17365
17366
17367
17368
17369
17370
17371
17372
17373
17374
17375
17376
17377
17378
17379
17380
17381
17382
# File 'lib/aws-sdk-sagemaker/types.rb', line 17358

class DescribeAutoMLJobResponse < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :problem_type,
  :auto_ml_job_config,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :generate_candidate_definitions_only,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result)
  SENSITIVE = []
  include Aws::Structure
end

#auto_ml_job_artifactsTypes::AutoMLJobArtifacts

Returns information on the job’s artifacts found in ‘AutoMLJobArtifacts`.



17358
17359
17360
17361
17362
17363
17364
17365
17366
17367
17368
17369
17370
17371
17372
17373
17374
17375
17376
17377
17378
17379
17380
17381
17382
# File 'lib/aws-sdk-sagemaker/types.rb', line 17358

class DescribeAutoMLJobResponse < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :problem_type,
  :auto_ml_job_config,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :generate_candidate_definitions_only,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result)
  SENSITIVE = []
  include Aws::Structure
end

#auto_ml_job_configTypes::AutoMLJobConfig

Returns the configuration for the AutoML job.



17358
17359
17360
17361
17362
17363
17364
17365
17366
17367
17368
17369
17370
17371
17372
17373
17374
17375
17376
17377
17378
17379
17380
17381
17382
# File 'lib/aws-sdk-sagemaker/types.rb', line 17358

class DescribeAutoMLJobResponse < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :problem_type,
  :auto_ml_job_config,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :generate_candidate_definitions_only,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result)
  SENSITIVE = []
  include Aws::Structure
end

#auto_ml_job_nameString

Returns the name of the AutoML job.

Returns:

  • (String)


17358
17359
17360
17361
17362
17363
17364
17365
17366
17367
17368
17369
17370
17371
17372
17373
17374
17375
17376
17377
17378
17379
17380
17381
17382
# File 'lib/aws-sdk-sagemaker/types.rb', line 17358

class DescribeAutoMLJobResponse < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :problem_type,
  :auto_ml_job_config,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :generate_candidate_definitions_only,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result)
  SENSITIVE = []
  include Aws::Structure
end

#auto_ml_job_objectiveTypes::AutoMLJobObjective

Returns the job’s objective.



17358
17359
17360
17361
17362
17363
17364
17365
17366
17367
17368
17369
17370
17371
17372
17373
17374
17375
17376
17377
17378
17379
17380
17381
17382
# File 'lib/aws-sdk-sagemaker/types.rb', line 17358

class DescribeAutoMLJobResponse < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :problem_type,
  :auto_ml_job_config,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :generate_candidate_definitions_only,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result)
  SENSITIVE = []
  include Aws::Structure
end

#auto_ml_job_secondary_statusString

Returns the secondary status of the AutoML job.

Returns:

  • (String)


17358
17359
17360
17361
17362
17363
17364
17365
17366
17367
17368
17369
17370
17371
17372
17373
17374
17375
17376
17377
17378
17379
17380
17381
17382
# File 'lib/aws-sdk-sagemaker/types.rb', line 17358

class DescribeAutoMLJobResponse < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :problem_type,
  :auto_ml_job_config,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :generate_candidate_definitions_only,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result)
  SENSITIVE = []
  include Aws::Structure
end

#auto_ml_job_statusString

Returns the status of the AutoML job.

Returns:

  • (String)


17358
17359
17360
17361
17362
17363
17364
17365
17366
17367
17368
17369
17370
17371
17372
17373
17374
17375
17376
17377
17378
17379
17380
17381
17382
# File 'lib/aws-sdk-sagemaker/types.rb', line 17358

class DescribeAutoMLJobResponse < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :problem_type,
  :auto_ml_job_config,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :generate_candidate_definitions_only,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result)
  SENSITIVE = []
  include Aws::Structure
end

#best_candidateTypes::AutoMLCandidate

The best model candidate selected by SageMaker AI Autopilot using both the best objective metric and lowest [InferenceLatency] for an experiment.

[1]: docs.aws.amazon.com/sagemaker/latest/dg/autopilot-metrics-validation.html



17358
17359
17360
17361
17362
17363
17364
17365
17366
17367
17368
17369
17370
17371
17372
17373
17374
17375
17376
17377
17378
17379
17380
17381
17382
# File 'lib/aws-sdk-sagemaker/types.rb', line 17358

class DescribeAutoMLJobResponse < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :problem_type,
  :auto_ml_job_config,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :generate_candidate_definitions_only,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

Returns the creation time of the AutoML job.

Returns:

  • (Time)


17358
17359
17360
17361
17362
17363
17364
17365
17366
17367
17368
17369
17370
17371
17372
17373
17374
17375
17376
17377
17378
17379
17380
17381
17382
# File 'lib/aws-sdk-sagemaker/types.rb', line 17358

class DescribeAutoMLJobResponse < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :problem_type,
  :auto_ml_job_config,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :generate_candidate_definitions_only,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

Returns the end time of the AutoML job.

Returns:

  • (Time)


17358
17359
17360
17361
17362
17363
17364
17365
17366
17367
17368
17369
17370
17371
17372
17373
17374
17375
17376
17377
17378
17379
17380
17381
17382
# File 'lib/aws-sdk-sagemaker/types.rb', line 17358

class DescribeAutoMLJobResponse < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :problem_type,
  :auto_ml_job_config,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :generate_candidate_definitions_only,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

Returns the failure reason for an AutoML job, when applicable.

Returns:

  • (String)


17358
17359
17360
17361
17362
17363
17364
17365
17366
17367
17368
17369
17370
17371
17372
17373
17374
17375
17376
17377
17378
17379
17380
17381
17382
# File 'lib/aws-sdk-sagemaker/types.rb', line 17358

class DescribeAutoMLJobResponse < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :problem_type,
  :auto_ml_job_config,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :generate_candidate_definitions_only,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result)
  SENSITIVE = []
  include Aws::Structure
end

#generate_candidate_definitions_onlyBoolean

Indicates whether the output for an AutoML job generates candidate definitions only.

Returns:

  • (Boolean)


17358
17359
17360
17361
17362
17363
17364
17365
17366
17367
17368
17369
17370
17371
17372
17373
17374
17375
17376
17377
17378
17379
17380
17381
17382
# File 'lib/aws-sdk-sagemaker/types.rb', line 17358

class DescribeAutoMLJobResponse < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :problem_type,
  :auto_ml_job_config,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :generate_candidate_definitions_only,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result)
  SENSITIVE = []
  include Aws::Structure
end

#input_data_configArray<Types::AutoMLChannel>

Returns the input data configuration for the AutoML job.

Returns:



17358
17359
17360
17361
17362
17363
17364
17365
17366
17367
17368
17369
17370
17371
17372
17373
17374
17375
17376
17377
17378
17379
17380
17381
17382
# File 'lib/aws-sdk-sagemaker/types.rb', line 17358

class DescribeAutoMLJobResponse < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :problem_type,
  :auto_ml_job_config,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :generate_candidate_definitions_only,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

Returns the job’s last modified time.

Returns:

  • (Time)


17358
17359
17360
17361
17362
17363
17364
17365
17366
17367
17368
17369
17370
17371
17372
17373
17374
17375
17376
17377
17378
17379
17380
17381
17382
# File 'lib/aws-sdk-sagemaker/types.rb', line 17358

class DescribeAutoMLJobResponse < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :problem_type,
  :auto_ml_job_config,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :generate_candidate_definitions_only,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result)
  SENSITIVE = []
  include Aws::Structure
end

#model_deploy_configTypes::ModelDeployConfig

Indicates whether the model was deployed automatically to an endpoint and the name of that endpoint if deployed automatically.



17358
17359
17360
17361
17362
17363
17364
17365
17366
17367
17368
17369
17370
17371
17372
17373
17374
17375
17376
17377
17378
17379
17380
17381
17382
# File 'lib/aws-sdk-sagemaker/types.rb', line 17358

class DescribeAutoMLJobResponse < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :problem_type,
  :auto_ml_job_config,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :generate_candidate_definitions_only,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result)
  SENSITIVE = []
  include Aws::Structure
end

#model_deploy_resultTypes::ModelDeployResult

Provides information about endpoint for the model deployment.



17358
17359
17360
17361
17362
17363
17364
17365
17366
17367
17368
17369
17370
17371
17372
17373
17374
17375
17376
17377
17378
17379
17380
17381
17382
# File 'lib/aws-sdk-sagemaker/types.rb', line 17358

class DescribeAutoMLJobResponse < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :problem_type,
  :auto_ml_job_config,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :generate_candidate_definitions_only,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result)
  SENSITIVE = []
  include Aws::Structure
end

#output_data_configTypes::AutoMLOutputDataConfig

Returns the job’s output data config.



17358
17359
17360
17361
17362
17363
17364
17365
17366
17367
17368
17369
17370
17371
17372
17373
17374
17375
17376
17377
17378
17379
17380
17381
17382
# File 'lib/aws-sdk-sagemaker/types.rb', line 17358

class DescribeAutoMLJobResponse < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :problem_type,
  :auto_ml_job_config,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :generate_candidate_definitions_only,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result)
  SENSITIVE = []
  include Aws::Structure
end

#partial_failure_reasonsArray<Types::AutoMLPartialFailureReason>

Returns a list of reasons for partial failures within an AutoML job.



17358
17359
17360
17361
17362
17363
17364
17365
17366
17367
17368
17369
17370
17371
17372
17373
17374
17375
17376
17377
17378
17379
17380
17381
17382
# File 'lib/aws-sdk-sagemaker/types.rb', line 17358

class DescribeAutoMLJobResponse < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :problem_type,
  :auto_ml_job_config,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :generate_candidate_definitions_only,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result)
  SENSITIVE = []
  include Aws::Structure
end

#problem_typeString

Returns the job’s problem type.

Returns:

  • (String)


17358
17359
17360
17361
17362
17363
17364
17365
17366
17367
17368
17369
17370
17371
17372
17373
17374
17375
17376
17377
17378
17379
17380
17381
17382
# File 'lib/aws-sdk-sagemaker/types.rb', line 17358

class DescribeAutoMLJobResponse < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :problem_type,
  :auto_ml_job_config,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :generate_candidate_definitions_only,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result)
  SENSITIVE = []
  include Aws::Structure
end

#resolved_attributesTypes::ResolvedAttributes

Contains ‘ProblemType`, `AutoMLJobObjective`, and `CompletionCriteria`. If you do not provide these values, they are inferred.



17358
17359
17360
17361
17362
17363
17364
17365
17366
17367
17368
17369
17370
17371
17372
17373
17374
17375
17376
17377
17378
17379
17380
17381
17382
# File 'lib/aws-sdk-sagemaker/types.rb', line 17358

class DescribeAutoMLJobResponse < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :problem_type,
  :auto_ml_job_config,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :generate_candidate_definitions_only,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The ARN of the IAM role that has read permission to the input data location and write permission to the output data location in Amazon S3.

Returns:

  • (String)


17358
17359
17360
17361
17362
17363
17364
17365
17366
17367
17368
17369
17370
17371
17372
17373
17374
17375
17376
17377
17378
17379
17380
17381
17382
# File 'lib/aws-sdk-sagemaker/types.rb', line 17358

class DescribeAutoMLJobResponse < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :problem_type,
  :auto_ml_job_config,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :generate_candidate_definitions_only,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result)
  SENSITIVE = []
  include Aws::Structure
end