Class: Aws::SageMaker::Types::DescribeAutoMLJobResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeAutoMLJobResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_ml_job_arn ⇒ String
Returns the ARN of the AutoML job.
-
#auto_ml_job_artifacts ⇒ Types::AutoMLJobArtifacts
Returns information on the job’s artifacts found in
AutoMLJobArtifacts. -
#auto_ml_job_config ⇒ Types::AutoMLJobConfig
Returns the configuration for the AutoML job.
-
#auto_ml_job_name ⇒ String
Returns the name of the AutoML job.
-
#auto_ml_job_objective ⇒ Types::AutoMLJobObjective
Returns the job’s objective.
-
#auto_ml_job_secondary_status ⇒ String
Returns the secondary status of the AutoML job.
-
#auto_ml_job_status ⇒ String
Returns the status of the AutoML job.
-
#best_candidate ⇒ Types::AutoMLCandidate
The best model candidate selected by SageMaker Autopilot using both the best objective metric and lowest [InferenceLatency] for an experiment.
-
#creation_time ⇒ Time
Returns the creation time of the AutoML job.
-
#end_time ⇒ Time
Returns the end time of the AutoML job.
-
#failure_reason ⇒ String
Returns the failure reason for an AutoML job, when applicable.
-
#generate_candidate_definitions_only ⇒ Boolean
Indicates whether the output for an AutoML job generates candidate definitions only.
-
#input_data_config ⇒ Array<Types::AutoMLChannel>
Returns the input data configuration for the AutoML job..
-
#last_modified_time ⇒ Time
Returns the job’s last modified time.
-
#model_deploy_config ⇒ Types::ModelDeployConfig
Indicates whether the model was deployed automatically to an endpoint and the name of that endpoint if deployed automatically.
-
#model_deploy_result ⇒ Types::ModelDeployResult
Provides information about endpoint for the model deployment.
-
#output_data_config ⇒ Types::AutoMLOutputDataConfig
Returns the job’s output data config.
-
#partial_failure_reasons ⇒ Array<Types::AutoMLPartialFailureReason>
Returns a list of reasons for partial failures within an AutoML job.
-
#problem_type ⇒ String
Returns the job’s problem type.
-
#resolved_attributes ⇒ Types::ResolvedAttributes
This contains
ProblemType,AutoMLJobObjective, andCompletionCriteria. -
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the Identity and Access Management (IAM) role that has read permission to the input data location and write permission to the output data location in Amazon S3.
Instance Attribute Details
#auto_ml_job_arn ⇒ String
Returns the ARN of the AutoML job.
10170 10171 10172 10173 10174 10175 10176 10177 10178 10179 10180 10181 10182 10183 10184 10185 10186 10187 10188 10189 10190 10191 10192 10193 10194 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10170 class DescribeAutoMLJobResponse < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :problem_type, :auto_ml_job_config, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :generate_candidate_definitions_only, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result) SENSITIVE = [] include Aws::Structure end |
#auto_ml_job_artifacts ⇒ Types::AutoMLJobArtifacts
Returns information on the job’s artifacts found in AutoMLJobArtifacts.
10170 10171 10172 10173 10174 10175 10176 10177 10178 10179 10180 10181 10182 10183 10184 10185 10186 10187 10188 10189 10190 10191 10192 10193 10194 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10170 class DescribeAutoMLJobResponse < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :problem_type, :auto_ml_job_config, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :generate_candidate_definitions_only, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result) SENSITIVE = [] include Aws::Structure end |
#auto_ml_job_config ⇒ Types::AutoMLJobConfig
Returns the configuration for the AutoML job.
10170 10171 10172 10173 10174 10175 10176 10177 10178 10179 10180 10181 10182 10183 10184 10185 10186 10187 10188 10189 10190 10191 10192 10193 10194 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10170 class DescribeAutoMLJobResponse < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :problem_type, :auto_ml_job_config, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :generate_candidate_definitions_only, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result) SENSITIVE = [] include Aws::Structure end |
#auto_ml_job_name ⇒ String
Returns the name of the AutoML job.
10170 10171 10172 10173 10174 10175 10176 10177 10178 10179 10180 10181 10182 10183 10184 10185 10186 10187 10188 10189 10190 10191 10192 10193 10194 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10170 class DescribeAutoMLJobResponse < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :problem_type, :auto_ml_job_config, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :generate_candidate_definitions_only, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result) SENSITIVE = [] include Aws::Structure end |
#auto_ml_job_objective ⇒ Types::AutoMLJobObjective
Returns the job’s objective.
10170 10171 10172 10173 10174 10175 10176 10177 10178 10179 10180 10181 10182 10183 10184 10185 10186 10187 10188 10189 10190 10191 10192 10193 10194 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10170 class DescribeAutoMLJobResponse < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :problem_type, :auto_ml_job_config, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :generate_candidate_definitions_only, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result) SENSITIVE = [] include Aws::Structure end |
#auto_ml_job_secondary_status ⇒ String
Returns the secondary status of the AutoML job.
10170 10171 10172 10173 10174 10175 10176 10177 10178 10179 10180 10181 10182 10183 10184 10185 10186 10187 10188 10189 10190 10191 10192 10193 10194 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10170 class DescribeAutoMLJobResponse < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :problem_type, :auto_ml_job_config, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :generate_candidate_definitions_only, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result) SENSITIVE = [] include Aws::Structure end |
#auto_ml_job_status ⇒ String
Returns the status of the AutoML job.
10170 10171 10172 10173 10174 10175 10176 10177 10178 10179 10180 10181 10182 10183 10184 10185 10186 10187 10188 10189 10190 10191 10192 10193 10194 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10170 class DescribeAutoMLJobResponse < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :problem_type, :auto_ml_job_config, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :generate_candidate_definitions_only, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result) SENSITIVE = [] include Aws::Structure end |
#best_candidate ⇒ Types::AutoMLCandidate
The best model candidate selected by SageMaker Autopilot using both the best objective metric and lowest [InferenceLatency] for an experiment.
[1]: docs.aws.amazon.com/sagemaker/latest/dg/autopilot-metrics-validation.html
10170 10171 10172 10173 10174 10175 10176 10177 10178 10179 10180 10181 10182 10183 10184 10185 10186 10187 10188 10189 10190 10191 10192 10193 10194 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10170 class DescribeAutoMLJobResponse < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :problem_type, :auto_ml_job_config, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :generate_candidate_definitions_only, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
Returns the creation time of the AutoML job.
10170 10171 10172 10173 10174 10175 10176 10177 10178 10179 10180 10181 10182 10183 10184 10185 10186 10187 10188 10189 10190 10191 10192 10193 10194 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10170 class DescribeAutoMLJobResponse < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :problem_type, :auto_ml_job_config, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :generate_candidate_definitions_only, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
Returns the end time of the AutoML job.
10170 10171 10172 10173 10174 10175 10176 10177 10178 10179 10180 10181 10182 10183 10184 10185 10186 10187 10188 10189 10190 10191 10192 10193 10194 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10170 class DescribeAutoMLJobResponse < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :problem_type, :auto_ml_job_config, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :generate_candidate_definitions_only, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
Returns the failure reason for an AutoML job, when applicable.
10170 10171 10172 10173 10174 10175 10176 10177 10178 10179 10180 10181 10182 10183 10184 10185 10186 10187 10188 10189 10190 10191 10192 10193 10194 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10170 class DescribeAutoMLJobResponse < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :problem_type, :auto_ml_job_config, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :generate_candidate_definitions_only, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result) SENSITIVE = [] include Aws::Structure end |
#generate_candidate_definitions_only ⇒ Boolean
Indicates whether the output for an AutoML job generates candidate definitions only.
10170 10171 10172 10173 10174 10175 10176 10177 10178 10179 10180 10181 10182 10183 10184 10185 10186 10187 10188 10189 10190 10191 10192 10193 10194 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10170 class DescribeAutoMLJobResponse < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :problem_type, :auto_ml_job_config, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :generate_candidate_definitions_only, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result) SENSITIVE = [] include Aws::Structure end |
#input_data_config ⇒ Array<Types::AutoMLChannel>
Returns the input data configuration for the AutoML job..
10170 10171 10172 10173 10174 10175 10176 10177 10178 10179 10180 10181 10182 10183 10184 10185 10186 10187 10188 10189 10190 10191 10192 10193 10194 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10170 class DescribeAutoMLJobResponse < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :problem_type, :auto_ml_job_config, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :generate_candidate_definitions_only, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
Returns the job’s last modified time.
10170 10171 10172 10173 10174 10175 10176 10177 10178 10179 10180 10181 10182 10183 10184 10185 10186 10187 10188 10189 10190 10191 10192 10193 10194 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10170 class DescribeAutoMLJobResponse < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :problem_type, :auto_ml_job_config, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :generate_candidate_definitions_only, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result) SENSITIVE = [] include Aws::Structure end |
#model_deploy_config ⇒ Types::ModelDeployConfig
Indicates whether the model was deployed automatically to an endpoint and the name of that endpoint if deployed automatically.
10170 10171 10172 10173 10174 10175 10176 10177 10178 10179 10180 10181 10182 10183 10184 10185 10186 10187 10188 10189 10190 10191 10192 10193 10194 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10170 class DescribeAutoMLJobResponse < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :problem_type, :auto_ml_job_config, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :generate_candidate_definitions_only, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result) SENSITIVE = [] include Aws::Structure end |
#model_deploy_result ⇒ Types::ModelDeployResult
Provides information about endpoint for the model deployment.
10170 10171 10172 10173 10174 10175 10176 10177 10178 10179 10180 10181 10182 10183 10184 10185 10186 10187 10188 10189 10190 10191 10192 10193 10194 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10170 class DescribeAutoMLJobResponse < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :problem_type, :auto_ml_job_config, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :generate_candidate_definitions_only, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result) SENSITIVE = [] include Aws::Structure end |
#output_data_config ⇒ Types::AutoMLOutputDataConfig
Returns the job’s output data config.
10170 10171 10172 10173 10174 10175 10176 10177 10178 10179 10180 10181 10182 10183 10184 10185 10186 10187 10188 10189 10190 10191 10192 10193 10194 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10170 class DescribeAutoMLJobResponse < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :problem_type, :auto_ml_job_config, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :generate_candidate_definitions_only, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result) SENSITIVE = [] include Aws::Structure end |
#partial_failure_reasons ⇒ Array<Types::AutoMLPartialFailureReason>
Returns a list of reasons for partial failures within an AutoML job.
10170 10171 10172 10173 10174 10175 10176 10177 10178 10179 10180 10181 10182 10183 10184 10185 10186 10187 10188 10189 10190 10191 10192 10193 10194 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10170 class DescribeAutoMLJobResponse < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :problem_type, :auto_ml_job_config, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :generate_candidate_definitions_only, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result) SENSITIVE = [] include Aws::Structure end |
#problem_type ⇒ String
Returns the job’s problem type.
10170 10171 10172 10173 10174 10175 10176 10177 10178 10179 10180 10181 10182 10183 10184 10185 10186 10187 10188 10189 10190 10191 10192 10193 10194 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10170 class DescribeAutoMLJobResponse < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :problem_type, :auto_ml_job_config, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :generate_candidate_definitions_only, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result) SENSITIVE = [] include Aws::Structure end |
#resolved_attributes ⇒ Types::ResolvedAttributes
This contains ProblemType, AutoMLJobObjective, and CompletionCriteria. If you do not provide these values, they are auto-inferred. If you do provide them, the values used are the ones you provide.
10170 10171 10172 10173 10174 10175 10176 10177 10178 10179 10180 10181 10182 10183 10184 10185 10186 10187 10188 10189 10190 10191 10192 10193 10194 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10170 class DescribeAutoMLJobResponse < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :problem_type, :auto_ml_job_config, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :generate_candidate_definitions_only, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the Identity and Access Management (IAM) role that has read permission to the input data location and write permission to the output data location in Amazon S3.
10170 10171 10172 10173 10174 10175 10176 10177 10178 10179 10180 10181 10182 10183 10184 10185 10186 10187 10188 10189 10190 10191 10192 10193 10194 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10170 class DescribeAutoMLJobResponse < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :problem_type, :auto_ml_job_config, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :generate_candidate_definitions_only, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result) SENSITIVE = [] include Aws::Structure end |