Class: Aws::SageMaker::Types::DescribeAutoMLJobV2Response

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_ml_compute_configTypes::AutoMLComputeConfig

The compute configuration used for the AutoML job V2.



17989
17990
17991
17992
17993
17994
17995
17996
17997
17998
17999
18000
18001
18002
18003
18004
18005
18006
18007
18008
18009
18010
18011
18012
18013
18014
18015
# File 'lib/aws-sdk-sagemaker/types.rb', line 17989

class DescribeAutoMLJobV2Response < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :auto_ml_job_input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :auto_ml_problem_type_config,
  :auto_ml_problem_type_config_name,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result,
  :data_split_config,
  :security_config,
  :auto_ml_compute_config)
  SENSITIVE = []
  include Aws::Structure
end

#auto_ml_job_arnString

Returns the Amazon Resource Name (ARN) of the AutoML job V2.

Returns:

  • (String)


17989
17990
17991
17992
17993
17994
17995
17996
17997
17998
17999
18000
18001
18002
18003
18004
18005
18006
18007
18008
18009
18010
18011
18012
18013
18014
18015
# File 'lib/aws-sdk-sagemaker/types.rb', line 17989

class DescribeAutoMLJobV2Response < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :auto_ml_job_input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :auto_ml_problem_type_config,
  :auto_ml_problem_type_config_name,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result,
  :data_split_config,
  :security_config,
  :auto_ml_compute_config)
  SENSITIVE = []
  include Aws::Structure
end

#auto_ml_job_artifactsTypes::AutoMLJobArtifacts

The artifacts that are generated during an AutoML job.



17989
17990
17991
17992
17993
17994
17995
17996
17997
17998
17999
18000
18001
18002
18003
18004
18005
18006
18007
18008
18009
18010
18011
18012
18013
18014
18015
# File 'lib/aws-sdk-sagemaker/types.rb', line 17989

class DescribeAutoMLJobV2Response < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :auto_ml_job_input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :auto_ml_problem_type_config,
  :auto_ml_problem_type_config_name,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result,
  :data_split_config,
  :security_config,
  :auto_ml_compute_config)
  SENSITIVE = []
  include Aws::Structure
end

#auto_ml_job_input_data_configArray<Types::AutoMLJobChannel>

Returns an array of channel objects describing the input data and their location.

Returns:



17989
17990
17991
17992
17993
17994
17995
17996
17997
17998
17999
18000
18001
18002
18003
18004
18005
18006
18007
18008
18009
18010
18011
18012
18013
18014
18015
# File 'lib/aws-sdk-sagemaker/types.rb', line 17989

class DescribeAutoMLJobV2Response < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :auto_ml_job_input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :auto_ml_problem_type_config,
  :auto_ml_problem_type_config_name,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result,
  :data_split_config,
  :security_config,
  :auto_ml_compute_config)
  SENSITIVE = []
  include Aws::Structure
end

#auto_ml_job_nameString

Returns the name of the AutoML job V2.

Returns:

  • (String)


17989
17990
17991
17992
17993
17994
17995
17996
17997
17998
17999
18000
18001
18002
18003
18004
18005
18006
18007
18008
18009
18010
18011
18012
18013
18014
18015
# File 'lib/aws-sdk-sagemaker/types.rb', line 17989

class DescribeAutoMLJobV2Response < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :auto_ml_job_input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :auto_ml_problem_type_config,
  :auto_ml_problem_type_config_name,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result,
  :data_split_config,
  :security_config,
  :auto_ml_compute_config)
  SENSITIVE = []
  include Aws::Structure
end

#auto_ml_job_objectiveTypes::AutoMLJobObjective

Returns the job's objective.



17989
17990
17991
17992
17993
17994
17995
17996
17997
17998
17999
18000
18001
18002
18003
18004
18005
18006
18007
18008
18009
18010
18011
18012
18013
18014
18015
# File 'lib/aws-sdk-sagemaker/types.rb', line 17989

class DescribeAutoMLJobV2Response < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :auto_ml_job_input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :auto_ml_problem_type_config,
  :auto_ml_problem_type_config_name,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result,
  :data_split_config,
  :security_config,
  :auto_ml_compute_config)
  SENSITIVE = []
  include Aws::Structure
end

#auto_ml_job_secondary_statusString

Returns the secondary status of the AutoML job V2.

Returns:

  • (String)


17989
17990
17991
17992
17993
17994
17995
17996
17997
17998
17999
18000
18001
18002
18003
18004
18005
18006
18007
18008
18009
18010
18011
18012
18013
18014
18015
# File 'lib/aws-sdk-sagemaker/types.rb', line 17989

class DescribeAutoMLJobV2Response < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :auto_ml_job_input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :auto_ml_problem_type_config,
  :auto_ml_problem_type_config_name,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result,
  :data_split_config,
  :security_config,
  :auto_ml_compute_config)
  SENSITIVE = []
  include Aws::Structure
end

#auto_ml_job_statusString

Returns the status of the AutoML job V2.

Returns:

  • (String)


17989
17990
17991
17992
17993
17994
17995
17996
17997
17998
17999
18000
18001
18002
18003
18004
18005
18006
18007
18008
18009
18010
18011
18012
18013
18014
18015
# File 'lib/aws-sdk-sagemaker/types.rb', line 17989

class DescribeAutoMLJobV2Response < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :auto_ml_job_input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :auto_ml_problem_type_config,
  :auto_ml_problem_type_config_name,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result,
  :data_split_config,
  :security_config,
  :auto_ml_compute_config)
  SENSITIVE = []
  include Aws::Structure
end

#auto_ml_problem_type_configTypes::AutoMLProblemTypeConfig

Returns the configuration settings of the problem type set for the AutoML job V2.



17989
17990
17991
17992
17993
17994
17995
17996
17997
17998
17999
18000
18001
18002
18003
18004
18005
18006
18007
18008
18009
18010
18011
18012
18013
18014
18015
# File 'lib/aws-sdk-sagemaker/types.rb', line 17989

class DescribeAutoMLJobV2Response < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :auto_ml_job_input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :auto_ml_problem_type_config,
  :auto_ml_problem_type_config_name,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result,
  :data_split_config,
  :security_config,
  :auto_ml_compute_config)
  SENSITIVE = []
  include Aws::Structure
end

#auto_ml_problem_type_config_nameString

Returns the name of the problem type configuration set for the AutoML job V2.

Returns:

  • (String)


17989
17990
17991
17992
17993
17994
17995
17996
17997
17998
17999
18000
18001
18002
18003
18004
18005
18006
18007
18008
18009
18010
18011
18012
18013
18014
18015
# File 'lib/aws-sdk-sagemaker/types.rb', line 17989

class DescribeAutoMLJobV2Response < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :auto_ml_job_input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :auto_ml_problem_type_config,
  :auto_ml_problem_type_config_name,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result,
  :data_split_config,
  :security_config,
  :auto_ml_compute_config)
  SENSITIVE = []
  include Aws::Structure
end

#best_candidateTypes::AutoMLCandidate

Information about the candidate produced by an AutoML training job V2, including its status, steps, and other properties.



17989
17990
17991
17992
17993
17994
17995
17996
17997
17998
17999
18000
18001
18002
18003
18004
18005
18006
18007
18008
18009
18010
18011
18012
18013
18014
18015
# File 'lib/aws-sdk-sagemaker/types.rb', line 17989

class DescribeAutoMLJobV2Response < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :auto_ml_job_input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :auto_ml_problem_type_config,
  :auto_ml_problem_type_config_name,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result,
  :data_split_config,
  :security_config,
  :auto_ml_compute_config)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

Returns the creation time of the AutoML job V2.

Returns:

  • (Time)


17989
17990
17991
17992
17993
17994
17995
17996
17997
17998
17999
18000
18001
18002
18003
18004
18005
18006
18007
18008
18009
18010
18011
18012
18013
18014
18015
# File 'lib/aws-sdk-sagemaker/types.rb', line 17989

class DescribeAutoMLJobV2Response < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :auto_ml_job_input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :auto_ml_problem_type_config,
  :auto_ml_problem_type_config_name,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result,
  :data_split_config,
  :security_config,
  :auto_ml_compute_config)
  SENSITIVE = []
  include Aws::Structure
end

#data_split_configTypes::AutoMLDataSplitConfig

Returns the configuration settings of how the data are split into train and validation datasets.



17989
17990
17991
17992
17993
17994
17995
17996
17997
17998
17999
18000
18001
18002
18003
18004
18005
18006
18007
18008
18009
18010
18011
18012
18013
18014
18015
# File 'lib/aws-sdk-sagemaker/types.rb', line 17989

class DescribeAutoMLJobV2Response < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :auto_ml_job_input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :auto_ml_problem_type_config,
  :auto_ml_problem_type_config_name,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result,
  :data_split_config,
  :security_config,
  :auto_ml_compute_config)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

Returns the end time of the AutoML job V2.

Returns:

  • (Time)


17989
17990
17991
17992
17993
17994
17995
17996
17997
17998
17999
18000
18001
18002
18003
18004
18005
18006
18007
18008
18009
18010
18011
18012
18013
18014
18015
# File 'lib/aws-sdk-sagemaker/types.rb', line 17989

class DescribeAutoMLJobV2Response < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :auto_ml_job_input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :auto_ml_problem_type_config,
  :auto_ml_problem_type_config_name,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result,
  :data_split_config,
  :security_config,
  :auto_ml_compute_config)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

Returns the reason for the failure of the AutoML job V2, when applicable.

Returns:

  • (String)


17989
17990
17991
17992
17993
17994
17995
17996
17997
17998
17999
18000
18001
18002
18003
18004
18005
18006
18007
18008
18009
18010
18011
18012
18013
18014
18015
# File 'lib/aws-sdk-sagemaker/types.rb', line 17989

class DescribeAutoMLJobV2Response < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :auto_ml_job_input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :auto_ml_problem_type_config,
  :auto_ml_problem_type_config_name,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result,
  :data_split_config,
  :security_config,
  :auto_ml_compute_config)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

Returns the job's last modified time.

Returns:

  • (Time)


17989
17990
17991
17992
17993
17994
17995
17996
17997
17998
17999
18000
18001
18002
18003
18004
18005
18006
18007
18008
18009
18010
18011
18012
18013
18014
18015
# File 'lib/aws-sdk-sagemaker/types.rb', line 17989

class DescribeAutoMLJobV2Response < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :auto_ml_job_input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :auto_ml_problem_type_config,
  :auto_ml_problem_type_config_name,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result,
  :data_split_config,
  :security_config,
  :auto_ml_compute_config)
  SENSITIVE = []
  include Aws::Structure
end

#model_deploy_configTypes::ModelDeployConfig

Indicates whether the model was deployed automatically to an endpoint and the name of that endpoint if deployed automatically.



17989
17990
17991
17992
17993
17994
17995
17996
17997
17998
17999
18000
18001
18002
18003
18004
18005
18006
18007
18008
18009
18010
18011
18012
18013
18014
18015
# File 'lib/aws-sdk-sagemaker/types.rb', line 17989

class DescribeAutoMLJobV2Response < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :auto_ml_job_input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :auto_ml_problem_type_config,
  :auto_ml_problem_type_config_name,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result,
  :data_split_config,
  :security_config,
  :auto_ml_compute_config)
  SENSITIVE = []
  include Aws::Structure
end

#model_deploy_resultTypes::ModelDeployResult

Provides information about endpoint for the model deployment.



17989
17990
17991
17992
17993
17994
17995
17996
17997
17998
17999
18000
18001
18002
18003
18004
18005
18006
18007
18008
18009
18010
18011
18012
18013
18014
18015
# File 'lib/aws-sdk-sagemaker/types.rb', line 17989

class DescribeAutoMLJobV2Response < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :auto_ml_job_input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :auto_ml_problem_type_config,
  :auto_ml_problem_type_config_name,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result,
  :data_split_config,
  :security_config,
  :auto_ml_compute_config)
  SENSITIVE = []
  include Aws::Structure
end

#output_data_configTypes::AutoMLOutputDataConfig

Returns the job's output data config.



17989
17990
17991
17992
17993
17994
17995
17996
17997
17998
17999
18000
18001
18002
18003
18004
18005
18006
18007
18008
18009
18010
18011
18012
18013
18014
18015
# File 'lib/aws-sdk-sagemaker/types.rb', line 17989

class DescribeAutoMLJobV2Response < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :auto_ml_job_input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :auto_ml_problem_type_config,
  :auto_ml_problem_type_config_name,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result,
  :data_split_config,
  :security_config,
  :auto_ml_compute_config)
  SENSITIVE = []
  include Aws::Structure
end

#partial_failure_reasonsArray<Types::AutoMLPartialFailureReason>

Returns a list of reasons for partial failures within an AutoML job V2.



17989
17990
17991
17992
17993
17994
17995
17996
17997
17998
17999
18000
18001
18002
18003
18004
18005
18006
18007
18008
18009
18010
18011
18012
18013
18014
18015
# File 'lib/aws-sdk-sagemaker/types.rb', line 17989

class DescribeAutoMLJobV2Response < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :auto_ml_job_input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :auto_ml_problem_type_config,
  :auto_ml_problem_type_config_name,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result,
  :data_split_config,
  :security_config,
  :auto_ml_compute_config)
  SENSITIVE = []
  include Aws::Structure
end

#resolved_attributesTypes::AutoMLResolvedAttributes

Returns the resolved attributes used by the AutoML job V2.



17989
17990
17991
17992
17993
17994
17995
17996
17997
17998
17999
18000
18001
18002
18003
18004
18005
18006
18007
18008
18009
18010
18011
18012
18013
18014
18015
# File 'lib/aws-sdk-sagemaker/types.rb', line 17989

class DescribeAutoMLJobV2Response < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :auto_ml_job_input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :auto_ml_problem_type_config,
  :auto_ml_problem_type_config_name,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result,
  :data_split_config,
  :security_config,
  :auto_ml_compute_config)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The ARN of the IAM role that has read permission to the input data location and write permission to the output data location in Amazon S3.

Returns:

  • (String)


17989
17990
17991
17992
17993
17994
17995
17996
17997
17998
17999
18000
18001
18002
18003
18004
18005
18006
18007
18008
18009
18010
18011
18012
18013
18014
18015
# File 'lib/aws-sdk-sagemaker/types.rb', line 17989

class DescribeAutoMLJobV2Response < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :auto_ml_job_input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :auto_ml_problem_type_config,
  :auto_ml_problem_type_config_name,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result,
  :data_split_config,
  :security_config,
  :auto_ml_compute_config)
  SENSITIVE = []
  include Aws::Structure
end

#security_configTypes::AutoMLSecurityConfig

Returns the security configuration for traffic encryption or Amazon VPC settings.



17989
17990
17991
17992
17993
17994
17995
17996
17997
17998
17999
18000
18001
18002
18003
18004
18005
18006
18007
18008
18009
18010
18011
18012
18013
18014
18015
# File 'lib/aws-sdk-sagemaker/types.rb', line 17989

class DescribeAutoMLJobV2Response < Struct.new(
  :auto_ml_job_name,
  :auto_ml_job_arn,
  :auto_ml_job_input_data_config,
  :output_data_config,
  :role_arn,
  :auto_ml_job_objective,
  :auto_ml_problem_type_config,
  :auto_ml_problem_type_config_name,
  :creation_time,
  :end_time,
  :last_modified_time,
  :failure_reason,
  :partial_failure_reasons,
  :best_candidate,
  :auto_ml_job_status,
  :auto_ml_job_secondary_status,
  :auto_ml_job_artifacts,
  :resolved_attributes,
  :model_deploy_config,
  :model_deploy_result,
  :data_split_config,
  :security_config,
  :auto_ml_compute_config)
  SENSITIVE = []
  include Aws::Structure
end