Class: Aws::SageMaker::Types::DescribeAutoMLJobV2Response
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeAutoMLJobV2Response
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_ml_compute_config ⇒ Types::AutoMLComputeConfig
The compute configuration used for the AutoML job V2.
-
#auto_ml_job_arn ⇒ String
Returns the Amazon Resource Name (ARN) of the AutoML job V2.
-
#auto_ml_job_artifacts ⇒ Types::AutoMLJobArtifacts
The artifacts that are generated during an AutoML job.
-
#auto_ml_job_input_data_config ⇒ Array<Types::AutoMLJobChannel>
Returns an array of channel objects describing the input data and their location.
-
#auto_ml_job_name ⇒ String
Returns the name of the AutoML job V2.
-
#auto_ml_job_objective ⇒ Types::AutoMLJobObjective
Returns the job’s objective.
-
#auto_ml_job_secondary_status ⇒ String
Returns the secondary status of the AutoML job V2.
-
#auto_ml_job_status ⇒ String
Returns the status of the AutoML job V2.
-
#auto_ml_problem_type_config ⇒ Types::AutoMLProblemTypeConfig
Returns the configuration settings of the problem type set for the AutoML job V2.
-
#auto_ml_problem_type_config_name ⇒ String
Returns the name of the problem type configuration set for the AutoML job V2.
-
#best_candidate ⇒ Types::AutoMLCandidate
Information about the candidate produced by an AutoML training job V2, including its status, steps, and other properties.
-
#creation_time ⇒ Time
Returns the creation time of the AutoML job V2.
-
#data_split_config ⇒ Types::AutoMLDataSplitConfig
Returns the configuration settings of how the data are split into train and validation datasets.
-
#end_time ⇒ Time
Returns the end time of the AutoML job V2.
-
#failure_reason ⇒ String
Returns the reason for the failure of the AutoML job V2, when applicable.
-
#last_modified_time ⇒ Time
Returns the job’s last modified time.
-
#model_deploy_config ⇒ Types::ModelDeployConfig
Indicates whether the model was deployed automatically to an endpoint and the name of that endpoint if deployed automatically.
-
#model_deploy_result ⇒ Types::ModelDeployResult
Provides information about endpoint for the model deployment.
-
#output_data_config ⇒ Types::AutoMLOutputDataConfig
Returns the job’s output data config.
-
#partial_failure_reasons ⇒ Array<Types::AutoMLPartialFailureReason>
Returns a list of reasons for partial failures within an AutoML job V2.
-
#resolved_attributes ⇒ Types::AutoMLResolvedAttributes
Returns the resolved attributes used by the AutoML job V2.
-
#role_arn ⇒ String
The ARN of the IAM role that has read permission to the input data location and write permission to the output data location in Amazon S3.
-
#security_config ⇒ Types::AutoMLSecurityConfig
Returns the security configuration for traffic encryption or Amazon VPC settings.
Instance Attribute Details
#auto_ml_compute_config ⇒ Types::AutoMLComputeConfig
The compute configuration used for the AutoML job V2.
17963 17964 17965 17966 17967 17968 17969 17970 17971 17972 17973 17974 17975 17976 17977 17978 17979 17980 17981 17982 17983 17984 17985 17986 17987 17988 17989 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17963 class DescribeAutoMLJobV2Response < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :auto_ml_job_input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :auto_ml_problem_type_config, :auto_ml_problem_type_config_name, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result, :data_split_config, :security_config, :auto_ml_compute_config) SENSITIVE = [] include Aws::Structure end |
#auto_ml_job_arn ⇒ String
Returns the Amazon Resource Name (ARN) of the AutoML job V2.
17963 17964 17965 17966 17967 17968 17969 17970 17971 17972 17973 17974 17975 17976 17977 17978 17979 17980 17981 17982 17983 17984 17985 17986 17987 17988 17989 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17963 class DescribeAutoMLJobV2Response < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :auto_ml_job_input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :auto_ml_problem_type_config, :auto_ml_problem_type_config_name, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result, :data_split_config, :security_config, :auto_ml_compute_config) SENSITIVE = [] include Aws::Structure end |
#auto_ml_job_artifacts ⇒ Types::AutoMLJobArtifacts
The artifacts that are generated during an AutoML job.
17963 17964 17965 17966 17967 17968 17969 17970 17971 17972 17973 17974 17975 17976 17977 17978 17979 17980 17981 17982 17983 17984 17985 17986 17987 17988 17989 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17963 class DescribeAutoMLJobV2Response < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :auto_ml_job_input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :auto_ml_problem_type_config, :auto_ml_problem_type_config_name, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result, :data_split_config, :security_config, :auto_ml_compute_config) SENSITIVE = [] include Aws::Structure end |
#auto_ml_job_input_data_config ⇒ Array<Types::AutoMLJobChannel>
Returns an array of channel objects describing the input data and their location.
17963 17964 17965 17966 17967 17968 17969 17970 17971 17972 17973 17974 17975 17976 17977 17978 17979 17980 17981 17982 17983 17984 17985 17986 17987 17988 17989 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17963 class DescribeAutoMLJobV2Response < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :auto_ml_job_input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :auto_ml_problem_type_config, :auto_ml_problem_type_config_name, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result, :data_split_config, :security_config, :auto_ml_compute_config) SENSITIVE = [] include Aws::Structure end |
#auto_ml_job_name ⇒ String
Returns the name of the AutoML job V2.
17963 17964 17965 17966 17967 17968 17969 17970 17971 17972 17973 17974 17975 17976 17977 17978 17979 17980 17981 17982 17983 17984 17985 17986 17987 17988 17989 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17963 class DescribeAutoMLJobV2Response < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :auto_ml_job_input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :auto_ml_problem_type_config, :auto_ml_problem_type_config_name, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result, :data_split_config, :security_config, :auto_ml_compute_config) SENSITIVE = [] include Aws::Structure end |
#auto_ml_job_objective ⇒ Types::AutoMLJobObjective
Returns the job’s objective.
17963 17964 17965 17966 17967 17968 17969 17970 17971 17972 17973 17974 17975 17976 17977 17978 17979 17980 17981 17982 17983 17984 17985 17986 17987 17988 17989 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17963 class DescribeAutoMLJobV2Response < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :auto_ml_job_input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :auto_ml_problem_type_config, :auto_ml_problem_type_config_name, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result, :data_split_config, :security_config, :auto_ml_compute_config) SENSITIVE = [] include Aws::Structure end |
#auto_ml_job_secondary_status ⇒ String
Returns the secondary status of the AutoML job V2.
17963 17964 17965 17966 17967 17968 17969 17970 17971 17972 17973 17974 17975 17976 17977 17978 17979 17980 17981 17982 17983 17984 17985 17986 17987 17988 17989 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17963 class DescribeAutoMLJobV2Response < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :auto_ml_job_input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :auto_ml_problem_type_config, :auto_ml_problem_type_config_name, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result, :data_split_config, :security_config, :auto_ml_compute_config) SENSITIVE = [] include Aws::Structure end |
#auto_ml_job_status ⇒ String
Returns the status of the AutoML job V2.
17963 17964 17965 17966 17967 17968 17969 17970 17971 17972 17973 17974 17975 17976 17977 17978 17979 17980 17981 17982 17983 17984 17985 17986 17987 17988 17989 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17963 class DescribeAutoMLJobV2Response < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :auto_ml_job_input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :auto_ml_problem_type_config, :auto_ml_problem_type_config_name, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result, :data_split_config, :security_config, :auto_ml_compute_config) SENSITIVE = [] include Aws::Structure end |
#auto_ml_problem_type_config ⇒ Types::AutoMLProblemTypeConfig
Returns the configuration settings of the problem type set for the AutoML job V2.
17963 17964 17965 17966 17967 17968 17969 17970 17971 17972 17973 17974 17975 17976 17977 17978 17979 17980 17981 17982 17983 17984 17985 17986 17987 17988 17989 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17963 class DescribeAutoMLJobV2Response < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :auto_ml_job_input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :auto_ml_problem_type_config, :auto_ml_problem_type_config_name, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result, :data_split_config, :security_config, :auto_ml_compute_config) SENSITIVE = [] include Aws::Structure end |
#auto_ml_problem_type_config_name ⇒ String
Returns the name of the problem type configuration set for the AutoML job V2.
17963 17964 17965 17966 17967 17968 17969 17970 17971 17972 17973 17974 17975 17976 17977 17978 17979 17980 17981 17982 17983 17984 17985 17986 17987 17988 17989 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17963 class DescribeAutoMLJobV2Response < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :auto_ml_job_input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :auto_ml_problem_type_config, :auto_ml_problem_type_config_name, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result, :data_split_config, :security_config, :auto_ml_compute_config) SENSITIVE = [] include Aws::Structure end |
#best_candidate ⇒ Types::AutoMLCandidate
Information about the candidate produced by an AutoML training job V2, including its status, steps, and other properties.
17963 17964 17965 17966 17967 17968 17969 17970 17971 17972 17973 17974 17975 17976 17977 17978 17979 17980 17981 17982 17983 17984 17985 17986 17987 17988 17989 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17963 class DescribeAutoMLJobV2Response < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :auto_ml_job_input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :auto_ml_problem_type_config, :auto_ml_problem_type_config_name, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result, :data_split_config, :security_config, :auto_ml_compute_config) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
Returns the creation time of the AutoML job V2.
17963 17964 17965 17966 17967 17968 17969 17970 17971 17972 17973 17974 17975 17976 17977 17978 17979 17980 17981 17982 17983 17984 17985 17986 17987 17988 17989 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17963 class DescribeAutoMLJobV2Response < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :auto_ml_job_input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :auto_ml_problem_type_config, :auto_ml_problem_type_config_name, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result, :data_split_config, :security_config, :auto_ml_compute_config) SENSITIVE = [] include Aws::Structure end |
#data_split_config ⇒ Types::AutoMLDataSplitConfig
Returns the configuration settings of how the data are split into train and validation datasets.
17963 17964 17965 17966 17967 17968 17969 17970 17971 17972 17973 17974 17975 17976 17977 17978 17979 17980 17981 17982 17983 17984 17985 17986 17987 17988 17989 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17963 class DescribeAutoMLJobV2Response < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :auto_ml_job_input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :auto_ml_problem_type_config, :auto_ml_problem_type_config_name, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result, :data_split_config, :security_config, :auto_ml_compute_config) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
Returns the end time of the AutoML job V2.
17963 17964 17965 17966 17967 17968 17969 17970 17971 17972 17973 17974 17975 17976 17977 17978 17979 17980 17981 17982 17983 17984 17985 17986 17987 17988 17989 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17963 class DescribeAutoMLJobV2Response < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :auto_ml_job_input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :auto_ml_problem_type_config, :auto_ml_problem_type_config_name, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result, :data_split_config, :security_config, :auto_ml_compute_config) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
Returns the reason for the failure of the AutoML job V2, when applicable.
17963 17964 17965 17966 17967 17968 17969 17970 17971 17972 17973 17974 17975 17976 17977 17978 17979 17980 17981 17982 17983 17984 17985 17986 17987 17988 17989 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17963 class DescribeAutoMLJobV2Response < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :auto_ml_job_input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :auto_ml_problem_type_config, :auto_ml_problem_type_config_name, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result, :data_split_config, :security_config, :auto_ml_compute_config) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
Returns the job’s last modified time.
17963 17964 17965 17966 17967 17968 17969 17970 17971 17972 17973 17974 17975 17976 17977 17978 17979 17980 17981 17982 17983 17984 17985 17986 17987 17988 17989 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17963 class DescribeAutoMLJobV2Response < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :auto_ml_job_input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :auto_ml_problem_type_config, :auto_ml_problem_type_config_name, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result, :data_split_config, :security_config, :auto_ml_compute_config) SENSITIVE = [] include Aws::Structure end |
#model_deploy_config ⇒ Types::ModelDeployConfig
Indicates whether the model was deployed automatically to an endpoint and the name of that endpoint if deployed automatically.
17963 17964 17965 17966 17967 17968 17969 17970 17971 17972 17973 17974 17975 17976 17977 17978 17979 17980 17981 17982 17983 17984 17985 17986 17987 17988 17989 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17963 class DescribeAutoMLJobV2Response < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :auto_ml_job_input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :auto_ml_problem_type_config, :auto_ml_problem_type_config_name, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result, :data_split_config, :security_config, :auto_ml_compute_config) SENSITIVE = [] include Aws::Structure end |
#model_deploy_result ⇒ Types::ModelDeployResult
Provides information about endpoint for the model deployment.
17963 17964 17965 17966 17967 17968 17969 17970 17971 17972 17973 17974 17975 17976 17977 17978 17979 17980 17981 17982 17983 17984 17985 17986 17987 17988 17989 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17963 class DescribeAutoMLJobV2Response < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :auto_ml_job_input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :auto_ml_problem_type_config, :auto_ml_problem_type_config_name, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result, :data_split_config, :security_config, :auto_ml_compute_config) SENSITIVE = [] include Aws::Structure end |
#output_data_config ⇒ Types::AutoMLOutputDataConfig
Returns the job’s output data config.
17963 17964 17965 17966 17967 17968 17969 17970 17971 17972 17973 17974 17975 17976 17977 17978 17979 17980 17981 17982 17983 17984 17985 17986 17987 17988 17989 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17963 class DescribeAutoMLJobV2Response < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :auto_ml_job_input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :auto_ml_problem_type_config, :auto_ml_problem_type_config_name, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result, :data_split_config, :security_config, :auto_ml_compute_config) SENSITIVE = [] include Aws::Structure end |
#partial_failure_reasons ⇒ Array<Types::AutoMLPartialFailureReason>
Returns a list of reasons for partial failures within an AutoML job V2.
17963 17964 17965 17966 17967 17968 17969 17970 17971 17972 17973 17974 17975 17976 17977 17978 17979 17980 17981 17982 17983 17984 17985 17986 17987 17988 17989 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17963 class DescribeAutoMLJobV2Response < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :auto_ml_job_input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :auto_ml_problem_type_config, :auto_ml_problem_type_config_name, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result, :data_split_config, :security_config, :auto_ml_compute_config) SENSITIVE = [] include Aws::Structure end |
#resolved_attributes ⇒ Types::AutoMLResolvedAttributes
Returns the resolved attributes used by the AutoML job V2.
17963 17964 17965 17966 17967 17968 17969 17970 17971 17972 17973 17974 17975 17976 17977 17978 17979 17980 17981 17982 17983 17984 17985 17986 17987 17988 17989 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17963 class DescribeAutoMLJobV2Response < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :auto_ml_job_input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :auto_ml_problem_type_config, :auto_ml_problem_type_config_name, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result, :data_split_config, :security_config, :auto_ml_compute_config) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The ARN of the IAM role that has read permission to the input data location and write permission to the output data location in Amazon S3.
17963 17964 17965 17966 17967 17968 17969 17970 17971 17972 17973 17974 17975 17976 17977 17978 17979 17980 17981 17982 17983 17984 17985 17986 17987 17988 17989 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17963 class DescribeAutoMLJobV2Response < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :auto_ml_job_input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :auto_ml_problem_type_config, :auto_ml_problem_type_config_name, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result, :data_split_config, :security_config, :auto_ml_compute_config) SENSITIVE = [] include Aws::Structure end |
#security_config ⇒ Types::AutoMLSecurityConfig
Returns the security configuration for traffic encryption or Amazon VPC settings.
17963 17964 17965 17966 17967 17968 17969 17970 17971 17972 17973 17974 17975 17976 17977 17978 17979 17980 17981 17982 17983 17984 17985 17986 17987 17988 17989 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17963 class DescribeAutoMLJobV2Response < Struct.new( :auto_ml_job_name, :auto_ml_job_arn, :auto_ml_job_input_data_config, :output_data_config, :role_arn, :auto_ml_job_objective, :auto_ml_problem_type_config, :auto_ml_problem_type_config_name, :creation_time, :end_time, :last_modified_time, :failure_reason, :partial_failure_reasons, :best_candidate, :auto_ml_job_status, :auto_ml_job_secondary_status, :auto_ml_job_artifacts, :resolved_attributes, :model_deploy_config, :model_deploy_result, :data_split_config, :security_config, :auto_ml_compute_config) SENSITIVE = [] include Aws::Structure end |