Class: Aws::SageMaker::Types::DescribeClusterNodeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeClusterNodeRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster_name ⇒ String
The string name or the Amazon Resource Name (ARN) of the SageMaker HyperPod cluster in which the node is.
-
#node_id ⇒ String
The ID of the SageMaker HyperPod cluster node.
-
#node_logical_id ⇒ String
The logical identifier of the node to describe.
Instance Attribute Details
#cluster_name ⇒ String
The string name or the Amazon Resource Name (ARN) of the SageMaker HyperPod cluster in which the node is.
18244 18245 18246 18247 18248 18249 18250 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18244 class DescribeClusterNodeRequest < Struct.new( :cluster_name, :node_id, :node_logical_id) SENSITIVE = [] include Aws::Structure end |
#node_id ⇒ String
The ID of the SageMaker HyperPod cluster node.
18244 18245 18246 18247 18248 18249 18250 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18244 class DescribeClusterNodeRequest < Struct.new( :cluster_name, :node_id, :node_logical_id) SENSITIVE = [] include Aws::Structure end |
#node_logical_id ⇒ String
The logical identifier of the node to describe. You can specify
either NodeLogicalId or InstanceId, but not both.
NodeLogicalId can be used to describe nodes that are still being
provisioned and don't yet have an InstanceId assigned.
18244 18245 18246 18247 18248 18249 18250 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18244 class DescribeClusterNodeRequest < Struct.new( :cluster_name, :node_id, :node_logical_id) SENSITIVE = [] include Aws::Structure end |