Class: Aws::SageMaker::Types::DescribeClusterResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeClusterResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_scaling ⇒ Types::ClusterAutoScalingConfigOutput
The current autoscaling configuration and status for the autoscaler.
-
#cluster_arn ⇒ String
The Amazon Resource Name (ARN) of the SageMaker HyperPod cluster.
-
#cluster_name ⇒ String
The name of the SageMaker HyperPod cluster.
-
#cluster_role ⇒ String
The Amazon Resource Name (ARN) of the IAM role that HyperPod uses for cluster autoscaling operations.
-
#cluster_status ⇒ String
The status of the SageMaker HyperPod cluster.
-
#creation_time ⇒ Time
The time when the SageMaker Cluster is created.
-
#failure_message ⇒ String
The failure message of the SageMaker HyperPod cluster.
-
#instance_groups ⇒ Array<Types::ClusterInstanceGroupDetails>
The instance groups of the SageMaker HyperPod cluster.
-
#node_provisioning_mode ⇒ String
The mode used for provisioning nodes in the cluster.
-
#node_recovery ⇒ String
The node recovery mode configured for the SageMaker HyperPod cluster.
-
#orchestrator ⇒ Types::ClusterOrchestrator
The type of orchestrator used for the SageMaker HyperPod cluster.
-
#restricted_instance_groups ⇒ Array<Types::ClusterRestrictedInstanceGroupDetails>
The specialized instance groups for training models like Amazon Nova to be created in the SageMaker HyperPod cluster.
-
#tiered_storage_config ⇒ Types::ClusterTieredStorageConfig
The current configuration for managed tier checkpointing on the HyperPod cluster.
-
#vpc_config ⇒ Types::VpcConfig
Specifies an Amazon Virtual Private Cloud (VPC) that your SageMaker jobs, hosted models, and compute resources have access to.
Instance Attribute Details
#auto_scaling ⇒ Types::ClusterAutoScalingConfigOutput
The current autoscaling configuration and status for the autoscaler.
17711 17712 17713 17714 17715 17716 17717 17718 17719 17720 17721 17722 17723 17724 17725 17726 17727 17728 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17711 class DescribeClusterResponse < Struct.new( :cluster_arn, :cluster_name, :cluster_status, :creation_time, :failure_message, :instance_groups, :restricted_instance_groups, :vpc_config, :orchestrator, :tiered_storage_config, :node_recovery, :node_provisioning_mode, :cluster_role, :auto_scaling) SENSITIVE = [] include Aws::Structure end |
#cluster_arn ⇒ String
The Amazon Resource Name (ARN) of the SageMaker HyperPod cluster.
17711 17712 17713 17714 17715 17716 17717 17718 17719 17720 17721 17722 17723 17724 17725 17726 17727 17728 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17711 class DescribeClusterResponse < Struct.new( :cluster_arn, :cluster_name, :cluster_status, :creation_time, :failure_message, :instance_groups, :restricted_instance_groups, :vpc_config, :orchestrator, :tiered_storage_config, :node_recovery, :node_provisioning_mode, :cluster_role, :auto_scaling) SENSITIVE = [] include Aws::Structure end |
#cluster_name ⇒ String
The name of the SageMaker HyperPod cluster.
17711 17712 17713 17714 17715 17716 17717 17718 17719 17720 17721 17722 17723 17724 17725 17726 17727 17728 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17711 class DescribeClusterResponse < Struct.new( :cluster_arn, :cluster_name, :cluster_status, :creation_time, :failure_message, :instance_groups, :restricted_instance_groups, :vpc_config, :orchestrator, :tiered_storage_config, :node_recovery, :node_provisioning_mode, :cluster_role, :auto_scaling) SENSITIVE = [] include Aws::Structure end |
#cluster_role ⇒ String
The Amazon Resource Name (ARN) of the IAM role that HyperPod uses for cluster autoscaling operations.
17711 17712 17713 17714 17715 17716 17717 17718 17719 17720 17721 17722 17723 17724 17725 17726 17727 17728 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17711 class DescribeClusterResponse < Struct.new( :cluster_arn, :cluster_name, :cluster_status, :creation_time, :failure_message, :instance_groups, :restricted_instance_groups, :vpc_config, :orchestrator, :tiered_storage_config, :node_recovery, :node_provisioning_mode, :cluster_role, :auto_scaling) SENSITIVE = [] include Aws::Structure end |
#cluster_status ⇒ String
The status of the SageMaker HyperPod cluster.
17711 17712 17713 17714 17715 17716 17717 17718 17719 17720 17721 17722 17723 17724 17725 17726 17727 17728 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17711 class DescribeClusterResponse < Struct.new( :cluster_arn, :cluster_name, :cluster_status, :creation_time, :failure_message, :instance_groups, :restricted_instance_groups, :vpc_config, :orchestrator, :tiered_storage_config, :node_recovery, :node_provisioning_mode, :cluster_role, :auto_scaling) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The time when the SageMaker Cluster is created.
17711 17712 17713 17714 17715 17716 17717 17718 17719 17720 17721 17722 17723 17724 17725 17726 17727 17728 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17711 class DescribeClusterResponse < Struct.new( :cluster_arn, :cluster_name, :cluster_status, :creation_time, :failure_message, :instance_groups, :restricted_instance_groups, :vpc_config, :orchestrator, :tiered_storage_config, :node_recovery, :node_provisioning_mode, :cluster_role, :auto_scaling) SENSITIVE = [] include Aws::Structure end |
#failure_message ⇒ String
The failure message of the SageMaker HyperPod cluster.
17711 17712 17713 17714 17715 17716 17717 17718 17719 17720 17721 17722 17723 17724 17725 17726 17727 17728 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17711 class DescribeClusterResponse < Struct.new( :cluster_arn, :cluster_name, :cluster_status, :creation_time, :failure_message, :instance_groups, :restricted_instance_groups, :vpc_config, :orchestrator, :tiered_storage_config, :node_recovery, :node_provisioning_mode, :cluster_role, :auto_scaling) SENSITIVE = [] include Aws::Structure end |
#instance_groups ⇒ Array<Types::ClusterInstanceGroupDetails>
The instance groups of the SageMaker HyperPod cluster.
17711 17712 17713 17714 17715 17716 17717 17718 17719 17720 17721 17722 17723 17724 17725 17726 17727 17728 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17711 class DescribeClusterResponse < Struct.new( :cluster_arn, :cluster_name, :cluster_status, :creation_time, :failure_message, :instance_groups, :restricted_instance_groups, :vpc_config, :orchestrator, :tiered_storage_config, :node_recovery, :node_provisioning_mode, :cluster_role, :auto_scaling) SENSITIVE = [] include Aws::Structure end |
#node_provisioning_mode ⇒ String
The mode used for provisioning nodes in the cluster.
17711 17712 17713 17714 17715 17716 17717 17718 17719 17720 17721 17722 17723 17724 17725 17726 17727 17728 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17711 class DescribeClusterResponse < Struct.new( :cluster_arn, :cluster_name, :cluster_status, :creation_time, :failure_message, :instance_groups, :restricted_instance_groups, :vpc_config, :orchestrator, :tiered_storage_config, :node_recovery, :node_provisioning_mode, :cluster_role, :auto_scaling) SENSITIVE = [] include Aws::Structure end |
#node_recovery ⇒ String
The node recovery mode configured for the SageMaker HyperPod cluster.
17711 17712 17713 17714 17715 17716 17717 17718 17719 17720 17721 17722 17723 17724 17725 17726 17727 17728 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17711 class DescribeClusterResponse < Struct.new( :cluster_arn, :cluster_name, :cluster_status, :creation_time, :failure_message, :instance_groups, :restricted_instance_groups, :vpc_config, :orchestrator, :tiered_storage_config, :node_recovery, :node_provisioning_mode, :cluster_role, :auto_scaling) SENSITIVE = [] include Aws::Structure end |
#orchestrator ⇒ Types::ClusterOrchestrator
The type of orchestrator used for the SageMaker HyperPod cluster.
17711 17712 17713 17714 17715 17716 17717 17718 17719 17720 17721 17722 17723 17724 17725 17726 17727 17728 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17711 class DescribeClusterResponse < Struct.new( :cluster_arn, :cluster_name, :cluster_status, :creation_time, :failure_message, :instance_groups, :restricted_instance_groups, :vpc_config, :orchestrator, :tiered_storage_config, :node_recovery, :node_provisioning_mode, :cluster_role, :auto_scaling) SENSITIVE = [] include Aws::Structure end |
#restricted_instance_groups ⇒ Array<Types::ClusterRestrictedInstanceGroupDetails>
The specialized instance groups for training models like Amazon Nova to be created in the SageMaker HyperPod cluster.
17711 17712 17713 17714 17715 17716 17717 17718 17719 17720 17721 17722 17723 17724 17725 17726 17727 17728 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17711 class DescribeClusterResponse < Struct.new( :cluster_arn, :cluster_name, :cluster_status, :creation_time, :failure_message, :instance_groups, :restricted_instance_groups, :vpc_config, :orchestrator, :tiered_storage_config, :node_recovery, :node_provisioning_mode, :cluster_role, :auto_scaling) SENSITIVE = [] include Aws::Structure end |
#tiered_storage_config ⇒ Types::ClusterTieredStorageConfig
The current configuration for managed tier checkpointing on the HyperPod cluster. For example, this shows whether the feature is enabled and the percentage of cluster memory allocated for checkpoint storage.
17711 17712 17713 17714 17715 17716 17717 17718 17719 17720 17721 17722 17723 17724 17725 17726 17727 17728 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17711 class DescribeClusterResponse < Struct.new( :cluster_arn, :cluster_name, :cluster_status, :creation_time, :failure_message, :instance_groups, :restricted_instance_groups, :vpc_config, :orchestrator, :tiered_storage_config, :node_recovery, :node_provisioning_mode, :cluster_role, :auto_scaling) SENSITIVE = [] include Aws::Structure end |
#vpc_config ⇒ Types::VpcConfig
Specifies an Amazon Virtual Private Cloud (VPC) that your SageMaker jobs, hosted models, and compute resources have access to. You can control access to and from your resources by configuring a VPC. For more information, see [Give SageMaker Access to Resources in your Amazon VPC].
[1]: docs.aws.amazon.com/sagemaker/latest/dg/infrastructure-give-access.html
17711 17712 17713 17714 17715 17716 17717 17718 17719 17720 17721 17722 17723 17724 17725 17726 17727 17728 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17711 class DescribeClusterResponse < Struct.new( :cluster_arn, :cluster_name, :cluster_status, :creation_time, :failure_message, :instance_groups, :restricted_instance_groups, :vpc_config, :orchestrator, :tiered_storage_config, :node_recovery, :node_provisioning_mode, :cluster_role, :auto_scaling) SENSITIVE = [] include Aws::Structure end |