Class: Aws::SageMaker::Types::DescribeClusterResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_scalingTypes::ClusterAutoScalingConfigOutput

The current autoscaling configuration and status for the autoscaler.



16489
16490
16491
16492
16493
16494
16495
16496
16497
16498
16499
16500
16501
16502
16503
16504
16505
16506
# File 'lib/aws-sdk-sagemaker/types.rb', line 16489

class DescribeClusterResponse < Struct.new(
  :cluster_arn,
  :cluster_name,
  :cluster_status,
  :creation_time,
  :failure_message,
  :instance_groups,
  :restricted_instance_groups,
  :vpc_config,
  :orchestrator,
  :tiered_storage_config,
  :node_recovery,
  :node_provisioning_mode,
  :cluster_role,
  :auto_scaling)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_arnString

The Amazon Resource Name (ARN) of the SageMaker HyperPod cluster.

Returns:

  • (String)


16489
16490
16491
16492
16493
16494
16495
16496
16497
16498
16499
16500
16501
16502
16503
16504
16505
16506
# File 'lib/aws-sdk-sagemaker/types.rb', line 16489

class DescribeClusterResponse < Struct.new(
  :cluster_arn,
  :cluster_name,
  :cluster_status,
  :creation_time,
  :failure_message,
  :instance_groups,
  :restricted_instance_groups,
  :vpc_config,
  :orchestrator,
  :tiered_storage_config,
  :node_recovery,
  :node_provisioning_mode,
  :cluster_role,
  :auto_scaling)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_nameString

The name of the SageMaker HyperPod cluster.

Returns:

  • (String)


16489
16490
16491
16492
16493
16494
16495
16496
16497
16498
16499
16500
16501
16502
16503
16504
16505
16506
# File 'lib/aws-sdk-sagemaker/types.rb', line 16489

class DescribeClusterResponse < Struct.new(
  :cluster_arn,
  :cluster_name,
  :cluster_status,
  :creation_time,
  :failure_message,
  :instance_groups,
  :restricted_instance_groups,
  :vpc_config,
  :orchestrator,
  :tiered_storage_config,
  :node_recovery,
  :node_provisioning_mode,
  :cluster_role,
  :auto_scaling)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_roleString

The Amazon Resource Name (ARN) of the IAM role that HyperPod uses for cluster autoscaling operations.

Returns:

  • (String)


16489
16490
16491
16492
16493
16494
16495
16496
16497
16498
16499
16500
16501
16502
16503
16504
16505
16506
# File 'lib/aws-sdk-sagemaker/types.rb', line 16489

class DescribeClusterResponse < Struct.new(
  :cluster_arn,
  :cluster_name,
  :cluster_status,
  :creation_time,
  :failure_message,
  :instance_groups,
  :restricted_instance_groups,
  :vpc_config,
  :orchestrator,
  :tiered_storage_config,
  :node_recovery,
  :node_provisioning_mode,
  :cluster_role,
  :auto_scaling)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_statusString

The status of the SageMaker HyperPod cluster.

Returns:

  • (String)


16489
16490
16491
16492
16493
16494
16495
16496
16497
16498
16499
16500
16501
16502
16503
16504
16505
16506
# File 'lib/aws-sdk-sagemaker/types.rb', line 16489

class DescribeClusterResponse < Struct.new(
  :cluster_arn,
  :cluster_name,
  :cluster_status,
  :creation_time,
  :failure_message,
  :instance_groups,
  :restricted_instance_groups,
  :vpc_config,
  :orchestrator,
  :tiered_storage_config,
  :node_recovery,
  :node_provisioning_mode,
  :cluster_role,
  :auto_scaling)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

The time when the SageMaker Cluster is created.

Returns:

  • (Time)


16489
16490
16491
16492
16493
16494
16495
16496
16497
16498
16499
16500
16501
16502
16503
16504
16505
16506
# File 'lib/aws-sdk-sagemaker/types.rb', line 16489

class DescribeClusterResponse < Struct.new(
  :cluster_arn,
  :cluster_name,
  :cluster_status,
  :creation_time,
  :failure_message,
  :instance_groups,
  :restricted_instance_groups,
  :vpc_config,
  :orchestrator,
  :tiered_storage_config,
  :node_recovery,
  :node_provisioning_mode,
  :cluster_role,
  :auto_scaling)
  SENSITIVE = []
  include Aws::Structure
end

#failure_messageString

The failure message of the SageMaker HyperPod cluster.

Returns:

  • (String)


16489
16490
16491
16492
16493
16494
16495
16496
16497
16498
16499
16500
16501
16502
16503
16504
16505
16506
# File 'lib/aws-sdk-sagemaker/types.rb', line 16489

class DescribeClusterResponse < Struct.new(
  :cluster_arn,
  :cluster_name,
  :cluster_status,
  :creation_time,
  :failure_message,
  :instance_groups,
  :restricted_instance_groups,
  :vpc_config,
  :orchestrator,
  :tiered_storage_config,
  :node_recovery,
  :node_provisioning_mode,
  :cluster_role,
  :auto_scaling)
  SENSITIVE = []
  include Aws::Structure
end

#instance_groupsArray<Types::ClusterInstanceGroupDetails>

The instance groups of the SageMaker HyperPod cluster.



16489
16490
16491
16492
16493
16494
16495
16496
16497
16498
16499
16500
16501
16502
16503
16504
16505
16506
# File 'lib/aws-sdk-sagemaker/types.rb', line 16489

class DescribeClusterResponse < Struct.new(
  :cluster_arn,
  :cluster_name,
  :cluster_status,
  :creation_time,
  :failure_message,
  :instance_groups,
  :restricted_instance_groups,
  :vpc_config,
  :orchestrator,
  :tiered_storage_config,
  :node_recovery,
  :node_provisioning_mode,
  :cluster_role,
  :auto_scaling)
  SENSITIVE = []
  include Aws::Structure
end

#node_provisioning_modeString

The mode used for provisioning nodes in the cluster.

Returns:

  • (String)


16489
16490
16491
16492
16493
16494
16495
16496
16497
16498
16499
16500
16501
16502
16503
16504
16505
16506
# File 'lib/aws-sdk-sagemaker/types.rb', line 16489

class DescribeClusterResponse < Struct.new(
  :cluster_arn,
  :cluster_name,
  :cluster_status,
  :creation_time,
  :failure_message,
  :instance_groups,
  :restricted_instance_groups,
  :vpc_config,
  :orchestrator,
  :tiered_storage_config,
  :node_recovery,
  :node_provisioning_mode,
  :cluster_role,
  :auto_scaling)
  SENSITIVE = []
  include Aws::Structure
end

#node_recoveryString

The node recovery mode configured for the SageMaker HyperPod cluster.

Returns:

  • (String)


16489
16490
16491
16492
16493
16494
16495
16496
16497
16498
16499
16500
16501
16502
16503
16504
16505
16506
# File 'lib/aws-sdk-sagemaker/types.rb', line 16489

class DescribeClusterResponse < Struct.new(
  :cluster_arn,
  :cluster_name,
  :cluster_status,
  :creation_time,
  :failure_message,
  :instance_groups,
  :restricted_instance_groups,
  :vpc_config,
  :orchestrator,
  :tiered_storage_config,
  :node_recovery,
  :node_provisioning_mode,
  :cluster_role,
  :auto_scaling)
  SENSITIVE = []
  include Aws::Structure
end

#orchestratorTypes::ClusterOrchestrator

The type of orchestrator used for the SageMaker HyperPod cluster.



16489
16490
16491
16492
16493
16494
16495
16496
16497
16498
16499
16500
16501
16502
16503
16504
16505
16506
# File 'lib/aws-sdk-sagemaker/types.rb', line 16489

class DescribeClusterResponse < Struct.new(
  :cluster_arn,
  :cluster_name,
  :cluster_status,
  :creation_time,
  :failure_message,
  :instance_groups,
  :restricted_instance_groups,
  :vpc_config,
  :orchestrator,
  :tiered_storage_config,
  :node_recovery,
  :node_provisioning_mode,
  :cluster_role,
  :auto_scaling)
  SENSITIVE = []
  include Aws::Structure
end

#restricted_instance_groupsArray<Types::ClusterRestrictedInstanceGroupDetails>

The specialized instance groups for training models like Amazon Nova to be created in the SageMaker HyperPod cluster.



16489
16490
16491
16492
16493
16494
16495
16496
16497
16498
16499
16500
16501
16502
16503
16504
16505
16506
# File 'lib/aws-sdk-sagemaker/types.rb', line 16489

class DescribeClusterResponse < Struct.new(
  :cluster_arn,
  :cluster_name,
  :cluster_status,
  :creation_time,
  :failure_message,
  :instance_groups,
  :restricted_instance_groups,
  :vpc_config,
  :orchestrator,
  :tiered_storage_config,
  :node_recovery,
  :node_provisioning_mode,
  :cluster_role,
  :auto_scaling)
  SENSITIVE = []
  include Aws::Structure
end

#tiered_storage_configTypes::ClusterTieredStorageConfig

The current configuration for managed tier checkpointing on the HyperPod cluster. For example, this shows whether the feature is enabled and the percentage of cluster memory allocated for checkpoint storage.



16489
16490
16491
16492
16493
16494
16495
16496
16497
16498
16499
16500
16501
16502
16503
16504
16505
16506
# File 'lib/aws-sdk-sagemaker/types.rb', line 16489

class DescribeClusterResponse < Struct.new(
  :cluster_arn,
  :cluster_name,
  :cluster_status,
  :creation_time,
  :failure_message,
  :instance_groups,
  :restricted_instance_groups,
  :vpc_config,
  :orchestrator,
  :tiered_storage_config,
  :node_recovery,
  :node_provisioning_mode,
  :cluster_role,
  :auto_scaling)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_configTypes::VpcConfig

Specifies an Amazon Virtual Private Cloud (VPC) that your SageMaker jobs, hosted models, and compute resources have access to. You can control access to and from your resources by configuring a VPC. For more information, see [Give SageMaker Access to Resources in your Amazon VPC].

[1]: docs.aws.amazon.com/sagemaker/latest/dg/infrastructure-give-access.html

Returns:



16489
16490
16491
16492
16493
16494
16495
16496
16497
16498
16499
16500
16501
16502
16503
16504
16505
16506
# File 'lib/aws-sdk-sagemaker/types.rb', line 16489

class DescribeClusterResponse < Struct.new(
  :cluster_arn,
  :cluster_name,
  :cluster_status,
  :creation_time,
  :failure_message,
  :instance_groups,
  :restricted_instance_groups,
  :vpc_config,
  :orchestrator,
  :tiered_storage_config,
  :node_recovery,
  :node_provisioning_mode,
  :cluster_role,
  :auto_scaling)
  SENSITIVE = []
  include Aws::Structure
end