Class: Aws::SageMaker::Types::DescribeClusterSchedulerConfigResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeClusterSchedulerConfigResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster_arn ⇒ String
ARN of the cluster where the cluster policy is applied.
-
#cluster_scheduler_config_arn ⇒ String
ARN of the cluster policy.
-
#cluster_scheduler_config_id ⇒ String
ID of the cluster policy.
-
#cluster_scheduler_config_version ⇒ Integer
Version of the cluster policy.
-
#created_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
-
#creation_time ⇒ Time
Creation time of the cluster policy.
-
#description ⇒ String
Description of the cluster policy.
-
#failure_reason ⇒ String
Failure reason of the cluster policy.
-
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
-
#last_modified_time ⇒ Time
Last modified time of the cluster policy.
-
#name ⇒ String
Name of the cluster policy.
-
#scheduler_config ⇒ Types::SchedulerConfig
Cluster policy configuration.
-
#status ⇒ String
Status of the cluster policy.
-
#status_details ⇒ Hash<String,String>
Additional details about the status of the cluster policy.
Instance Attribute Details
#cluster_arn ⇒ String
ARN of the cluster where the cluster policy is applied.
17785 17786 17787 17788 17789 17790 17791 17792 17793 17794 17795 17796 17797 17798 17799 17800 17801 17802 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17785 class DescribeClusterSchedulerConfigResponse < Struct.new( :cluster_scheduler_config_arn, :cluster_scheduler_config_id, :name, :cluster_scheduler_config_version, :status, :failure_reason, :status_details, :cluster_arn, :scheduler_config, :description, :creation_time, :created_by, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#cluster_scheduler_config_arn ⇒ String
ARN of the cluster policy.
17785 17786 17787 17788 17789 17790 17791 17792 17793 17794 17795 17796 17797 17798 17799 17800 17801 17802 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17785 class DescribeClusterSchedulerConfigResponse < Struct.new( :cluster_scheduler_config_arn, :cluster_scheduler_config_id, :name, :cluster_scheduler_config_version, :status, :failure_reason, :status_details, :cluster_arn, :scheduler_config, :description, :creation_time, :created_by, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#cluster_scheduler_config_id ⇒ String
ID of the cluster policy.
17785 17786 17787 17788 17789 17790 17791 17792 17793 17794 17795 17796 17797 17798 17799 17800 17801 17802 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17785 class DescribeClusterSchedulerConfigResponse < Struct.new( :cluster_scheduler_config_arn, :cluster_scheduler_config_id, :name, :cluster_scheduler_config_version, :status, :failure_reason, :status_details, :cluster_arn, :scheduler_config, :description, :creation_time, :created_by, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#cluster_scheduler_config_version ⇒ Integer
Version of the cluster policy.
17785 17786 17787 17788 17789 17790 17791 17792 17793 17794 17795 17796 17797 17798 17799 17800 17801 17802 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17785 class DescribeClusterSchedulerConfigResponse < Struct.new( :cluster_scheduler_config_arn, :cluster_scheduler_config_id, :name, :cluster_scheduler_config_version, :status, :failure_reason, :status_details, :cluster_arn, :scheduler_config, :description, :creation_time, :created_by, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
17785 17786 17787 17788 17789 17790 17791 17792 17793 17794 17795 17796 17797 17798 17799 17800 17801 17802 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17785 class DescribeClusterSchedulerConfigResponse < Struct.new( :cluster_scheduler_config_arn, :cluster_scheduler_config_id, :name, :cluster_scheduler_config_version, :status, :failure_reason, :status_details, :cluster_arn, :scheduler_config, :description, :creation_time, :created_by, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
Creation time of the cluster policy.
17785 17786 17787 17788 17789 17790 17791 17792 17793 17794 17795 17796 17797 17798 17799 17800 17801 17802 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17785 class DescribeClusterSchedulerConfigResponse < Struct.new( :cluster_scheduler_config_arn, :cluster_scheduler_config_id, :name, :cluster_scheduler_config_version, :status, :failure_reason, :status_details, :cluster_arn, :scheduler_config, :description, :creation_time, :created_by, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
Description of the cluster policy.
17785 17786 17787 17788 17789 17790 17791 17792 17793 17794 17795 17796 17797 17798 17799 17800 17801 17802 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17785 class DescribeClusterSchedulerConfigResponse < Struct.new( :cluster_scheduler_config_arn, :cluster_scheduler_config_id, :name, :cluster_scheduler_config_version, :status, :failure_reason, :status_details, :cluster_arn, :scheduler_config, :description, :creation_time, :created_by, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
Failure reason of the cluster policy.
17785 17786 17787 17788 17789 17790 17791 17792 17793 17794 17795 17796 17797 17798 17799 17800 17801 17802 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17785 class DescribeClusterSchedulerConfigResponse < Struct.new( :cluster_scheduler_config_arn, :cluster_scheduler_config_id, :name, :cluster_scheduler_config_version, :status, :failure_reason, :status_details, :cluster_arn, :scheduler_config, :description, :creation_time, :created_by, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
17785 17786 17787 17788 17789 17790 17791 17792 17793 17794 17795 17796 17797 17798 17799 17800 17801 17802 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17785 class DescribeClusterSchedulerConfigResponse < Struct.new( :cluster_scheduler_config_arn, :cluster_scheduler_config_id, :name, :cluster_scheduler_config_version, :status, :failure_reason, :status_details, :cluster_arn, :scheduler_config, :description, :creation_time, :created_by, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
Last modified time of the cluster policy.
17785 17786 17787 17788 17789 17790 17791 17792 17793 17794 17795 17796 17797 17798 17799 17800 17801 17802 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17785 class DescribeClusterSchedulerConfigResponse < Struct.new( :cluster_scheduler_config_arn, :cluster_scheduler_config_id, :name, :cluster_scheduler_config_version, :status, :failure_reason, :status_details, :cluster_arn, :scheduler_config, :description, :creation_time, :created_by, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Name of the cluster policy.
17785 17786 17787 17788 17789 17790 17791 17792 17793 17794 17795 17796 17797 17798 17799 17800 17801 17802 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17785 class DescribeClusterSchedulerConfigResponse < Struct.new( :cluster_scheduler_config_arn, :cluster_scheduler_config_id, :name, :cluster_scheduler_config_version, :status, :failure_reason, :status_details, :cluster_arn, :scheduler_config, :description, :creation_time, :created_by, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#scheduler_config ⇒ Types::SchedulerConfig
Cluster policy configuration. This policy is used for task prioritization and fair-share allocation. This helps prioritize critical workloads and distributes idle compute across entities.
17785 17786 17787 17788 17789 17790 17791 17792 17793 17794 17795 17796 17797 17798 17799 17800 17801 17802 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17785 class DescribeClusterSchedulerConfigResponse < Struct.new( :cluster_scheduler_config_arn, :cluster_scheduler_config_id, :name, :cluster_scheduler_config_version, :status, :failure_reason, :status_details, :cluster_arn, :scheduler_config, :description, :creation_time, :created_by, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Status of the cluster policy.
17785 17786 17787 17788 17789 17790 17791 17792 17793 17794 17795 17796 17797 17798 17799 17800 17801 17802 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17785 class DescribeClusterSchedulerConfigResponse < Struct.new( :cluster_scheduler_config_arn, :cluster_scheduler_config_id, :name, :cluster_scheduler_config_version, :status, :failure_reason, :status_details, :cluster_arn, :scheduler_config, :description, :creation_time, :created_by, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#status_details ⇒ Hash<String,String>
Additional details about the status of the cluster policy. This field provides context when the policy is in a non-active state, such as during creation, updates, or if failures occur.
17785 17786 17787 17788 17789 17790 17791 17792 17793 17794 17795 17796 17797 17798 17799 17800 17801 17802 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17785 class DescribeClusterSchedulerConfigResponse < Struct.new( :cluster_scheduler_config_arn, :cluster_scheduler_config_id, :name, :cluster_scheduler_config_version, :status, :failure_reason, :status_details, :cluster_arn, :scheduler_config, :description, :creation_time, :created_by, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |