Class: Aws::SageMaker::Types::DescribeClusterSchedulerConfigResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_arnString

ARN of the cluster where the cluster policy is applied.

Returns:

  • (String)


16589
16590
16591
16592
16593
16594
16595
16596
16597
16598
16599
16600
16601
16602
16603
16604
16605
16606
# File 'lib/aws-sdk-sagemaker/types.rb', line 16589

class DescribeClusterSchedulerConfigResponse < Struct.new(
  :cluster_scheduler_config_arn,
  :cluster_scheduler_config_id,
  :name,
  :cluster_scheduler_config_version,
  :status,
  :failure_reason,
  :status_details,
  :cluster_arn,
  :scheduler_config,
  :description,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_scheduler_config_arnString

ARN of the cluster policy.

Returns:

  • (String)


16589
16590
16591
16592
16593
16594
16595
16596
16597
16598
16599
16600
16601
16602
16603
16604
16605
16606
# File 'lib/aws-sdk-sagemaker/types.rb', line 16589

class DescribeClusterSchedulerConfigResponse < Struct.new(
  :cluster_scheduler_config_arn,
  :cluster_scheduler_config_id,
  :name,
  :cluster_scheduler_config_version,
  :status,
  :failure_reason,
  :status_details,
  :cluster_arn,
  :scheduler_config,
  :description,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_scheduler_config_idString

ID of the cluster policy.

Returns:

  • (String)


16589
16590
16591
16592
16593
16594
16595
16596
16597
16598
16599
16600
16601
16602
16603
16604
16605
16606
# File 'lib/aws-sdk-sagemaker/types.rb', line 16589

class DescribeClusterSchedulerConfigResponse < Struct.new(
  :cluster_scheduler_config_arn,
  :cluster_scheduler_config_id,
  :name,
  :cluster_scheduler_config_version,
  :status,
  :failure_reason,
  :status_details,
  :cluster_arn,
  :scheduler_config,
  :description,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_scheduler_config_versionInteger

Version of the cluster policy.

Returns:

  • (Integer)


16589
16590
16591
16592
16593
16594
16595
16596
16597
16598
16599
16600
16601
16602
16603
16604
16605
16606
# File 'lib/aws-sdk-sagemaker/types.rb', line 16589

class DescribeClusterSchedulerConfigResponse < Struct.new(
  :cluster_scheduler_config_arn,
  :cluster_scheduler_config_id,
  :name,
  :cluster_scheduler_config_version,
  :status,
  :failure_reason,
  :status_details,
  :cluster_arn,
  :scheduler_config,
  :description,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#created_byTypes::UserContext

Information about the user who created or modified a SageMaker resource.

Returns:



16589
16590
16591
16592
16593
16594
16595
16596
16597
16598
16599
16600
16601
16602
16603
16604
16605
16606
# File 'lib/aws-sdk-sagemaker/types.rb', line 16589

class DescribeClusterSchedulerConfigResponse < Struct.new(
  :cluster_scheduler_config_arn,
  :cluster_scheduler_config_id,
  :name,
  :cluster_scheduler_config_version,
  :status,
  :failure_reason,
  :status_details,
  :cluster_arn,
  :scheduler_config,
  :description,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

Creation time of the cluster policy.

Returns:

  • (Time)


16589
16590
16591
16592
16593
16594
16595
16596
16597
16598
16599
16600
16601
16602
16603
16604
16605
16606
# File 'lib/aws-sdk-sagemaker/types.rb', line 16589

class DescribeClusterSchedulerConfigResponse < Struct.new(
  :cluster_scheduler_config_arn,
  :cluster_scheduler_config_id,
  :name,
  :cluster_scheduler_config_version,
  :status,
  :failure_reason,
  :status_details,
  :cluster_arn,
  :scheduler_config,
  :description,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

Description of the cluster policy.

Returns:

  • (String)


16589
16590
16591
16592
16593
16594
16595
16596
16597
16598
16599
16600
16601
16602
16603
16604
16605
16606
# File 'lib/aws-sdk-sagemaker/types.rb', line 16589

class DescribeClusterSchedulerConfigResponse < Struct.new(
  :cluster_scheduler_config_arn,
  :cluster_scheduler_config_id,
  :name,
  :cluster_scheduler_config_version,
  :status,
  :failure_reason,
  :status_details,
  :cluster_arn,
  :scheduler_config,
  :description,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

Failure reason of the cluster policy.

Returns:

  • (String)


16589
16590
16591
16592
16593
16594
16595
16596
16597
16598
16599
16600
16601
16602
16603
16604
16605
16606
# File 'lib/aws-sdk-sagemaker/types.rb', line 16589

class DescribeClusterSchedulerConfigResponse < Struct.new(
  :cluster_scheduler_config_arn,
  :cluster_scheduler_config_id,
  :name,
  :cluster_scheduler_config_version,
  :status,
  :failure_reason,
  :status_details,
  :cluster_arn,
  :scheduler_config,
  :description,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_byTypes::UserContext

Information about the user who created or modified a SageMaker resource.

Returns:



16589
16590
16591
16592
16593
16594
16595
16596
16597
16598
16599
16600
16601
16602
16603
16604
16605
16606
# File 'lib/aws-sdk-sagemaker/types.rb', line 16589

class DescribeClusterSchedulerConfigResponse < Struct.new(
  :cluster_scheduler_config_arn,
  :cluster_scheduler_config_id,
  :name,
  :cluster_scheduler_config_version,
  :status,
  :failure_reason,
  :status_details,
  :cluster_arn,
  :scheduler_config,
  :description,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

Last modified time of the cluster policy.

Returns:

  • (Time)


16589
16590
16591
16592
16593
16594
16595
16596
16597
16598
16599
16600
16601
16602
16603
16604
16605
16606
# File 'lib/aws-sdk-sagemaker/types.rb', line 16589

class DescribeClusterSchedulerConfigResponse < Struct.new(
  :cluster_scheduler_config_arn,
  :cluster_scheduler_config_id,
  :name,
  :cluster_scheduler_config_version,
  :status,
  :failure_reason,
  :status_details,
  :cluster_arn,
  :scheduler_config,
  :description,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Name of the cluster policy.

Returns:

  • (String)


16589
16590
16591
16592
16593
16594
16595
16596
16597
16598
16599
16600
16601
16602
16603
16604
16605
16606
# File 'lib/aws-sdk-sagemaker/types.rb', line 16589

class DescribeClusterSchedulerConfigResponse < Struct.new(
  :cluster_scheduler_config_arn,
  :cluster_scheduler_config_id,
  :name,
  :cluster_scheduler_config_version,
  :status,
  :failure_reason,
  :status_details,
  :cluster_arn,
  :scheduler_config,
  :description,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#scheduler_configTypes::SchedulerConfig

Cluster policy configuration. This policy is used for task prioritization and fair-share allocation. This helps prioritize critical workloads and distributes idle compute across entities.



16589
16590
16591
16592
16593
16594
16595
16596
16597
16598
16599
16600
16601
16602
16603
16604
16605
16606
# File 'lib/aws-sdk-sagemaker/types.rb', line 16589

class DescribeClusterSchedulerConfigResponse < Struct.new(
  :cluster_scheduler_config_arn,
  :cluster_scheduler_config_id,
  :name,
  :cluster_scheduler_config_version,
  :status,
  :failure_reason,
  :status_details,
  :cluster_arn,
  :scheduler_config,
  :description,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

Status of the cluster policy.

Returns:

  • (String)


16589
16590
16591
16592
16593
16594
16595
16596
16597
16598
16599
16600
16601
16602
16603
16604
16605
16606
# File 'lib/aws-sdk-sagemaker/types.rb', line 16589

class DescribeClusterSchedulerConfigResponse < Struct.new(
  :cluster_scheduler_config_arn,
  :cluster_scheduler_config_id,
  :name,
  :cluster_scheduler_config_version,
  :status,
  :failure_reason,
  :status_details,
  :cluster_arn,
  :scheduler_config,
  :description,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#status_detailsHash<String,String>

Additional details about the status of the cluster policy. This field provides context when the policy is in a non-active state, such as during creation, updates, or if failures occur.

Returns:

  • (Hash<String,String>)


16589
16590
16591
16592
16593
16594
16595
16596
16597
16598
16599
16600
16601
16602
16603
16604
16605
16606
# File 'lib/aws-sdk-sagemaker/types.rb', line 16589

class DescribeClusterSchedulerConfigResponse < Struct.new(
  :cluster_scheduler_config_arn,
  :cluster_scheduler_config_id,
  :name,
  :cluster_scheduler_config_version,
  :status,
  :failure_reason,
  :status_details,
  :cluster_arn,
  :scheduler_config,
  :description,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end