Class: Aws::SageMaker::Types::DescribeCodeRepositoryOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#code_repository_arnString

The Amazon Resource Name (ARN) of the Git repository.

Returns:

  • (String)


18309
18310
18311
18312
18313
18314
18315
18316
18317
# File 'lib/aws-sdk-sagemaker/types.rb', line 18309

class DescribeCodeRepositoryOutput < Struct.new(
  :code_repository_name,
  :code_repository_arn,
  :creation_time,
  :last_modified_time,
  :git_config)
  SENSITIVE = []
  include Aws::Structure
end

#code_repository_nameString

The name of the Git repository.

Returns:

  • (String)


18309
18310
18311
18312
18313
18314
18315
18316
18317
# File 'lib/aws-sdk-sagemaker/types.rb', line 18309

class DescribeCodeRepositoryOutput < Struct.new(
  :code_repository_name,
  :code_repository_arn,
  :creation_time,
  :last_modified_time,
  :git_config)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

The date and time that the repository was created.

Returns:

  • (Time)


18309
18310
18311
18312
18313
18314
18315
18316
18317
# File 'lib/aws-sdk-sagemaker/types.rb', line 18309

class DescribeCodeRepositoryOutput < Struct.new(
  :code_repository_name,
  :code_repository_arn,
  :creation_time,
  :last_modified_time,
  :git_config)
  SENSITIVE = []
  include Aws::Structure
end

#git_configTypes::GitConfig

Configuration details about the repository, including the URL where the repository is located, the default branch, and the Amazon Resource Name (ARN) of the Amazon Web Services Secrets Manager secret that contains the credentials used to access the repository.

Returns:



18309
18310
18311
18312
18313
18314
18315
18316
18317
# File 'lib/aws-sdk-sagemaker/types.rb', line 18309

class DescribeCodeRepositoryOutput < Struct.new(
  :code_repository_name,
  :code_repository_arn,
  :creation_time,
  :last_modified_time,
  :git_config)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The date and time that the repository was last changed.

Returns:

  • (Time)


18309
18310
18311
18312
18313
18314
18315
18316
18317
# File 'lib/aws-sdk-sagemaker/types.rb', line 18309

class DescribeCodeRepositoryOutput < Struct.new(
  :code_repository_name,
  :code_repository_arn,
  :creation_time,
  :last_modified_time,
  :git_config)
  SENSITIVE = []
  include Aws::Structure
end