Class: Aws::SageMaker::Types::DescribeCodeRepositoryOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeCodeRepositoryOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code_repository_arn ⇒ String
The Amazon Resource Name (ARN) of the Git repository.
-
#code_repository_name ⇒ String
The name of the Git repository.
-
#creation_time ⇒ Time
The date and time that the repository was created.
-
#git_config ⇒ Types::GitConfig
Configuration details about the repository, including the URL where the repository is located, the default branch, and the Amazon Resource Name (ARN) of the Amazon Web Services Secrets Manager secret that contains the credentials used to access the repository.
-
#last_modified_time ⇒ Time
The date and time that the repository was last changed.
Instance Attribute Details
#code_repository_arn ⇒ String
The Amazon Resource Name (ARN) of the Git repository.
17867 17868 17869 17870 17871 17872 17873 17874 17875 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17867 class DescribeCodeRepositoryOutput < Struct.new( :code_repository_name, :code_repository_arn, :creation_time, :last_modified_time, :git_config) SENSITIVE = [] include Aws::Structure end |
#code_repository_name ⇒ String
The name of the Git repository.
17867 17868 17869 17870 17871 17872 17873 17874 17875 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17867 class DescribeCodeRepositoryOutput < Struct.new( :code_repository_name, :code_repository_arn, :creation_time, :last_modified_time, :git_config) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The date and time that the repository was created.
17867 17868 17869 17870 17871 17872 17873 17874 17875 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17867 class DescribeCodeRepositoryOutput < Struct.new( :code_repository_name, :code_repository_arn, :creation_time, :last_modified_time, :git_config) SENSITIVE = [] include Aws::Structure end |
#git_config ⇒ Types::GitConfig
Configuration details about the repository, including the URL where the repository is located, the default branch, and the Amazon Resource Name (ARN) of the Amazon Web Services Secrets Manager secret that contains the credentials used to access the repository.
17867 17868 17869 17870 17871 17872 17873 17874 17875 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17867 class DescribeCodeRepositoryOutput < Struct.new( :code_repository_name, :code_repository_arn, :creation_time, :last_modified_time, :git_config) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The date and time that the repository was last changed.
17867 17868 17869 17870 17871 17872 17873 17874 17875 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 17867 class DescribeCodeRepositoryOutput < Struct.new( :code_repository_name, :code_repository_arn, :creation_time, :last_modified_time, :git_config) SENSITIVE = [] include Aws::Structure end |