Class: Aws::SageMaker::Types::DescribeCompilationJobResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeCompilationJobResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compilation_end_time ⇒ Time
The time when the model compilation job on a compilation job instance ended.
-
#compilation_job_arn ⇒ String
The Amazon Resource Name (ARN) of the model compilation job.
-
#compilation_job_name ⇒ String
The name of the model compilation job.
-
#compilation_job_status ⇒ String
The status of the model compilation job.
-
#compilation_start_time ⇒ Time
The time when the model compilation job started the
CompilationJobinstances. -
#creation_time ⇒ Time
The time that the model compilation job was created.
-
#failure_reason ⇒ String
If a model compilation job failed, the reason it failed.
-
#inference_image ⇒ String
The inference image to use when compiling a model.
-
#input_config ⇒ Types::InputConfig
Information about the location in Amazon S3 of the input model artifacts, the name and shape of the expected data inputs, and the framework in which the model was trained.
-
#last_modified_time ⇒ Time
The time that the status of the model compilation job was last modified.
-
#model_artifacts ⇒ Types::ModelArtifacts
Information about the location in Amazon S3 that has been configured for storing the model artifacts used in the compilation job.
-
#model_digests ⇒ Types::ModelDigests
Provides a BLAKE2 hash value that identifies the compiled model artifacts in Amazon S3.
-
#model_package_version_arn ⇒ String
The Amazon Resource Name (ARN) of the versioned model package that was provided to SageMaker Neo when you initiated a compilation job.
-
#output_config ⇒ Types::OutputConfig
Information about the output location for the compiled model and the target device that the model runs on.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker assumes to perform the model compilation job.
-
#stopping_condition ⇒ Types::StoppingCondition
Specifies a limit to how long a model compilation job can run.
-
#vpc_config ⇒ Types::NeoVpcConfig
A VpcConfig object that specifies the VPC that you want your compilation job to connect to.
Instance Attribute Details
#compilation_end_time ⇒ Time
The time when the model compilation job on a compilation job instance ended. For a successful or stopped job, this is when the job’s model artifacts have finished uploading. For a failed job, this is when Amazon SageMaker detected that the job failed.
10354 10355 10356 10357 10358 10359 10360 10361 10362 10363 10364 10365 10366 10367 10368 10369 10370 10371 10372 10373 10374 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10354 class DescribeCompilationJobResponse < Struct.new( :compilation_job_name, :compilation_job_arn, :compilation_job_status, :compilation_start_time, :compilation_end_time, :stopping_condition, :inference_image, :model_package_version_arn, :creation_time, :last_modified_time, :failure_reason, :model_artifacts, :model_digests, :role_arn, :input_config, :output_config, :vpc_config) SENSITIVE = [] include Aws::Structure end |
#compilation_job_arn ⇒ String
The Amazon Resource Name (ARN) of the model compilation job.
10354 10355 10356 10357 10358 10359 10360 10361 10362 10363 10364 10365 10366 10367 10368 10369 10370 10371 10372 10373 10374 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10354 class DescribeCompilationJobResponse < Struct.new( :compilation_job_name, :compilation_job_arn, :compilation_job_status, :compilation_start_time, :compilation_end_time, :stopping_condition, :inference_image, :model_package_version_arn, :creation_time, :last_modified_time, :failure_reason, :model_artifacts, :model_digests, :role_arn, :input_config, :output_config, :vpc_config) SENSITIVE = [] include Aws::Structure end |
#compilation_job_name ⇒ String
The name of the model compilation job.
10354 10355 10356 10357 10358 10359 10360 10361 10362 10363 10364 10365 10366 10367 10368 10369 10370 10371 10372 10373 10374 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10354 class DescribeCompilationJobResponse < Struct.new( :compilation_job_name, :compilation_job_arn, :compilation_job_status, :compilation_start_time, :compilation_end_time, :stopping_condition, :inference_image, :model_package_version_arn, :creation_time, :last_modified_time, :failure_reason, :model_artifacts, :model_digests, :role_arn, :input_config, :output_config, :vpc_config) SENSITIVE = [] include Aws::Structure end |
#compilation_job_status ⇒ String
The status of the model compilation job.
10354 10355 10356 10357 10358 10359 10360 10361 10362 10363 10364 10365 10366 10367 10368 10369 10370 10371 10372 10373 10374 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10354 class DescribeCompilationJobResponse < Struct.new( :compilation_job_name, :compilation_job_arn, :compilation_job_status, :compilation_start_time, :compilation_end_time, :stopping_condition, :inference_image, :model_package_version_arn, :creation_time, :last_modified_time, :failure_reason, :model_artifacts, :model_digests, :role_arn, :input_config, :output_config, :vpc_config) SENSITIVE = [] include Aws::Structure end |
#compilation_start_time ⇒ Time
The time when the model compilation job started the CompilationJob instances.
You are billed for the time between this timestamp and the timestamp in the DescribeCompilationJobResponse$CompilationEndTime field. In Amazon CloudWatch Logs, the start time might be later than this time. That’s because it takes time to download the compilation job, which depends on the size of the compilation job container.
10354 10355 10356 10357 10358 10359 10360 10361 10362 10363 10364 10365 10366 10367 10368 10369 10370 10371 10372 10373 10374 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10354 class DescribeCompilationJobResponse < Struct.new( :compilation_job_name, :compilation_job_arn, :compilation_job_status, :compilation_start_time, :compilation_end_time, :stopping_condition, :inference_image, :model_package_version_arn, :creation_time, :last_modified_time, :failure_reason, :model_artifacts, :model_digests, :role_arn, :input_config, :output_config, :vpc_config) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The time that the model compilation job was created.
10354 10355 10356 10357 10358 10359 10360 10361 10362 10363 10364 10365 10366 10367 10368 10369 10370 10371 10372 10373 10374 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10354 class DescribeCompilationJobResponse < Struct.new( :compilation_job_name, :compilation_job_arn, :compilation_job_status, :compilation_start_time, :compilation_end_time, :stopping_condition, :inference_image, :model_package_version_arn, :creation_time, :last_modified_time, :failure_reason, :model_artifacts, :model_digests, :role_arn, :input_config, :output_config, :vpc_config) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
If a model compilation job failed, the reason it failed.
10354 10355 10356 10357 10358 10359 10360 10361 10362 10363 10364 10365 10366 10367 10368 10369 10370 10371 10372 10373 10374 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10354 class DescribeCompilationJobResponse < Struct.new( :compilation_job_name, :compilation_job_arn, :compilation_job_status, :compilation_start_time, :compilation_end_time, :stopping_condition, :inference_image, :model_package_version_arn, :creation_time, :last_modified_time, :failure_reason, :model_artifacts, :model_digests, :role_arn, :input_config, :output_config, :vpc_config) SENSITIVE = [] include Aws::Structure end |
#inference_image ⇒ String
The inference image to use when compiling a model. Specify an image only if the target device is a cloud instance.
10354 10355 10356 10357 10358 10359 10360 10361 10362 10363 10364 10365 10366 10367 10368 10369 10370 10371 10372 10373 10374 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10354 class DescribeCompilationJobResponse < Struct.new( :compilation_job_name, :compilation_job_arn, :compilation_job_status, :compilation_start_time, :compilation_end_time, :stopping_condition, :inference_image, :model_package_version_arn, :creation_time, :last_modified_time, :failure_reason, :model_artifacts, :model_digests, :role_arn, :input_config, :output_config, :vpc_config) SENSITIVE = [] include Aws::Structure end |
#input_config ⇒ Types::InputConfig
Information about the location in Amazon S3 of the input model artifacts, the name and shape of the expected data inputs, and the framework in which the model was trained.
10354 10355 10356 10357 10358 10359 10360 10361 10362 10363 10364 10365 10366 10367 10368 10369 10370 10371 10372 10373 10374 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10354 class DescribeCompilationJobResponse < Struct.new( :compilation_job_name, :compilation_job_arn, :compilation_job_status, :compilation_start_time, :compilation_end_time, :stopping_condition, :inference_image, :model_package_version_arn, :creation_time, :last_modified_time, :failure_reason, :model_artifacts, :model_digests, :role_arn, :input_config, :output_config, :vpc_config) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The time that the status of the model compilation job was last modified.
10354 10355 10356 10357 10358 10359 10360 10361 10362 10363 10364 10365 10366 10367 10368 10369 10370 10371 10372 10373 10374 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10354 class DescribeCompilationJobResponse < Struct.new( :compilation_job_name, :compilation_job_arn, :compilation_job_status, :compilation_start_time, :compilation_end_time, :stopping_condition, :inference_image, :model_package_version_arn, :creation_time, :last_modified_time, :failure_reason, :model_artifacts, :model_digests, :role_arn, :input_config, :output_config, :vpc_config) SENSITIVE = [] include Aws::Structure end |
#model_artifacts ⇒ Types::ModelArtifacts
Information about the location in Amazon S3 that has been configured for storing the model artifacts used in the compilation job.
10354 10355 10356 10357 10358 10359 10360 10361 10362 10363 10364 10365 10366 10367 10368 10369 10370 10371 10372 10373 10374 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10354 class DescribeCompilationJobResponse < Struct.new( :compilation_job_name, :compilation_job_arn, :compilation_job_status, :compilation_start_time, :compilation_end_time, :stopping_condition, :inference_image, :model_package_version_arn, :creation_time, :last_modified_time, :failure_reason, :model_artifacts, :model_digests, :role_arn, :input_config, :output_config, :vpc_config) SENSITIVE = [] include Aws::Structure end |
#model_digests ⇒ Types::ModelDigests
Provides a BLAKE2 hash value that identifies the compiled model artifacts in Amazon S3.
10354 10355 10356 10357 10358 10359 10360 10361 10362 10363 10364 10365 10366 10367 10368 10369 10370 10371 10372 10373 10374 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10354 class DescribeCompilationJobResponse < Struct.new( :compilation_job_name, :compilation_job_arn, :compilation_job_status, :compilation_start_time, :compilation_end_time, :stopping_condition, :inference_image, :model_package_version_arn, :creation_time, :last_modified_time, :failure_reason, :model_artifacts, :model_digests, :role_arn, :input_config, :output_config, :vpc_config) SENSITIVE = [] include Aws::Structure end |
#model_package_version_arn ⇒ String
The Amazon Resource Name (ARN) of the versioned model package that was provided to SageMaker Neo when you initiated a compilation job.
10354 10355 10356 10357 10358 10359 10360 10361 10362 10363 10364 10365 10366 10367 10368 10369 10370 10371 10372 10373 10374 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10354 class DescribeCompilationJobResponse < Struct.new( :compilation_job_name, :compilation_job_arn, :compilation_job_status, :compilation_start_time, :compilation_end_time, :stopping_condition, :inference_image, :model_package_version_arn, :creation_time, :last_modified_time, :failure_reason, :model_artifacts, :model_digests, :role_arn, :input_config, :output_config, :vpc_config) SENSITIVE = [] include Aws::Structure end |
#output_config ⇒ Types::OutputConfig
Information about the output location for the compiled model and the target device that the model runs on.
10354 10355 10356 10357 10358 10359 10360 10361 10362 10363 10364 10365 10366 10367 10368 10369 10370 10371 10372 10373 10374 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10354 class DescribeCompilationJobResponse < Struct.new( :compilation_job_name, :compilation_job_arn, :compilation_job_status, :compilation_start_time, :compilation_end_time, :stopping_condition, :inference_image, :model_package_version_arn, :creation_time, :last_modified_time, :failure_reason, :model_artifacts, :model_digests, :role_arn, :input_config, :output_config, :vpc_config) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker assumes to perform the model compilation job.
10354 10355 10356 10357 10358 10359 10360 10361 10362 10363 10364 10365 10366 10367 10368 10369 10370 10371 10372 10373 10374 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10354 class DescribeCompilationJobResponse < Struct.new( :compilation_job_name, :compilation_job_arn, :compilation_job_status, :compilation_start_time, :compilation_end_time, :stopping_condition, :inference_image, :model_package_version_arn, :creation_time, :last_modified_time, :failure_reason, :model_artifacts, :model_digests, :role_arn, :input_config, :output_config, :vpc_config) SENSITIVE = [] include Aws::Structure end |
#stopping_condition ⇒ Types::StoppingCondition
Specifies a limit to how long a model compilation job can run. When the job reaches the time limit, Amazon SageMaker ends the compilation job. Use this API to cap model training costs.
10354 10355 10356 10357 10358 10359 10360 10361 10362 10363 10364 10365 10366 10367 10368 10369 10370 10371 10372 10373 10374 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10354 class DescribeCompilationJobResponse < Struct.new( :compilation_job_name, :compilation_job_arn, :compilation_job_status, :compilation_start_time, :compilation_end_time, :stopping_condition, :inference_image, :model_package_version_arn, :creation_time, :last_modified_time, :failure_reason, :model_artifacts, :model_digests, :role_arn, :input_config, :output_config, :vpc_config) SENSITIVE = [] include Aws::Structure end |
#vpc_config ⇒ Types::NeoVpcConfig
A VpcConfig object that specifies the VPC that you want your compilation job to connect to. Control access to your models by configuring the VPC. For more information, see [Protect Compilation Jobs by Using an Amazon Virtual Private Cloud].
10354 10355 10356 10357 10358 10359 10360 10361 10362 10363 10364 10365 10366 10367 10368 10369 10370 10371 10372 10373 10374 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 10354 class DescribeCompilationJobResponse < Struct.new( :compilation_job_name, :compilation_job_arn, :compilation_job_status, :compilation_start_time, :compilation_end_time, :stopping_condition, :inference_image, :model_package_version_arn, :creation_time, :last_modified_time, :failure_reason, :model_artifacts, :model_digests, :role_arn, :input_config, :output_config, :vpc_config) SENSITIVE = [] include Aws::Structure end |