Class: Aws::SageMaker::Types::DescribeComputeQuotaResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#activation_stateString

The state of the compute allocation being described. Use to enable or disable compute allocation.

Default is ‘Enabled`.

Returns:

  • (String)


18125
18126
18127
18128
18129
18130
18131
18132
18133
18134
18135
18136
18137
18138
18139
18140
18141
18142
18143
# File 'lib/aws-sdk-sagemaker/types.rb', line 18125

class DescribeComputeQuotaResponse < Struct.new(
  :compute_quota_arn,
  :compute_quota_id,
  :name,
  :description,
  :compute_quota_version,
  :status,
  :failure_reason,
  :cluster_arn,
  :compute_quota_config,
  :compute_quota_target,
  :activation_state,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_arnString

ARN of the cluster.

Returns:

  • (String)


18125
18126
18127
18128
18129
18130
18131
18132
18133
18134
18135
18136
18137
18138
18139
18140
18141
18142
18143
# File 'lib/aws-sdk-sagemaker/types.rb', line 18125

class DescribeComputeQuotaResponse < Struct.new(
  :compute_quota_arn,
  :compute_quota_id,
  :name,
  :description,
  :compute_quota_version,
  :status,
  :failure_reason,
  :cluster_arn,
  :compute_quota_config,
  :compute_quota_target,
  :activation_state,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#compute_quota_arnString

ARN of the compute allocation definition.

Returns:

  • (String)


18125
18126
18127
18128
18129
18130
18131
18132
18133
18134
18135
18136
18137
18138
18139
18140
18141
18142
18143
# File 'lib/aws-sdk-sagemaker/types.rb', line 18125

class DescribeComputeQuotaResponse < Struct.new(
  :compute_quota_arn,
  :compute_quota_id,
  :name,
  :description,
  :compute_quota_version,
  :status,
  :failure_reason,
  :cluster_arn,
  :compute_quota_config,
  :compute_quota_target,
  :activation_state,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#compute_quota_configTypes::ComputeQuotaConfig

Configuration of the compute allocation definition. This includes the resource sharing option, and the setting to preempt low priority tasks.



18125
18126
18127
18128
18129
18130
18131
18132
18133
18134
18135
18136
18137
18138
18139
18140
18141
18142
18143
# File 'lib/aws-sdk-sagemaker/types.rb', line 18125

class DescribeComputeQuotaResponse < Struct.new(
  :compute_quota_arn,
  :compute_quota_id,
  :name,
  :description,
  :compute_quota_version,
  :status,
  :failure_reason,
  :cluster_arn,
  :compute_quota_config,
  :compute_quota_target,
  :activation_state,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#compute_quota_idString

ID of the compute allocation definition.

Returns:

  • (String)


18125
18126
18127
18128
18129
18130
18131
18132
18133
18134
18135
18136
18137
18138
18139
18140
18141
18142
18143
# File 'lib/aws-sdk-sagemaker/types.rb', line 18125

class DescribeComputeQuotaResponse < Struct.new(
  :compute_quota_arn,
  :compute_quota_id,
  :name,
  :description,
  :compute_quota_version,
  :status,
  :failure_reason,
  :cluster_arn,
  :compute_quota_config,
  :compute_quota_target,
  :activation_state,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#compute_quota_targetTypes::ComputeQuotaTarget

The target entity to allocate compute resources to.



18125
18126
18127
18128
18129
18130
18131
18132
18133
18134
18135
18136
18137
18138
18139
18140
18141
18142
18143
# File 'lib/aws-sdk-sagemaker/types.rb', line 18125

class DescribeComputeQuotaResponse < Struct.new(
  :compute_quota_arn,
  :compute_quota_id,
  :name,
  :description,
  :compute_quota_version,
  :status,
  :failure_reason,
  :cluster_arn,
  :compute_quota_config,
  :compute_quota_target,
  :activation_state,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#compute_quota_versionInteger

Version of the compute allocation definition.

Returns:

  • (Integer)


18125
18126
18127
18128
18129
18130
18131
18132
18133
18134
18135
18136
18137
18138
18139
18140
18141
18142
18143
# File 'lib/aws-sdk-sagemaker/types.rb', line 18125

class DescribeComputeQuotaResponse < Struct.new(
  :compute_quota_arn,
  :compute_quota_id,
  :name,
  :description,
  :compute_quota_version,
  :status,
  :failure_reason,
  :cluster_arn,
  :compute_quota_config,
  :compute_quota_target,
  :activation_state,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#created_byTypes::UserContext

Information about the user who created or modified a SageMaker resource.

Returns:



18125
18126
18127
18128
18129
18130
18131
18132
18133
18134
18135
18136
18137
18138
18139
18140
18141
18142
18143
# File 'lib/aws-sdk-sagemaker/types.rb', line 18125

class DescribeComputeQuotaResponse < Struct.new(
  :compute_quota_arn,
  :compute_quota_id,
  :name,
  :description,
  :compute_quota_version,
  :status,
  :failure_reason,
  :cluster_arn,
  :compute_quota_config,
  :compute_quota_target,
  :activation_state,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

Creation time of the compute allocation configuration.

Returns:

  • (Time)


18125
18126
18127
18128
18129
18130
18131
18132
18133
18134
18135
18136
18137
18138
18139
18140
18141
18142
18143
# File 'lib/aws-sdk-sagemaker/types.rb', line 18125

class DescribeComputeQuotaResponse < Struct.new(
  :compute_quota_arn,
  :compute_quota_id,
  :name,
  :description,
  :compute_quota_version,
  :status,
  :failure_reason,
  :cluster_arn,
  :compute_quota_config,
  :compute_quota_target,
  :activation_state,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

Description of the compute allocation definition.

Returns:

  • (String)


18125
18126
18127
18128
18129
18130
18131
18132
18133
18134
18135
18136
18137
18138
18139
18140
18141
18142
18143
# File 'lib/aws-sdk-sagemaker/types.rb', line 18125

class DescribeComputeQuotaResponse < Struct.new(
  :compute_quota_arn,
  :compute_quota_id,
  :name,
  :description,
  :compute_quota_version,
  :status,
  :failure_reason,
  :cluster_arn,
  :compute_quota_config,
  :compute_quota_target,
  :activation_state,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

Failure reason of the compute allocation definition.

Returns:

  • (String)


18125
18126
18127
18128
18129
18130
18131
18132
18133
18134
18135
18136
18137
18138
18139
18140
18141
18142
18143
# File 'lib/aws-sdk-sagemaker/types.rb', line 18125

class DescribeComputeQuotaResponse < Struct.new(
  :compute_quota_arn,
  :compute_quota_id,
  :name,
  :description,
  :compute_quota_version,
  :status,
  :failure_reason,
  :cluster_arn,
  :compute_quota_config,
  :compute_quota_target,
  :activation_state,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_byTypes::UserContext

Information about the user who created or modified a SageMaker resource.

Returns:



18125
18126
18127
18128
18129
18130
18131
18132
18133
18134
18135
18136
18137
18138
18139
18140
18141
18142
18143
# File 'lib/aws-sdk-sagemaker/types.rb', line 18125

class DescribeComputeQuotaResponse < Struct.new(
  :compute_quota_arn,
  :compute_quota_id,
  :name,
  :description,
  :compute_quota_version,
  :status,
  :failure_reason,
  :cluster_arn,
  :compute_quota_config,
  :compute_quota_target,
  :activation_state,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

Last modified time of the compute allocation configuration.

Returns:

  • (Time)


18125
18126
18127
18128
18129
18130
18131
18132
18133
18134
18135
18136
18137
18138
18139
18140
18141
18142
18143
# File 'lib/aws-sdk-sagemaker/types.rb', line 18125

class DescribeComputeQuotaResponse < Struct.new(
  :compute_quota_arn,
  :compute_quota_id,
  :name,
  :description,
  :compute_quota_version,
  :status,
  :failure_reason,
  :cluster_arn,
  :compute_quota_config,
  :compute_quota_target,
  :activation_state,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Name of the compute allocation definition.

Returns:

  • (String)


18125
18126
18127
18128
18129
18130
18131
18132
18133
18134
18135
18136
18137
18138
18139
18140
18141
18142
18143
# File 'lib/aws-sdk-sagemaker/types.rb', line 18125

class DescribeComputeQuotaResponse < Struct.new(
  :compute_quota_arn,
  :compute_quota_id,
  :name,
  :description,
  :compute_quota_version,
  :status,
  :failure_reason,
  :cluster_arn,
  :compute_quota_config,
  :compute_quota_target,
  :activation_state,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

Status of the compute allocation definition.

Returns:

  • (String)


18125
18126
18127
18128
18129
18130
18131
18132
18133
18134
18135
18136
18137
18138
18139
18140
18141
18142
18143
# File 'lib/aws-sdk-sagemaker/types.rb', line 18125

class DescribeComputeQuotaResponse < Struct.new(
  :compute_quota_arn,
  :compute_quota_id,
  :name,
  :description,
  :compute_quota_version,
  :status,
  :failure_reason,
  :cluster_arn,
  :compute_quota_config,
  :compute_quota_target,
  :activation_state,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end