Class: Aws::SageMaker::Types::DescribeComputeQuotaResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeComputeQuotaResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#activation_state ⇒ String
The state of the compute allocation being described.
-
#cluster_arn ⇒ String
ARN of the cluster.
-
#compute_quota_arn ⇒ String
ARN of the compute allocation definition.
-
#compute_quota_config ⇒ Types::ComputeQuotaConfig
Configuration of the compute allocation definition.
-
#compute_quota_id ⇒ String
ID of the compute allocation definition.
-
#compute_quota_target ⇒ Types::ComputeQuotaTarget
The target entity to allocate compute resources to.
-
#compute_quota_version ⇒ Integer
Version of the compute allocation definition.
-
#created_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
-
#creation_time ⇒ Time
Creation time of the compute allocation configuration.
-
#description ⇒ String
Description of the compute allocation definition.
-
#failure_reason ⇒ String
Failure reason of the compute allocation definition.
-
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
-
#last_modified_time ⇒ Time
Last modified time of the compute allocation configuration.
-
#name ⇒ String
Name of the compute allocation definition.
-
#status ⇒ String
Status of the compute allocation definition.
Instance Attribute Details
#activation_state ⇒ String
The state of the compute allocation being described. Use to enable or disable compute allocation.
Default is ‘Enabled`.
18103 18104 18105 18106 18107 18108 18109 18110 18111 18112 18113 18114 18115 18116 18117 18118 18119 18120 18121 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18103 class DescribeComputeQuotaResponse < Struct.new( :compute_quota_arn, :compute_quota_id, :name, :description, :compute_quota_version, :status, :failure_reason, :cluster_arn, :compute_quota_config, :compute_quota_target, :activation_state, :creation_time, :created_by, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#cluster_arn ⇒ String
ARN of the cluster.
18103 18104 18105 18106 18107 18108 18109 18110 18111 18112 18113 18114 18115 18116 18117 18118 18119 18120 18121 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18103 class DescribeComputeQuotaResponse < Struct.new( :compute_quota_arn, :compute_quota_id, :name, :description, :compute_quota_version, :status, :failure_reason, :cluster_arn, :compute_quota_config, :compute_quota_target, :activation_state, :creation_time, :created_by, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#compute_quota_arn ⇒ String
ARN of the compute allocation definition.
18103 18104 18105 18106 18107 18108 18109 18110 18111 18112 18113 18114 18115 18116 18117 18118 18119 18120 18121 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18103 class DescribeComputeQuotaResponse < Struct.new( :compute_quota_arn, :compute_quota_id, :name, :description, :compute_quota_version, :status, :failure_reason, :cluster_arn, :compute_quota_config, :compute_quota_target, :activation_state, :creation_time, :created_by, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#compute_quota_config ⇒ Types::ComputeQuotaConfig
Configuration of the compute allocation definition. This includes the resource sharing option, and the setting to preempt low priority tasks.
18103 18104 18105 18106 18107 18108 18109 18110 18111 18112 18113 18114 18115 18116 18117 18118 18119 18120 18121 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18103 class DescribeComputeQuotaResponse < Struct.new( :compute_quota_arn, :compute_quota_id, :name, :description, :compute_quota_version, :status, :failure_reason, :cluster_arn, :compute_quota_config, :compute_quota_target, :activation_state, :creation_time, :created_by, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#compute_quota_id ⇒ String
ID of the compute allocation definition.
18103 18104 18105 18106 18107 18108 18109 18110 18111 18112 18113 18114 18115 18116 18117 18118 18119 18120 18121 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18103 class DescribeComputeQuotaResponse < Struct.new( :compute_quota_arn, :compute_quota_id, :name, :description, :compute_quota_version, :status, :failure_reason, :cluster_arn, :compute_quota_config, :compute_quota_target, :activation_state, :creation_time, :created_by, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#compute_quota_target ⇒ Types::ComputeQuotaTarget
The target entity to allocate compute resources to.
18103 18104 18105 18106 18107 18108 18109 18110 18111 18112 18113 18114 18115 18116 18117 18118 18119 18120 18121 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18103 class DescribeComputeQuotaResponse < Struct.new( :compute_quota_arn, :compute_quota_id, :name, :description, :compute_quota_version, :status, :failure_reason, :cluster_arn, :compute_quota_config, :compute_quota_target, :activation_state, :creation_time, :created_by, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#compute_quota_version ⇒ Integer
Version of the compute allocation definition.
18103 18104 18105 18106 18107 18108 18109 18110 18111 18112 18113 18114 18115 18116 18117 18118 18119 18120 18121 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18103 class DescribeComputeQuotaResponse < Struct.new( :compute_quota_arn, :compute_quota_id, :name, :description, :compute_quota_version, :status, :failure_reason, :cluster_arn, :compute_quota_config, :compute_quota_target, :activation_state, :creation_time, :created_by, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
18103 18104 18105 18106 18107 18108 18109 18110 18111 18112 18113 18114 18115 18116 18117 18118 18119 18120 18121 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18103 class DescribeComputeQuotaResponse < Struct.new( :compute_quota_arn, :compute_quota_id, :name, :description, :compute_quota_version, :status, :failure_reason, :cluster_arn, :compute_quota_config, :compute_quota_target, :activation_state, :creation_time, :created_by, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
Creation time of the compute allocation configuration.
18103 18104 18105 18106 18107 18108 18109 18110 18111 18112 18113 18114 18115 18116 18117 18118 18119 18120 18121 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18103 class DescribeComputeQuotaResponse < Struct.new( :compute_quota_arn, :compute_quota_id, :name, :description, :compute_quota_version, :status, :failure_reason, :cluster_arn, :compute_quota_config, :compute_quota_target, :activation_state, :creation_time, :created_by, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
Description of the compute allocation definition.
18103 18104 18105 18106 18107 18108 18109 18110 18111 18112 18113 18114 18115 18116 18117 18118 18119 18120 18121 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18103 class DescribeComputeQuotaResponse < Struct.new( :compute_quota_arn, :compute_quota_id, :name, :description, :compute_quota_version, :status, :failure_reason, :cluster_arn, :compute_quota_config, :compute_quota_target, :activation_state, :creation_time, :created_by, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
Failure reason of the compute allocation definition.
18103 18104 18105 18106 18107 18108 18109 18110 18111 18112 18113 18114 18115 18116 18117 18118 18119 18120 18121 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18103 class DescribeComputeQuotaResponse < Struct.new( :compute_quota_arn, :compute_quota_id, :name, :description, :compute_quota_version, :status, :failure_reason, :cluster_arn, :compute_quota_config, :compute_quota_target, :activation_state, :creation_time, :created_by, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
18103 18104 18105 18106 18107 18108 18109 18110 18111 18112 18113 18114 18115 18116 18117 18118 18119 18120 18121 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18103 class DescribeComputeQuotaResponse < Struct.new( :compute_quota_arn, :compute_quota_id, :name, :description, :compute_quota_version, :status, :failure_reason, :cluster_arn, :compute_quota_config, :compute_quota_target, :activation_state, :creation_time, :created_by, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
Last modified time of the compute allocation configuration.
18103 18104 18105 18106 18107 18108 18109 18110 18111 18112 18113 18114 18115 18116 18117 18118 18119 18120 18121 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18103 class DescribeComputeQuotaResponse < Struct.new( :compute_quota_arn, :compute_quota_id, :name, :description, :compute_quota_version, :status, :failure_reason, :cluster_arn, :compute_quota_config, :compute_quota_target, :activation_state, :creation_time, :created_by, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Name of the compute allocation definition.
18103 18104 18105 18106 18107 18108 18109 18110 18111 18112 18113 18114 18115 18116 18117 18118 18119 18120 18121 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18103 class DescribeComputeQuotaResponse < Struct.new( :compute_quota_arn, :compute_quota_id, :name, :description, :compute_quota_version, :status, :failure_reason, :cluster_arn, :compute_quota_config, :compute_quota_target, :activation_state, :creation_time, :created_by, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Status of the compute allocation definition.
18103 18104 18105 18106 18107 18108 18109 18110 18111 18112 18113 18114 18115 18116 18117 18118 18119 18120 18121 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18103 class DescribeComputeQuotaResponse < Struct.new( :compute_quota_arn, :compute_quota_id, :name, :description, :compute_quota_version, :status, :failure_reason, :cluster_arn, :compute_quota_config, :compute_quota_target, :activation_state, :creation_time, :created_by, :last_modified_time, :last_modified_by) SENSITIVE = [] include Aws::Structure end |