Class: Aws::SageMaker::Types::DescribeComputeQuotaResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#activation_stateString

The state of the compute allocation being described. Use to enable or disable compute allocation.

Default is ‘Enabled`.

Returns:

  • (String)


16881
16882
16883
16884
16885
16886
16887
16888
16889
16890
16891
16892
16893
16894
16895
16896
16897
16898
16899
# File 'lib/aws-sdk-sagemaker/types.rb', line 16881

class DescribeComputeQuotaResponse < Struct.new(
  :compute_quota_arn,
  :compute_quota_id,
  :name,
  :description,
  :compute_quota_version,
  :status,
  :failure_reason,
  :cluster_arn,
  :compute_quota_config,
  :compute_quota_target,
  :activation_state,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_arnString

ARN of the cluster.

Returns:

  • (String)


16881
16882
16883
16884
16885
16886
16887
16888
16889
16890
16891
16892
16893
16894
16895
16896
16897
16898
16899
# File 'lib/aws-sdk-sagemaker/types.rb', line 16881

class DescribeComputeQuotaResponse < Struct.new(
  :compute_quota_arn,
  :compute_quota_id,
  :name,
  :description,
  :compute_quota_version,
  :status,
  :failure_reason,
  :cluster_arn,
  :compute_quota_config,
  :compute_quota_target,
  :activation_state,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#compute_quota_arnString

ARN of the compute allocation definition.

Returns:

  • (String)


16881
16882
16883
16884
16885
16886
16887
16888
16889
16890
16891
16892
16893
16894
16895
16896
16897
16898
16899
# File 'lib/aws-sdk-sagemaker/types.rb', line 16881

class DescribeComputeQuotaResponse < Struct.new(
  :compute_quota_arn,
  :compute_quota_id,
  :name,
  :description,
  :compute_quota_version,
  :status,
  :failure_reason,
  :cluster_arn,
  :compute_quota_config,
  :compute_quota_target,
  :activation_state,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#compute_quota_configTypes::ComputeQuotaConfig

Configuration of the compute allocation definition. This includes the resource sharing option, and the setting to preempt low priority tasks.



16881
16882
16883
16884
16885
16886
16887
16888
16889
16890
16891
16892
16893
16894
16895
16896
16897
16898
16899
# File 'lib/aws-sdk-sagemaker/types.rb', line 16881

class DescribeComputeQuotaResponse < Struct.new(
  :compute_quota_arn,
  :compute_quota_id,
  :name,
  :description,
  :compute_quota_version,
  :status,
  :failure_reason,
  :cluster_arn,
  :compute_quota_config,
  :compute_quota_target,
  :activation_state,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#compute_quota_idString

ID of the compute allocation definition.

Returns:

  • (String)


16881
16882
16883
16884
16885
16886
16887
16888
16889
16890
16891
16892
16893
16894
16895
16896
16897
16898
16899
# File 'lib/aws-sdk-sagemaker/types.rb', line 16881

class DescribeComputeQuotaResponse < Struct.new(
  :compute_quota_arn,
  :compute_quota_id,
  :name,
  :description,
  :compute_quota_version,
  :status,
  :failure_reason,
  :cluster_arn,
  :compute_quota_config,
  :compute_quota_target,
  :activation_state,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#compute_quota_targetTypes::ComputeQuotaTarget

The target entity to allocate compute resources to.



16881
16882
16883
16884
16885
16886
16887
16888
16889
16890
16891
16892
16893
16894
16895
16896
16897
16898
16899
# File 'lib/aws-sdk-sagemaker/types.rb', line 16881

class DescribeComputeQuotaResponse < Struct.new(
  :compute_quota_arn,
  :compute_quota_id,
  :name,
  :description,
  :compute_quota_version,
  :status,
  :failure_reason,
  :cluster_arn,
  :compute_quota_config,
  :compute_quota_target,
  :activation_state,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#compute_quota_versionInteger

Version of the compute allocation definition.

Returns:

  • (Integer)


16881
16882
16883
16884
16885
16886
16887
16888
16889
16890
16891
16892
16893
16894
16895
16896
16897
16898
16899
# File 'lib/aws-sdk-sagemaker/types.rb', line 16881

class DescribeComputeQuotaResponse < Struct.new(
  :compute_quota_arn,
  :compute_quota_id,
  :name,
  :description,
  :compute_quota_version,
  :status,
  :failure_reason,
  :cluster_arn,
  :compute_quota_config,
  :compute_quota_target,
  :activation_state,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#created_byTypes::UserContext

Information about the user who created or modified a SageMaker resource.

Returns:



16881
16882
16883
16884
16885
16886
16887
16888
16889
16890
16891
16892
16893
16894
16895
16896
16897
16898
16899
# File 'lib/aws-sdk-sagemaker/types.rb', line 16881

class DescribeComputeQuotaResponse < Struct.new(
  :compute_quota_arn,
  :compute_quota_id,
  :name,
  :description,
  :compute_quota_version,
  :status,
  :failure_reason,
  :cluster_arn,
  :compute_quota_config,
  :compute_quota_target,
  :activation_state,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

Creation time of the compute allocation configuration.

Returns:

  • (Time)


16881
16882
16883
16884
16885
16886
16887
16888
16889
16890
16891
16892
16893
16894
16895
16896
16897
16898
16899
# File 'lib/aws-sdk-sagemaker/types.rb', line 16881

class DescribeComputeQuotaResponse < Struct.new(
  :compute_quota_arn,
  :compute_quota_id,
  :name,
  :description,
  :compute_quota_version,
  :status,
  :failure_reason,
  :cluster_arn,
  :compute_quota_config,
  :compute_quota_target,
  :activation_state,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

Description of the compute allocation definition.

Returns:

  • (String)


16881
16882
16883
16884
16885
16886
16887
16888
16889
16890
16891
16892
16893
16894
16895
16896
16897
16898
16899
# File 'lib/aws-sdk-sagemaker/types.rb', line 16881

class DescribeComputeQuotaResponse < Struct.new(
  :compute_quota_arn,
  :compute_quota_id,
  :name,
  :description,
  :compute_quota_version,
  :status,
  :failure_reason,
  :cluster_arn,
  :compute_quota_config,
  :compute_quota_target,
  :activation_state,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

Failure reason of the compute allocation definition.

Returns:

  • (String)


16881
16882
16883
16884
16885
16886
16887
16888
16889
16890
16891
16892
16893
16894
16895
16896
16897
16898
16899
# File 'lib/aws-sdk-sagemaker/types.rb', line 16881

class DescribeComputeQuotaResponse < Struct.new(
  :compute_quota_arn,
  :compute_quota_id,
  :name,
  :description,
  :compute_quota_version,
  :status,
  :failure_reason,
  :cluster_arn,
  :compute_quota_config,
  :compute_quota_target,
  :activation_state,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_byTypes::UserContext

Information about the user who created or modified a SageMaker resource.

Returns:



16881
16882
16883
16884
16885
16886
16887
16888
16889
16890
16891
16892
16893
16894
16895
16896
16897
16898
16899
# File 'lib/aws-sdk-sagemaker/types.rb', line 16881

class DescribeComputeQuotaResponse < Struct.new(
  :compute_quota_arn,
  :compute_quota_id,
  :name,
  :description,
  :compute_quota_version,
  :status,
  :failure_reason,
  :cluster_arn,
  :compute_quota_config,
  :compute_quota_target,
  :activation_state,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

Last modified time of the compute allocation configuration.

Returns:

  • (Time)


16881
16882
16883
16884
16885
16886
16887
16888
16889
16890
16891
16892
16893
16894
16895
16896
16897
16898
16899
# File 'lib/aws-sdk-sagemaker/types.rb', line 16881

class DescribeComputeQuotaResponse < Struct.new(
  :compute_quota_arn,
  :compute_quota_id,
  :name,
  :description,
  :compute_quota_version,
  :status,
  :failure_reason,
  :cluster_arn,
  :compute_quota_config,
  :compute_quota_target,
  :activation_state,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Name of the compute allocation definition.

Returns:

  • (String)


16881
16882
16883
16884
16885
16886
16887
16888
16889
16890
16891
16892
16893
16894
16895
16896
16897
16898
16899
# File 'lib/aws-sdk-sagemaker/types.rb', line 16881

class DescribeComputeQuotaResponse < Struct.new(
  :compute_quota_arn,
  :compute_quota_id,
  :name,
  :description,
  :compute_quota_version,
  :status,
  :failure_reason,
  :cluster_arn,
  :compute_quota_config,
  :compute_quota_target,
  :activation_state,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

Status of the compute allocation definition.

Returns:

  • (String)


16881
16882
16883
16884
16885
16886
16887
16888
16889
16890
16891
16892
16893
16894
16895
16896
16897
16898
16899
# File 'lib/aws-sdk-sagemaker/types.rb', line 16881

class DescribeComputeQuotaResponse < Struct.new(
  :compute_quota_arn,
  :compute_quota_id,
  :name,
  :description,
  :compute_quota_version,
  :status,
  :failure_reason,
  :cluster_arn,
  :compute_quota_config,
  :compute_quota_target,
  :activation_state,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end