Class: Aws::SageMaker::Types::DescribeDeviceResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeDeviceResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_version ⇒ String
Edge Manager agent version.
-
#description ⇒ String
A description of the device.
-
#device_arn ⇒ String
The Amazon Resource Name (ARN) of the device.
-
#device_fleet_name ⇒ String
The name of the fleet the device belongs to.
-
#device_name ⇒ String
The unique identifier of the device.
-
#iot_thing_name ⇒ String
The Amazon Web Services Internet of Things (IoT) object thing name associated with the device.
-
#latest_heartbeat ⇒ Time
The last heartbeat received from the device.
-
#max_models ⇒ Integer
The maximum number of models.
-
#models ⇒ Array<Types::EdgeModel>
Models on the device.
-
#next_token ⇒ String
The response from the last list when returning a list large enough to need tokening.
-
#registration_time ⇒ Time
The timestamp of the last registration or de-reregistration.
Instance Attribute Details
#agent_version ⇒ String
Edge Manager agent version.
19055 19056 19057 19058 19059 19060 19061 19062 19063 19064 19065 19066 19067 19068 19069 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19055 class DescribeDeviceResponse < Struct.new( :device_arn, :device_name, :description, :device_fleet_name, :iot_thing_name, :registration_time, :latest_heartbeat, :models, :max_models, :next_token, :agent_version) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the device.
19055 19056 19057 19058 19059 19060 19061 19062 19063 19064 19065 19066 19067 19068 19069 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19055 class DescribeDeviceResponse < Struct.new( :device_arn, :device_name, :description, :device_fleet_name, :iot_thing_name, :registration_time, :latest_heartbeat, :models, :max_models, :next_token, :agent_version) SENSITIVE = [] include Aws::Structure end |
#device_arn ⇒ String
The Amazon Resource Name (ARN) of the device.
19055 19056 19057 19058 19059 19060 19061 19062 19063 19064 19065 19066 19067 19068 19069 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19055 class DescribeDeviceResponse < Struct.new( :device_arn, :device_name, :description, :device_fleet_name, :iot_thing_name, :registration_time, :latest_heartbeat, :models, :max_models, :next_token, :agent_version) SENSITIVE = [] include Aws::Structure end |
#device_fleet_name ⇒ String
The name of the fleet the device belongs to.
19055 19056 19057 19058 19059 19060 19061 19062 19063 19064 19065 19066 19067 19068 19069 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19055 class DescribeDeviceResponse < Struct.new( :device_arn, :device_name, :description, :device_fleet_name, :iot_thing_name, :registration_time, :latest_heartbeat, :models, :max_models, :next_token, :agent_version) SENSITIVE = [] include Aws::Structure end |
#device_name ⇒ String
The unique identifier of the device.
19055 19056 19057 19058 19059 19060 19061 19062 19063 19064 19065 19066 19067 19068 19069 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19055 class DescribeDeviceResponse < Struct.new( :device_arn, :device_name, :description, :device_fleet_name, :iot_thing_name, :registration_time, :latest_heartbeat, :models, :max_models, :next_token, :agent_version) SENSITIVE = [] include Aws::Structure end |
#iot_thing_name ⇒ String
The Amazon Web Services Internet of Things (IoT) object thing name associated with the device.
19055 19056 19057 19058 19059 19060 19061 19062 19063 19064 19065 19066 19067 19068 19069 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19055 class DescribeDeviceResponse < Struct.new( :device_arn, :device_name, :description, :device_fleet_name, :iot_thing_name, :registration_time, :latest_heartbeat, :models, :max_models, :next_token, :agent_version) SENSITIVE = [] include Aws::Structure end |
#latest_heartbeat ⇒ Time
The last heartbeat received from the device.
19055 19056 19057 19058 19059 19060 19061 19062 19063 19064 19065 19066 19067 19068 19069 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19055 class DescribeDeviceResponse < Struct.new( :device_arn, :device_name, :description, :device_fleet_name, :iot_thing_name, :registration_time, :latest_heartbeat, :models, :max_models, :next_token, :agent_version) SENSITIVE = [] include Aws::Structure end |
#max_models ⇒ Integer
The maximum number of models.
19055 19056 19057 19058 19059 19060 19061 19062 19063 19064 19065 19066 19067 19068 19069 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19055 class DescribeDeviceResponse < Struct.new( :device_arn, :device_name, :description, :device_fleet_name, :iot_thing_name, :registration_time, :latest_heartbeat, :models, :max_models, :next_token, :agent_version) SENSITIVE = [] include Aws::Structure end |
#models ⇒ Array<Types::EdgeModel>
Models on the device.
19055 19056 19057 19058 19059 19060 19061 19062 19063 19064 19065 19066 19067 19068 19069 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19055 class DescribeDeviceResponse < Struct.new( :device_arn, :device_name, :description, :device_fleet_name, :iot_thing_name, :registration_time, :latest_heartbeat, :models, :max_models, :next_token, :agent_version) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The response from the last list when returning a list large enough to need tokening.
19055 19056 19057 19058 19059 19060 19061 19062 19063 19064 19065 19066 19067 19068 19069 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19055 class DescribeDeviceResponse < Struct.new( :device_arn, :device_name, :description, :device_fleet_name, :iot_thing_name, :registration_time, :latest_heartbeat, :models, :max_models, :next_token, :agent_version) SENSITIVE = [] include Aws::Structure end |
#registration_time ⇒ Time
The timestamp of the last registration or de-reregistration.
19055 19056 19057 19058 19059 19060 19061 19062 19063 19064 19065 19066 19067 19068 19069 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19055 class DescribeDeviceResponse < Struct.new( :device_arn, :device_name, :description, :device_fleet_name, :iot_thing_name, :registration_time, :latest_heartbeat, :models, :max_models, :next_token, :agent_version) SENSITIVE = [] include Aws::Structure end |