Class: Aws::SageMaker::Types::DescribeDomainResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeDomainResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#app_network_access_type ⇒ String
Specifies the VPC used for non-EFS traffic.
-
#app_security_group_management ⇒ String
The entity that creates and manages the required security groups for inter-app communication in ‘VPCOnly` mode.
-
#auth_mode ⇒ String
The domain’s authentication mode.
-
#creation_time ⇒ Time
The creation time.
-
#default_space_settings ⇒ Types::DefaultSpaceSettings
The default settings for shared spaces that users create in the domain.
-
#default_user_settings ⇒ Types::UserSettings
Settings which are applied to UserProfiles in this domain if settings are not explicitly specified in a given UserProfile.
-
#domain_arn ⇒ String
The domain’s Amazon Resource Name (ARN).
-
#domain_id ⇒ String
The domain ID.
-
#domain_name ⇒ String
The domain name.
-
#domain_settings ⇒ Types::DomainSettings
A collection of ‘Domain` settings.
-
#failure_reason ⇒ String
The failure reason.
-
#home_efs_file_system_id ⇒ String
The ID of the Amazon Elastic File System managed by this Domain.
-
#home_efs_file_system_kms_key_id ⇒ String
Use ‘KmsKeyId`.
-
#kms_key_id ⇒ String
The Amazon Web Services KMS customer managed key used to encrypt the EFS volume attached to the domain.
-
#last_modified_time ⇒ Time
The last modified time.
-
#security_group_id_for_domain_boundary ⇒ String
The ID of the security group that authorizes traffic between the ‘RSessionGateway` apps and the `RStudioServerPro` app.
-
#single_sign_on_application_arn ⇒ String
The ARN of the application managed by SageMaker AI in IAM Identity Center.
-
#single_sign_on_managed_application_instance_id ⇒ String
The IAM Identity Center managed application instance ID.
-
#status ⇒ String
The status.
-
#subnet_ids ⇒ Array<String>
The VPC subnets that the domain uses for communication.
-
#tag_propagation ⇒ String
Indicates whether custom tag propagation is supported for the domain.
-
#url ⇒ String
The domain’s URL.
-
#vpc_id ⇒ String
The ID of the Amazon Virtual Private Cloud (VPC) that the domain uses for communication.
Instance Attribute Details
#app_network_access_type ⇒ String
Specifies the VPC used for non-EFS traffic. The default value is ‘PublicInternetOnly`.
-
‘PublicInternetOnly` - Non-EFS traffic is through a VPC managed by Amazon SageMaker AI, which allows direct internet access
-
‘VpcOnly` - All traffic is through the specified VPC and subnets
18573 18574 18575 18576 18577 18578 18579 18580 18581 18582 18583 18584 18585 18586 18587 18588 18589 18590 18591 18592 18593 18594 18595 18596 18597 18598 18599 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18573 class DescribeDomainResponse < Struct.new( :domain_arn, :domain_id, :domain_name, :home_efs_file_system_id, :single_sign_on_managed_application_instance_id, :single_sign_on_application_arn, :status, :creation_time, :last_modified_time, :failure_reason, :security_group_id_for_domain_boundary, :auth_mode, :default_user_settings, :domain_settings, :app_network_access_type, :home_efs_file_system_kms_key_id, :subnet_ids, :url, :vpc_id, :kms_key_id, :app_security_group_management, :tag_propagation, :default_space_settings) SENSITIVE = [] include Aws::Structure end |
#app_security_group_management ⇒ String
The entity that creates and manages the required security groups for inter-app communication in ‘VPCOnly` mode. Required when `CreateDomain.AppNetworkAccessType` is `VPCOnly` and `DomainSettings.RStudioServerProDomainSettings.DomainExecutionRoleArn` is provided.
18573 18574 18575 18576 18577 18578 18579 18580 18581 18582 18583 18584 18585 18586 18587 18588 18589 18590 18591 18592 18593 18594 18595 18596 18597 18598 18599 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18573 class DescribeDomainResponse < Struct.new( :domain_arn, :domain_id, :domain_name, :home_efs_file_system_id, :single_sign_on_managed_application_instance_id, :single_sign_on_application_arn, :status, :creation_time, :last_modified_time, :failure_reason, :security_group_id_for_domain_boundary, :auth_mode, :default_user_settings, :domain_settings, :app_network_access_type, :home_efs_file_system_kms_key_id, :subnet_ids, :url, :vpc_id, :kms_key_id, :app_security_group_management, :tag_propagation, :default_space_settings) SENSITIVE = [] include Aws::Structure end |
#auth_mode ⇒ String
The domain’s authentication mode.
18573 18574 18575 18576 18577 18578 18579 18580 18581 18582 18583 18584 18585 18586 18587 18588 18589 18590 18591 18592 18593 18594 18595 18596 18597 18598 18599 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18573 class DescribeDomainResponse < Struct.new( :domain_arn, :domain_id, :domain_name, :home_efs_file_system_id, :single_sign_on_managed_application_instance_id, :single_sign_on_application_arn, :status, :creation_time, :last_modified_time, :failure_reason, :security_group_id_for_domain_boundary, :auth_mode, :default_user_settings, :domain_settings, :app_network_access_type, :home_efs_file_system_kms_key_id, :subnet_ids, :url, :vpc_id, :kms_key_id, :app_security_group_management, :tag_propagation, :default_space_settings) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The creation time.
18573 18574 18575 18576 18577 18578 18579 18580 18581 18582 18583 18584 18585 18586 18587 18588 18589 18590 18591 18592 18593 18594 18595 18596 18597 18598 18599 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18573 class DescribeDomainResponse < Struct.new( :domain_arn, :domain_id, :domain_name, :home_efs_file_system_id, :single_sign_on_managed_application_instance_id, :single_sign_on_application_arn, :status, :creation_time, :last_modified_time, :failure_reason, :security_group_id_for_domain_boundary, :auth_mode, :default_user_settings, :domain_settings, :app_network_access_type, :home_efs_file_system_kms_key_id, :subnet_ids, :url, :vpc_id, :kms_key_id, :app_security_group_management, :tag_propagation, :default_space_settings) SENSITIVE = [] include Aws::Structure end |
#default_space_settings ⇒ Types::DefaultSpaceSettings
The default settings for shared spaces that users create in the domain.
18573 18574 18575 18576 18577 18578 18579 18580 18581 18582 18583 18584 18585 18586 18587 18588 18589 18590 18591 18592 18593 18594 18595 18596 18597 18598 18599 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18573 class DescribeDomainResponse < Struct.new( :domain_arn, :domain_id, :domain_name, :home_efs_file_system_id, :single_sign_on_managed_application_instance_id, :single_sign_on_application_arn, :status, :creation_time, :last_modified_time, :failure_reason, :security_group_id_for_domain_boundary, :auth_mode, :default_user_settings, :domain_settings, :app_network_access_type, :home_efs_file_system_kms_key_id, :subnet_ids, :url, :vpc_id, :kms_key_id, :app_security_group_management, :tag_propagation, :default_space_settings) SENSITIVE = [] include Aws::Structure end |
#default_user_settings ⇒ Types::UserSettings
Settings which are applied to UserProfiles in this domain if settings are not explicitly specified in a given UserProfile.
18573 18574 18575 18576 18577 18578 18579 18580 18581 18582 18583 18584 18585 18586 18587 18588 18589 18590 18591 18592 18593 18594 18595 18596 18597 18598 18599 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18573 class DescribeDomainResponse < Struct.new( :domain_arn, :domain_id, :domain_name, :home_efs_file_system_id, :single_sign_on_managed_application_instance_id, :single_sign_on_application_arn, :status, :creation_time, :last_modified_time, :failure_reason, :security_group_id_for_domain_boundary, :auth_mode, :default_user_settings, :domain_settings, :app_network_access_type, :home_efs_file_system_kms_key_id, :subnet_ids, :url, :vpc_id, :kms_key_id, :app_security_group_management, :tag_propagation, :default_space_settings) SENSITIVE = [] include Aws::Structure end |
#domain_arn ⇒ String
The domain’s Amazon Resource Name (ARN).
18573 18574 18575 18576 18577 18578 18579 18580 18581 18582 18583 18584 18585 18586 18587 18588 18589 18590 18591 18592 18593 18594 18595 18596 18597 18598 18599 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18573 class DescribeDomainResponse < Struct.new( :domain_arn, :domain_id, :domain_name, :home_efs_file_system_id, :single_sign_on_managed_application_instance_id, :single_sign_on_application_arn, :status, :creation_time, :last_modified_time, :failure_reason, :security_group_id_for_domain_boundary, :auth_mode, :default_user_settings, :domain_settings, :app_network_access_type, :home_efs_file_system_kms_key_id, :subnet_ids, :url, :vpc_id, :kms_key_id, :app_security_group_management, :tag_propagation, :default_space_settings) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
The domain ID.
18573 18574 18575 18576 18577 18578 18579 18580 18581 18582 18583 18584 18585 18586 18587 18588 18589 18590 18591 18592 18593 18594 18595 18596 18597 18598 18599 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18573 class DescribeDomainResponse < Struct.new( :domain_arn, :domain_id, :domain_name, :home_efs_file_system_id, :single_sign_on_managed_application_instance_id, :single_sign_on_application_arn, :status, :creation_time, :last_modified_time, :failure_reason, :security_group_id_for_domain_boundary, :auth_mode, :default_user_settings, :domain_settings, :app_network_access_type, :home_efs_file_system_kms_key_id, :subnet_ids, :url, :vpc_id, :kms_key_id, :app_security_group_management, :tag_propagation, :default_space_settings) SENSITIVE = [] include Aws::Structure end |
#domain_name ⇒ String
The domain name.
18573 18574 18575 18576 18577 18578 18579 18580 18581 18582 18583 18584 18585 18586 18587 18588 18589 18590 18591 18592 18593 18594 18595 18596 18597 18598 18599 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18573 class DescribeDomainResponse < Struct.new( :domain_arn, :domain_id, :domain_name, :home_efs_file_system_id, :single_sign_on_managed_application_instance_id, :single_sign_on_application_arn, :status, :creation_time, :last_modified_time, :failure_reason, :security_group_id_for_domain_boundary, :auth_mode, :default_user_settings, :domain_settings, :app_network_access_type, :home_efs_file_system_kms_key_id, :subnet_ids, :url, :vpc_id, :kms_key_id, :app_security_group_management, :tag_propagation, :default_space_settings) SENSITIVE = [] include Aws::Structure end |
#domain_settings ⇒ Types::DomainSettings
A collection of ‘Domain` settings.
18573 18574 18575 18576 18577 18578 18579 18580 18581 18582 18583 18584 18585 18586 18587 18588 18589 18590 18591 18592 18593 18594 18595 18596 18597 18598 18599 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18573 class DescribeDomainResponse < Struct.new( :domain_arn, :domain_id, :domain_name, :home_efs_file_system_id, :single_sign_on_managed_application_instance_id, :single_sign_on_application_arn, :status, :creation_time, :last_modified_time, :failure_reason, :security_group_id_for_domain_boundary, :auth_mode, :default_user_settings, :domain_settings, :app_network_access_type, :home_efs_file_system_kms_key_id, :subnet_ids, :url, :vpc_id, :kms_key_id, :app_security_group_management, :tag_propagation, :default_space_settings) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
The failure reason.
18573 18574 18575 18576 18577 18578 18579 18580 18581 18582 18583 18584 18585 18586 18587 18588 18589 18590 18591 18592 18593 18594 18595 18596 18597 18598 18599 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18573 class DescribeDomainResponse < Struct.new( :domain_arn, :domain_id, :domain_name, :home_efs_file_system_id, :single_sign_on_managed_application_instance_id, :single_sign_on_application_arn, :status, :creation_time, :last_modified_time, :failure_reason, :security_group_id_for_domain_boundary, :auth_mode, :default_user_settings, :domain_settings, :app_network_access_type, :home_efs_file_system_kms_key_id, :subnet_ids, :url, :vpc_id, :kms_key_id, :app_security_group_management, :tag_propagation, :default_space_settings) SENSITIVE = [] include Aws::Structure end |
#home_efs_file_system_id ⇒ String
The ID of the Amazon Elastic File System managed by this Domain.
18573 18574 18575 18576 18577 18578 18579 18580 18581 18582 18583 18584 18585 18586 18587 18588 18589 18590 18591 18592 18593 18594 18595 18596 18597 18598 18599 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18573 class DescribeDomainResponse < Struct.new( :domain_arn, :domain_id, :domain_name, :home_efs_file_system_id, :single_sign_on_managed_application_instance_id, :single_sign_on_application_arn, :status, :creation_time, :last_modified_time, :failure_reason, :security_group_id_for_domain_boundary, :auth_mode, :default_user_settings, :domain_settings, :app_network_access_type, :home_efs_file_system_kms_key_id, :subnet_ids, :url, :vpc_id, :kms_key_id, :app_security_group_management, :tag_propagation, :default_space_settings) SENSITIVE = [] include Aws::Structure end |
#home_efs_file_system_kms_key_id ⇒ String
Use ‘KmsKeyId`.
18573 18574 18575 18576 18577 18578 18579 18580 18581 18582 18583 18584 18585 18586 18587 18588 18589 18590 18591 18592 18593 18594 18595 18596 18597 18598 18599 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18573 class DescribeDomainResponse < Struct.new( :domain_arn, :domain_id, :domain_name, :home_efs_file_system_id, :single_sign_on_managed_application_instance_id, :single_sign_on_application_arn, :status, :creation_time, :last_modified_time, :failure_reason, :security_group_id_for_domain_boundary, :auth_mode, :default_user_settings, :domain_settings, :app_network_access_type, :home_efs_file_system_kms_key_id, :subnet_ids, :url, :vpc_id, :kms_key_id, :app_security_group_management, :tag_propagation, :default_space_settings) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The Amazon Web Services KMS customer managed key used to encrypt the EFS volume attached to the domain.
18573 18574 18575 18576 18577 18578 18579 18580 18581 18582 18583 18584 18585 18586 18587 18588 18589 18590 18591 18592 18593 18594 18595 18596 18597 18598 18599 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18573 class DescribeDomainResponse < Struct.new( :domain_arn, :domain_id, :domain_name, :home_efs_file_system_id, :single_sign_on_managed_application_instance_id, :single_sign_on_application_arn, :status, :creation_time, :last_modified_time, :failure_reason, :security_group_id_for_domain_boundary, :auth_mode, :default_user_settings, :domain_settings, :app_network_access_type, :home_efs_file_system_kms_key_id, :subnet_ids, :url, :vpc_id, :kms_key_id, :app_security_group_management, :tag_propagation, :default_space_settings) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The last modified time.
18573 18574 18575 18576 18577 18578 18579 18580 18581 18582 18583 18584 18585 18586 18587 18588 18589 18590 18591 18592 18593 18594 18595 18596 18597 18598 18599 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18573 class DescribeDomainResponse < Struct.new( :domain_arn, :domain_id, :domain_name, :home_efs_file_system_id, :single_sign_on_managed_application_instance_id, :single_sign_on_application_arn, :status, :creation_time, :last_modified_time, :failure_reason, :security_group_id_for_domain_boundary, :auth_mode, :default_user_settings, :domain_settings, :app_network_access_type, :home_efs_file_system_kms_key_id, :subnet_ids, :url, :vpc_id, :kms_key_id, :app_security_group_management, :tag_propagation, :default_space_settings) SENSITIVE = [] include Aws::Structure end |
#security_group_id_for_domain_boundary ⇒ String
The ID of the security group that authorizes traffic between the ‘RSessionGateway` apps and the `RStudioServerPro` app.
18573 18574 18575 18576 18577 18578 18579 18580 18581 18582 18583 18584 18585 18586 18587 18588 18589 18590 18591 18592 18593 18594 18595 18596 18597 18598 18599 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18573 class DescribeDomainResponse < Struct.new( :domain_arn, :domain_id, :domain_name, :home_efs_file_system_id, :single_sign_on_managed_application_instance_id, :single_sign_on_application_arn, :status, :creation_time, :last_modified_time, :failure_reason, :security_group_id_for_domain_boundary, :auth_mode, :default_user_settings, :domain_settings, :app_network_access_type, :home_efs_file_system_kms_key_id, :subnet_ids, :url, :vpc_id, :kms_key_id, :app_security_group_management, :tag_propagation, :default_space_settings) SENSITIVE = [] include Aws::Structure end |
#single_sign_on_application_arn ⇒ String
The ARN of the application managed by SageMaker AI in IAM Identity Center. This value is only returned for domains created after October 1, 2023.
18573 18574 18575 18576 18577 18578 18579 18580 18581 18582 18583 18584 18585 18586 18587 18588 18589 18590 18591 18592 18593 18594 18595 18596 18597 18598 18599 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18573 class DescribeDomainResponse < Struct.new( :domain_arn, :domain_id, :domain_name, :home_efs_file_system_id, :single_sign_on_managed_application_instance_id, :single_sign_on_application_arn, :status, :creation_time, :last_modified_time, :failure_reason, :security_group_id_for_domain_boundary, :auth_mode, :default_user_settings, :domain_settings, :app_network_access_type, :home_efs_file_system_kms_key_id, :subnet_ids, :url, :vpc_id, :kms_key_id, :app_security_group_management, :tag_propagation, :default_space_settings) SENSITIVE = [] include Aws::Structure end |
#single_sign_on_managed_application_instance_id ⇒ String
The IAM Identity Center managed application instance ID.
18573 18574 18575 18576 18577 18578 18579 18580 18581 18582 18583 18584 18585 18586 18587 18588 18589 18590 18591 18592 18593 18594 18595 18596 18597 18598 18599 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18573 class DescribeDomainResponse < Struct.new( :domain_arn, :domain_id, :domain_name, :home_efs_file_system_id, :single_sign_on_managed_application_instance_id, :single_sign_on_application_arn, :status, :creation_time, :last_modified_time, :failure_reason, :security_group_id_for_domain_boundary, :auth_mode, :default_user_settings, :domain_settings, :app_network_access_type, :home_efs_file_system_kms_key_id, :subnet_ids, :url, :vpc_id, :kms_key_id, :app_security_group_management, :tag_propagation, :default_space_settings) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status.
18573 18574 18575 18576 18577 18578 18579 18580 18581 18582 18583 18584 18585 18586 18587 18588 18589 18590 18591 18592 18593 18594 18595 18596 18597 18598 18599 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18573 class DescribeDomainResponse < Struct.new( :domain_arn, :domain_id, :domain_name, :home_efs_file_system_id, :single_sign_on_managed_application_instance_id, :single_sign_on_application_arn, :status, :creation_time, :last_modified_time, :failure_reason, :security_group_id_for_domain_boundary, :auth_mode, :default_user_settings, :domain_settings, :app_network_access_type, :home_efs_file_system_kms_key_id, :subnet_ids, :url, :vpc_id, :kms_key_id, :app_security_group_management, :tag_propagation, :default_space_settings) SENSITIVE = [] include Aws::Structure end |
#subnet_ids ⇒ Array<String>
The VPC subnets that the domain uses for communication.
18573 18574 18575 18576 18577 18578 18579 18580 18581 18582 18583 18584 18585 18586 18587 18588 18589 18590 18591 18592 18593 18594 18595 18596 18597 18598 18599 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18573 class DescribeDomainResponse < Struct.new( :domain_arn, :domain_id, :domain_name, :home_efs_file_system_id, :single_sign_on_managed_application_instance_id, :single_sign_on_application_arn, :status, :creation_time, :last_modified_time, :failure_reason, :security_group_id_for_domain_boundary, :auth_mode, :default_user_settings, :domain_settings, :app_network_access_type, :home_efs_file_system_kms_key_id, :subnet_ids, :url, :vpc_id, :kms_key_id, :app_security_group_management, :tag_propagation, :default_space_settings) SENSITIVE = [] include Aws::Structure end |
#tag_propagation ⇒ String
Indicates whether custom tag propagation is supported for the domain.
18573 18574 18575 18576 18577 18578 18579 18580 18581 18582 18583 18584 18585 18586 18587 18588 18589 18590 18591 18592 18593 18594 18595 18596 18597 18598 18599 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18573 class DescribeDomainResponse < Struct.new( :domain_arn, :domain_id, :domain_name, :home_efs_file_system_id, :single_sign_on_managed_application_instance_id, :single_sign_on_application_arn, :status, :creation_time, :last_modified_time, :failure_reason, :security_group_id_for_domain_boundary, :auth_mode, :default_user_settings, :domain_settings, :app_network_access_type, :home_efs_file_system_kms_key_id, :subnet_ids, :url, :vpc_id, :kms_key_id, :app_security_group_management, :tag_propagation, :default_space_settings) SENSITIVE = [] include Aws::Structure end |
#url ⇒ String
The domain’s URL.
18573 18574 18575 18576 18577 18578 18579 18580 18581 18582 18583 18584 18585 18586 18587 18588 18589 18590 18591 18592 18593 18594 18595 18596 18597 18598 18599 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18573 class DescribeDomainResponse < Struct.new( :domain_arn, :domain_id, :domain_name, :home_efs_file_system_id, :single_sign_on_managed_application_instance_id, :single_sign_on_application_arn, :status, :creation_time, :last_modified_time, :failure_reason, :security_group_id_for_domain_boundary, :auth_mode, :default_user_settings, :domain_settings, :app_network_access_type, :home_efs_file_system_kms_key_id, :subnet_ids, :url, :vpc_id, :kms_key_id, :app_security_group_management, :tag_propagation, :default_space_settings) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the Amazon Virtual Private Cloud (VPC) that the domain uses for communication.
18573 18574 18575 18576 18577 18578 18579 18580 18581 18582 18583 18584 18585 18586 18587 18588 18589 18590 18591 18592 18593 18594 18595 18596 18597 18598 18599 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18573 class DescribeDomainResponse < Struct.new( :domain_arn, :domain_id, :domain_name, :home_efs_file_system_id, :single_sign_on_managed_application_instance_id, :single_sign_on_application_arn, :status, :creation_time, :last_modified_time, :failure_reason, :security_group_id_for_domain_boundary, :auth_mode, :default_user_settings, :domain_settings, :app_network_access_type, :home_efs_file_system_kms_key_id, :subnet_ids, :url, :vpc_id, :kms_key_id, :app_security_group_management, :tag_propagation, :default_space_settings) SENSITIVE = [] include Aws::Structure end |