Class: Aws::SageMaker::Types::DescribeEdgeDeploymentPlanRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeEdgeDeploymentPlanRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#edge_deployment_plan_name ⇒ String
The name of the deployment plan to describe.
-
#max_results ⇒ Integer
The maximum number of results to select (50 by default).
-
#next_token ⇒ String
If the edge deployment plan has enough stages to require tokening, then this is the response from the last list of stages returned.
Instance Attribute Details
#edge_deployment_plan_name ⇒ String
The name of the deployment plan to describe.
18577 18578 18579 18580 18581 18582 18583 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18577 class DescribeEdgeDeploymentPlanRequest < Struct.new( :edge_deployment_plan_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to select (50 by default).
18577 18578 18579 18580 18581 18582 18583 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18577 class DescribeEdgeDeploymentPlanRequest < Struct.new( :edge_deployment_plan_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the edge deployment plan has enough stages to require tokening, then this is the response from the last list of stages returned.
18577 18578 18579 18580 18581 18582 18583 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18577 class DescribeEdgeDeploymentPlanRequest < Struct.new( :edge_deployment_plan_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |