Class: Aws::SageMaker::Types::DescribeEdgeDeploymentPlanResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeEdgeDeploymentPlanResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Time
The time when the edge deployment plan was created.
-
#device_fleet_name ⇒ String
The device fleet used for this edge deployment plan.
-
#edge_deployment_failed ⇒ Integer
The number of edge devices that failed the deployment.
-
#edge_deployment_pending ⇒ Integer
The number of edge devices yet to pick up deployment, or in progress.
-
#edge_deployment_plan_arn ⇒ String
The ARN of edge deployment plan.
-
#edge_deployment_plan_name ⇒ String
The name of the edge deployment plan.
-
#edge_deployment_success ⇒ Integer
The number of edge devices with the successful deployment.
-
#last_modified_time ⇒ Time
The time when the edge deployment plan was last updated.
-
#model_configs ⇒ Array<Types::EdgeDeploymentModelConfig>
List of models associated with the edge deployment plan.
-
#next_token ⇒ String
Token to use when calling the next set of stages in the edge deployment plan.
-
#stages ⇒ Array<Types::DeploymentStageStatusSummary>
List of stages in the edge deployment plan.
Instance Attribute Details
#creation_time ⇒ Time
The time when the edge deployment plan was created.
19299 19300 19301 19302 19303 19304 19305 19306 19307 19308 19309 19310 19311 19312 19313 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19299 class DescribeEdgeDeploymentPlanResponse < Struct.new( :edge_deployment_plan_arn, :edge_deployment_plan_name, :model_configs, :device_fleet_name, :edge_deployment_success, :edge_deployment_pending, :edge_deployment_failed, :stages, :next_token, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#device_fleet_name ⇒ String
The device fleet used for this edge deployment plan.
19299 19300 19301 19302 19303 19304 19305 19306 19307 19308 19309 19310 19311 19312 19313 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19299 class DescribeEdgeDeploymentPlanResponse < Struct.new( :edge_deployment_plan_arn, :edge_deployment_plan_name, :model_configs, :device_fleet_name, :edge_deployment_success, :edge_deployment_pending, :edge_deployment_failed, :stages, :next_token, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#edge_deployment_failed ⇒ Integer
The number of edge devices that failed the deployment.
19299 19300 19301 19302 19303 19304 19305 19306 19307 19308 19309 19310 19311 19312 19313 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19299 class DescribeEdgeDeploymentPlanResponse < Struct.new( :edge_deployment_plan_arn, :edge_deployment_plan_name, :model_configs, :device_fleet_name, :edge_deployment_success, :edge_deployment_pending, :edge_deployment_failed, :stages, :next_token, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#edge_deployment_pending ⇒ Integer
The number of edge devices yet to pick up deployment, or in progress.
19299 19300 19301 19302 19303 19304 19305 19306 19307 19308 19309 19310 19311 19312 19313 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19299 class DescribeEdgeDeploymentPlanResponse < Struct.new( :edge_deployment_plan_arn, :edge_deployment_plan_name, :model_configs, :device_fleet_name, :edge_deployment_success, :edge_deployment_pending, :edge_deployment_failed, :stages, :next_token, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#edge_deployment_plan_arn ⇒ String
The ARN of edge deployment plan.
19299 19300 19301 19302 19303 19304 19305 19306 19307 19308 19309 19310 19311 19312 19313 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19299 class DescribeEdgeDeploymentPlanResponse < Struct.new( :edge_deployment_plan_arn, :edge_deployment_plan_name, :model_configs, :device_fleet_name, :edge_deployment_success, :edge_deployment_pending, :edge_deployment_failed, :stages, :next_token, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#edge_deployment_plan_name ⇒ String
The name of the edge deployment plan.
19299 19300 19301 19302 19303 19304 19305 19306 19307 19308 19309 19310 19311 19312 19313 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19299 class DescribeEdgeDeploymentPlanResponse < Struct.new( :edge_deployment_plan_arn, :edge_deployment_plan_name, :model_configs, :device_fleet_name, :edge_deployment_success, :edge_deployment_pending, :edge_deployment_failed, :stages, :next_token, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#edge_deployment_success ⇒ Integer
The number of edge devices with the successful deployment.
19299 19300 19301 19302 19303 19304 19305 19306 19307 19308 19309 19310 19311 19312 19313 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19299 class DescribeEdgeDeploymentPlanResponse < Struct.new( :edge_deployment_plan_arn, :edge_deployment_plan_name, :model_configs, :device_fleet_name, :edge_deployment_success, :edge_deployment_pending, :edge_deployment_failed, :stages, :next_token, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The time when the edge deployment plan was last updated.
19299 19300 19301 19302 19303 19304 19305 19306 19307 19308 19309 19310 19311 19312 19313 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19299 class DescribeEdgeDeploymentPlanResponse < Struct.new( :edge_deployment_plan_arn, :edge_deployment_plan_name, :model_configs, :device_fleet_name, :edge_deployment_success, :edge_deployment_pending, :edge_deployment_failed, :stages, :next_token, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#model_configs ⇒ Array<Types::EdgeDeploymentModelConfig>
List of models associated with the edge deployment plan.
19299 19300 19301 19302 19303 19304 19305 19306 19307 19308 19309 19310 19311 19312 19313 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19299 class DescribeEdgeDeploymentPlanResponse < Struct.new( :edge_deployment_plan_arn, :edge_deployment_plan_name, :model_configs, :device_fleet_name, :edge_deployment_success, :edge_deployment_pending, :edge_deployment_failed, :stages, :next_token, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Token to use when calling the next set of stages in the edge deployment plan.
19299 19300 19301 19302 19303 19304 19305 19306 19307 19308 19309 19310 19311 19312 19313 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19299 class DescribeEdgeDeploymentPlanResponse < Struct.new( :edge_deployment_plan_arn, :edge_deployment_plan_name, :model_configs, :device_fleet_name, :edge_deployment_success, :edge_deployment_pending, :edge_deployment_failed, :stages, :next_token, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#stages ⇒ Array<Types::DeploymentStageStatusSummary>
List of stages in the edge deployment plan.
19299 19300 19301 19302 19303 19304 19305 19306 19307 19308 19309 19310 19311 19312 19313 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19299 class DescribeEdgeDeploymentPlanResponse < Struct.new( :edge_deployment_plan_arn, :edge_deployment_plan_name, :model_configs, :device_fleet_name, :edge_deployment_success, :edge_deployment_pending, :edge_deployment_failed, :stages, :next_token, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |