Class: Aws::SageMaker::Types::DescribeEdgeDeploymentPlanResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeEdgeDeploymentPlanResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Time
The time when the edge deployment plan was created.
-
#device_fleet_name ⇒ String
The device fleet used for this edge deployment plan.
-
#edge_deployment_failed ⇒ Integer
The number of edge devices that failed the deployment.
-
#edge_deployment_pending ⇒ Integer
The number of edge devices yet to pick up deployment, or in progress.
-
#edge_deployment_plan_arn ⇒ String
The ARN of edge deployment plan.
-
#edge_deployment_plan_name ⇒ String
The name of the edge deployment plan.
-
#edge_deployment_success ⇒ Integer
The number of edge devices with the successful deployment.
-
#last_modified_time ⇒ Time
The time when the edge deployment plan was last updated.
-
#model_configs ⇒ Array<Types::EdgeDeploymentModelConfig>
List of models associated with the edge deployment plan.
-
#next_token ⇒ String
Token to use when calling the next set of stages in the edge deployment plan.
-
#stages ⇒ Array<Types::DeploymentStageStatusSummary>
List of stages in the edge deployment plan.
Instance Attribute Details
#creation_time ⇒ Time
The time when the edge deployment plan was created.
18650 18651 18652 18653 18654 18655 18656 18657 18658 18659 18660 18661 18662 18663 18664 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18650 class DescribeEdgeDeploymentPlanResponse < Struct.new( :edge_deployment_plan_arn, :edge_deployment_plan_name, :model_configs, :device_fleet_name, :edge_deployment_success, :edge_deployment_pending, :edge_deployment_failed, :stages, :next_token, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#device_fleet_name ⇒ String
The device fleet used for this edge deployment plan.
18650 18651 18652 18653 18654 18655 18656 18657 18658 18659 18660 18661 18662 18663 18664 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18650 class DescribeEdgeDeploymentPlanResponse < Struct.new( :edge_deployment_plan_arn, :edge_deployment_plan_name, :model_configs, :device_fleet_name, :edge_deployment_success, :edge_deployment_pending, :edge_deployment_failed, :stages, :next_token, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#edge_deployment_failed ⇒ Integer
The number of edge devices that failed the deployment.
18650 18651 18652 18653 18654 18655 18656 18657 18658 18659 18660 18661 18662 18663 18664 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18650 class DescribeEdgeDeploymentPlanResponse < Struct.new( :edge_deployment_plan_arn, :edge_deployment_plan_name, :model_configs, :device_fleet_name, :edge_deployment_success, :edge_deployment_pending, :edge_deployment_failed, :stages, :next_token, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#edge_deployment_pending ⇒ Integer
The number of edge devices yet to pick up deployment, or in progress.
18650 18651 18652 18653 18654 18655 18656 18657 18658 18659 18660 18661 18662 18663 18664 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18650 class DescribeEdgeDeploymentPlanResponse < Struct.new( :edge_deployment_plan_arn, :edge_deployment_plan_name, :model_configs, :device_fleet_name, :edge_deployment_success, :edge_deployment_pending, :edge_deployment_failed, :stages, :next_token, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#edge_deployment_plan_arn ⇒ String
The ARN of edge deployment plan.
18650 18651 18652 18653 18654 18655 18656 18657 18658 18659 18660 18661 18662 18663 18664 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18650 class DescribeEdgeDeploymentPlanResponse < Struct.new( :edge_deployment_plan_arn, :edge_deployment_plan_name, :model_configs, :device_fleet_name, :edge_deployment_success, :edge_deployment_pending, :edge_deployment_failed, :stages, :next_token, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#edge_deployment_plan_name ⇒ String
The name of the edge deployment plan.
18650 18651 18652 18653 18654 18655 18656 18657 18658 18659 18660 18661 18662 18663 18664 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18650 class DescribeEdgeDeploymentPlanResponse < Struct.new( :edge_deployment_plan_arn, :edge_deployment_plan_name, :model_configs, :device_fleet_name, :edge_deployment_success, :edge_deployment_pending, :edge_deployment_failed, :stages, :next_token, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#edge_deployment_success ⇒ Integer
The number of edge devices with the successful deployment.
18650 18651 18652 18653 18654 18655 18656 18657 18658 18659 18660 18661 18662 18663 18664 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18650 class DescribeEdgeDeploymentPlanResponse < Struct.new( :edge_deployment_plan_arn, :edge_deployment_plan_name, :model_configs, :device_fleet_name, :edge_deployment_success, :edge_deployment_pending, :edge_deployment_failed, :stages, :next_token, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The time when the edge deployment plan was last updated.
18650 18651 18652 18653 18654 18655 18656 18657 18658 18659 18660 18661 18662 18663 18664 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18650 class DescribeEdgeDeploymentPlanResponse < Struct.new( :edge_deployment_plan_arn, :edge_deployment_plan_name, :model_configs, :device_fleet_name, :edge_deployment_success, :edge_deployment_pending, :edge_deployment_failed, :stages, :next_token, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#model_configs ⇒ Array<Types::EdgeDeploymentModelConfig>
List of models associated with the edge deployment plan.
18650 18651 18652 18653 18654 18655 18656 18657 18658 18659 18660 18661 18662 18663 18664 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18650 class DescribeEdgeDeploymentPlanResponse < Struct.new( :edge_deployment_plan_arn, :edge_deployment_plan_name, :model_configs, :device_fleet_name, :edge_deployment_success, :edge_deployment_pending, :edge_deployment_failed, :stages, :next_token, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Token to use when calling the next set of stages in the edge deployment plan.
18650 18651 18652 18653 18654 18655 18656 18657 18658 18659 18660 18661 18662 18663 18664 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18650 class DescribeEdgeDeploymentPlanResponse < Struct.new( :edge_deployment_plan_arn, :edge_deployment_plan_name, :model_configs, :device_fleet_name, :edge_deployment_success, :edge_deployment_pending, :edge_deployment_failed, :stages, :next_token, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#stages ⇒ Array<Types::DeploymentStageStatusSummary>
List of stages in the edge deployment plan.
18650 18651 18652 18653 18654 18655 18656 18657 18658 18659 18660 18661 18662 18663 18664 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18650 class DescribeEdgeDeploymentPlanResponse < Struct.new( :edge_deployment_plan_arn, :edge_deployment_plan_name, :model_configs, :device_fleet_name, :edge_deployment_success, :edge_deployment_pending, :edge_deployment_failed, :stages, :next_token, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |