Class: Aws::SageMaker::Types::DescribeEdgePackagingJobResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeEdgePackagingJobResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compilation_job_name ⇒ String
The name of the SageMaker Neo compilation job that is used to locate model artifacts that are being packaged.
-
#creation_time ⇒ Time
The timestamp of when the packaging job was created.
-
#edge_packaging_job_arn ⇒ String
The Amazon Resource Name (ARN) of the edge packaging job.
-
#edge_packaging_job_name ⇒ String
The name of the edge packaging job.
-
#edge_packaging_job_status ⇒ String
The current status of the packaging job.
-
#edge_packaging_job_status_message ⇒ String
Returns a message describing the job status and error messages.
-
#last_modified_time ⇒ Time
The timestamp of when the job was last updated.
-
#model_artifact ⇒ String
The Amazon Simple Storage (S3) URI where model artifacts ares stored.
-
#model_name ⇒ String
The name of the model.
-
#model_signature ⇒ String
The signature document of files in the model artifact.
-
#model_version ⇒ String
The version of the model.
-
#output_config ⇒ Types::EdgeOutputConfig
The output configuration for the edge packaging job.
-
#preset_deployment_output ⇒ Types::EdgePresetDeploymentOutput
The output of a SageMaker Edge Manager deployable resource.
-
#resource_key ⇒ String
The Amazon Web Services KMS key to use when encrypting the EBS volume the job run on.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that enables Amazon SageMaker to download and upload the model, and to contact Neo.
Instance Attribute Details
#compilation_job_name ⇒ String
The name of the SageMaker Neo compilation job that is used to locate model artifacts that are being packaged.
19008 19009 19010 19011 19012 19013 19014 19015 19016 19017 19018 19019 19020 19021 19022 19023 19024 19025 19026 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19008 class DescribeEdgePackagingJobResponse < Struct.new( :edge_packaging_job_arn, :edge_packaging_job_name, :compilation_job_name, :model_name, :model_version, :role_arn, :output_config, :resource_key, :edge_packaging_job_status, :edge_packaging_job_status_message, :creation_time, :last_modified_time, :model_artifact, :model_signature, :preset_deployment_output) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The timestamp of when the packaging job was created.
19008 19009 19010 19011 19012 19013 19014 19015 19016 19017 19018 19019 19020 19021 19022 19023 19024 19025 19026 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19008 class DescribeEdgePackagingJobResponse < Struct.new( :edge_packaging_job_arn, :edge_packaging_job_name, :compilation_job_name, :model_name, :model_version, :role_arn, :output_config, :resource_key, :edge_packaging_job_status, :edge_packaging_job_status_message, :creation_time, :last_modified_time, :model_artifact, :model_signature, :preset_deployment_output) SENSITIVE = [] include Aws::Structure end |
#edge_packaging_job_arn ⇒ String
The Amazon Resource Name (ARN) of the edge packaging job.
19008 19009 19010 19011 19012 19013 19014 19015 19016 19017 19018 19019 19020 19021 19022 19023 19024 19025 19026 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19008 class DescribeEdgePackagingJobResponse < Struct.new( :edge_packaging_job_arn, :edge_packaging_job_name, :compilation_job_name, :model_name, :model_version, :role_arn, :output_config, :resource_key, :edge_packaging_job_status, :edge_packaging_job_status_message, :creation_time, :last_modified_time, :model_artifact, :model_signature, :preset_deployment_output) SENSITIVE = [] include Aws::Structure end |
#edge_packaging_job_name ⇒ String
The name of the edge packaging job.
19008 19009 19010 19011 19012 19013 19014 19015 19016 19017 19018 19019 19020 19021 19022 19023 19024 19025 19026 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19008 class DescribeEdgePackagingJobResponse < Struct.new( :edge_packaging_job_arn, :edge_packaging_job_name, :compilation_job_name, :model_name, :model_version, :role_arn, :output_config, :resource_key, :edge_packaging_job_status, :edge_packaging_job_status_message, :creation_time, :last_modified_time, :model_artifact, :model_signature, :preset_deployment_output) SENSITIVE = [] include Aws::Structure end |
#edge_packaging_job_status ⇒ String
The current status of the packaging job.
19008 19009 19010 19011 19012 19013 19014 19015 19016 19017 19018 19019 19020 19021 19022 19023 19024 19025 19026 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19008 class DescribeEdgePackagingJobResponse < Struct.new( :edge_packaging_job_arn, :edge_packaging_job_name, :compilation_job_name, :model_name, :model_version, :role_arn, :output_config, :resource_key, :edge_packaging_job_status, :edge_packaging_job_status_message, :creation_time, :last_modified_time, :model_artifact, :model_signature, :preset_deployment_output) SENSITIVE = [] include Aws::Structure end |
#edge_packaging_job_status_message ⇒ String
Returns a message describing the job status and error messages.
19008 19009 19010 19011 19012 19013 19014 19015 19016 19017 19018 19019 19020 19021 19022 19023 19024 19025 19026 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19008 class DescribeEdgePackagingJobResponse < Struct.new( :edge_packaging_job_arn, :edge_packaging_job_name, :compilation_job_name, :model_name, :model_version, :role_arn, :output_config, :resource_key, :edge_packaging_job_status, :edge_packaging_job_status_message, :creation_time, :last_modified_time, :model_artifact, :model_signature, :preset_deployment_output) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp of when the job was last updated.
19008 19009 19010 19011 19012 19013 19014 19015 19016 19017 19018 19019 19020 19021 19022 19023 19024 19025 19026 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19008 class DescribeEdgePackagingJobResponse < Struct.new( :edge_packaging_job_arn, :edge_packaging_job_name, :compilation_job_name, :model_name, :model_version, :role_arn, :output_config, :resource_key, :edge_packaging_job_status, :edge_packaging_job_status_message, :creation_time, :last_modified_time, :model_artifact, :model_signature, :preset_deployment_output) SENSITIVE = [] include Aws::Structure end |
#model_artifact ⇒ String
The Amazon Simple Storage (S3) URI where model artifacts ares stored.
19008 19009 19010 19011 19012 19013 19014 19015 19016 19017 19018 19019 19020 19021 19022 19023 19024 19025 19026 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19008 class DescribeEdgePackagingJobResponse < Struct.new( :edge_packaging_job_arn, :edge_packaging_job_name, :compilation_job_name, :model_name, :model_version, :role_arn, :output_config, :resource_key, :edge_packaging_job_status, :edge_packaging_job_status_message, :creation_time, :last_modified_time, :model_artifact, :model_signature, :preset_deployment_output) SENSITIVE = [] include Aws::Structure end |
#model_name ⇒ String
The name of the model.
19008 19009 19010 19011 19012 19013 19014 19015 19016 19017 19018 19019 19020 19021 19022 19023 19024 19025 19026 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19008 class DescribeEdgePackagingJobResponse < Struct.new( :edge_packaging_job_arn, :edge_packaging_job_name, :compilation_job_name, :model_name, :model_version, :role_arn, :output_config, :resource_key, :edge_packaging_job_status, :edge_packaging_job_status_message, :creation_time, :last_modified_time, :model_artifact, :model_signature, :preset_deployment_output) SENSITIVE = [] include Aws::Structure end |
#model_signature ⇒ String
The signature document of files in the model artifact.
19008 19009 19010 19011 19012 19013 19014 19015 19016 19017 19018 19019 19020 19021 19022 19023 19024 19025 19026 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19008 class DescribeEdgePackagingJobResponse < Struct.new( :edge_packaging_job_arn, :edge_packaging_job_name, :compilation_job_name, :model_name, :model_version, :role_arn, :output_config, :resource_key, :edge_packaging_job_status, :edge_packaging_job_status_message, :creation_time, :last_modified_time, :model_artifact, :model_signature, :preset_deployment_output) SENSITIVE = [] include Aws::Structure end |
#model_version ⇒ String
The version of the model.
19008 19009 19010 19011 19012 19013 19014 19015 19016 19017 19018 19019 19020 19021 19022 19023 19024 19025 19026 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19008 class DescribeEdgePackagingJobResponse < Struct.new( :edge_packaging_job_arn, :edge_packaging_job_name, :compilation_job_name, :model_name, :model_version, :role_arn, :output_config, :resource_key, :edge_packaging_job_status, :edge_packaging_job_status_message, :creation_time, :last_modified_time, :model_artifact, :model_signature, :preset_deployment_output) SENSITIVE = [] include Aws::Structure end |
#output_config ⇒ Types::EdgeOutputConfig
The output configuration for the edge packaging job.
19008 19009 19010 19011 19012 19013 19014 19015 19016 19017 19018 19019 19020 19021 19022 19023 19024 19025 19026 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19008 class DescribeEdgePackagingJobResponse < Struct.new( :edge_packaging_job_arn, :edge_packaging_job_name, :compilation_job_name, :model_name, :model_version, :role_arn, :output_config, :resource_key, :edge_packaging_job_status, :edge_packaging_job_status_message, :creation_time, :last_modified_time, :model_artifact, :model_signature, :preset_deployment_output) SENSITIVE = [] include Aws::Structure end |
#preset_deployment_output ⇒ Types::EdgePresetDeploymentOutput
The output of a SageMaker Edge Manager deployable resource.
19008 19009 19010 19011 19012 19013 19014 19015 19016 19017 19018 19019 19020 19021 19022 19023 19024 19025 19026 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19008 class DescribeEdgePackagingJobResponse < Struct.new( :edge_packaging_job_arn, :edge_packaging_job_name, :compilation_job_name, :model_name, :model_version, :role_arn, :output_config, :resource_key, :edge_packaging_job_status, :edge_packaging_job_status_message, :creation_time, :last_modified_time, :model_artifact, :model_signature, :preset_deployment_output) SENSITIVE = [] include Aws::Structure end |
#resource_key ⇒ String
The Amazon Web Services KMS key to use when encrypting the EBS volume the job run on.
19008 19009 19010 19011 19012 19013 19014 19015 19016 19017 19018 19019 19020 19021 19022 19023 19024 19025 19026 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19008 class DescribeEdgePackagingJobResponse < Struct.new( :edge_packaging_job_arn, :edge_packaging_job_name, :compilation_job_name, :model_name, :model_version, :role_arn, :output_config, :resource_key, :edge_packaging_job_status, :edge_packaging_job_status_message, :creation_time, :last_modified_time, :model_artifact, :model_signature, :preset_deployment_output) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that enables Amazon SageMaker to download and upload the model, and to contact Neo.
19008 19009 19010 19011 19012 19013 19014 19015 19016 19017 19018 19019 19020 19021 19022 19023 19024 19025 19026 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19008 class DescribeEdgePackagingJobResponse < Struct.new( :edge_packaging_job_arn, :edge_packaging_job_name, :compilation_job_name, :model_name, :model_version, :role_arn, :output_config, :resource_key, :edge_packaging_job_status, :edge_packaging_job_status_message, :creation_time, :last_modified_time, :model_artifact, :model_signature, :preset_deployment_output) SENSITIVE = [] include Aws::Structure end |