Class: Aws::SageMaker::Types::DescribeEndpointConfigOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeEndpointConfigOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#async_inference_config ⇒ Types::AsyncInferenceConfig
Returns the description of an endpoint configuration created using the [
CreateEndpointConfig][1] API. -
#creation_time ⇒ Time
A timestamp that shows when the endpoint configuration was created.
-
#data_capture_config ⇒ Types::DataCaptureConfig
Configuration to control how SageMaker AI captures inference data.
-
#enable_network_isolation ⇒ Boolean
Indicates whether all model containers deployed to the endpoint are isolated.
-
#endpoint_config_arn ⇒ String
The Amazon Resource Name (ARN) of the endpoint configuration.
-
#endpoint_config_name ⇒ String
Name of the SageMaker endpoint configuration.
-
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that you assigned to the endpoint configuration.
-
#explainer_config ⇒ Types::ExplainerConfig
The configuration parameters for an explainer.
-
#kms_key_id ⇒ String
Amazon Web Services KMS key ID Amazon SageMaker uses to encrypt data when storing it on the ML storage volume attached to the instance.
-
#metrics_config ⇒ Types::MetricsConfig
The configuration parameters for utilization metrics.
-
#production_variants ⇒ Array<Types::ProductionVariant>
An array of
ProductionVariantobjects, one for each model that you want to host at this endpoint. -
#shadow_production_variants ⇒ Array<Types::ProductionVariant>
An array of
ProductionVariantobjects, one for each model that you want to host at this endpoint in shadow mode with production traffic replicated from the model specified onProductionVariants. -
#vpc_config ⇒ Types::VpcConfig
Specifies an Amazon Virtual Private Cloud (VPC) that your SageMaker jobs, hosted models, and compute resources have access to.
Instance Attribute Details
#async_inference_config ⇒ Types::AsyncInferenceConfig
Returns the description of an endpoint configuration created using
the CreateEndpointConfig API.
19479 19480 19481 19482 19483 19484 19485 19486 19487 19488 19489 19490 19491 19492 19493 19494 19495 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19479 class DescribeEndpointConfigOutput < Struct.new( :endpoint_config_name, :endpoint_config_arn, :production_variants, :data_capture_config, :kms_key_id, :creation_time, :async_inference_config, :explainer_config, :shadow_production_variants, :execution_role_arn, :vpc_config, :enable_network_isolation, :metrics_config) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
A timestamp that shows when the endpoint configuration was created.
19479 19480 19481 19482 19483 19484 19485 19486 19487 19488 19489 19490 19491 19492 19493 19494 19495 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19479 class DescribeEndpointConfigOutput < Struct.new( :endpoint_config_name, :endpoint_config_arn, :production_variants, :data_capture_config, :kms_key_id, :creation_time, :async_inference_config, :explainer_config, :shadow_production_variants, :execution_role_arn, :vpc_config, :enable_network_isolation, :metrics_config) SENSITIVE = [] include Aws::Structure end |
#data_capture_config ⇒ Types::DataCaptureConfig
Configuration to control how SageMaker AI captures inference data.
19479 19480 19481 19482 19483 19484 19485 19486 19487 19488 19489 19490 19491 19492 19493 19494 19495 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19479 class DescribeEndpointConfigOutput < Struct.new( :endpoint_config_name, :endpoint_config_arn, :production_variants, :data_capture_config, :kms_key_id, :creation_time, :async_inference_config, :explainer_config, :shadow_production_variants, :execution_role_arn, :vpc_config, :enable_network_isolation, :metrics_config) SENSITIVE = [] include Aws::Structure end |
#enable_network_isolation ⇒ Boolean
Indicates whether all model containers deployed to the endpoint are isolated. If they are, no inbound or outbound network calls can be made to or from the model containers.
19479 19480 19481 19482 19483 19484 19485 19486 19487 19488 19489 19490 19491 19492 19493 19494 19495 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19479 class DescribeEndpointConfigOutput < Struct.new( :endpoint_config_name, :endpoint_config_arn, :production_variants, :data_capture_config, :kms_key_id, :creation_time, :async_inference_config, :explainer_config, :shadow_production_variants, :execution_role_arn, :vpc_config, :enable_network_isolation, :metrics_config) SENSITIVE = [] include Aws::Structure end |
#endpoint_config_arn ⇒ String
The Amazon Resource Name (ARN) of the endpoint configuration.
19479 19480 19481 19482 19483 19484 19485 19486 19487 19488 19489 19490 19491 19492 19493 19494 19495 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19479 class DescribeEndpointConfigOutput < Struct.new( :endpoint_config_name, :endpoint_config_arn, :production_variants, :data_capture_config, :kms_key_id, :creation_time, :async_inference_config, :explainer_config, :shadow_production_variants, :execution_role_arn, :vpc_config, :enable_network_isolation, :metrics_config) SENSITIVE = [] include Aws::Structure end |
#endpoint_config_name ⇒ String
Name of the SageMaker endpoint configuration.
19479 19480 19481 19482 19483 19484 19485 19486 19487 19488 19489 19490 19491 19492 19493 19494 19495 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19479 class DescribeEndpointConfigOutput < Struct.new( :endpoint_config_name, :endpoint_config_arn, :production_variants, :data_capture_config, :kms_key_id, :creation_time, :async_inference_config, :explainer_config, :shadow_production_variants, :execution_role_arn, :vpc_config, :enable_network_isolation, :metrics_config) SENSITIVE = [] include Aws::Structure end |
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that you assigned to the endpoint configuration.
19479 19480 19481 19482 19483 19484 19485 19486 19487 19488 19489 19490 19491 19492 19493 19494 19495 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19479 class DescribeEndpointConfigOutput < Struct.new( :endpoint_config_name, :endpoint_config_arn, :production_variants, :data_capture_config, :kms_key_id, :creation_time, :async_inference_config, :explainer_config, :shadow_production_variants, :execution_role_arn, :vpc_config, :enable_network_isolation, :metrics_config) SENSITIVE = [] include Aws::Structure end |
#explainer_config ⇒ Types::ExplainerConfig
The configuration parameters for an explainer.
19479 19480 19481 19482 19483 19484 19485 19486 19487 19488 19489 19490 19491 19492 19493 19494 19495 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19479 class DescribeEndpointConfigOutput < Struct.new( :endpoint_config_name, :endpoint_config_arn, :production_variants, :data_capture_config, :kms_key_id, :creation_time, :async_inference_config, :explainer_config, :shadow_production_variants, :execution_role_arn, :vpc_config, :enable_network_isolation, :metrics_config) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
Amazon Web Services KMS key ID Amazon SageMaker uses to encrypt data when storing it on the ML storage volume attached to the instance.
19479 19480 19481 19482 19483 19484 19485 19486 19487 19488 19489 19490 19491 19492 19493 19494 19495 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19479 class DescribeEndpointConfigOutput < Struct.new( :endpoint_config_name, :endpoint_config_arn, :production_variants, :data_capture_config, :kms_key_id, :creation_time, :async_inference_config, :explainer_config, :shadow_production_variants, :execution_role_arn, :vpc_config, :enable_network_isolation, :metrics_config) SENSITIVE = [] include Aws::Structure end |
#metrics_config ⇒ Types::MetricsConfig
The configuration parameters for utilization metrics.
19479 19480 19481 19482 19483 19484 19485 19486 19487 19488 19489 19490 19491 19492 19493 19494 19495 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19479 class DescribeEndpointConfigOutput < Struct.new( :endpoint_config_name, :endpoint_config_arn, :production_variants, :data_capture_config, :kms_key_id, :creation_time, :async_inference_config, :explainer_config, :shadow_production_variants, :execution_role_arn, :vpc_config, :enable_network_isolation, :metrics_config) SENSITIVE = [] include Aws::Structure end |
#production_variants ⇒ Array<Types::ProductionVariant>
An array of ProductionVariant objects, one for each model that you
want to host at this endpoint.
19479 19480 19481 19482 19483 19484 19485 19486 19487 19488 19489 19490 19491 19492 19493 19494 19495 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19479 class DescribeEndpointConfigOutput < Struct.new( :endpoint_config_name, :endpoint_config_arn, :production_variants, :data_capture_config, :kms_key_id, :creation_time, :async_inference_config, :explainer_config, :shadow_production_variants, :execution_role_arn, :vpc_config, :enable_network_isolation, :metrics_config) SENSITIVE = [] include Aws::Structure end |
#shadow_production_variants ⇒ Array<Types::ProductionVariant>
An array of ProductionVariant objects, one for each model that you
want to host at this endpoint in shadow mode with production traffic
replicated from the model specified on ProductionVariants.
19479 19480 19481 19482 19483 19484 19485 19486 19487 19488 19489 19490 19491 19492 19493 19494 19495 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19479 class DescribeEndpointConfigOutput < Struct.new( :endpoint_config_name, :endpoint_config_arn, :production_variants, :data_capture_config, :kms_key_id, :creation_time, :async_inference_config, :explainer_config, :shadow_production_variants, :execution_role_arn, :vpc_config, :enable_network_isolation, :metrics_config) SENSITIVE = [] include Aws::Structure end |
#vpc_config ⇒ Types::VpcConfig
Specifies an Amazon Virtual Private Cloud (VPC) that your SageMaker jobs, hosted models, and compute resources have access to. You can control access to and from your resources by configuring a VPC. For more information, see Give SageMaker Access to Resources in your Amazon VPC.
19479 19480 19481 19482 19483 19484 19485 19486 19487 19488 19489 19490 19491 19492 19493 19494 19495 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19479 class DescribeEndpointConfigOutput < Struct.new( :endpoint_config_name, :endpoint_config_arn, :production_variants, :data_capture_config, :kms_key_id, :creation_time, :async_inference_config, :explainer_config, :shadow_production_variants, :execution_role_arn, :vpc_config, :enable_network_isolation, :metrics_config) SENSITIVE = [] include Aws::Structure end |