Class: Aws::SageMaker::Types::DescribeEndpointOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#async_inference_configTypes::AsyncInferenceConfig

Returns the description of an endpoint configuration created using the [ ‘CreateEndpointConfig` ][1] API.

[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateEndpointConfig.html



18985
18986
18987
18988
18989
18990
18991
18992
18993
18994
18995
18996
18997
18998
18999
19000
19001
19002
19003
# File 'lib/aws-sdk-sagemaker/types.rb', line 18985

class DescribeEndpointOutput < Struct.new(
  :endpoint_name,
  :endpoint_arn,
  :endpoint_config_name,
  :production_variants,
  :data_capture_config,
  :endpoint_status,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :last_deployment_config,
  :async_inference_config,
  :pending_deployment_summary,
  :explainer_config,
  :shadow_production_variants,
  :metrics_config)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

A timestamp that shows when the endpoint was created.

Returns:

  • (Time)


18985
18986
18987
18988
18989
18990
18991
18992
18993
18994
18995
18996
18997
18998
18999
19000
19001
19002
19003
# File 'lib/aws-sdk-sagemaker/types.rb', line 18985

class DescribeEndpointOutput < Struct.new(
  :endpoint_name,
  :endpoint_arn,
  :endpoint_config_name,
  :production_variants,
  :data_capture_config,
  :endpoint_status,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :last_deployment_config,
  :async_inference_config,
  :pending_deployment_summary,
  :explainer_config,
  :shadow_production_variants,
  :metrics_config)
  SENSITIVE = []
  include Aws::Structure
end

#data_capture_configTypes::DataCaptureConfigSummary

The currently active data capture configuration used by your Endpoint.



18985
18986
18987
18988
18989
18990
18991
18992
18993
18994
18995
18996
18997
18998
18999
19000
19001
19002
19003
# File 'lib/aws-sdk-sagemaker/types.rb', line 18985

class DescribeEndpointOutput < Struct.new(
  :endpoint_name,
  :endpoint_arn,
  :endpoint_config_name,
  :production_variants,
  :data_capture_config,
  :endpoint_status,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :last_deployment_config,
  :async_inference_config,
  :pending_deployment_summary,
  :explainer_config,
  :shadow_production_variants,
  :metrics_config)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_arnString

The Amazon Resource Name (ARN) of the endpoint.

Returns:

  • (String)


18985
18986
18987
18988
18989
18990
18991
18992
18993
18994
18995
18996
18997
18998
18999
19000
19001
19002
19003
# File 'lib/aws-sdk-sagemaker/types.rb', line 18985

class DescribeEndpointOutput < Struct.new(
  :endpoint_name,
  :endpoint_arn,
  :endpoint_config_name,
  :production_variants,
  :data_capture_config,
  :endpoint_status,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :last_deployment_config,
  :async_inference_config,
  :pending_deployment_summary,
  :explainer_config,
  :shadow_production_variants,
  :metrics_config)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_config_nameString

The name of the endpoint configuration associated with this endpoint.

Returns:

  • (String)


18985
18986
18987
18988
18989
18990
18991
18992
18993
18994
18995
18996
18997
18998
18999
19000
19001
19002
19003
# File 'lib/aws-sdk-sagemaker/types.rb', line 18985

class DescribeEndpointOutput < Struct.new(
  :endpoint_name,
  :endpoint_arn,
  :endpoint_config_name,
  :production_variants,
  :data_capture_config,
  :endpoint_status,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :last_deployment_config,
  :async_inference_config,
  :pending_deployment_summary,
  :explainer_config,
  :shadow_production_variants,
  :metrics_config)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_nameString

Name of the endpoint.

Returns:

  • (String)


18985
18986
18987
18988
18989
18990
18991
18992
18993
18994
18995
18996
18997
18998
18999
19000
19001
19002
19003
# File 'lib/aws-sdk-sagemaker/types.rb', line 18985

class DescribeEndpointOutput < Struct.new(
  :endpoint_name,
  :endpoint_arn,
  :endpoint_config_name,
  :production_variants,
  :data_capture_config,
  :endpoint_status,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :last_deployment_config,
  :async_inference_config,
  :pending_deployment_summary,
  :explainer_config,
  :shadow_production_variants,
  :metrics_config)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_statusString

The status of the endpoint.

  • ‘OutOfService`: Endpoint is not available to take incoming requests.

  • ‘Creating`: [CreateEndpoint] is executing.

  • ‘Updating`: [UpdateEndpoint] or

    UpdateEndpointWeightsAndCapacities][3

    is executing.

  • ‘SystemUpdating`: Endpoint is undergoing maintenance and cannot be updated or deleted or re-scaled until it has completed. This maintenance operation does not change any customer-specified values such as VPC config, KMS encryption, model, instance type, or instance count.

  • ‘RollingBack`: Endpoint fails to scale up or down or change its variant weight and is in the process of rolling back to its previous configuration. Once the rollback completes, endpoint returns to an `InService` status. This transitional status only applies to an endpoint that has autoscaling enabled and is undergoing variant weight or capacity changes as part of an

    UpdateEndpointWeightsAndCapacities][3

    call or when the

    UpdateEndpointWeightsAndCapacities][3

    operation is called

    explicitly.

  • ‘InService`: Endpoint is available to process incoming requests.

  • ‘Deleting`: [DeleteEndpoint] is executing.

  • ‘Failed`: Endpoint could not be created, updated, or re-scaled. Use the `FailureReason` value returned by [DescribeEndpoint] for information about the failure. [DeleteEndpoint] is the only operation that can be performed on a failed endpoint.

  • ‘UpdateRollbackFailed`: Both the rolling deployment and auto-rollback failed. Your endpoint is in service with a mix of the old and new endpoint configurations. For information about how to remedy this issue and restore the endpoint’s status to ‘InService`, see [Rolling Deployments].

[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateEndpoint.html [2]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_UpdateEndpoint.html [3]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_UpdateEndpointWeightsAndCapacities.html [4]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteEndpoint.html [5]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeEndpoint.html [6]: docs.aws.amazon.com/sagemaker/latest/dg/deployment-guardrails-rolling.html

Returns:

  • (String)


18985
18986
18987
18988
18989
18990
18991
18992
18993
18994
18995
18996
18997
18998
18999
19000
19001
19002
19003
# File 'lib/aws-sdk-sagemaker/types.rb', line 18985

class DescribeEndpointOutput < Struct.new(
  :endpoint_name,
  :endpoint_arn,
  :endpoint_config_name,
  :production_variants,
  :data_capture_config,
  :endpoint_status,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :last_deployment_config,
  :async_inference_config,
  :pending_deployment_summary,
  :explainer_config,
  :shadow_production_variants,
  :metrics_config)
  SENSITIVE = []
  include Aws::Structure
end

#explainer_configTypes::ExplainerConfig

The configuration parameters for an explainer.



18985
18986
18987
18988
18989
18990
18991
18992
18993
18994
18995
18996
18997
18998
18999
19000
19001
19002
19003
# File 'lib/aws-sdk-sagemaker/types.rb', line 18985

class DescribeEndpointOutput < Struct.new(
  :endpoint_name,
  :endpoint_arn,
  :endpoint_config_name,
  :production_variants,
  :data_capture_config,
  :endpoint_status,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :last_deployment_config,
  :async_inference_config,
  :pending_deployment_summary,
  :explainer_config,
  :shadow_production_variants,
  :metrics_config)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

If the status of the endpoint is ‘Failed`, the reason why it failed.

Returns:

  • (String)


18985
18986
18987
18988
18989
18990
18991
18992
18993
18994
18995
18996
18997
18998
18999
19000
19001
19002
19003
# File 'lib/aws-sdk-sagemaker/types.rb', line 18985

class DescribeEndpointOutput < Struct.new(
  :endpoint_name,
  :endpoint_arn,
  :endpoint_config_name,
  :production_variants,
  :data_capture_config,
  :endpoint_status,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :last_deployment_config,
  :async_inference_config,
  :pending_deployment_summary,
  :explainer_config,
  :shadow_production_variants,
  :metrics_config)
  SENSITIVE = []
  include Aws::Structure
end

#last_deployment_configTypes::DeploymentConfig

The most recent deployment configuration for the endpoint.



18985
18986
18987
18988
18989
18990
18991
18992
18993
18994
18995
18996
18997
18998
18999
19000
19001
19002
19003
# File 'lib/aws-sdk-sagemaker/types.rb', line 18985

class DescribeEndpointOutput < Struct.new(
  :endpoint_name,
  :endpoint_arn,
  :endpoint_config_name,
  :production_variants,
  :data_capture_config,
  :endpoint_status,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :last_deployment_config,
  :async_inference_config,
  :pending_deployment_summary,
  :explainer_config,
  :shadow_production_variants,
  :metrics_config)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

A timestamp that shows when the endpoint was last modified.

Returns:

  • (Time)


18985
18986
18987
18988
18989
18990
18991
18992
18993
18994
18995
18996
18997
18998
18999
19000
19001
19002
19003
# File 'lib/aws-sdk-sagemaker/types.rb', line 18985

class DescribeEndpointOutput < Struct.new(
  :endpoint_name,
  :endpoint_arn,
  :endpoint_config_name,
  :production_variants,
  :data_capture_config,
  :endpoint_status,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :last_deployment_config,
  :async_inference_config,
  :pending_deployment_summary,
  :explainer_config,
  :shadow_production_variants,
  :metrics_config)
  SENSITIVE = []
  include Aws::Structure
end

#metrics_configTypes::MetricsConfig

The configuration parameters for utilization metrics.



18985
18986
18987
18988
18989
18990
18991
18992
18993
18994
18995
18996
18997
18998
18999
19000
19001
19002
19003
# File 'lib/aws-sdk-sagemaker/types.rb', line 18985

class DescribeEndpointOutput < Struct.new(
  :endpoint_name,
  :endpoint_arn,
  :endpoint_config_name,
  :production_variants,
  :data_capture_config,
  :endpoint_status,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :last_deployment_config,
  :async_inference_config,
  :pending_deployment_summary,
  :explainer_config,
  :shadow_production_variants,
  :metrics_config)
  SENSITIVE = []
  include Aws::Structure
end

#pending_deployment_summaryTypes::PendingDeploymentSummary

Returns the summary of an in-progress deployment. This field is only returned when the endpoint is creating or updating with a new endpoint configuration.



18985
18986
18987
18988
18989
18990
18991
18992
18993
18994
18995
18996
18997
18998
18999
19000
19001
19002
19003
# File 'lib/aws-sdk-sagemaker/types.rb', line 18985

class DescribeEndpointOutput < Struct.new(
  :endpoint_name,
  :endpoint_arn,
  :endpoint_config_name,
  :production_variants,
  :data_capture_config,
  :endpoint_status,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :last_deployment_config,
  :async_inference_config,
  :pending_deployment_summary,
  :explainer_config,
  :shadow_production_variants,
  :metrics_config)
  SENSITIVE = []
  include Aws::Structure
end

#production_variantsArray<Types::ProductionVariantSummary>

An array of [ProductionVariantSummary] objects, one for each model hosted behind this endpoint.

[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_ProductionVariantSummary.html



18985
18986
18987
18988
18989
18990
18991
18992
18993
18994
18995
18996
18997
18998
18999
19000
19001
19002
19003
# File 'lib/aws-sdk-sagemaker/types.rb', line 18985

class DescribeEndpointOutput < Struct.new(
  :endpoint_name,
  :endpoint_arn,
  :endpoint_config_name,
  :production_variants,
  :data_capture_config,
  :endpoint_status,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :last_deployment_config,
  :async_inference_config,
  :pending_deployment_summary,
  :explainer_config,
  :shadow_production_variants,
  :metrics_config)
  SENSITIVE = []
  include Aws::Structure
end

#shadow_production_variantsArray<Types::ProductionVariantSummary>

An array of [ProductionVariantSummary] objects, one for each model that you want to host at this endpoint in shadow mode with production traffic replicated from the model specified on ‘ProductionVariants`.

[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_ProductionVariantSummary.html



18985
18986
18987
18988
18989
18990
18991
18992
18993
18994
18995
18996
18997
18998
18999
19000
19001
19002
19003
# File 'lib/aws-sdk-sagemaker/types.rb', line 18985

class DescribeEndpointOutput < Struct.new(
  :endpoint_name,
  :endpoint_arn,
  :endpoint_config_name,
  :production_variants,
  :data_capture_config,
  :endpoint_status,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :last_deployment_config,
  :async_inference_config,
  :pending_deployment_summary,
  :explainer_config,
  :shadow_production_variants,
  :metrics_config)
  SENSITIVE = []
  include Aws::Structure
end