Class: Aws::SageMaker::Types::DescribeFeatureGroupResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timeTime

A timestamp indicating when SageMaker created the FeatureGroup.

Returns:

  • (Time)


11397
11398
11399
11400
11401
11402
11403
11404
11405
11406
11407
11408
11409
11410
11411
11412
11413
11414
11415
11416
11417
# File 'lib/aws-sdk-sagemaker/types.rb', line 11397

class DescribeFeatureGroupResponse < Struct.new(
  :feature_group_arn,
  :feature_group_name,
  :record_identifier_feature_name,
  :event_time_feature_name,
  :feature_definitions,
  :creation_time,
  :last_modified_time,
  :online_store_config,
  :offline_store_config,
  :role_arn,
  :feature_group_status,
  :offline_store_status,
  :last_update_status,
  :failure_reason,
  :description,
  :next_token,
  :online_store_total_size_bytes)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A free form description of the feature group.

Returns:

  • (String)


11397
11398
11399
11400
11401
11402
11403
11404
11405
11406
11407
11408
11409
11410
11411
11412
11413
11414
11415
11416
11417
# File 'lib/aws-sdk-sagemaker/types.rb', line 11397

class DescribeFeatureGroupResponse < Struct.new(
  :feature_group_arn,
  :feature_group_name,
  :record_identifier_feature_name,
  :event_time_feature_name,
  :feature_definitions,
  :creation_time,
  :last_modified_time,
  :online_store_config,
  :offline_store_config,
  :role_arn,
  :feature_group_status,
  :offline_store_status,
  :last_update_status,
  :failure_reason,
  :description,
  :next_token,
  :online_store_total_size_bytes)
  SENSITIVE = []
  include Aws::Structure
end

#event_time_feature_nameString

The name of the feature that stores the EventTime of a Record in a FeatureGroup.

An EventTime is a point in time when a new event occurs that corresponds to the creation or update of a Record in a FeatureGroup. All Records in the FeatureGroup have a corresponding EventTime.

Returns:

  • (String)


11397
11398
11399
11400
11401
11402
11403
11404
11405
11406
11407
11408
11409
11410
11411
11412
11413
11414
11415
11416
11417
# File 'lib/aws-sdk-sagemaker/types.rb', line 11397

class DescribeFeatureGroupResponse < Struct.new(
  :feature_group_arn,
  :feature_group_name,
  :record_identifier_feature_name,
  :event_time_feature_name,
  :feature_definitions,
  :creation_time,
  :last_modified_time,
  :online_store_config,
  :offline_store_config,
  :role_arn,
  :feature_group_status,
  :offline_store_status,
  :last_update_status,
  :failure_reason,
  :description,
  :next_token,
  :online_store_total_size_bytes)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

The reason that the FeatureGroup failed to be replicated in the OfflineStore. This is failure can occur because:

  • The FeatureGroup could not be created in the OfflineStore.

  • The FeatureGroup could not be deleted from the OfflineStore.

Returns:

  • (String)


11397
11398
11399
11400
11401
11402
11403
11404
11405
11406
11407
11408
11409
11410
11411
11412
11413
11414
11415
11416
11417
# File 'lib/aws-sdk-sagemaker/types.rb', line 11397

class DescribeFeatureGroupResponse < Struct.new(
  :feature_group_arn,
  :feature_group_name,
  :record_identifier_feature_name,
  :event_time_feature_name,
  :feature_definitions,
  :creation_time,
  :last_modified_time,
  :online_store_config,
  :offline_store_config,
  :role_arn,
  :feature_group_status,
  :offline_store_status,
  :last_update_status,
  :failure_reason,
  :description,
  :next_token,
  :online_store_total_size_bytes)
  SENSITIVE = []
  include Aws::Structure
end

#feature_definitionsArray<Types::FeatureDefinition>

A list of the Features in the FeatureGroup. Each feature is defined by a FeatureName and FeatureType.

Returns:



11397
11398
11399
11400
11401
11402
11403
11404
11405
11406
11407
11408
11409
11410
11411
11412
11413
11414
11415
11416
11417
# File 'lib/aws-sdk-sagemaker/types.rb', line 11397

class DescribeFeatureGroupResponse < Struct.new(
  :feature_group_arn,
  :feature_group_name,
  :record_identifier_feature_name,
  :event_time_feature_name,
  :feature_definitions,
  :creation_time,
  :last_modified_time,
  :online_store_config,
  :offline_store_config,
  :role_arn,
  :feature_group_status,
  :offline_store_status,
  :last_update_status,
  :failure_reason,
  :description,
  :next_token,
  :online_store_total_size_bytes)
  SENSITIVE = []
  include Aws::Structure
end

#feature_group_arnString

The Amazon Resource Name (ARN) of the FeatureGroup.

Returns:

  • (String)


11397
11398
11399
11400
11401
11402
11403
11404
11405
11406
11407
11408
11409
11410
11411
11412
11413
11414
11415
11416
11417
# File 'lib/aws-sdk-sagemaker/types.rb', line 11397

class DescribeFeatureGroupResponse < Struct.new(
  :feature_group_arn,
  :feature_group_name,
  :record_identifier_feature_name,
  :event_time_feature_name,
  :feature_definitions,
  :creation_time,
  :last_modified_time,
  :online_store_config,
  :offline_store_config,
  :role_arn,
  :feature_group_status,
  :offline_store_status,
  :last_update_status,
  :failure_reason,
  :description,
  :next_token,
  :online_store_total_size_bytes)
  SENSITIVE = []
  include Aws::Structure
end

#feature_group_nameString

he name of the FeatureGroup.

Returns:

  • (String)


11397
11398
11399
11400
11401
11402
11403
11404
11405
11406
11407
11408
11409
11410
11411
11412
11413
11414
11415
11416
11417
# File 'lib/aws-sdk-sagemaker/types.rb', line 11397

class DescribeFeatureGroupResponse < Struct.new(
  :feature_group_arn,
  :feature_group_name,
  :record_identifier_feature_name,
  :event_time_feature_name,
  :feature_definitions,
  :creation_time,
  :last_modified_time,
  :online_store_config,
  :offline_store_config,
  :role_arn,
  :feature_group_status,
  :offline_store_status,
  :last_update_status,
  :failure_reason,
  :description,
  :next_token,
  :online_store_total_size_bytes)
  SENSITIVE = []
  include Aws::Structure
end

#feature_group_statusString

The status of the feature group.

Returns:

  • (String)


11397
11398
11399
11400
11401
11402
11403
11404
11405
11406
11407
11408
11409
11410
11411
11412
11413
11414
11415
11416
11417
# File 'lib/aws-sdk-sagemaker/types.rb', line 11397

class DescribeFeatureGroupResponse < Struct.new(
  :feature_group_arn,
  :feature_group_name,
  :record_identifier_feature_name,
  :event_time_feature_name,
  :feature_definitions,
  :creation_time,
  :last_modified_time,
  :online_store_config,
  :offline_store_config,
  :role_arn,
  :feature_group_status,
  :offline_store_status,
  :last_update_status,
  :failure_reason,
  :description,
  :next_token,
  :online_store_total_size_bytes)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

A timestamp indicating when the feature group was last updated.

Returns:

  • (Time)


11397
11398
11399
11400
11401
11402
11403
11404
11405
11406
11407
11408
11409
11410
11411
11412
11413
11414
11415
11416
11417
# File 'lib/aws-sdk-sagemaker/types.rb', line 11397

class DescribeFeatureGroupResponse < Struct.new(
  :feature_group_arn,
  :feature_group_name,
  :record_identifier_feature_name,
  :event_time_feature_name,
  :feature_definitions,
  :creation_time,
  :last_modified_time,
  :online_store_config,
  :offline_store_config,
  :role_arn,
  :feature_group_status,
  :offline_store_status,
  :last_update_status,
  :failure_reason,
  :description,
  :next_token,
  :online_store_total_size_bytes)
  SENSITIVE = []
  include Aws::Structure
end

#last_update_statusTypes::LastUpdateStatus

A value indicating whether the update made to the feature group was successful.



11397
11398
11399
11400
11401
11402
11403
11404
11405
11406
11407
11408
11409
11410
11411
11412
11413
11414
11415
11416
11417
# File 'lib/aws-sdk-sagemaker/types.rb', line 11397

class DescribeFeatureGroupResponse < Struct.new(
  :feature_group_arn,
  :feature_group_name,
  :record_identifier_feature_name,
  :event_time_feature_name,
  :feature_definitions,
  :creation_time,
  :last_modified_time,
  :online_store_config,
  :offline_store_config,
  :role_arn,
  :feature_group_status,
  :offline_store_status,
  :last_update_status,
  :failure_reason,
  :description,
  :next_token,
  :online_store_total_size_bytes)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token to resume pagination of the list of Features (FeatureDefinitions).

Returns:

  • (String)


11397
11398
11399
11400
11401
11402
11403
11404
11405
11406
11407
11408
11409
11410
11411
11412
11413
11414
11415
11416
11417
# File 'lib/aws-sdk-sagemaker/types.rb', line 11397

class DescribeFeatureGroupResponse < Struct.new(
  :feature_group_arn,
  :feature_group_name,
  :record_identifier_feature_name,
  :event_time_feature_name,
  :feature_definitions,
  :creation_time,
  :last_modified_time,
  :online_store_config,
  :offline_store_config,
  :role_arn,
  :feature_group_status,
  :offline_store_status,
  :last_update_status,
  :failure_reason,
  :description,
  :next_token,
  :online_store_total_size_bytes)
  SENSITIVE = []
  include Aws::Structure
end

#offline_store_configTypes::OfflineStoreConfig

The configuration of the offline store. It includes the following configurations:

  • Amazon S3 location of the offline store.

  • Configuration of the Glue data catalog.

  • Table format of the offline store.

  • Option to disable the automatic creation of a Glue table for the offline store.

  • Encryption configuration.



11397
11398
11399
11400
11401
11402
11403
11404
11405
11406
11407
11408
11409
11410
11411
11412
11413
11414
11415
11416
11417
# File 'lib/aws-sdk-sagemaker/types.rb', line 11397

class DescribeFeatureGroupResponse < Struct.new(
  :feature_group_arn,
  :feature_group_name,
  :record_identifier_feature_name,
  :event_time_feature_name,
  :feature_definitions,
  :creation_time,
  :last_modified_time,
  :online_store_config,
  :offline_store_config,
  :role_arn,
  :feature_group_status,
  :offline_store_status,
  :last_update_status,
  :failure_reason,
  :description,
  :next_token,
  :online_store_total_size_bytes)
  SENSITIVE = []
  include Aws::Structure
end

#offline_store_statusTypes::OfflineStoreStatus

The status of the OfflineStore. Notifies you if replicating data into the OfflineStore has failed. Returns either: Active or Blocked



11397
11398
11399
11400
11401
11402
11403
11404
11405
11406
11407
11408
11409
11410
11411
11412
11413
11414
11415
11416
11417
# File 'lib/aws-sdk-sagemaker/types.rb', line 11397

class DescribeFeatureGroupResponse < Struct.new(
  :feature_group_arn,
  :feature_group_name,
  :record_identifier_feature_name,
  :event_time_feature_name,
  :feature_definitions,
  :creation_time,
  :last_modified_time,
  :online_store_config,
  :offline_store_config,
  :role_arn,
  :feature_group_status,
  :offline_store_status,
  :last_update_status,
  :failure_reason,
  :description,
  :next_token,
  :online_store_total_size_bytes)
  SENSITIVE = []
  include Aws::Structure
end

#online_store_configTypes::OnlineStoreConfig

The configuration for the OnlineStore.



11397
11398
11399
11400
11401
11402
11403
11404
11405
11406
11407
11408
11409
11410
11411
11412
11413
11414
11415
11416
11417
# File 'lib/aws-sdk-sagemaker/types.rb', line 11397

class DescribeFeatureGroupResponse < Struct.new(
  :feature_group_arn,
  :feature_group_name,
  :record_identifier_feature_name,
  :event_time_feature_name,
  :feature_definitions,
  :creation_time,
  :last_modified_time,
  :online_store_config,
  :offline_store_config,
  :role_arn,
  :feature_group_status,
  :offline_store_status,
  :last_update_status,
  :failure_reason,
  :description,
  :next_token,
  :online_store_total_size_bytes)
  SENSITIVE = []
  include Aws::Structure
end

#online_store_total_size_bytesInteger

The size of the OnlineStore in bytes.

Returns:

  • (Integer)


11397
11398
11399
11400
11401
11402
11403
11404
11405
11406
11407
11408
11409
11410
11411
11412
11413
11414
11415
11416
11417
# File 'lib/aws-sdk-sagemaker/types.rb', line 11397

class DescribeFeatureGroupResponse < Struct.new(
  :feature_group_arn,
  :feature_group_name,
  :record_identifier_feature_name,
  :event_time_feature_name,
  :feature_definitions,
  :creation_time,
  :last_modified_time,
  :online_store_config,
  :offline_store_config,
  :role_arn,
  :feature_group_status,
  :offline_store_status,
  :last_update_status,
  :failure_reason,
  :description,
  :next_token,
  :online_store_total_size_bytes)
  SENSITIVE = []
  include Aws::Structure
end

#record_identifier_feature_nameString

The name of the Feature used for RecordIdentifier, whose value uniquely identifies a record stored in the feature store.

Returns:

  • (String)


11397
11398
11399
11400
11401
11402
11403
11404
11405
11406
11407
11408
11409
11410
11411
11412
11413
11414
11415
11416
11417
# File 'lib/aws-sdk-sagemaker/types.rb', line 11397

class DescribeFeatureGroupResponse < Struct.new(
  :feature_group_arn,
  :feature_group_name,
  :record_identifier_feature_name,
  :event_time_feature_name,
  :feature_definitions,
  :creation_time,
  :last_modified_time,
  :online_store_config,
  :offline_store_config,
  :role_arn,
  :feature_group_status,
  :offline_store_status,
  :last_update_status,
  :failure_reason,
  :description,
  :next_token,
  :online_store_total_size_bytes)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of the IAM execution role used to persist data into the OfflineStore if an OfflineStoreConfig is provided.

Returns:

  • (String)


11397
11398
11399
11400
11401
11402
11403
11404
11405
11406
11407
11408
11409
11410
11411
11412
11413
11414
11415
11416
11417
# File 'lib/aws-sdk-sagemaker/types.rb', line 11397

class DescribeFeatureGroupResponse < Struct.new(
  :feature_group_arn,
  :feature_group_name,
  :record_identifier_feature_name,
  :event_time_feature_name,
  :feature_definitions,
  :creation_time,
  :last_modified_time,
  :online_store_config,
  :offline_store_config,
  :role_arn,
  :feature_group_status,
  :offline_store_status,
  :last_update_status,
  :failure_reason,
  :description,
  :next_token,
  :online_store_total_size_bytes)
  SENSITIVE = []
  include Aws::Structure
end