Class: Aws::SageMaker::Types::DescribeFlowDefinitionResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timeTime

The timestamp when the flow definition was created.

Returns:

  • (Time)


20018
20019
20020
20021
20022
20023
20024
20025
20026
20027
20028
20029
20030
20031
# File 'lib/aws-sdk-sagemaker/types.rb', line 20018

class DescribeFlowDefinitionResponse < Struct.new(
  :flow_definition_arn,
  :flow_definition_name,
  :flow_definition_status,
  :creation_time,
  :human_loop_request_source,
  :human_loop_activation_config,
  :human_loop_config,
  :output_config,
  :role_arn,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

The reason your flow definition failed.

Returns:

  • (String)


20018
20019
20020
20021
20022
20023
20024
20025
20026
20027
20028
20029
20030
20031
# File 'lib/aws-sdk-sagemaker/types.rb', line 20018

class DescribeFlowDefinitionResponse < Struct.new(
  :flow_definition_arn,
  :flow_definition_name,
  :flow_definition_status,
  :creation_time,
  :human_loop_request_source,
  :human_loop_activation_config,
  :human_loop_config,
  :output_config,
  :role_arn,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#flow_definition_arnString

The Amazon Resource Name (ARN) of the flow defintion.

Returns:

  • (String)


20018
20019
20020
20021
20022
20023
20024
20025
20026
20027
20028
20029
20030
20031
# File 'lib/aws-sdk-sagemaker/types.rb', line 20018

class DescribeFlowDefinitionResponse < Struct.new(
  :flow_definition_arn,
  :flow_definition_name,
  :flow_definition_status,
  :creation_time,
  :human_loop_request_source,
  :human_loop_activation_config,
  :human_loop_config,
  :output_config,
  :role_arn,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#flow_definition_nameString

The Amazon Resource Name (ARN) of the flow definition.

Returns:

  • (String)


20018
20019
20020
20021
20022
20023
20024
20025
20026
20027
20028
20029
20030
20031
# File 'lib/aws-sdk-sagemaker/types.rb', line 20018

class DescribeFlowDefinitionResponse < Struct.new(
  :flow_definition_arn,
  :flow_definition_name,
  :flow_definition_status,
  :creation_time,
  :human_loop_request_source,
  :human_loop_activation_config,
  :human_loop_config,
  :output_config,
  :role_arn,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#flow_definition_statusString

The status of the flow definition. Valid values are listed below.

Returns:

  • (String)


20018
20019
20020
20021
20022
20023
20024
20025
20026
20027
20028
20029
20030
20031
# File 'lib/aws-sdk-sagemaker/types.rb', line 20018

class DescribeFlowDefinitionResponse < Struct.new(
  :flow_definition_arn,
  :flow_definition_name,
  :flow_definition_status,
  :creation_time,
  :human_loop_request_source,
  :human_loop_activation_config,
  :human_loop_config,
  :output_config,
  :role_arn,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#human_loop_activation_configTypes::HumanLoopActivationConfig

An object containing information about what triggers a human review workflow.



20018
20019
20020
20021
20022
20023
20024
20025
20026
20027
20028
20029
20030
20031
# File 'lib/aws-sdk-sagemaker/types.rb', line 20018

class DescribeFlowDefinitionResponse < Struct.new(
  :flow_definition_arn,
  :flow_definition_name,
  :flow_definition_status,
  :creation_time,
  :human_loop_request_source,
  :human_loop_activation_config,
  :human_loop_config,
  :output_config,
  :role_arn,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#human_loop_configTypes::HumanLoopConfig

An object containing information about who works on the task, the workforce task price, and other task details.



20018
20019
20020
20021
20022
20023
20024
20025
20026
20027
20028
20029
20030
20031
# File 'lib/aws-sdk-sagemaker/types.rb', line 20018

class DescribeFlowDefinitionResponse < Struct.new(
  :flow_definition_arn,
  :flow_definition_name,
  :flow_definition_status,
  :creation_time,
  :human_loop_request_source,
  :human_loop_activation_config,
  :human_loop_config,
  :output_config,
  :role_arn,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#human_loop_request_sourceTypes::HumanLoopRequestSource

Container for configuring the source of human task requests. Used to specify if Amazon Rekognition or Amazon Textract is used as an integration source.



20018
20019
20020
20021
20022
20023
20024
20025
20026
20027
20028
20029
20030
20031
# File 'lib/aws-sdk-sagemaker/types.rb', line 20018

class DescribeFlowDefinitionResponse < Struct.new(
  :flow_definition_arn,
  :flow_definition_name,
  :flow_definition_status,
  :creation_time,
  :human_loop_request_source,
  :human_loop_activation_config,
  :human_loop_config,
  :output_config,
  :role_arn,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#output_configTypes::FlowDefinitionOutputConfig

An object containing information about the output file.



20018
20019
20020
20021
20022
20023
20024
20025
20026
20027
20028
20029
20030
20031
# File 'lib/aws-sdk-sagemaker/types.rb', line 20018

class DescribeFlowDefinitionResponse < Struct.new(
  :flow_definition_arn,
  :flow_definition_name,
  :flow_definition_status,
  :creation_time,
  :human_loop_request_source,
  :human_loop_activation_config,
  :human_loop_config,
  :output_config,
  :role_arn,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of the Amazon Web Services Identity and Access Management (IAM) execution role for the flow definition.

Returns:

  • (String)


20018
20019
20020
20021
20022
20023
20024
20025
20026
20027
20028
20029
20030
20031
# File 'lib/aws-sdk-sagemaker/types.rb', line 20018

class DescribeFlowDefinitionResponse < Struct.new(
  :flow_definition_arn,
  :flow_definition_name,
  :flow_definition_status,
  :creation_time,
  :human_loop_request_source,
  :human_loop_activation_config,
  :human_loop_config,
  :output_config,
  :role_arn,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end