Class: Aws::SageMaker::Types::DescribeFlowDefinitionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeFlowDefinitionResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Time
The timestamp when the flow definition was created.
-
#failure_reason ⇒ String
The reason your flow definition failed.
-
#flow_definition_arn ⇒ String
The Amazon Resource Name (ARN) of the flow defintion.
-
#flow_definition_name ⇒ String
The Amazon Resource Name (ARN) of the flow definition.
-
#flow_definition_status ⇒ String
The status of the flow definition.
-
#human_loop_activation_config ⇒ Types::HumanLoopActivationConfig
An object containing information about what triggers a human review workflow.
-
#human_loop_config ⇒ Types::HumanLoopConfig
An object containing information about who works on the task, the workforce task price, and other task details.
-
#human_loop_request_source ⇒ Types::HumanLoopRequestSource
Container for configuring the source of human task requests.
-
#output_config ⇒ Types::FlowDefinitionOutputConfig
An object containing information about the output file.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Web Services Identity and Access Management (IAM) execution role for the flow definition.
Instance Attribute Details
#creation_time ⇒ Time
The timestamp when the flow definition was created.
19389 19390 19391 19392 19393 19394 19395 19396 19397 19398 19399 19400 19401 19402 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19389 class DescribeFlowDefinitionResponse < Struct.new( :flow_definition_arn, :flow_definition_name, :flow_definition_status, :creation_time, :human_loop_request_source, :human_loop_activation_config, :human_loop_config, :output_config, :role_arn, :failure_reason) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
The reason your flow definition failed.
19389 19390 19391 19392 19393 19394 19395 19396 19397 19398 19399 19400 19401 19402 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19389 class DescribeFlowDefinitionResponse < Struct.new( :flow_definition_arn, :flow_definition_name, :flow_definition_status, :creation_time, :human_loop_request_source, :human_loop_activation_config, :human_loop_config, :output_config, :role_arn, :failure_reason) SENSITIVE = [] include Aws::Structure end |
#flow_definition_arn ⇒ String
The Amazon Resource Name (ARN) of the flow defintion.
19389 19390 19391 19392 19393 19394 19395 19396 19397 19398 19399 19400 19401 19402 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19389 class DescribeFlowDefinitionResponse < Struct.new( :flow_definition_arn, :flow_definition_name, :flow_definition_status, :creation_time, :human_loop_request_source, :human_loop_activation_config, :human_loop_config, :output_config, :role_arn, :failure_reason) SENSITIVE = [] include Aws::Structure end |
#flow_definition_name ⇒ String
The Amazon Resource Name (ARN) of the flow definition.
19389 19390 19391 19392 19393 19394 19395 19396 19397 19398 19399 19400 19401 19402 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19389 class DescribeFlowDefinitionResponse < Struct.new( :flow_definition_arn, :flow_definition_name, :flow_definition_status, :creation_time, :human_loop_request_source, :human_loop_activation_config, :human_loop_config, :output_config, :role_arn, :failure_reason) SENSITIVE = [] include Aws::Structure end |
#flow_definition_status ⇒ String
The status of the flow definition. Valid values are listed below.
19389 19390 19391 19392 19393 19394 19395 19396 19397 19398 19399 19400 19401 19402 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19389 class DescribeFlowDefinitionResponse < Struct.new( :flow_definition_arn, :flow_definition_name, :flow_definition_status, :creation_time, :human_loop_request_source, :human_loop_activation_config, :human_loop_config, :output_config, :role_arn, :failure_reason) SENSITIVE = [] include Aws::Structure end |
#human_loop_activation_config ⇒ Types::HumanLoopActivationConfig
An object containing information about what triggers a human review workflow.
19389 19390 19391 19392 19393 19394 19395 19396 19397 19398 19399 19400 19401 19402 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19389 class DescribeFlowDefinitionResponse < Struct.new( :flow_definition_arn, :flow_definition_name, :flow_definition_status, :creation_time, :human_loop_request_source, :human_loop_activation_config, :human_loop_config, :output_config, :role_arn, :failure_reason) SENSITIVE = [] include Aws::Structure end |
#human_loop_config ⇒ Types::HumanLoopConfig
An object containing information about who works on the task, the workforce task price, and other task details.
19389 19390 19391 19392 19393 19394 19395 19396 19397 19398 19399 19400 19401 19402 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19389 class DescribeFlowDefinitionResponse < Struct.new( :flow_definition_arn, :flow_definition_name, :flow_definition_status, :creation_time, :human_loop_request_source, :human_loop_activation_config, :human_loop_config, :output_config, :role_arn, :failure_reason) SENSITIVE = [] include Aws::Structure end |
#human_loop_request_source ⇒ Types::HumanLoopRequestSource
Container for configuring the source of human task requests. Used to specify if Amazon Rekognition or Amazon Textract is used as an integration source.
19389 19390 19391 19392 19393 19394 19395 19396 19397 19398 19399 19400 19401 19402 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19389 class DescribeFlowDefinitionResponse < Struct.new( :flow_definition_arn, :flow_definition_name, :flow_definition_status, :creation_time, :human_loop_request_source, :human_loop_activation_config, :human_loop_config, :output_config, :role_arn, :failure_reason) SENSITIVE = [] include Aws::Structure end |
#output_config ⇒ Types::FlowDefinitionOutputConfig
An object containing information about the output file.
19389 19390 19391 19392 19393 19394 19395 19396 19397 19398 19399 19400 19401 19402 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19389 class DescribeFlowDefinitionResponse < Struct.new( :flow_definition_arn, :flow_definition_name, :flow_definition_status, :creation_time, :human_loop_request_source, :human_loop_activation_config, :human_loop_config, :output_config, :role_arn, :failure_reason) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Web Services Identity and Access Management (IAM) execution role for the flow definition.
19389 19390 19391 19392 19393 19394 19395 19396 19397 19398 19399 19400 19401 19402 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19389 class DescribeFlowDefinitionResponse < Struct.new( :flow_definition_arn, :flow_definition_name, :flow_definition_status, :creation_time, :human_loop_request_source, :human_loop_activation_config, :human_loop_config, :output_config, :role_arn, :failure_reason) SENSITIVE = [] include Aws::Structure end |