Class: Aws::SageMaker::Types::DescribeHubContentResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeHubContentResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Time
The date and time that hub content was created.
-
#document_schema_version ⇒ String
The document schema version for the hub content.
-
#failure_reason ⇒ String
The failure reason if importing hub content failed.
-
#hub_arn ⇒ String
The Amazon Resource Name (ARN) of the hub that contains the content.
-
#hub_content_arn ⇒ String
The Amazon Resource Name (ARN) of the hub content.
-
#hub_content_dependencies ⇒ Array<Types::HubContentDependency>
The location of any dependencies that the hub content has, such as scripts, model artifacts, datasets, or notebooks.
-
#hub_content_description ⇒ String
A description of the hub content.
-
#hub_content_display_name ⇒ String
The display name of the hub content.
-
#hub_content_document ⇒ String
The hub content document that describes information about the hub content such as type, associated containers, scripts, and more.
-
#hub_content_markdown ⇒ String
A string that provides a description of the hub content.
-
#hub_content_name ⇒ String
The name of the hub content.
-
#hub_content_search_keywords ⇒ Array<String>
The searchable keywords for the hub content.
-
#hub_content_status ⇒ String
The status of the hub content.
-
#hub_content_type ⇒ String
The type of hub content.
-
#hub_content_version ⇒ String
The version of the hub content.
-
#hub_name ⇒ String
The name of the hub that contains the content.
-
#last_modified_time ⇒ Time
The last modified time of the hub content.
-
#reference_min_version ⇒ String
The minimum version of the hub content.
-
#sage_maker_public_hub_content_arn ⇒ String
The ARN of the public hub content.
-
#support_status ⇒ String
The support status of the hub content.
Instance Attribute Details
#creation_time ⇒ Time
The date and time that hub content was created.
19651 19652 19653 19654 19655 19656 19657 19658 19659 19660 19661 19662 19663 19664 19665 19666 19667 19668 19669 19670 19671 19672 19673 19674 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19651 class DescribeHubContentResponse < Struct.new( :hub_content_name, :hub_content_arn, :hub_content_version, :hub_content_type, :document_schema_version, :hub_name, :hub_arn, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_document, :sage_maker_public_hub_content_arn, :reference_min_version, :support_status, :hub_content_search_keywords, :hub_content_dependencies, :hub_content_status, :failure_reason, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#document_schema_version ⇒ String
The document schema version for the hub content.
19651 19652 19653 19654 19655 19656 19657 19658 19659 19660 19661 19662 19663 19664 19665 19666 19667 19668 19669 19670 19671 19672 19673 19674 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19651 class DescribeHubContentResponse < Struct.new( :hub_content_name, :hub_content_arn, :hub_content_version, :hub_content_type, :document_schema_version, :hub_name, :hub_arn, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_document, :sage_maker_public_hub_content_arn, :reference_min_version, :support_status, :hub_content_search_keywords, :hub_content_dependencies, :hub_content_status, :failure_reason, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
The failure reason if importing hub content failed.
19651 19652 19653 19654 19655 19656 19657 19658 19659 19660 19661 19662 19663 19664 19665 19666 19667 19668 19669 19670 19671 19672 19673 19674 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19651 class DescribeHubContentResponse < Struct.new( :hub_content_name, :hub_content_arn, :hub_content_version, :hub_content_type, :document_schema_version, :hub_name, :hub_arn, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_document, :sage_maker_public_hub_content_arn, :reference_min_version, :support_status, :hub_content_search_keywords, :hub_content_dependencies, :hub_content_status, :failure_reason, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#hub_arn ⇒ String
The Amazon Resource Name (ARN) of the hub that contains the content.
19651 19652 19653 19654 19655 19656 19657 19658 19659 19660 19661 19662 19663 19664 19665 19666 19667 19668 19669 19670 19671 19672 19673 19674 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19651 class DescribeHubContentResponse < Struct.new( :hub_content_name, :hub_content_arn, :hub_content_version, :hub_content_type, :document_schema_version, :hub_name, :hub_arn, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_document, :sage_maker_public_hub_content_arn, :reference_min_version, :support_status, :hub_content_search_keywords, :hub_content_dependencies, :hub_content_status, :failure_reason, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#hub_content_arn ⇒ String
The Amazon Resource Name (ARN) of the hub content.
19651 19652 19653 19654 19655 19656 19657 19658 19659 19660 19661 19662 19663 19664 19665 19666 19667 19668 19669 19670 19671 19672 19673 19674 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19651 class DescribeHubContentResponse < Struct.new( :hub_content_name, :hub_content_arn, :hub_content_version, :hub_content_type, :document_schema_version, :hub_name, :hub_arn, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_document, :sage_maker_public_hub_content_arn, :reference_min_version, :support_status, :hub_content_search_keywords, :hub_content_dependencies, :hub_content_status, :failure_reason, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#hub_content_dependencies ⇒ Array<Types::HubContentDependency>
The location of any dependencies that the hub content has, such as scripts, model artifacts, datasets, or notebooks.
19651 19652 19653 19654 19655 19656 19657 19658 19659 19660 19661 19662 19663 19664 19665 19666 19667 19668 19669 19670 19671 19672 19673 19674 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19651 class DescribeHubContentResponse < Struct.new( :hub_content_name, :hub_content_arn, :hub_content_version, :hub_content_type, :document_schema_version, :hub_name, :hub_arn, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_document, :sage_maker_public_hub_content_arn, :reference_min_version, :support_status, :hub_content_search_keywords, :hub_content_dependencies, :hub_content_status, :failure_reason, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#hub_content_description ⇒ String
A description of the hub content.
19651 19652 19653 19654 19655 19656 19657 19658 19659 19660 19661 19662 19663 19664 19665 19666 19667 19668 19669 19670 19671 19672 19673 19674 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19651 class DescribeHubContentResponse < Struct.new( :hub_content_name, :hub_content_arn, :hub_content_version, :hub_content_type, :document_schema_version, :hub_name, :hub_arn, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_document, :sage_maker_public_hub_content_arn, :reference_min_version, :support_status, :hub_content_search_keywords, :hub_content_dependencies, :hub_content_status, :failure_reason, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#hub_content_display_name ⇒ String
The display name of the hub content.
19651 19652 19653 19654 19655 19656 19657 19658 19659 19660 19661 19662 19663 19664 19665 19666 19667 19668 19669 19670 19671 19672 19673 19674 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19651 class DescribeHubContentResponse < Struct.new( :hub_content_name, :hub_content_arn, :hub_content_version, :hub_content_type, :document_schema_version, :hub_name, :hub_arn, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_document, :sage_maker_public_hub_content_arn, :reference_min_version, :support_status, :hub_content_search_keywords, :hub_content_dependencies, :hub_content_status, :failure_reason, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#hub_content_document ⇒ String
The hub content document that describes information about the hub content such as type, associated containers, scripts, and more.
19651 19652 19653 19654 19655 19656 19657 19658 19659 19660 19661 19662 19663 19664 19665 19666 19667 19668 19669 19670 19671 19672 19673 19674 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19651 class DescribeHubContentResponse < Struct.new( :hub_content_name, :hub_content_arn, :hub_content_version, :hub_content_type, :document_schema_version, :hub_name, :hub_arn, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_document, :sage_maker_public_hub_content_arn, :reference_min_version, :support_status, :hub_content_search_keywords, :hub_content_dependencies, :hub_content_status, :failure_reason, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#hub_content_markdown ⇒ String
A string that provides a description of the hub content. This string can include links, tables, and standard markdown formating.
19651 19652 19653 19654 19655 19656 19657 19658 19659 19660 19661 19662 19663 19664 19665 19666 19667 19668 19669 19670 19671 19672 19673 19674 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19651 class DescribeHubContentResponse < Struct.new( :hub_content_name, :hub_content_arn, :hub_content_version, :hub_content_type, :document_schema_version, :hub_name, :hub_arn, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_document, :sage_maker_public_hub_content_arn, :reference_min_version, :support_status, :hub_content_search_keywords, :hub_content_dependencies, :hub_content_status, :failure_reason, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#hub_content_name ⇒ String
The name of the hub content.
19651 19652 19653 19654 19655 19656 19657 19658 19659 19660 19661 19662 19663 19664 19665 19666 19667 19668 19669 19670 19671 19672 19673 19674 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19651 class DescribeHubContentResponse < Struct.new( :hub_content_name, :hub_content_arn, :hub_content_version, :hub_content_type, :document_schema_version, :hub_name, :hub_arn, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_document, :sage_maker_public_hub_content_arn, :reference_min_version, :support_status, :hub_content_search_keywords, :hub_content_dependencies, :hub_content_status, :failure_reason, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#hub_content_search_keywords ⇒ Array<String>
The searchable keywords for the hub content.
19651 19652 19653 19654 19655 19656 19657 19658 19659 19660 19661 19662 19663 19664 19665 19666 19667 19668 19669 19670 19671 19672 19673 19674 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19651 class DescribeHubContentResponse < Struct.new( :hub_content_name, :hub_content_arn, :hub_content_version, :hub_content_type, :document_schema_version, :hub_name, :hub_arn, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_document, :sage_maker_public_hub_content_arn, :reference_min_version, :support_status, :hub_content_search_keywords, :hub_content_dependencies, :hub_content_status, :failure_reason, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#hub_content_status ⇒ String
The status of the hub content.
19651 19652 19653 19654 19655 19656 19657 19658 19659 19660 19661 19662 19663 19664 19665 19666 19667 19668 19669 19670 19671 19672 19673 19674 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19651 class DescribeHubContentResponse < Struct.new( :hub_content_name, :hub_content_arn, :hub_content_version, :hub_content_type, :document_schema_version, :hub_name, :hub_arn, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_document, :sage_maker_public_hub_content_arn, :reference_min_version, :support_status, :hub_content_search_keywords, :hub_content_dependencies, :hub_content_status, :failure_reason, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#hub_content_type ⇒ String
The type of hub content.
19651 19652 19653 19654 19655 19656 19657 19658 19659 19660 19661 19662 19663 19664 19665 19666 19667 19668 19669 19670 19671 19672 19673 19674 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19651 class DescribeHubContentResponse < Struct.new( :hub_content_name, :hub_content_arn, :hub_content_version, :hub_content_type, :document_schema_version, :hub_name, :hub_arn, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_document, :sage_maker_public_hub_content_arn, :reference_min_version, :support_status, :hub_content_search_keywords, :hub_content_dependencies, :hub_content_status, :failure_reason, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#hub_content_version ⇒ String
The version of the hub content.
19651 19652 19653 19654 19655 19656 19657 19658 19659 19660 19661 19662 19663 19664 19665 19666 19667 19668 19669 19670 19671 19672 19673 19674 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19651 class DescribeHubContentResponse < Struct.new( :hub_content_name, :hub_content_arn, :hub_content_version, :hub_content_type, :document_schema_version, :hub_name, :hub_arn, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_document, :sage_maker_public_hub_content_arn, :reference_min_version, :support_status, :hub_content_search_keywords, :hub_content_dependencies, :hub_content_status, :failure_reason, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#hub_name ⇒ String
The name of the hub that contains the content.
19651 19652 19653 19654 19655 19656 19657 19658 19659 19660 19661 19662 19663 19664 19665 19666 19667 19668 19669 19670 19671 19672 19673 19674 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19651 class DescribeHubContentResponse < Struct.new( :hub_content_name, :hub_content_arn, :hub_content_version, :hub_content_type, :document_schema_version, :hub_name, :hub_arn, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_document, :sage_maker_public_hub_content_arn, :reference_min_version, :support_status, :hub_content_search_keywords, :hub_content_dependencies, :hub_content_status, :failure_reason, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The last modified time of the hub content.
19651 19652 19653 19654 19655 19656 19657 19658 19659 19660 19661 19662 19663 19664 19665 19666 19667 19668 19669 19670 19671 19672 19673 19674 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19651 class DescribeHubContentResponse < Struct.new( :hub_content_name, :hub_content_arn, :hub_content_version, :hub_content_type, :document_schema_version, :hub_name, :hub_arn, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_document, :sage_maker_public_hub_content_arn, :reference_min_version, :support_status, :hub_content_search_keywords, :hub_content_dependencies, :hub_content_status, :failure_reason, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#reference_min_version ⇒ String
The minimum version of the hub content.
19651 19652 19653 19654 19655 19656 19657 19658 19659 19660 19661 19662 19663 19664 19665 19666 19667 19668 19669 19670 19671 19672 19673 19674 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19651 class DescribeHubContentResponse < Struct.new( :hub_content_name, :hub_content_arn, :hub_content_version, :hub_content_type, :document_schema_version, :hub_name, :hub_arn, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_document, :sage_maker_public_hub_content_arn, :reference_min_version, :support_status, :hub_content_search_keywords, :hub_content_dependencies, :hub_content_status, :failure_reason, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#sage_maker_public_hub_content_arn ⇒ String
The ARN of the public hub content.
19651 19652 19653 19654 19655 19656 19657 19658 19659 19660 19661 19662 19663 19664 19665 19666 19667 19668 19669 19670 19671 19672 19673 19674 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19651 class DescribeHubContentResponse < Struct.new( :hub_content_name, :hub_content_arn, :hub_content_version, :hub_content_type, :document_schema_version, :hub_name, :hub_arn, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_document, :sage_maker_public_hub_content_arn, :reference_min_version, :support_status, :hub_content_search_keywords, :hub_content_dependencies, :hub_content_status, :failure_reason, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#support_status ⇒ String
The support status of the hub content.
19651 19652 19653 19654 19655 19656 19657 19658 19659 19660 19661 19662 19663 19664 19665 19666 19667 19668 19669 19670 19671 19672 19673 19674 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19651 class DescribeHubContentResponse < Struct.new( :hub_content_name, :hub_content_arn, :hub_content_version, :hub_content_type, :document_schema_version, :hub_name, :hub_arn, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_document, :sage_maker_public_hub_content_arn, :reference_min_version, :support_status, :hub_content_search_keywords, :hub_content_dependencies, :hub_content_status, :failure_reason, :creation_time, :last_modified_time) SENSITIVE = [] include Aws::Structure end |