Class: Aws::SageMaker::Types::DescribeHyperParameterTuningJobResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#autotuneTypes::Autotune

A flag to indicate if autotune is enabled for the hyperparameter tuning job.

Returns:



19768
19769
19770
19771
19772
19773
19774
19775
19776
19777
19778
19779
19780
19781
19782
19783
19784
19785
19786
19787
19788
19789
# File 'lib/aws-sdk-sagemaker/types.rb', line 19768

class DescribeHyperParameterTuningJobResponse < Struct.new(
  :hyper_parameter_tuning_job_name,
  :hyper_parameter_tuning_job_arn,
  :hyper_parameter_tuning_job_config,
  :training_job_definition,
  :training_job_definitions,
  :hyper_parameter_tuning_job_status,
  :creation_time,
  :hyper_parameter_tuning_end_time,
  :last_modified_time,
  :training_job_status_counters,
  :objective_status_counters,
  :best_training_job,
  :overall_best_training_job,
  :warm_start_config,
  :autotune,
  :failure_reason,
  :tuning_job_completion_details,
  :consumed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#best_training_jobTypes::HyperParameterTrainingJobSummary



19768
19769
19770
19771
19772
19773
19774
19775
19776
19777
19778
19779
19780
19781
19782
19783
19784
19785
19786
19787
19788
19789
# File 'lib/aws-sdk-sagemaker/types.rb', line 19768

class DescribeHyperParameterTuningJobResponse < Struct.new(
  :hyper_parameter_tuning_job_name,
  :hyper_parameter_tuning_job_arn,
  :hyper_parameter_tuning_job_config,
  :training_job_definition,
  :training_job_definitions,
  :hyper_parameter_tuning_job_status,
  :creation_time,
  :hyper_parameter_tuning_end_time,
  :last_modified_time,
  :training_job_status_counters,
  :objective_status_counters,
  :best_training_job,
  :overall_best_training_job,
  :warm_start_config,
  :autotune,
  :failure_reason,
  :tuning_job_completion_details,
  :consumed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#consumed_resourcesTypes::HyperParameterTuningJobConsumedResources

The total resources consumed by your hyperparameter tuning job.



19768
19769
19770
19771
19772
19773
19774
19775
19776
19777
19778
19779
19780
19781
19782
19783
19784
19785
19786
19787
19788
19789
# File 'lib/aws-sdk-sagemaker/types.rb', line 19768

class DescribeHyperParameterTuningJobResponse < Struct.new(
  :hyper_parameter_tuning_job_name,
  :hyper_parameter_tuning_job_arn,
  :hyper_parameter_tuning_job_config,
  :training_job_definition,
  :training_job_definitions,
  :hyper_parameter_tuning_job_status,
  :creation_time,
  :hyper_parameter_tuning_end_time,
  :last_modified_time,
  :training_job_status_counters,
  :objective_status_counters,
  :best_training_job,
  :overall_best_training_job,
  :warm_start_config,
  :autotune,
  :failure_reason,
  :tuning_job_completion_details,
  :consumed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

The date and time that the tuning job started.

Returns:

  • (Time)


19768
19769
19770
19771
19772
19773
19774
19775
19776
19777
19778
19779
19780
19781
19782
19783
19784
19785
19786
19787
19788
19789
# File 'lib/aws-sdk-sagemaker/types.rb', line 19768

class DescribeHyperParameterTuningJobResponse < Struct.new(
  :hyper_parameter_tuning_job_name,
  :hyper_parameter_tuning_job_arn,
  :hyper_parameter_tuning_job_config,
  :training_job_definition,
  :training_job_definitions,
  :hyper_parameter_tuning_job_status,
  :creation_time,
  :hyper_parameter_tuning_end_time,
  :last_modified_time,
  :training_job_status_counters,
  :objective_status_counters,
  :best_training_job,
  :overall_best_training_job,
  :warm_start_config,
  :autotune,
  :failure_reason,
  :tuning_job_completion_details,
  :consumed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

If the tuning job failed, the reason it failed.

Returns:

  • (String)


19768
19769
19770
19771
19772
19773
19774
19775
19776
19777
19778
19779
19780
19781
19782
19783
19784
19785
19786
19787
19788
19789
# File 'lib/aws-sdk-sagemaker/types.rb', line 19768

class DescribeHyperParameterTuningJobResponse < Struct.new(
  :hyper_parameter_tuning_job_name,
  :hyper_parameter_tuning_job_arn,
  :hyper_parameter_tuning_job_config,
  :training_job_definition,
  :training_job_definitions,
  :hyper_parameter_tuning_job_status,
  :creation_time,
  :hyper_parameter_tuning_end_time,
  :last_modified_time,
  :training_job_status_counters,
  :objective_status_counters,
  :best_training_job,
  :overall_best_training_job,
  :warm_start_config,
  :autotune,
  :failure_reason,
  :tuning_job_completion_details,
  :consumed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#hyper_parameter_tuning_end_timeTime

The date and time that the tuning job ended.

Returns:

  • (Time)


19768
19769
19770
19771
19772
19773
19774
19775
19776
19777
19778
19779
19780
19781
19782
19783
19784
19785
19786
19787
19788
19789
# File 'lib/aws-sdk-sagemaker/types.rb', line 19768

class DescribeHyperParameterTuningJobResponse < Struct.new(
  :hyper_parameter_tuning_job_name,
  :hyper_parameter_tuning_job_arn,
  :hyper_parameter_tuning_job_config,
  :training_job_definition,
  :training_job_definitions,
  :hyper_parameter_tuning_job_status,
  :creation_time,
  :hyper_parameter_tuning_end_time,
  :last_modified_time,
  :training_job_status_counters,
  :objective_status_counters,
  :best_training_job,
  :overall_best_training_job,
  :warm_start_config,
  :autotune,
  :failure_reason,
  :tuning_job_completion_details,
  :consumed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#hyper_parameter_tuning_job_arnString

The Amazon Resource Name (ARN) of the tuning job.

Returns:

  • (String)


19768
19769
19770
19771
19772
19773
19774
19775
19776
19777
19778
19779
19780
19781
19782
19783
19784
19785
19786
19787
19788
19789
# File 'lib/aws-sdk-sagemaker/types.rb', line 19768

class DescribeHyperParameterTuningJobResponse < Struct.new(
  :hyper_parameter_tuning_job_name,
  :hyper_parameter_tuning_job_arn,
  :hyper_parameter_tuning_job_config,
  :training_job_definition,
  :training_job_definitions,
  :hyper_parameter_tuning_job_status,
  :creation_time,
  :hyper_parameter_tuning_end_time,
  :last_modified_time,
  :training_job_status_counters,
  :objective_status_counters,
  :best_training_job,
  :overall_best_training_job,
  :warm_start_config,
  :autotune,
  :failure_reason,
  :tuning_job_completion_details,
  :consumed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#hyper_parameter_tuning_job_configTypes::HyperParameterTuningJobConfig



19768
19769
19770
19771
19772
19773
19774
19775
19776
19777
19778
19779
19780
19781
19782
19783
19784
19785
19786
19787
19788
19789
# File 'lib/aws-sdk-sagemaker/types.rb', line 19768

class DescribeHyperParameterTuningJobResponse < Struct.new(
  :hyper_parameter_tuning_job_name,
  :hyper_parameter_tuning_job_arn,
  :hyper_parameter_tuning_job_config,
  :training_job_definition,
  :training_job_definitions,
  :hyper_parameter_tuning_job_status,
  :creation_time,
  :hyper_parameter_tuning_end_time,
  :last_modified_time,
  :training_job_status_counters,
  :objective_status_counters,
  :best_training_job,
  :overall_best_training_job,
  :warm_start_config,
  :autotune,
  :failure_reason,
  :tuning_job_completion_details,
  :consumed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#hyper_parameter_tuning_job_nameString

The name of the hyperparameter tuning job.

Returns:

  • (String)


19768
19769
19770
19771
19772
19773
19774
19775
19776
19777
19778
19779
19780
19781
19782
19783
19784
19785
19786
19787
19788
19789
# File 'lib/aws-sdk-sagemaker/types.rb', line 19768

class DescribeHyperParameterTuningJobResponse < Struct.new(
  :hyper_parameter_tuning_job_name,
  :hyper_parameter_tuning_job_arn,
  :hyper_parameter_tuning_job_config,
  :training_job_definition,
  :training_job_definitions,
  :hyper_parameter_tuning_job_status,
  :creation_time,
  :hyper_parameter_tuning_end_time,
  :last_modified_time,
  :training_job_status_counters,
  :objective_status_counters,
  :best_training_job,
  :overall_best_training_job,
  :warm_start_config,
  :autotune,
  :failure_reason,
  :tuning_job_completion_details,
  :consumed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#hyper_parameter_tuning_job_statusString

The status of the tuning job.

Returns:

  • (String)


19768
19769
19770
19771
19772
19773
19774
19775
19776
19777
19778
19779
19780
19781
19782
19783
19784
19785
19786
19787
19788
19789
# File 'lib/aws-sdk-sagemaker/types.rb', line 19768

class DescribeHyperParameterTuningJobResponse < Struct.new(
  :hyper_parameter_tuning_job_name,
  :hyper_parameter_tuning_job_arn,
  :hyper_parameter_tuning_job_config,
  :training_job_definition,
  :training_job_definitions,
  :hyper_parameter_tuning_job_status,
  :creation_time,
  :hyper_parameter_tuning_end_time,
  :last_modified_time,
  :training_job_status_counters,
  :objective_status_counters,
  :best_training_job,
  :overall_best_training_job,
  :warm_start_config,
  :autotune,
  :failure_reason,
  :tuning_job_completion_details,
  :consumed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The date and time that the status of the tuning job was modified.

Returns:

  • (Time)


19768
19769
19770
19771
19772
19773
19774
19775
19776
19777
19778
19779
19780
19781
19782
19783
19784
19785
19786
19787
19788
19789
# File 'lib/aws-sdk-sagemaker/types.rb', line 19768

class DescribeHyperParameterTuningJobResponse < Struct.new(
  :hyper_parameter_tuning_job_name,
  :hyper_parameter_tuning_job_arn,
  :hyper_parameter_tuning_job_config,
  :training_job_definition,
  :training_job_definitions,
  :hyper_parameter_tuning_job_status,
  :creation_time,
  :hyper_parameter_tuning_end_time,
  :last_modified_time,
  :training_job_status_counters,
  :objective_status_counters,
  :best_training_job,
  :overall_best_training_job,
  :warm_start_config,
  :autotune,
  :failure_reason,
  :tuning_job_completion_details,
  :consumed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#objective_status_countersTypes::ObjectiveStatusCounters

The [ObjectiveStatusCounters] object that specifies the number of training jobs, categorized by the status of their final objective metric, that this tuning job launched.

[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_ObjectiveStatusCounters.html



19768
19769
19770
19771
19772
19773
19774
19775
19776
19777
19778
19779
19780
19781
19782
19783
19784
19785
19786
19787
19788
19789
# File 'lib/aws-sdk-sagemaker/types.rb', line 19768

class DescribeHyperParameterTuningJobResponse < Struct.new(
  :hyper_parameter_tuning_job_name,
  :hyper_parameter_tuning_job_arn,
  :hyper_parameter_tuning_job_config,
  :training_job_definition,
  :training_job_definitions,
  :hyper_parameter_tuning_job_status,
  :creation_time,
  :hyper_parameter_tuning_end_time,
  :last_modified_time,
  :training_job_status_counters,
  :objective_status_counters,
  :best_training_job,
  :overall_best_training_job,
  :warm_start_config,
  :autotune,
  :failure_reason,
  :tuning_job_completion_details,
  :consumed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#overall_best_training_jobTypes::HyperParameterTrainingJobSummary

If the hyperparameter tuning job is an warm start tuning job with a ‘WarmStartType` of `IDENTICAL_DATA_AND_ALGORITHM`, this is the

TrainingJobSummary][1

for the training job with the best objective

metric value of all training jobs launched by this tuning job and all parent jobs specified for the warm start tuning job.

[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_TrainingJobSummary.html



19768
19769
19770
19771
19772
19773
19774
19775
19776
19777
19778
19779
19780
19781
19782
19783
19784
19785
19786
19787
19788
19789
# File 'lib/aws-sdk-sagemaker/types.rb', line 19768

class DescribeHyperParameterTuningJobResponse < Struct.new(
  :hyper_parameter_tuning_job_name,
  :hyper_parameter_tuning_job_arn,
  :hyper_parameter_tuning_job_config,
  :training_job_definition,
  :training_job_definitions,
  :hyper_parameter_tuning_job_status,
  :creation_time,
  :hyper_parameter_tuning_end_time,
  :last_modified_time,
  :training_job_status_counters,
  :objective_status_counters,
  :best_training_job,
  :overall_best_training_job,
  :warm_start_config,
  :autotune,
  :failure_reason,
  :tuning_job_completion_details,
  :consumed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#training_job_definitionTypes::HyperParameterTrainingJobDefinition

The [HyperParameterTrainingJobDefinition] object that specifies the definition of the training jobs that this tuning job launches.

[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_HyperParameterTrainingJobDefinition.html



19768
19769
19770
19771
19772
19773
19774
19775
19776
19777
19778
19779
19780
19781
19782
19783
19784
19785
19786
19787
19788
19789
# File 'lib/aws-sdk-sagemaker/types.rb', line 19768

class DescribeHyperParameterTuningJobResponse < Struct.new(
  :hyper_parameter_tuning_job_name,
  :hyper_parameter_tuning_job_arn,
  :hyper_parameter_tuning_job_config,
  :training_job_definition,
  :training_job_definitions,
  :hyper_parameter_tuning_job_status,
  :creation_time,
  :hyper_parameter_tuning_end_time,
  :last_modified_time,
  :training_job_status_counters,
  :objective_status_counters,
  :best_training_job,
  :overall_best_training_job,
  :warm_start_config,
  :autotune,
  :failure_reason,
  :tuning_job_completion_details,
  :consumed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#training_job_definitionsArray<Types::HyperParameterTrainingJobDefinition>



19768
19769
19770
19771
19772
19773
19774
19775
19776
19777
19778
19779
19780
19781
19782
19783
19784
19785
19786
19787
19788
19789
# File 'lib/aws-sdk-sagemaker/types.rb', line 19768

class DescribeHyperParameterTuningJobResponse < Struct.new(
  :hyper_parameter_tuning_job_name,
  :hyper_parameter_tuning_job_arn,
  :hyper_parameter_tuning_job_config,
  :training_job_definition,
  :training_job_definitions,
  :hyper_parameter_tuning_job_status,
  :creation_time,
  :hyper_parameter_tuning_end_time,
  :last_modified_time,
  :training_job_status_counters,
  :objective_status_counters,
  :best_training_job,
  :overall_best_training_job,
  :warm_start_config,
  :autotune,
  :failure_reason,
  :tuning_job_completion_details,
  :consumed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#training_job_status_countersTypes::TrainingJobStatusCounters

The [TrainingJobStatusCounters] object that specifies the number of training jobs, categorized by status, that this tuning job launched.

[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_TrainingJobStatusCounters.html



19768
19769
19770
19771
19772
19773
19774
19775
19776
19777
19778
19779
19780
19781
19782
19783
19784
19785
19786
19787
19788
19789
# File 'lib/aws-sdk-sagemaker/types.rb', line 19768

class DescribeHyperParameterTuningJobResponse < Struct.new(
  :hyper_parameter_tuning_job_name,
  :hyper_parameter_tuning_job_arn,
  :hyper_parameter_tuning_job_config,
  :training_job_definition,
  :training_job_definitions,
  :hyper_parameter_tuning_job_status,
  :creation_time,
  :hyper_parameter_tuning_end_time,
  :last_modified_time,
  :training_job_status_counters,
  :objective_status_counters,
  :best_training_job,
  :overall_best_training_job,
  :warm_start_config,
  :autotune,
  :failure_reason,
  :tuning_job_completion_details,
  :consumed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#tuning_job_completion_detailsTypes::HyperParameterTuningJobCompletionDetails

Tuning job completion information returned as the response from a hyperparameter tuning job. This information tells if your tuning job has or has not converged. It also includes the number of training jobs that have not improved model performance as evaluated against the objective function.



19768
19769
19770
19771
19772
19773
19774
19775
19776
19777
19778
19779
19780
19781
19782
19783
19784
19785
19786
19787
19788
19789
# File 'lib/aws-sdk-sagemaker/types.rb', line 19768

class DescribeHyperParameterTuningJobResponse < Struct.new(
  :hyper_parameter_tuning_job_name,
  :hyper_parameter_tuning_job_arn,
  :hyper_parameter_tuning_job_config,
  :training_job_definition,
  :training_job_definitions,
  :hyper_parameter_tuning_job_status,
  :creation_time,
  :hyper_parameter_tuning_end_time,
  :last_modified_time,
  :training_job_status_counters,
  :objective_status_counters,
  :best_training_job,
  :overall_best_training_job,
  :warm_start_config,
  :autotune,
  :failure_reason,
  :tuning_job_completion_details,
  :consumed_resources)
  SENSITIVE = []
  include Aws::Structure
end

#warm_start_configTypes::HyperParameterTuningJobWarmStartConfig

The configuration for starting the hyperparameter parameter tuning job using one or more previous tuning jobs as a starting point. The results of previous tuning jobs are used to inform which combinations of hyperparameters to search over in the new tuning job.



19768
19769
19770
19771
19772
19773
19774
19775
19776
19777
19778
19779
19780
19781
19782
19783
19784
19785
19786
19787
19788
19789
# File 'lib/aws-sdk-sagemaker/types.rb', line 19768

class DescribeHyperParameterTuningJobResponse < Struct.new(
  :hyper_parameter_tuning_job_name,
  :hyper_parameter_tuning_job_arn,
  :hyper_parameter_tuning_job_config,
  :training_job_definition,
  :training_job_definitions,
  :hyper_parameter_tuning_job_status,
  :creation_time,
  :hyper_parameter_tuning_end_time,
  :last_modified_time,
  :training_job_status_counters,
  :objective_status_counters,
  :best_training_job,
  :overall_best_training_job,
  :warm_start_config,
  :autotune,
  :failure_reason,
  :tuning_job_completion_details,
  :consumed_resources)
  SENSITIVE = []
  include Aws::Structure
end