Class: Aws::SageMaker::Types::DescribeHyperParameterTuningJobResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeHyperParameterTuningJobResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#best_training_job ⇒ Types::HyperParameterTrainingJobSummary
A TrainingJobSummary object that describes the training job that completed with the best current HyperParameterTuningJobObjective.
-
#consumed_resources ⇒ Types::HyperParameterTuningJobConsumedResources
The total resources consumed by your hyperparameter tuning job.
-
#creation_time ⇒ Time
The date and time that the tuning job started.
-
#failure_reason ⇒ String
If the tuning job failed, the reason it failed.
-
#hyper_parameter_tuning_end_time ⇒ Time
The date and time that the tuning job ended.
-
#hyper_parameter_tuning_job_arn ⇒ String
The Amazon Resource Name (ARN) of the tuning job.
-
#hyper_parameter_tuning_job_config ⇒ Types::HyperParameterTuningJobConfig
The HyperParameterTuningJobConfig object that specifies the configuration of the tuning job.
-
#hyper_parameter_tuning_job_name ⇒ String
The name of the tuning job.
-
#hyper_parameter_tuning_job_status ⇒ String
The status of the tuning job: InProgress, Completed, Failed, Stopping, or Stopped.
-
#last_modified_time ⇒ Time
The date and time that the status of the tuning job was modified.
-
#objective_status_counters ⇒ Types::ObjectiveStatusCounters
The ObjectiveStatusCounters object that specifies the number of training jobs, categorized by the status of their final objective metric, that this tuning job launched.
-
#overall_best_training_job ⇒ Types::HyperParameterTrainingJobSummary
If the hyperparameter tuning job is an warm start tuning job with a
WarmStartTypeofIDENTICAL_DATA_AND_ALGORITHM, this is the TrainingJobSummary for the training job with the best objective metric value of all training jobs launched by this tuning job and all parent jobs specified for the warm start tuning job. -
#training_job_definition ⇒ Types::HyperParameterTrainingJobDefinition
The HyperParameterTrainingJobDefinition object that specifies the definition of the training jobs that this tuning job launches.
-
#training_job_definitions ⇒ Array<Types::HyperParameterTrainingJobDefinition>
A list of the HyperParameterTrainingJobDefinition objects launched for this tuning job.
-
#training_job_status_counters ⇒ Types::TrainingJobStatusCounters
The TrainingJobStatusCounters object that specifies the number of training jobs, categorized by status, that this tuning job launched.
-
#tuning_job_completion_details ⇒ Types::HyperParameterTuningJobCompletionDetails
Tuning job completion information returned as the response from a hyperparameter tuning job.
-
#warm_start_config ⇒ Types::HyperParameterTuningJobWarmStartConfig
The configuration for starting the hyperparameter parameter tuning job using one or more previous tuning jobs as a starting point.
Instance Attribute Details
#best_training_job ⇒ Types::HyperParameterTrainingJobSummary
A TrainingJobSummary object that describes the training job that completed with the best current HyperParameterTuningJobObjective.
11894 11895 11896 11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 11894 class DescribeHyperParameterTuningJobResponse < Struct.new( :hyper_parameter_tuning_job_name, :hyper_parameter_tuning_job_arn, :hyper_parameter_tuning_job_config, :training_job_definition, :training_job_definitions, :hyper_parameter_tuning_job_status, :creation_time, :hyper_parameter_tuning_end_time, :last_modified_time, :training_job_status_counters, :objective_status_counters, :best_training_job, :overall_best_training_job, :warm_start_config, :failure_reason, :tuning_job_completion_details, :consumed_resources) SENSITIVE = [] include Aws::Structure end |
#consumed_resources ⇒ Types::HyperParameterTuningJobConsumedResources
The total resources consumed by your hyperparameter tuning job.
11894 11895 11896 11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 11894 class DescribeHyperParameterTuningJobResponse < Struct.new( :hyper_parameter_tuning_job_name, :hyper_parameter_tuning_job_arn, :hyper_parameter_tuning_job_config, :training_job_definition, :training_job_definitions, :hyper_parameter_tuning_job_status, :creation_time, :hyper_parameter_tuning_end_time, :last_modified_time, :training_job_status_counters, :objective_status_counters, :best_training_job, :overall_best_training_job, :warm_start_config, :failure_reason, :tuning_job_completion_details, :consumed_resources) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The date and time that the tuning job started.
11894 11895 11896 11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 11894 class DescribeHyperParameterTuningJobResponse < Struct.new( :hyper_parameter_tuning_job_name, :hyper_parameter_tuning_job_arn, :hyper_parameter_tuning_job_config, :training_job_definition, :training_job_definitions, :hyper_parameter_tuning_job_status, :creation_time, :hyper_parameter_tuning_end_time, :last_modified_time, :training_job_status_counters, :objective_status_counters, :best_training_job, :overall_best_training_job, :warm_start_config, :failure_reason, :tuning_job_completion_details, :consumed_resources) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
If the tuning job failed, the reason it failed.
11894 11895 11896 11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 11894 class DescribeHyperParameterTuningJobResponse < Struct.new( :hyper_parameter_tuning_job_name, :hyper_parameter_tuning_job_arn, :hyper_parameter_tuning_job_config, :training_job_definition, :training_job_definitions, :hyper_parameter_tuning_job_status, :creation_time, :hyper_parameter_tuning_end_time, :last_modified_time, :training_job_status_counters, :objective_status_counters, :best_training_job, :overall_best_training_job, :warm_start_config, :failure_reason, :tuning_job_completion_details, :consumed_resources) SENSITIVE = [] include Aws::Structure end |
#hyper_parameter_tuning_end_time ⇒ Time
The date and time that the tuning job ended.
11894 11895 11896 11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 11894 class DescribeHyperParameterTuningJobResponse < Struct.new( :hyper_parameter_tuning_job_name, :hyper_parameter_tuning_job_arn, :hyper_parameter_tuning_job_config, :training_job_definition, :training_job_definitions, :hyper_parameter_tuning_job_status, :creation_time, :hyper_parameter_tuning_end_time, :last_modified_time, :training_job_status_counters, :objective_status_counters, :best_training_job, :overall_best_training_job, :warm_start_config, :failure_reason, :tuning_job_completion_details, :consumed_resources) SENSITIVE = [] include Aws::Structure end |
#hyper_parameter_tuning_job_arn ⇒ String
The Amazon Resource Name (ARN) of the tuning job.
11894 11895 11896 11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 11894 class DescribeHyperParameterTuningJobResponse < Struct.new( :hyper_parameter_tuning_job_name, :hyper_parameter_tuning_job_arn, :hyper_parameter_tuning_job_config, :training_job_definition, :training_job_definitions, :hyper_parameter_tuning_job_status, :creation_time, :hyper_parameter_tuning_end_time, :last_modified_time, :training_job_status_counters, :objective_status_counters, :best_training_job, :overall_best_training_job, :warm_start_config, :failure_reason, :tuning_job_completion_details, :consumed_resources) SENSITIVE = [] include Aws::Structure end |
#hyper_parameter_tuning_job_config ⇒ Types::HyperParameterTuningJobConfig
The HyperParameterTuningJobConfig object that specifies the configuration of the tuning job.
11894 11895 11896 11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 11894 class DescribeHyperParameterTuningJobResponse < Struct.new( :hyper_parameter_tuning_job_name, :hyper_parameter_tuning_job_arn, :hyper_parameter_tuning_job_config, :training_job_definition, :training_job_definitions, :hyper_parameter_tuning_job_status, :creation_time, :hyper_parameter_tuning_end_time, :last_modified_time, :training_job_status_counters, :objective_status_counters, :best_training_job, :overall_best_training_job, :warm_start_config, :failure_reason, :tuning_job_completion_details, :consumed_resources) SENSITIVE = [] include Aws::Structure end |
#hyper_parameter_tuning_job_name ⇒ String
The name of the tuning job.
11894 11895 11896 11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 11894 class DescribeHyperParameterTuningJobResponse < Struct.new( :hyper_parameter_tuning_job_name, :hyper_parameter_tuning_job_arn, :hyper_parameter_tuning_job_config, :training_job_definition, :training_job_definitions, :hyper_parameter_tuning_job_status, :creation_time, :hyper_parameter_tuning_end_time, :last_modified_time, :training_job_status_counters, :objective_status_counters, :best_training_job, :overall_best_training_job, :warm_start_config, :failure_reason, :tuning_job_completion_details, :consumed_resources) SENSITIVE = [] include Aws::Structure end |
#hyper_parameter_tuning_job_status ⇒ String
The status of the tuning job: InProgress, Completed, Failed, Stopping, or Stopped.
11894 11895 11896 11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 11894 class DescribeHyperParameterTuningJobResponse < Struct.new( :hyper_parameter_tuning_job_name, :hyper_parameter_tuning_job_arn, :hyper_parameter_tuning_job_config, :training_job_definition, :training_job_definitions, :hyper_parameter_tuning_job_status, :creation_time, :hyper_parameter_tuning_end_time, :last_modified_time, :training_job_status_counters, :objective_status_counters, :best_training_job, :overall_best_training_job, :warm_start_config, :failure_reason, :tuning_job_completion_details, :consumed_resources) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The date and time that the status of the tuning job was modified.
11894 11895 11896 11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 11894 class DescribeHyperParameterTuningJobResponse < Struct.new( :hyper_parameter_tuning_job_name, :hyper_parameter_tuning_job_arn, :hyper_parameter_tuning_job_config, :training_job_definition, :training_job_definitions, :hyper_parameter_tuning_job_status, :creation_time, :hyper_parameter_tuning_end_time, :last_modified_time, :training_job_status_counters, :objective_status_counters, :best_training_job, :overall_best_training_job, :warm_start_config, :failure_reason, :tuning_job_completion_details, :consumed_resources) SENSITIVE = [] include Aws::Structure end |
#objective_status_counters ⇒ Types::ObjectiveStatusCounters
The ObjectiveStatusCounters object that specifies the number of training jobs, categorized by the status of their final objective metric, that this tuning job launched.
11894 11895 11896 11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 11894 class DescribeHyperParameterTuningJobResponse < Struct.new( :hyper_parameter_tuning_job_name, :hyper_parameter_tuning_job_arn, :hyper_parameter_tuning_job_config, :training_job_definition, :training_job_definitions, :hyper_parameter_tuning_job_status, :creation_time, :hyper_parameter_tuning_end_time, :last_modified_time, :training_job_status_counters, :objective_status_counters, :best_training_job, :overall_best_training_job, :warm_start_config, :failure_reason, :tuning_job_completion_details, :consumed_resources) SENSITIVE = [] include Aws::Structure end |
#overall_best_training_job ⇒ Types::HyperParameterTrainingJobSummary
If the hyperparameter tuning job is an warm start tuning job with a WarmStartType of IDENTICAL_DATA_AND_ALGORITHM, this is the TrainingJobSummary for the training job with the best objective metric value of all training jobs launched by this tuning job and all parent jobs specified for the warm start tuning job.
11894 11895 11896 11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 11894 class DescribeHyperParameterTuningJobResponse < Struct.new( :hyper_parameter_tuning_job_name, :hyper_parameter_tuning_job_arn, :hyper_parameter_tuning_job_config, :training_job_definition, :training_job_definitions, :hyper_parameter_tuning_job_status, :creation_time, :hyper_parameter_tuning_end_time, :last_modified_time, :training_job_status_counters, :objective_status_counters, :best_training_job, :overall_best_training_job, :warm_start_config, :failure_reason, :tuning_job_completion_details, :consumed_resources) SENSITIVE = [] include Aws::Structure end |
#training_job_definition ⇒ Types::HyperParameterTrainingJobDefinition
The HyperParameterTrainingJobDefinition object that specifies the definition of the training jobs that this tuning job launches.
11894 11895 11896 11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 11894 class DescribeHyperParameterTuningJobResponse < Struct.new( :hyper_parameter_tuning_job_name, :hyper_parameter_tuning_job_arn, :hyper_parameter_tuning_job_config, :training_job_definition, :training_job_definitions, :hyper_parameter_tuning_job_status, :creation_time, :hyper_parameter_tuning_end_time, :last_modified_time, :training_job_status_counters, :objective_status_counters, :best_training_job, :overall_best_training_job, :warm_start_config, :failure_reason, :tuning_job_completion_details, :consumed_resources) SENSITIVE = [] include Aws::Structure end |
#training_job_definitions ⇒ Array<Types::HyperParameterTrainingJobDefinition>
A list of the HyperParameterTrainingJobDefinition objects launched for this tuning job.
11894 11895 11896 11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 11894 class DescribeHyperParameterTuningJobResponse < Struct.new( :hyper_parameter_tuning_job_name, :hyper_parameter_tuning_job_arn, :hyper_parameter_tuning_job_config, :training_job_definition, :training_job_definitions, :hyper_parameter_tuning_job_status, :creation_time, :hyper_parameter_tuning_end_time, :last_modified_time, :training_job_status_counters, :objective_status_counters, :best_training_job, :overall_best_training_job, :warm_start_config, :failure_reason, :tuning_job_completion_details, :consumed_resources) SENSITIVE = [] include Aws::Structure end |
#training_job_status_counters ⇒ Types::TrainingJobStatusCounters
The TrainingJobStatusCounters object that specifies the number of training jobs, categorized by status, that this tuning job launched.
11894 11895 11896 11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 11894 class DescribeHyperParameterTuningJobResponse < Struct.new( :hyper_parameter_tuning_job_name, :hyper_parameter_tuning_job_arn, :hyper_parameter_tuning_job_config, :training_job_definition, :training_job_definitions, :hyper_parameter_tuning_job_status, :creation_time, :hyper_parameter_tuning_end_time, :last_modified_time, :training_job_status_counters, :objective_status_counters, :best_training_job, :overall_best_training_job, :warm_start_config, :failure_reason, :tuning_job_completion_details, :consumed_resources) SENSITIVE = [] include Aws::Structure end |
#tuning_job_completion_details ⇒ Types::HyperParameterTuningJobCompletionDetails
Tuning job completion information returned as the response from a hyperparameter tuning job. This information tells if your tuning job has or has not converged. It also includes the number of training jobs that have not improved model performance as evaluated against the objective function.
11894 11895 11896 11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 11894 class DescribeHyperParameterTuningJobResponse < Struct.new( :hyper_parameter_tuning_job_name, :hyper_parameter_tuning_job_arn, :hyper_parameter_tuning_job_config, :training_job_definition, :training_job_definitions, :hyper_parameter_tuning_job_status, :creation_time, :hyper_parameter_tuning_end_time, :last_modified_time, :training_job_status_counters, :objective_status_counters, :best_training_job, :overall_best_training_job, :warm_start_config, :failure_reason, :tuning_job_completion_details, :consumed_resources) SENSITIVE = [] include Aws::Structure end |
#warm_start_config ⇒ Types::HyperParameterTuningJobWarmStartConfig
The configuration for starting the hyperparameter parameter tuning job using one or more previous tuning jobs as a starting point. The results of previous tuning jobs are used to inform which combinations of hyperparameters to search over in the new tuning job.
11894 11895 11896 11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 11894 class DescribeHyperParameterTuningJobResponse < Struct.new( :hyper_parameter_tuning_job_name, :hyper_parameter_tuning_job_arn, :hyper_parameter_tuning_job_config, :training_job_definition, :training_job_definitions, :hyper_parameter_tuning_job_status, :creation_time, :hyper_parameter_tuning_end_time, :last_modified_time, :training_job_status_counters, :objective_status_counters, :best_training_job, :overall_best_training_job, :warm_start_config, :failure_reason, :tuning_job_completion_details, :consumed_resources) SENSITIVE = [] include Aws::Structure end |