Class: Aws::SageMaker::Types::DescribeImageResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeImageResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Time
When the image was created.
-
#description ⇒ String
The description of the image.
-
#display_name ⇒ String
The name of the image as displayed.
-
#failure_reason ⇒ String
When a create, update, or delete operation fails, the reason for the failure.
-
#image_arn ⇒ String
The ARN of the image.
-
#image_name ⇒ String
The name of the image.
-
#image_status ⇒ String
The status of the image.
-
#last_modified_time ⇒ Time
When the image was last modified.
-
#role_arn ⇒ String
The ARN of the IAM role that enables Amazon SageMaker AI to perform tasks on your behalf.
Instance Attribute Details
#creation_time ⇒ Time
When the image was created.
20342 20343 20344 20345 20346 20347 20348 20349 20350 20351 20352 20353 20354 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20342 class DescribeImageResponse < Struct.new( :creation_time, :description, :display_name, :failure_reason, :image_arn, :image_name, :image_status, :last_modified_time, :role_arn) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the image.
20342 20343 20344 20345 20346 20347 20348 20349 20350 20351 20352 20353 20354 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20342 class DescribeImageResponse < Struct.new( :creation_time, :description, :display_name, :failure_reason, :image_arn, :image_name, :image_status, :last_modified_time, :role_arn) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The name of the image as displayed.
20342 20343 20344 20345 20346 20347 20348 20349 20350 20351 20352 20353 20354 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20342 class DescribeImageResponse < Struct.new( :creation_time, :description, :display_name, :failure_reason, :image_arn, :image_name, :image_status, :last_modified_time, :role_arn) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
When a create, update, or delete operation fails, the reason for the failure.
20342 20343 20344 20345 20346 20347 20348 20349 20350 20351 20352 20353 20354 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20342 class DescribeImageResponse < Struct.new( :creation_time, :description, :display_name, :failure_reason, :image_arn, :image_name, :image_status, :last_modified_time, :role_arn) SENSITIVE = [] include Aws::Structure end |
#image_arn ⇒ String
The ARN of the image.
20342 20343 20344 20345 20346 20347 20348 20349 20350 20351 20352 20353 20354 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20342 class DescribeImageResponse < Struct.new( :creation_time, :description, :display_name, :failure_reason, :image_arn, :image_name, :image_status, :last_modified_time, :role_arn) SENSITIVE = [] include Aws::Structure end |
#image_name ⇒ String
The name of the image.
20342 20343 20344 20345 20346 20347 20348 20349 20350 20351 20352 20353 20354 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20342 class DescribeImageResponse < Struct.new( :creation_time, :description, :display_name, :failure_reason, :image_arn, :image_name, :image_status, :last_modified_time, :role_arn) SENSITIVE = [] include Aws::Structure end |
#image_status ⇒ String
The status of the image.
20342 20343 20344 20345 20346 20347 20348 20349 20350 20351 20352 20353 20354 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20342 class DescribeImageResponse < Struct.new( :creation_time, :description, :display_name, :failure_reason, :image_arn, :image_name, :image_status, :last_modified_time, :role_arn) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
When the image was last modified.
20342 20343 20344 20345 20346 20347 20348 20349 20350 20351 20352 20353 20354 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20342 class DescribeImageResponse < Struct.new( :creation_time, :description, :display_name, :failure_reason, :image_arn, :image_name, :image_status, :last_modified_time, :role_arn) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The ARN of the IAM role that enables Amazon SageMaker AI to perform tasks on your behalf.
20342 20343 20344 20345 20346 20347 20348 20349 20350 20351 20352 20353 20354 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20342 class DescribeImageResponse < Struct.new( :creation_time, :description, :display_name, :failure_reason, :image_arn, :image_name, :image_status, :last_modified_time, :role_arn) SENSITIVE = [] include Aws::Structure end |