Class: Aws::SageMaker::Types::DescribeImageVersionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeImageVersionResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#base_image ⇒ String
The registry path of the container image on which this image version is based.
-
#container_image ⇒ String
The registry path of the container image that contains this image version.
-
#creation_time ⇒ Time
When the version was created.
-
#failure_reason ⇒ String
When a create or delete operation fails, the reason for the failure.
-
#horovod ⇒ Boolean
Indicates Horovod compatibility.
-
#image_arn ⇒ String
The ARN of the image the version is based on.
-
#image_version_arn ⇒ String
The ARN of the version.
-
#image_version_status ⇒ String
The status of the version.
-
#job_type ⇒ String
Indicates SageMaker AI job type compatibility.
-
#last_modified_time ⇒ Time
When the version was last modified.
-
#ml_framework ⇒ String
The machine learning framework vended in the image version.
-
#processor ⇒ String
Indicates CPU or GPU compatibility.
-
#programming_lang ⇒ String
The supported programming language and its version.
-
#release_notes ⇒ String
The maintainer description of the image version.
-
#vendor_guidance ⇒ String
The stability of the image version specified by the maintainer.
-
#version ⇒ Integer
The version number.
Instance Attribute Details
#base_image ⇒ String
The registry path of the container image on which this image version is based.
18596 18597 18598 18599 18600 18601 18602 18603 18604 18605 18606 18607 18608 18609 18610 18611 18612 18613 18614 18615 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18596 class DescribeImageVersionResponse < Struct.new( :base_image, :container_image, :creation_time, :failure_reason, :image_arn, :image_version_arn, :image_version_status, :last_modified_time, :version, :vendor_guidance, :job_type, :ml_framework, :programming_lang, :processor, :horovod, :release_notes) SENSITIVE = [] include Aws::Structure end |
#container_image ⇒ String
The registry path of the container image that contains this image version.
18596 18597 18598 18599 18600 18601 18602 18603 18604 18605 18606 18607 18608 18609 18610 18611 18612 18613 18614 18615 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18596 class DescribeImageVersionResponse < Struct.new( :base_image, :container_image, :creation_time, :failure_reason, :image_arn, :image_version_arn, :image_version_status, :last_modified_time, :version, :vendor_guidance, :job_type, :ml_framework, :programming_lang, :processor, :horovod, :release_notes) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
When the version was created.
18596 18597 18598 18599 18600 18601 18602 18603 18604 18605 18606 18607 18608 18609 18610 18611 18612 18613 18614 18615 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18596 class DescribeImageVersionResponse < Struct.new( :base_image, :container_image, :creation_time, :failure_reason, :image_arn, :image_version_arn, :image_version_status, :last_modified_time, :version, :vendor_guidance, :job_type, :ml_framework, :programming_lang, :processor, :horovod, :release_notes) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
When a create or delete operation fails, the reason for the failure.
18596 18597 18598 18599 18600 18601 18602 18603 18604 18605 18606 18607 18608 18609 18610 18611 18612 18613 18614 18615 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18596 class DescribeImageVersionResponse < Struct.new( :base_image, :container_image, :creation_time, :failure_reason, :image_arn, :image_version_arn, :image_version_status, :last_modified_time, :version, :vendor_guidance, :job_type, :ml_framework, :programming_lang, :processor, :horovod, :release_notes) SENSITIVE = [] include Aws::Structure end |
#horovod ⇒ Boolean
Indicates Horovod compatibility.
18596 18597 18598 18599 18600 18601 18602 18603 18604 18605 18606 18607 18608 18609 18610 18611 18612 18613 18614 18615 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18596 class DescribeImageVersionResponse < Struct.new( :base_image, :container_image, :creation_time, :failure_reason, :image_arn, :image_version_arn, :image_version_status, :last_modified_time, :version, :vendor_guidance, :job_type, :ml_framework, :programming_lang, :processor, :horovod, :release_notes) SENSITIVE = [] include Aws::Structure end |
#image_arn ⇒ String
The ARN of the image the version is based on.
18596 18597 18598 18599 18600 18601 18602 18603 18604 18605 18606 18607 18608 18609 18610 18611 18612 18613 18614 18615 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18596 class DescribeImageVersionResponse < Struct.new( :base_image, :container_image, :creation_time, :failure_reason, :image_arn, :image_version_arn, :image_version_status, :last_modified_time, :version, :vendor_guidance, :job_type, :ml_framework, :programming_lang, :processor, :horovod, :release_notes) SENSITIVE = [] include Aws::Structure end |
#image_version_arn ⇒ String
The ARN of the version.
18596 18597 18598 18599 18600 18601 18602 18603 18604 18605 18606 18607 18608 18609 18610 18611 18612 18613 18614 18615 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18596 class DescribeImageVersionResponse < Struct.new( :base_image, :container_image, :creation_time, :failure_reason, :image_arn, :image_version_arn, :image_version_status, :last_modified_time, :version, :vendor_guidance, :job_type, :ml_framework, :programming_lang, :processor, :horovod, :release_notes) SENSITIVE = [] include Aws::Structure end |
#image_version_status ⇒ String
The status of the version.
18596 18597 18598 18599 18600 18601 18602 18603 18604 18605 18606 18607 18608 18609 18610 18611 18612 18613 18614 18615 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18596 class DescribeImageVersionResponse < Struct.new( :base_image, :container_image, :creation_time, :failure_reason, :image_arn, :image_version_arn, :image_version_status, :last_modified_time, :version, :vendor_guidance, :job_type, :ml_framework, :programming_lang, :processor, :horovod, :release_notes) SENSITIVE = [] include Aws::Structure end |
#job_type ⇒ String
Indicates SageMaker AI job type compatibility.
-
TRAINING: The image version is compatible with SageMaker AI training jobs. -
INFERENCE: The image version is compatible with SageMaker AI inference jobs. -
NOTEBOOK_KERNEL: The image version is compatible with SageMaker AI notebook kernels.
18596 18597 18598 18599 18600 18601 18602 18603 18604 18605 18606 18607 18608 18609 18610 18611 18612 18613 18614 18615 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18596 class DescribeImageVersionResponse < Struct.new( :base_image, :container_image, :creation_time, :failure_reason, :image_arn, :image_version_arn, :image_version_status, :last_modified_time, :version, :vendor_guidance, :job_type, :ml_framework, :programming_lang, :processor, :horovod, :release_notes) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
When the version was last modified.
18596 18597 18598 18599 18600 18601 18602 18603 18604 18605 18606 18607 18608 18609 18610 18611 18612 18613 18614 18615 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18596 class DescribeImageVersionResponse < Struct.new( :base_image, :container_image, :creation_time, :failure_reason, :image_arn, :image_version_arn, :image_version_status, :last_modified_time, :version, :vendor_guidance, :job_type, :ml_framework, :programming_lang, :processor, :horovod, :release_notes) SENSITIVE = [] include Aws::Structure end |
#ml_framework ⇒ String
The machine learning framework vended in the image version.
18596 18597 18598 18599 18600 18601 18602 18603 18604 18605 18606 18607 18608 18609 18610 18611 18612 18613 18614 18615 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18596 class DescribeImageVersionResponse < Struct.new( :base_image, :container_image, :creation_time, :failure_reason, :image_arn, :image_version_arn, :image_version_status, :last_modified_time, :version, :vendor_guidance, :job_type, :ml_framework, :programming_lang, :processor, :horovod, :release_notes) SENSITIVE = [] include Aws::Structure end |
#processor ⇒ String
Indicates CPU or GPU compatibility.
-
CPU: The image version is compatible with CPU. -
GPU: The image version is compatible with GPU.
18596 18597 18598 18599 18600 18601 18602 18603 18604 18605 18606 18607 18608 18609 18610 18611 18612 18613 18614 18615 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18596 class DescribeImageVersionResponse < Struct.new( :base_image, :container_image, :creation_time, :failure_reason, :image_arn, :image_version_arn, :image_version_status, :last_modified_time, :version, :vendor_guidance, :job_type, :ml_framework, :programming_lang, :processor, :horovod, :release_notes) SENSITIVE = [] include Aws::Structure end |
#programming_lang ⇒ String
The supported programming language and its version.
18596 18597 18598 18599 18600 18601 18602 18603 18604 18605 18606 18607 18608 18609 18610 18611 18612 18613 18614 18615 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18596 class DescribeImageVersionResponse < Struct.new( :base_image, :container_image, :creation_time, :failure_reason, :image_arn, :image_version_arn, :image_version_status, :last_modified_time, :version, :vendor_guidance, :job_type, :ml_framework, :programming_lang, :processor, :horovod, :release_notes) SENSITIVE = [] include Aws::Structure end |
#release_notes ⇒ String
The maintainer description of the image version.
18596 18597 18598 18599 18600 18601 18602 18603 18604 18605 18606 18607 18608 18609 18610 18611 18612 18613 18614 18615 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18596 class DescribeImageVersionResponse < Struct.new( :base_image, :container_image, :creation_time, :failure_reason, :image_arn, :image_version_arn, :image_version_status, :last_modified_time, :version, :vendor_guidance, :job_type, :ml_framework, :programming_lang, :processor, :horovod, :release_notes) SENSITIVE = [] include Aws::Structure end |
#vendor_guidance ⇒ String
The stability of the image version specified by the maintainer.
-
NOT_PROVIDED: The maintainers did not provide a status for image version stability. -
STABLE: The image version is stable. -
TO_BE_ARCHIVED: The image version is set to be archived. Custom image versions that are set to be archived are automatically archived after three months. -
ARCHIVED: The image version is archived. Archived image versions are not searchable and are no longer actively supported.
18596 18597 18598 18599 18600 18601 18602 18603 18604 18605 18606 18607 18608 18609 18610 18611 18612 18613 18614 18615 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18596 class DescribeImageVersionResponse < Struct.new( :base_image, :container_image, :creation_time, :failure_reason, :image_arn, :image_version_arn, :image_version_status, :last_modified_time, :version, :vendor_guidance, :job_type, :ml_framework, :programming_lang, :processor, :horovod, :release_notes) SENSITIVE = [] include Aws::Structure end |
#version ⇒ Integer
The version number.
18596 18597 18598 18599 18600 18601 18602 18603 18604 18605 18606 18607 18608 18609 18610 18611 18612 18613 18614 18615 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18596 class DescribeImageVersionResponse < Struct.new( :base_image, :container_image, :creation_time, :failure_reason, :image_arn, :image_version_arn, :image_version_status, :last_modified_time, :version, :vendor_guidance, :job_type, :ml_framework, :programming_lang, :processor, :horovod, :release_notes) SENSITIVE = [] include Aws::Structure end |