Class: Aws::SageMaker::Types::DescribeInferenceComponentOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeInferenceComponentOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Time
The time when the inference component was created.
-
#endpoint_arn ⇒ String
The Amazon Resource Name (ARN) of the endpoint that hosts the inference component.
-
#endpoint_name ⇒ String
The name of the endpoint that hosts the inference component.
-
#failure_reason ⇒ String
If the inference component status is ‘Failed`, the reason for the failure.
-
#inference_component_arn ⇒ String
The Amazon Resource Name (ARN) of the inference component.
-
#inference_component_name ⇒ String
The name of the inference component.
-
#inference_component_status ⇒ String
The status of the inference component.
-
#last_deployment_config ⇒ Types::InferenceComponentDeploymentConfig
The deployment and rollback settings that you assigned to the inference component.
-
#last_modified_time ⇒ Time
The time when the inference component was last updated.
-
#runtime_config ⇒ Types::InferenceComponentRuntimeConfigSummary
Details about the runtime settings for the model that is deployed with the inference component.
-
#specification ⇒ Types::InferenceComponentSpecificationSummary
Details about the resources that are deployed with this inference component.
-
#specifications ⇒ Array<Types::InferenceComponentSpecificationSummary>
A list of specification summaries for the inference component, one per instance type.
-
#variant_name ⇒ String
The name of the production variant that hosts the inference component.
Instance Attribute Details
#creation_time ⇒ Time
The time when the inference component was created.
20079 20080 20081 20082 20083 20084 20085 20086 20087 20088 20089 20090 20091 20092 20093 20094 20095 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20079 class DescribeInferenceComponentOutput < Struct.new( :inference_component_name, :inference_component_arn, :endpoint_name, :endpoint_arn, :variant_name, :failure_reason, :specification, :specifications, :runtime_config, :creation_time, :last_modified_time, :inference_component_status, :last_deployment_config) SENSITIVE = [] include Aws::Structure end |
#endpoint_arn ⇒ String
The Amazon Resource Name (ARN) of the endpoint that hosts the inference component.
20079 20080 20081 20082 20083 20084 20085 20086 20087 20088 20089 20090 20091 20092 20093 20094 20095 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20079 class DescribeInferenceComponentOutput < Struct.new( :inference_component_name, :inference_component_arn, :endpoint_name, :endpoint_arn, :variant_name, :failure_reason, :specification, :specifications, :runtime_config, :creation_time, :last_modified_time, :inference_component_status, :last_deployment_config) SENSITIVE = [] include Aws::Structure end |
#endpoint_name ⇒ String
The name of the endpoint that hosts the inference component.
20079 20080 20081 20082 20083 20084 20085 20086 20087 20088 20089 20090 20091 20092 20093 20094 20095 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20079 class DescribeInferenceComponentOutput < Struct.new( :inference_component_name, :inference_component_arn, :endpoint_name, :endpoint_arn, :variant_name, :failure_reason, :specification, :specifications, :runtime_config, :creation_time, :last_modified_time, :inference_component_status, :last_deployment_config) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
If the inference component status is ‘Failed`, the reason for the failure.
20079 20080 20081 20082 20083 20084 20085 20086 20087 20088 20089 20090 20091 20092 20093 20094 20095 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20079 class DescribeInferenceComponentOutput < Struct.new( :inference_component_name, :inference_component_arn, :endpoint_name, :endpoint_arn, :variant_name, :failure_reason, :specification, :specifications, :runtime_config, :creation_time, :last_modified_time, :inference_component_status, :last_deployment_config) SENSITIVE = [] include Aws::Structure end |
#inference_component_arn ⇒ String
The Amazon Resource Name (ARN) of the inference component.
20079 20080 20081 20082 20083 20084 20085 20086 20087 20088 20089 20090 20091 20092 20093 20094 20095 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20079 class DescribeInferenceComponentOutput < Struct.new( :inference_component_name, :inference_component_arn, :endpoint_name, :endpoint_arn, :variant_name, :failure_reason, :specification, :specifications, :runtime_config, :creation_time, :last_modified_time, :inference_component_status, :last_deployment_config) SENSITIVE = [] include Aws::Structure end |
#inference_component_name ⇒ String
The name of the inference component.
20079 20080 20081 20082 20083 20084 20085 20086 20087 20088 20089 20090 20091 20092 20093 20094 20095 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20079 class DescribeInferenceComponentOutput < Struct.new( :inference_component_name, :inference_component_arn, :endpoint_name, :endpoint_arn, :variant_name, :failure_reason, :specification, :specifications, :runtime_config, :creation_time, :last_modified_time, :inference_component_status, :last_deployment_config) SENSITIVE = [] include Aws::Structure end |
#inference_component_status ⇒ String
The status of the inference component.
20079 20080 20081 20082 20083 20084 20085 20086 20087 20088 20089 20090 20091 20092 20093 20094 20095 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20079 class DescribeInferenceComponentOutput < Struct.new( :inference_component_name, :inference_component_arn, :endpoint_name, :endpoint_arn, :variant_name, :failure_reason, :specification, :specifications, :runtime_config, :creation_time, :last_modified_time, :inference_component_status, :last_deployment_config) SENSITIVE = [] include Aws::Structure end |
#last_deployment_config ⇒ Types::InferenceComponentDeploymentConfig
The deployment and rollback settings that you assigned to the inference component.
20079 20080 20081 20082 20083 20084 20085 20086 20087 20088 20089 20090 20091 20092 20093 20094 20095 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20079 class DescribeInferenceComponentOutput < Struct.new( :inference_component_name, :inference_component_arn, :endpoint_name, :endpoint_arn, :variant_name, :failure_reason, :specification, :specifications, :runtime_config, :creation_time, :last_modified_time, :inference_component_status, :last_deployment_config) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The time when the inference component was last updated.
20079 20080 20081 20082 20083 20084 20085 20086 20087 20088 20089 20090 20091 20092 20093 20094 20095 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20079 class DescribeInferenceComponentOutput < Struct.new( :inference_component_name, :inference_component_arn, :endpoint_name, :endpoint_arn, :variant_name, :failure_reason, :specification, :specifications, :runtime_config, :creation_time, :last_modified_time, :inference_component_status, :last_deployment_config) SENSITIVE = [] include Aws::Structure end |
#runtime_config ⇒ Types::InferenceComponentRuntimeConfigSummary
Details about the runtime settings for the model that is deployed with the inference component.
20079 20080 20081 20082 20083 20084 20085 20086 20087 20088 20089 20090 20091 20092 20093 20094 20095 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20079 class DescribeInferenceComponentOutput < Struct.new( :inference_component_name, :inference_component_arn, :endpoint_name, :endpoint_arn, :variant_name, :failure_reason, :specification, :specifications, :runtime_config, :creation_time, :last_modified_time, :inference_component_status, :last_deployment_config) SENSITIVE = [] include Aws::Structure end |
#specification ⇒ Types::InferenceComponentSpecificationSummary
Details about the resources that are deployed with this inference component.
20079 20080 20081 20082 20083 20084 20085 20086 20087 20088 20089 20090 20091 20092 20093 20094 20095 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20079 class DescribeInferenceComponentOutput < Struct.new( :inference_component_name, :inference_component_arn, :endpoint_name, :endpoint_arn, :variant_name, :failure_reason, :specification, :specifications, :runtime_config, :creation_time, :last_modified_time, :inference_component_status, :last_deployment_config) SENSITIVE = [] include Aws::Structure end |
#specifications ⇒ Array<Types::InferenceComponentSpecificationSummary>
A list of specification summaries for the inference component, one per instance type. This parameter is populated when the inference component was created with multiple specifications. When this parameter is populated, the singular ‘Specification` parameter is not returned.
20079 20080 20081 20082 20083 20084 20085 20086 20087 20088 20089 20090 20091 20092 20093 20094 20095 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20079 class DescribeInferenceComponentOutput < Struct.new( :inference_component_name, :inference_component_arn, :endpoint_name, :endpoint_arn, :variant_name, :failure_reason, :specification, :specifications, :runtime_config, :creation_time, :last_modified_time, :inference_component_status, :last_deployment_config) SENSITIVE = [] include Aws::Structure end |
#variant_name ⇒ String
The name of the production variant that hosts the inference component.
20079 20080 20081 20082 20083 20084 20085 20086 20087 20088 20089 20090 20091 20092 20093 20094 20095 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20079 class DescribeInferenceComponentOutput < Struct.new( :inference_component_name, :inference_component_arn, :endpoint_name, :endpoint_arn, :variant_name, :failure_reason, :specification, :specifications, :runtime_config, :creation_time, :last_modified_time, :inference_component_status, :last_deployment_config) SENSITIVE = [] include Aws::Structure end |