Class: Aws::SageMaker::Types::DescribeInferenceComponentOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timeTime

The time when the inference component was created.

Returns:



14173
14174
14175
14176
14177
14178
14179
14180
14181
14182
14183
14184
14185
14186
14187
# File 'lib/aws-sdk-sagemaker/types.rb', line 14173

class DescribeInferenceComponentOutput < Struct.new(
  :inference_component_name,
  :inference_component_arn,
  :endpoint_name,
  :endpoint_arn,
  :variant_name,
  :failure_reason,
  :specification,
  :runtime_config,
  :creation_time,
  :last_modified_time,
  :inference_component_status)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_arnString

The Amazon Resource Name (ARN) of the endpoint that hosts the inference component.

Returns:



14173
14174
14175
14176
14177
14178
14179
14180
14181
14182
14183
14184
14185
14186
14187
# File 'lib/aws-sdk-sagemaker/types.rb', line 14173

class DescribeInferenceComponentOutput < Struct.new(
  :inference_component_name,
  :inference_component_arn,
  :endpoint_name,
  :endpoint_arn,
  :variant_name,
  :failure_reason,
  :specification,
  :runtime_config,
  :creation_time,
  :last_modified_time,
  :inference_component_status)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_nameString

The name of the endpoint that hosts the inference component.

Returns:



14173
14174
14175
14176
14177
14178
14179
14180
14181
14182
14183
14184
14185
14186
14187
# File 'lib/aws-sdk-sagemaker/types.rb', line 14173

class DescribeInferenceComponentOutput < Struct.new(
  :inference_component_name,
  :inference_component_arn,
  :endpoint_name,
  :endpoint_arn,
  :variant_name,
  :failure_reason,
  :specification,
  :runtime_config,
  :creation_time,
  :last_modified_time,
  :inference_component_status)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

If the inference component status is Failed, the reason for the failure.

Returns:



14173
14174
14175
14176
14177
14178
14179
14180
14181
14182
14183
14184
14185
14186
14187
# File 'lib/aws-sdk-sagemaker/types.rb', line 14173

class DescribeInferenceComponentOutput < Struct.new(
  :inference_component_name,
  :inference_component_arn,
  :endpoint_name,
  :endpoint_arn,
  :variant_name,
  :failure_reason,
  :specification,
  :runtime_config,
  :creation_time,
  :last_modified_time,
  :inference_component_status)
  SENSITIVE = []
  include Aws::Structure
end

#inference_component_arnString

The Amazon Resource Name (ARN) of the inference component.

Returns:



14173
14174
14175
14176
14177
14178
14179
14180
14181
14182
14183
14184
14185
14186
14187
# File 'lib/aws-sdk-sagemaker/types.rb', line 14173

class DescribeInferenceComponentOutput < Struct.new(
  :inference_component_name,
  :inference_component_arn,
  :endpoint_name,
  :endpoint_arn,
  :variant_name,
  :failure_reason,
  :specification,
  :runtime_config,
  :creation_time,
  :last_modified_time,
  :inference_component_status)
  SENSITIVE = []
  include Aws::Structure
end

#inference_component_nameString

The name of the inference component.

Returns:



14173
14174
14175
14176
14177
14178
14179
14180
14181
14182
14183
14184
14185
14186
14187
# File 'lib/aws-sdk-sagemaker/types.rb', line 14173

class DescribeInferenceComponentOutput < Struct.new(
  :inference_component_name,
  :inference_component_arn,
  :endpoint_name,
  :endpoint_arn,
  :variant_name,
  :failure_reason,
  :specification,
  :runtime_config,
  :creation_time,
  :last_modified_time,
  :inference_component_status)
  SENSITIVE = []
  include Aws::Structure
end

#inference_component_statusString

The status of the inference component.

Returns:



14173
14174
14175
14176
14177
14178
14179
14180
14181
14182
14183
14184
14185
14186
14187
# File 'lib/aws-sdk-sagemaker/types.rb', line 14173

class DescribeInferenceComponentOutput < Struct.new(
  :inference_component_name,
  :inference_component_arn,
  :endpoint_name,
  :endpoint_arn,
  :variant_name,
  :failure_reason,
  :specification,
  :runtime_config,
  :creation_time,
  :last_modified_time,
  :inference_component_status)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The time when the inference component was last updated.

Returns:



14173
14174
14175
14176
14177
14178
14179
14180
14181
14182
14183
14184
14185
14186
14187
# File 'lib/aws-sdk-sagemaker/types.rb', line 14173

class DescribeInferenceComponentOutput < Struct.new(
  :inference_component_name,
  :inference_component_arn,
  :endpoint_name,
  :endpoint_arn,
  :variant_name,
  :failure_reason,
  :specification,
  :runtime_config,
  :creation_time,
  :last_modified_time,
  :inference_component_status)
  SENSITIVE = []
  include Aws::Structure
end

#runtime_configTypes::InferenceComponentRuntimeConfigSummary

Details about the runtime settings for the model that is deployed with the inference component.

Returns:



14173
14174
14175
14176
14177
14178
14179
14180
14181
14182
14183
14184
14185
14186
14187
# File 'lib/aws-sdk-sagemaker/types.rb', line 14173

class DescribeInferenceComponentOutput < Struct.new(
  :inference_component_name,
  :inference_component_arn,
  :endpoint_name,
  :endpoint_arn,
  :variant_name,
  :failure_reason,
  :specification,
  :runtime_config,
  :creation_time,
  :last_modified_time,
  :inference_component_status)
  SENSITIVE = []
  include Aws::Structure
end

#specificationTypes::InferenceComponentSpecificationSummary

Details about the resources that are deployed with this inference component.

Returns:



14173
14174
14175
14176
14177
14178
14179
14180
14181
14182
14183
14184
14185
14186
14187
# File 'lib/aws-sdk-sagemaker/types.rb', line 14173

class DescribeInferenceComponentOutput < Struct.new(
  :inference_component_name,
  :inference_component_arn,
  :endpoint_name,
  :endpoint_arn,
  :variant_name,
  :failure_reason,
  :specification,
  :runtime_config,
  :creation_time,
  :last_modified_time,
  :inference_component_status)
  SENSITIVE = []
  include Aws::Structure
end

#variant_nameString

The name of the production variant that hosts the inference component.

Returns:



14173
14174
14175
14176
14177
14178
14179
14180
14181
14182
14183
14184
14185
14186
14187
# File 'lib/aws-sdk-sagemaker/types.rb', line 14173

class DescribeInferenceComponentOutput < Struct.new(
  :inference_component_name,
  :inference_component_arn,
  :endpoint_name,
  :endpoint_arn,
  :variant_name,
  :failure_reason,
  :specification,
  :runtime_config,
  :creation_time,
  :last_modified_time,
  :inference_component_status)
  SENSITIVE = []
  include Aws::Structure
end