Class: Aws::SageMaker::Types::DescribeInferenceRecommendationsJobResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#completion_timeTime

A timestamp that shows when the job completed.

Returns:

  • (Time)


20787
20788
20789
20790
20791
20792
20793
20794
20795
20796
20797
20798
20799
20800
20801
20802
20803
20804
# File 'lib/aws-sdk-sagemaker/types.rb', line 20787

class DescribeInferenceRecommendationsJobResponse < Struct.new(
  :job_name,
  :job_description,
  :job_type,
  :job_arn,
  :role_arn,
  :status,
  :creation_time,
  :completion_time,
  :last_modified_time,
  :failure_reason,
  :input_config,
  :stopping_conditions,
  :inference_recommendations,
  :endpoint_performances)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

A timestamp that shows when the job was created.

Returns:

  • (Time)


20787
20788
20789
20790
20791
20792
20793
20794
20795
20796
20797
20798
20799
20800
20801
20802
20803
20804
# File 'lib/aws-sdk-sagemaker/types.rb', line 20787

class DescribeInferenceRecommendationsJobResponse < Struct.new(
  :job_name,
  :job_description,
  :job_type,
  :job_arn,
  :role_arn,
  :status,
  :creation_time,
  :completion_time,
  :last_modified_time,
  :failure_reason,
  :input_config,
  :stopping_conditions,
  :inference_recommendations,
  :endpoint_performances)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_performancesArray<Types::EndpointPerformance>

The performance results from running an Inference Recommender job on an existing endpoint.

Returns:



20787
20788
20789
20790
20791
20792
20793
20794
20795
20796
20797
20798
20799
20800
20801
20802
20803
20804
# File 'lib/aws-sdk-sagemaker/types.rb', line 20787

class DescribeInferenceRecommendationsJobResponse < Struct.new(
  :job_name,
  :job_description,
  :job_type,
  :job_arn,
  :role_arn,
  :status,
  :creation_time,
  :completion_time,
  :last_modified_time,
  :failure_reason,
  :input_config,
  :stopping_conditions,
  :inference_recommendations,
  :endpoint_performances)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

If the job fails, provides information why the job failed.

Returns:

  • (String)


20787
20788
20789
20790
20791
20792
20793
20794
20795
20796
20797
20798
20799
20800
20801
20802
20803
20804
# File 'lib/aws-sdk-sagemaker/types.rb', line 20787

class DescribeInferenceRecommendationsJobResponse < Struct.new(
  :job_name,
  :job_description,
  :job_type,
  :job_arn,
  :role_arn,
  :status,
  :creation_time,
  :completion_time,
  :last_modified_time,
  :failure_reason,
  :input_config,
  :stopping_conditions,
  :inference_recommendations,
  :endpoint_performances)
  SENSITIVE = []
  include Aws::Structure
end

#inference_recommendationsArray<Types::InferenceRecommendation>

The recommendations made by Inference Recommender.

Returns:



20787
20788
20789
20790
20791
20792
20793
20794
20795
20796
20797
20798
20799
20800
20801
20802
20803
20804
# File 'lib/aws-sdk-sagemaker/types.rb', line 20787

class DescribeInferenceRecommendationsJobResponse < Struct.new(
  :job_name,
  :job_description,
  :job_type,
  :job_arn,
  :role_arn,
  :status,
  :creation_time,
  :completion_time,
  :last_modified_time,
  :failure_reason,
  :input_config,
  :stopping_conditions,
  :inference_recommendations,
  :endpoint_performances)
  SENSITIVE = []
  include Aws::Structure
end

#input_configTypes::RecommendationJobInputConfig

Returns information about the versioned model package Amazon Resource Name (ARN), the traffic pattern, and endpoint configurations you provided when you initiated the job.



20787
20788
20789
20790
20791
20792
20793
20794
20795
20796
20797
20798
20799
20800
20801
20802
20803
20804
# File 'lib/aws-sdk-sagemaker/types.rb', line 20787

class DescribeInferenceRecommendationsJobResponse < Struct.new(
  :job_name,
  :job_description,
  :job_type,
  :job_arn,
  :role_arn,
  :status,
  :creation_time,
  :completion_time,
  :last_modified_time,
  :failure_reason,
  :input_config,
  :stopping_conditions,
  :inference_recommendations,
  :endpoint_performances)
  SENSITIVE = []
  include Aws::Structure
end

#job_arnString

The Amazon Resource Name (ARN) of the job.

Returns:

  • (String)


20787
20788
20789
20790
20791
20792
20793
20794
20795
20796
20797
20798
20799
20800
20801
20802
20803
20804
# File 'lib/aws-sdk-sagemaker/types.rb', line 20787

class DescribeInferenceRecommendationsJobResponse < Struct.new(
  :job_name,
  :job_description,
  :job_type,
  :job_arn,
  :role_arn,
  :status,
  :creation_time,
  :completion_time,
  :last_modified_time,
  :failure_reason,
  :input_config,
  :stopping_conditions,
  :inference_recommendations,
  :endpoint_performances)
  SENSITIVE = []
  include Aws::Structure
end

#job_descriptionString

The job description that you provided when you initiated the job.

Returns:

  • (String)


20787
20788
20789
20790
20791
20792
20793
20794
20795
20796
20797
20798
20799
20800
20801
20802
20803
20804
# File 'lib/aws-sdk-sagemaker/types.rb', line 20787

class DescribeInferenceRecommendationsJobResponse < Struct.new(
  :job_name,
  :job_description,
  :job_type,
  :job_arn,
  :role_arn,
  :status,
  :creation_time,
  :completion_time,
  :last_modified_time,
  :failure_reason,
  :input_config,
  :stopping_conditions,
  :inference_recommendations,
  :endpoint_performances)
  SENSITIVE = []
  include Aws::Structure
end

#job_nameString

The name of the job. The name must be unique within an Amazon Web Services Region in the Amazon Web Services account.

Returns:

  • (String)


20787
20788
20789
20790
20791
20792
20793
20794
20795
20796
20797
20798
20799
20800
20801
20802
20803
20804
# File 'lib/aws-sdk-sagemaker/types.rb', line 20787

class DescribeInferenceRecommendationsJobResponse < Struct.new(
  :job_name,
  :job_description,
  :job_type,
  :job_arn,
  :role_arn,
  :status,
  :creation_time,
  :completion_time,
  :last_modified_time,
  :failure_reason,
  :input_config,
  :stopping_conditions,
  :inference_recommendations,
  :endpoint_performances)
  SENSITIVE = []
  include Aws::Structure
end

#job_typeString

The job type that you provided when you initiated the job.

Returns:

  • (String)


20787
20788
20789
20790
20791
20792
20793
20794
20795
20796
20797
20798
20799
20800
20801
20802
20803
20804
# File 'lib/aws-sdk-sagemaker/types.rb', line 20787

class DescribeInferenceRecommendationsJobResponse < Struct.new(
  :job_name,
  :job_description,
  :job_type,
  :job_arn,
  :role_arn,
  :status,
  :creation_time,
  :completion_time,
  :last_modified_time,
  :failure_reason,
  :input_config,
  :stopping_conditions,
  :inference_recommendations,
  :endpoint_performances)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

A timestamp that shows when the job was last modified.

Returns:

  • (Time)


20787
20788
20789
20790
20791
20792
20793
20794
20795
20796
20797
20798
20799
20800
20801
20802
20803
20804
# File 'lib/aws-sdk-sagemaker/types.rb', line 20787

class DescribeInferenceRecommendationsJobResponse < Struct.new(
  :job_name,
  :job_description,
  :job_type,
  :job_arn,
  :role_arn,
  :status,
  :creation_time,
  :completion_time,
  :last_modified_time,
  :failure_reason,
  :input_config,
  :stopping_conditions,
  :inference_recommendations,
  :endpoint_performances)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of the Amazon Web Services Identity and Access Management (IAM) role you provided when you initiated the job.

Returns:

  • (String)


20787
20788
20789
20790
20791
20792
20793
20794
20795
20796
20797
20798
20799
20800
20801
20802
20803
20804
# File 'lib/aws-sdk-sagemaker/types.rb', line 20787

class DescribeInferenceRecommendationsJobResponse < Struct.new(
  :job_name,
  :job_description,
  :job_type,
  :job_arn,
  :role_arn,
  :status,
  :creation_time,
  :completion_time,
  :last_modified_time,
  :failure_reason,
  :input_config,
  :stopping_conditions,
  :inference_recommendations,
  :endpoint_performances)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the job.

Returns:

  • (String)


20787
20788
20789
20790
20791
20792
20793
20794
20795
20796
20797
20798
20799
20800
20801
20802
20803
20804
# File 'lib/aws-sdk-sagemaker/types.rb', line 20787

class DescribeInferenceRecommendationsJobResponse < Struct.new(
  :job_name,
  :job_description,
  :job_type,
  :job_arn,
  :role_arn,
  :status,
  :creation_time,
  :completion_time,
  :last_modified_time,
  :failure_reason,
  :input_config,
  :stopping_conditions,
  :inference_recommendations,
  :endpoint_performances)
  SENSITIVE = []
  include Aws::Structure
end

#stopping_conditionsTypes::RecommendationJobStoppingConditions

The stopping conditions that you provided when you initiated the job.



20787
20788
20789
20790
20791
20792
20793
20794
20795
20796
20797
20798
20799
20800
20801
20802
20803
20804
# File 'lib/aws-sdk-sagemaker/types.rb', line 20787

class DescribeInferenceRecommendationsJobResponse < Struct.new(
  :job_name,
  :job_description,
  :job_type,
  :job_arn,
  :role_arn,
  :status,
  :creation_time,
  :completion_time,
  :last_modified_time,
  :failure_reason,
  :input_config,
  :stopping_conditions,
  :inference_recommendations,
  :endpoint_performances)
  SENSITIVE = []
  include Aws::Structure
end