Class: Aws::SageMaker::Types::DescribeInferenceRecommendationsJobResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeInferenceRecommendationsJobResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#completion_time ⇒ Time
A timestamp that shows when the job completed.
-
#creation_time ⇒ Time
A timestamp that shows when the job was created.
-
#endpoint_performances ⇒ Array<Types::EndpointPerformance>
The performance results from running an Inference Recommender job on an existing endpoint.
-
#failure_reason ⇒ String
If the job fails, provides information why the job failed.
-
#inference_recommendations ⇒ Array<Types::InferenceRecommendation>
The recommendations made by Inference Recommender.
-
#input_config ⇒ Types::RecommendationJobInputConfig
Returns information about the versioned model package Amazon Resource Name (ARN), the traffic pattern, and endpoint configurations you provided when you initiated the job.
-
#job_arn ⇒ String
The Amazon Resource Name (ARN) of the job.
-
#job_description ⇒ String
The job description that you provided when you initiated the job.
-
#job_name ⇒ String
The name of the job.
-
#job_type ⇒ String
The job type that you provided when you initiated the job.
-
#last_modified_time ⇒ Time
A timestamp that shows when the job was last modified.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Web Services Identity and Access Management (IAM) role you provided when you initiated the job.
-
#status ⇒ String
The status of the job.
-
#stopping_conditions ⇒ Types::RecommendationJobStoppingConditions
The stopping conditions that you provided when you initiated the job.
Instance Attribute Details
#completion_time ⇒ Time
A timestamp that shows when the job completed.
18928 18929 18930 18931 18932 18933 18934 18935 18936 18937 18938 18939 18940 18941 18942 18943 18944 18945 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18928 class DescribeInferenceRecommendationsJobResponse < Struct.new( :job_name, :job_description, :job_type, :job_arn, :role_arn, :status, :creation_time, :completion_time, :last_modified_time, :failure_reason, :input_config, :stopping_conditions, :inference_recommendations, :endpoint_performances) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
A timestamp that shows when the job was created.
18928 18929 18930 18931 18932 18933 18934 18935 18936 18937 18938 18939 18940 18941 18942 18943 18944 18945 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18928 class DescribeInferenceRecommendationsJobResponse < Struct.new( :job_name, :job_description, :job_type, :job_arn, :role_arn, :status, :creation_time, :completion_time, :last_modified_time, :failure_reason, :input_config, :stopping_conditions, :inference_recommendations, :endpoint_performances) SENSITIVE = [] include Aws::Structure end |
#endpoint_performances ⇒ Array<Types::EndpointPerformance>
The performance results from running an Inference Recommender job on an existing endpoint.
18928 18929 18930 18931 18932 18933 18934 18935 18936 18937 18938 18939 18940 18941 18942 18943 18944 18945 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18928 class DescribeInferenceRecommendationsJobResponse < Struct.new( :job_name, :job_description, :job_type, :job_arn, :role_arn, :status, :creation_time, :completion_time, :last_modified_time, :failure_reason, :input_config, :stopping_conditions, :inference_recommendations, :endpoint_performances) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
If the job fails, provides information why the job failed.
18928 18929 18930 18931 18932 18933 18934 18935 18936 18937 18938 18939 18940 18941 18942 18943 18944 18945 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18928 class DescribeInferenceRecommendationsJobResponse < Struct.new( :job_name, :job_description, :job_type, :job_arn, :role_arn, :status, :creation_time, :completion_time, :last_modified_time, :failure_reason, :input_config, :stopping_conditions, :inference_recommendations, :endpoint_performances) SENSITIVE = [] include Aws::Structure end |
#inference_recommendations ⇒ Array<Types::InferenceRecommendation>
The recommendations made by Inference Recommender.
18928 18929 18930 18931 18932 18933 18934 18935 18936 18937 18938 18939 18940 18941 18942 18943 18944 18945 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18928 class DescribeInferenceRecommendationsJobResponse < Struct.new( :job_name, :job_description, :job_type, :job_arn, :role_arn, :status, :creation_time, :completion_time, :last_modified_time, :failure_reason, :input_config, :stopping_conditions, :inference_recommendations, :endpoint_performances) SENSITIVE = [] include Aws::Structure end |
#input_config ⇒ Types::RecommendationJobInputConfig
Returns information about the versioned model package Amazon Resource Name (ARN), the traffic pattern, and endpoint configurations you provided when you initiated the job.
18928 18929 18930 18931 18932 18933 18934 18935 18936 18937 18938 18939 18940 18941 18942 18943 18944 18945 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18928 class DescribeInferenceRecommendationsJobResponse < Struct.new( :job_name, :job_description, :job_type, :job_arn, :role_arn, :status, :creation_time, :completion_time, :last_modified_time, :failure_reason, :input_config, :stopping_conditions, :inference_recommendations, :endpoint_performances) SENSITIVE = [] include Aws::Structure end |
#job_arn ⇒ String
The Amazon Resource Name (ARN) of the job.
18928 18929 18930 18931 18932 18933 18934 18935 18936 18937 18938 18939 18940 18941 18942 18943 18944 18945 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18928 class DescribeInferenceRecommendationsJobResponse < Struct.new( :job_name, :job_description, :job_type, :job_arn, :role_arn, :status, :creation_time, :completion_time, :last_modified_time, :failure_reason, :input_config, :stopping_conditions, :inference_recommendations, :endpoint_performances) SENSITIVE = [] include Aws::Structure end |
#job_description ⇒ String
The job description that you provided when you initiated the job.
18928 18929 18930 18931 18932 18933 18934 18935 18936 18937 18938 18939 18940 18941 18942 18943 18944 18945 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18928 class DescribeInferenceRecommendationsJobResponse < Struct.new( :job_name, :job_description, :job_type, :job_arn, :role_arn, :status, :creation_time, :completion_time, :last_modified_time, :failure_reason, :input_config, :stopping_conditions, :inference_recommendations, :endpoint_performances) SENSITIVE = [] include Aws::Structure end |
#job_name ⇒ String
The name of the job. The name must be unique within an Amazon Web Services Region in the Amazon Web Services account.
18928 18929 18930 18931 18932 18933 18934 18935 18936 18937 18938 18939 18940 18941 18942 18943 18944 18945 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18928 class DescribeInferenceRecommendationsJobResponse < Struct.new( :job_name, :job_description, :job_type, :job_arn, :role_arn, :status, :creation_time, :completion_time, :last_modified_time, :failure_reason, :input_config, :stopping_conditions, :inference_recommendations, :endpoint_performances) SENSITIVE = [] include Aws::Structure end |
#job_type ⇒ String
The job type that you provided when you initiated the job.
18928 18929 18930 18931 18932 18933 18934 18935 18936 18937 18938 18939 18940 18941 18942 18943 18944 18945 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18928 class DescribeInferenceRecommendationsJobResponse < Struct.new( :job_name, :job_description, :job_type, :job_arn, :role_arn, :status, :creation_time, :completion_time, :last_modified_time, :failure_reason, :input_config, :stopping_conditions, :inference_recommendations, :endpoint_performances) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
A timestamp that shows when the job was last modified.
18928 18929 18930 18931 18932 18933 18934 18935 18936 18937 18938 18939 18940 18941 18942 18943 18944 18945 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18928 class DescribeInferenceRecommendationsJobResponse < Struct.new( :job_name, :job_description, :job_type, :job_arn, :role_arn, :status, :creation_time, :completion_time, :last_modified_time, :failure_reason, :input_config, :stopping_conditions, :inference_recommendations, :endpoint_performances) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Web Services Identity and Access Management (IAM) role you provided when you initiated the job.
18928 18929 18930 18931 18932 18933 18934 18935 18936 18937 18938 18939 18940 18941 18942 18943 18944 18945 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18928 class DescribeInferenceRecommendationsJobResponse < Struct.new( :job_name, :job_description, :job_type, :job_arn, :role_arn, :status, :creation_time, :completion_time, :last_modified_time, :failure_reason, :input_config, :stopping_conditions, :inference_recommendations, :endpoint_performances) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the job.
18928 18929 18930 18931 18932 18933 18934 18935 18936 18937 18938 18939 18940 18941 18942 18943 18944 18945 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18928 class DescribeInferenceRecommendationsJobResponse < Struct.new( :job_name, :job_description, :job_type, :job_arn, :role_arn, :status, :creation_time, :completion_time, :last_modified_time, :failure_reason, :input_config, :stopping_conditions, :inference_recommendations, :endpoint_performances) SENSITIVE = [] include Aws::Structure end |
#stopping_conditions ⇒ Types::RecommendationJobStoppingConditions
The stopping conditions that you provided when you initiated the job.
18928 18929 18930 18931 18932 18933 18934 18935 18936 18937 18938 18939 18940 18941 18942 18943 18944 18945 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 18928 class DescribeInferenceRecommendationsJobResponse < Struct.new( :job_name, :job_description, :job_type, :job_arn, :role_arn, :status, :creation_time, :completion_time, :last_modified_time, :failure_reason, :input_config, :stopping_conditions, :inference_recommendations, :endpoint_performances) SENSITIVE = [] include Aws::Structure end |