Class: Aws::SageMaker::Types::DescribeJobResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timeTime

The date and time that the job was created.

Returns:

  • (Time)


21086
21087
21088
21089
21090
21091
21092
21093
21094
21095
21096
21097
21098
21099
21100
21101
21102
21103
# File 'lib/aws-sdk-sagemaker/types.rb', line 21086

class DescribeJobResponse < Struct.new(
  :job_name,
  :job_arn,
  :role_arn,
  :job_category,
  :job_config_schema_version,
  :job_config_document,
  :creation_time,
  :last_modified_time,
  :end_time,
  :job_status,
  :secondary_status,
  :secondary_status_transitions,
  :failure_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

The date and time that the job ended.

Returns:

  • (Time)


21086
21087
21088
21089
21090
21091
21092
21093
21094
21095
21096
21097
21098
21099
21100
21101
21102
21103
# File 'lib/aws-sdk-sagemaker/types.rb', line 21086

class DescribeJobResponse < Struct.new(
  :job_name,
  :job_arn,
  :role_arn,
  :job_category,
  :job_config_schema_version,
  :job_config_document,
  :creation_time,
  :last_modified_time,
  :end_time,
  :job_status,
  :secondary_status,
  :secondary_status_transitions,
  :failure_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

If the job failed, the reason it failed.

Returns:

  • (String)


21086
21087
21088
21089
21090
21091
21092
21093
21094
21095
21096
21097
21098
21099
21100
21101
21102
21103
# File 'lib/aws-sdk-sagemaker/types.rb', line 21086

class DescribeJobResponse < Struct.new(
  :job_name,
  :job_arn,
  :role_arn,
  :job_category,
  :job_config_schema_version,
  :job_config_document,
  :creation_time,
  :last_modified_time,
  :end_time,
  :job_status,
  :secondary_status,
  :secondary_status_transitions,
  :failure_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#job_arnString

The Amazon Resource Name (ARN) of the job.

Returns:

  • (String)


21086
21087
21088
21089
21090
21091
21092
21093
21094
21095
21096
21097
21098
21099
21100
21101
21102
21103
# File 'lib/aws-sdk-sagemaker/types.rb', line 21086

class DescribeJobResponse < Struct.new(
  :job_name,
  :job_arn,
  :role_arn,
  :job_category,
  :job_config_schema_version,
  :job_config_document,
  :creation_time,
  :last_modified_time,
  :end_time,
  :job_status,
  :secondary_status,
  :secondary_status_transitions,
  :failure_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#job_categoryString

The category of the job.

Returns:

  • (String)


21086
21087
21088
21089
21090
21091
21092
21093
21094
21095
21096
21097
21098
21099
21100
21101
21102
21103
# File 'lib/aws-sdk-sagemaker/types.rb', line 21086

class DescribeJobResponse < Struct.new(
  :job_name,
  :job_arn,
  :role_arn,
  :job_category,
  :job_config_schema_version,
  :job_config_document,
  :creation_time,
  :last_modified_time,
  :end_time,
  :job_status,
  :secondary_status,
  :secondary_status_transitions,
  :failure_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#job_config_documentString

The JSON configuration document for the job.

Returns:

  • (String)


21086
21087
21088
21089
21090
21091
21092
21093
21094
21095
21096
21097
21098
21099
21100
21101
21102
21103
# File 'lib/aws-sdk-sagemaker/types.rb', line 21086

class DescribeJobResponse < Struct.new(
  :job_name,
  :job_arn,
  :role_arn,
  :job_category,
  :job_config_schema_version,
  :job_config_document,
  :creation_time,
  :last_modified_time,
  :end_time,
  :job_status,
  :secondary_status,
  :secondary_status_transitions,
  :failure_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#job_config_schema_versionString

The schema version used for the job configuration document.

Returns:

  • (String)


21086
21087
21088
21089
21090
21091
21092
21093
21094
21095
21096
21097
21098
21099
21100
21101
21102
21103
# File 'lib/aws-sdk-sagemaker/types.rb', line 21086

class DescribeJobResponse < Struct.new(
  :job_name,
  :job_arn,
  :role_arn,
  :job_category,
  :job_config_schema_version,
  :job_config_document,
  :creation_time,
  :last_modified_time,
  :end_time,
  :job_status,
  :secondary_status,
  :secondary_status_transitions,
  :failure_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#job_nameString

The name of the job.

Returns:

  • (String)


21086
21087
21088
21089
21090
21091
21092
21093
21094
21095
21096
21097
21098
21099
21100
21101
21102
21103
# File 'lib/aws-sdk-sagemaker/types.rb', line 21086

class DescribeJobResponse < Struct.new(
  :job_name,
  :job_arn,
  :role_arn,
  :job_category,
  :job_config_schema_version,
  :job_config_document,
  :creation_time,
  :last_modified_time,
  :end_time,
  :job_status,
  :secondary_status,
  :secondary_status_transitions,
  :failure_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#job_statusString

The current status of the job.

Returns:

  • (String)


21086
21087
21088
21089
21090
21091
21092
21093
21094
21095
21096
21097
21098
21099
21100
21101
21102
21103
# File 'lib/aws-sdk-sagemaker/types.rb', line 21086

class DescribeJobResponse < Struct.new(
  :job_name,
  :job_arn,
  :role_arn,
  :job_category,
  :job_config_schema_version,
  :job_config_document,
  :creation_time,
  :last_modified_time,
  :end_time,
  :job_status,
  :secondary_status,
  :secondary_status_transitions,
  :failure_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The date and time that the job was last modified.

Returns:

  • (Time)


21086
21087
21088
21089
21090
21091
21092
21093
21094
21095
21096
21097
21098
21099
21100
21101
21102
21103
# File 'lib/aws-sdk-sagemaker/types.rb', line 21086

class DescribeJobResponse < Struct.new(
  :job_name,
  :job_arn,
  :role_arn,
  :job_category,
  :job_config_schema_version,
  :job_config_document,
  :creation_time,
  :last_modified_time,
  :end_time,
  :job_status,
  :secondary_status,
  :secondary_status_transitions,
  :failure_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The ARN of the IAM role associated with the job.

Returns:

  • (String)


21086
21087
21088
21089
21090
21091
21092
21093
21094
21095
21096
21097
21098
21099
21100
21101
21102
21103
# File 'lib/aws-sdk-sagemaker/types.rb', line 21086

class DescribeJobResponse < Struct.new(
  :job_name,
  :job_arn,
  :role_arn,
  :job_category,
  :job_config_schema_version,
  :job_config_document,
  :creation_time,
  :last_modified_time,
  :end_time,
  :job_status,
  :secondary_status,
  :secondary_status_transitions,
  :failure_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#secondary_statusString

The detailed secondary status of the job, providing more granular information about the job's progress. Secondary statuses may change between releases.

Returns:

  • (String)


21086
21087
21088
21089
21090
21091
21092
21093
21094
21095
21096
21097
21098
21099
21100
21101
21102
21103
# File 'lib/aws-sdk-sagemaker/types.rb', line 21086

class DescribeJobResponse < Struct.new(
  :job_name,
  :job_arn,
  :role_arn,
  :job_category,
  :job_config_schema_version,
  :job_config_document,
  :creation_time,
  :last_modified_time,
  :end_time,
  :job_status,
  :secondary_status,
  :secondary_status_transitions,
  :failure_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#secondary_status_transitionsArray<Types::JobSecondaryStatusTransition>

A list of secondary status transitions for the job, with timestamps and optional status messages.



21086
21087
21088
21089
21090
21091
21092
21093
21094
21095
21096
21097
21098
21099
21100
21101
21102
21103
# File 'lib/aws-sdk-sagemaker/types.rb', line 21086

class DescribeJobResponse < Struct.new(
  :job_name,
  :job_arn,
  :role_arn,
  :job_category,
  :job_config_schema_version,
  :job_config_document,
  :creation_time,
  :last_modified_time,
  :end_time,
  :job_status,
  :secondary_status,
  :secondary_status_transitions,
  :failure_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The tags associated with the job.

Returns:



21086
21087
21088
21089
21090
21091
21092
21093
21094
21095
21096
21097
21098
21099
21100
21101
21102
21103
# File 'lib/aws-sdk-sagemaker/types.rb', line 21086

class DescribeJobResponse < Struct.new(
  :job_name,
  :job_arn,
  :role_arn,
  :job_category,
  :job_config_schema_version,
  :job_config_document,
  :creation_time,
  :last_modified_time,
  :end_time,
  :job_status,
  :secondary_status,
  :secondary_status_transitions,
  :failure_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end