Class: Aws::SageMaker::Types::DescribeJobResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeJobResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Time
The date and time that the job was created.
-
#end_time ⇒ Time
The date and time that the job ended.
-
#failure_reason ⇒ String
If the job failed, the reason it failed.
-
#job_arn ⇒ String
The Amazon Resource Name (ARN) of the job.
-
#job_category ⇒ String
The category of the job.
-
#job_config_document ⇒ String
The JSON configuration document for the job.
-
#job_config_schema_version ⇒ String
The schema version used for the job configuration document.
-
#job_name ⇒ String
The name of the job.
-
#job_status ⇒ String
The current status of the job.
-
#last_modified_time ⇒ Time
The date and time that the job was last modified.
-
#role_arn ⇒ String
The ARN of the IAM role associated with the job.
-
#secondary_status ⇒ String
The detailed secondary status of the job, providing more granular information about the job's progress.
-
#secondary_status_transitions ⇒ Array<Types::JobSecondaryStatusTransition>
A list of secondary status transitions for the job, with timestamps and optional status messages.
-
#tags ⇒ Array<Types::Tag>
The tags associated with the job.
Instance Attribute Details
#creation_time ⇒ Time
The date and time that the job was created.
21144 21145 21146 21147 21148 21149 21150 21151 21152 21153 21154 21155 21156 21157 21158 21159 21160 21161 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21144 class DescribeJobResponse < Struct.new( :job_name, :job_arn, :role_arn, :job_category, :job_config_schema_version, :job_config_document, :creation_time, :last_modified_time, :end_time, :job_status, :secondary_status, :secondary_status_transitions, :failure_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
The date and time that the job ended.
21144 21145 21146 21147 21148 21149 21150 21151 21152 21153 21154 21155 21156 21157 21158 21159 21160 21161 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21144 class DescribeJobResponse < Struct.new( :job_name, :job_arn, :role_arn, :job_category, :job_config_schema_version, :job_config_document, :creation_time, :last_modified_time, :end_time, :job_status, :secondary_status, :secondary_status_transitions, :failure_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
If the job failed, the reason it failed.
21144 21145 21146 21147 21148 21149 21150 21151 21152 21153 21154 21155 21156 21157 21158 21159 21160 21161 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21144 class DescribeJobResponse < Struct.new( :job_name, :job_arn, :role_arn, :job_category, :job_config_schema_version, :job_config_document, :creation_time, :last_modified_time, :end_time, :job_status, :secondary_status, :secondary_status_transitions, :failure_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#job_arn ⇒ String
The Amazon Resource Name (ARN) of the job.
21144 21145 21146 21147 21148 21149 21150 21151 21152 21153 21154 21155 21156 21157 21158 21159 21160 21161 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21144 class DescribeJobResponse < Struct.new( :job_name, :job_arn, :role_arn, :job_category, :job_config_schema_version, :job_config_document, :creation_time, :last_modified_time, :end_time, :job_status, :secondary_status, :secondary_status_transitions, :failure_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#job_category ⇒ String
The category of the job.
21144 21145 21146 21147 21148 21149 21150 21151 21152 21153 21154 21155 21156 21157 21158 21159 21160 21161 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21144 class DescribeJobResponse < Struct.new( :job_name, :job_arn, :role_arn, :job_category, :job_config_schema_version, :job_config_document, :creation_time, :last_modified_time, :end_time, :job_status, :secondary_status, :secondary_status_transitions, :failure_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#job_config_document ⇒ String
The JSON configuration document for the job.
21144 21145 21146 21147 21148 21149 21150 21151 21152 21153 21154 21155 21156 21157 21158 21159 21160 21161 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21144 class DescribeJobResponse < Struct.new( :job_name, :job_arn, :role_arn, :job_category, :job_config_schema_version, :job_config_document, :creation_time, :last_modified_time, :end_time, :job_status, :secondary_status, :secondary_status_transitions, :failure_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#job_config_schema_version ⇒ String
The schema version used for the job configuration document.
21144 21145 21146 21147 21148 21149 21150 21151 21152 21153 21154 21155 21156 21157 21158 21159 21160 21161 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21144 class DescribeJobResponse < Struct.new( :job_name, :job_arn, :role_arn, :job_category, :job_config_schema_version, :job_config_document, :creation_time, :last_modified_time, :end_time, :job_status, :secondary_status, :secondary_status_transitions, :failure_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#job_name ⇒ String
The name of the job.
21144 21145 21146 21147 21148 21149 21150 21151 21152 21153 21154 21155 21156 21157 21158 21159 21160 21161 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21144 class DescribeJobResponse < Struct.new( :job_name, :job_arn, :role_arn, :job_category, :job_config_schema_version, :job_config_document, :creation_time, :last_modified_time, :end_time, :job_status, :secondary_status, :secondary_status_transitions, :failure_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#job_status ⇒ String
The current status of the job.
21144 21145 21146 21147 21148 21149 21150 21151 21152 21153 21154 21155 21156 21157 21158 21159 21160 21161 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21144 class DescribeJobResponse < Struct.new( :job_name, :job_arn, :role_arn, :job_category, :job_config_schema_version, :job_config_document, :creation_time, :last_modified_time, :end_time, :job_status, :secondary_status, :secondary_status_transitions, :failure_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The date and time that the job was last modified.
21144 21145 21146 21147 21148 21149 21150 21151 21152 21153 21154 21155 21156 21157 21158 21159 21160 21161 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21144 class DescribeJobResponse < Struct.new( :job_name, :job_arn, :role_arn, :job_category, :job_config_schema_version, :job_config_document, :creation_time, :last_modified_time, :end_time, :job_status, :secondary_status, :secondary_status_transitions, :failure_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The ARN of the IAM role associated with the job.
21144 21145 21146 21147 21148 21149 21150 21151 21152 21153 21154 21155 21156 21157 21158 21159 21160 21161 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21144 class DescribeJobResponse < Struct.new( :job_name, :job_arn, :role_arn, :job_category, :job_config_schema_version, :job_config_document, :creation_time, :last_modified_time, :end_time, :job_status, :secondary_status, :secondary_status_transitions, :failure_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#secondary_status ⇒ String
The detailed secondary status of the job, providing more granular information about the job's progress. Secondary statuses may change between releases.
21144 21145 21146 21147 21148 21149 21150 21151 21152 21153 21154 21155 21156 21157 21158 21159 21160 21161 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21144 class DescribeJobResponse < Struct.new( :job_name, :job_arn, :role_arn, :job_category, :job_config_schema_version, :job_config_document, :creation_time, :last_modified_time, :end_time, :job_status, :secondary_status, :secondary_status_transitions, :failure_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#secondary_status_transitions ⇒ Array<Types::JobSecondaryStatusTransition>
A list of secondary status transitions for the job, with timestamps and optional status messages.
21144 21145 21146 21147 21148 21149 21150 21151 21152 21153 21154 21155 21156 21157 21158 21159 21160 21161 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21144 class DescribeJobResponse < Struct.new( :job_name, :job_arn, :role_arn, :job_category, :job_config_schema_version, :job_config_document, :creation_time, :last_modified_time, :end_time, :job_status, :secondary_status, :secondary_status_transitions, :failure_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags associated with the job.
21144 21145 21146 21147 21148 21149 21150 21151 21152 21153 21154 21155 21156 21157 21158 21159 21160 21161 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21144 class DescribeJobResponse < Struct.new( :job_name, :job_arn, :role_arn, :job_category, :job_config_schema_version, :job_config_document, :creation_time, :last_modified_time, :end_time, :job_status, :secondary_status, :secondary_status_transitions, :failure_reason, :tags) SENSITIVE = [] include Aws::Structure end |