Class: Aws::SageMaker::Types::DescribeLabelingJobResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timeTime

The date and time that the labeling job was created.

Returns:

  • (Time)


20465
20466
20467
20468
20469
20470
20471
20472
20473
20474
20475
20476
20477
20478
20479
20480
20481
20482
20483
20484
20485
20486
# File 'lib/aws-sdk-sagemaker/types.rb', line 20465

class DescribeLabelingJobResponse < Struct.new(
  :labeling_job_status,
  :label_counters,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :job_reference_code,
  :labeling_job_name,
  :labeling_job_arn,
  :label_attribute_name,
  :input_config,
  :output_config,
  :role_arn,
  :label_category_config_s3_uri,
  :stopping_conditions,
  :labeling_job_algorithms_config,
  :human_task_config,
  :tags,
  :labeling_job_output)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

If the job failed, the reason that it failed.

Returns:

  • (String)


20465
20466
20467
20468
20469
20470
20471
20472
20473
20474
20475
20476
20477
20478
20479
20480
20481
20482
20483
20484
20485
20486
# File 'lib/aws-sdk-sagemaker/types.rb', line 20465

class DescribeLabelingJobResponse < Struct.new(
  :labeling_job_status,
  :label_counters,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :job_reference_code,
  :labeling_job_name,
  :labeling_job_arn,
  :label_attribute_name,
  :input_config,
  :output_config,
  :role_arn,
  :label_category_config_s3_uri,
  :stopping_conditions,
  :labeling_job_algorithms_config,
  :human_task_config,
  :tags,
  :labeling_job_output)
  SENSITIVE = []
  include Aws::Structure
end

#human_task_configTypes::HumanTaskConfig

Configuration information required for human workers to complete a labeling task.



20465
20466
20467
20468
20469
20470
20471
20472
20473
20474
20475
20476
20477
20478
20479
20480
20481
20482
20483
20484
20485
20486
# File 'lib/aws-sdk-sagemaker/types.rb', line 20465

class DescribeLabelingJobResponse < Struct.new(
  :labeling_job_status,
  :label_counters,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :job_reference_code,
  :labeling_job_name,
  :labeling_job_arn,
  :label_attribute_name,
  :input_config,
  :output_config,
  :role_arn,
  :label_category_config_s3_uri,
  :stopping_conditions,
  :labeling_job_algorithms_config,
  :human_task_config,
  :tags,
  :labeling_job_output)
  SENSITIVE = []
  include Aws::Structure
end

#input_configTypes::LabelingJobInputConfig

Input configuration information for the labeling job, such as the Amazon S3 location of the data objects and the location of the manifest file that describes the data objects.



20465
20466
20467
20468
20469
20470
20471
20472
20473
20474
20475
20476
20477
20478
20479
20480
20481
20482
20483
20484
20485
20486
# File 'lib/aws-sdk-sagemaker/types.rb', line 20465

class DescribeLabelingJobResponse < Struct.new(
  :labeling_job_status,
  :label_counters,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :job_reference_code,
  :labeling_job_name,
  :labeling_job_arn,
  :label_attribute_name,
  :input_config,
  :output_config,
  :role_arn,
  :label_category_config_s3_uri,
  :stopping_conditions,
  :labeling_job_algorithms_config,
  :human_task_config,
  :tags,
  :labeling_job_output)
  SENSITIVE = []
  include Aws::Structure
end

#job_reference_codeString

A unique identifier for work done as part of a labeling job.

Returns:

  • (String)


20465
20466
20467
20468
20469
20470
20471
20472
20473
20474
20475
20476
20477
20478
20479
20480
20481
20482
20483
20484
20485
20486
# File 'lib/aws-sdk-sagemaker/types.rb', line 20465

class DescribeLabelingJobResponse < Struct.new(
  :labeling_job_status,
  :label_counters,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :job_reference_code,
  :labeling_job_name,
  :labeling_job_arn,
  :label_attribute_name,
  :input_config,
  :output_config,
  :role_arn,
  :label_category_config_s3_uri,
  :stopping_conditions,
  :labeling_job_algorithms_config,
  :human_task_config,
  :tags,
  :labeling_job_output)
  SENSITIVE = []
  include Aws::Structure
end

#label_attribute_nameString

The attribute used as the label in the output manifest file.

Returns:

  • (String)


20465
20466
20467
20468
20469
20470
20471
20472
20473
20474
20475
20476
20477
20478
20479
20480
20481
20482
20483
20484
20485
20486
# File 'lib/aws-sdk-sagemaker/types.rb', line 20465

class DescribeLabelingJobResponse < Struct.new(
  :labeling_job_status,
  :label_counters,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :job_reference_code,
  :labeling_job_name,
  :labeling_job_arn,
  :label_attribute_name,
  :input_config,
  :output_config,
  :role_arn,
  :label_category_config_s3_uri,
  :stopping_conditions,
  :labeling_job_algorithms_config,
  :human_task_config,
  :tags,
  :labeling_job_output)
  SENSITIVE = []
  include Aws::Structure
end

#label_category_config_s3_uriString

The S3 location of the JSON file that defines the categories used to label data objects. Please note the following label-category limits:

  • Semantic segmentation labeling jobs using automated labeling: 20 labels

  • Box bounding labeling jobs (all): 10 labels

The file is a JSON structure in the following format:

‘{`

‘ “document-version”: “2018-11-28”`

‘ “labels”: [`

‘ {`

‘ “label”: “label 1”`

‘ },`

‘ {`

‘ “label”: “label 2”`

‘ },`

‘ …`

‘ {`

‘ “label”: “label n”`

‘ }`

‘ ]`

‘}`

Returns:

  • (String)


20465
20466
20467
20468
20469
20470
20471
20472
20473
20474
20475
20476
20477
20478
20479
20480
20481
20482
20483
20484
20485
20486
# File 'lib/aws-sdk-sagemaker/types.rb', line 20465

class DescribeLabelingJobResponse < Struct.new(
  :labeling_job_status,
  :label_counters,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :job_reference_code,
  :labeling_job_name,
  :labeling_job_arn,
  :label_attribute_name,
  :input_config,
  :output_config,
  :role_arn,
  :label_category_config_s3_uri,
  :stopping_conditions,
  :labeling_job_algorithms_config,
  :human_task_config,
  :tags,
  :labeling_job_output)
  SENSITIVE = []
  include Aws::Structure
end

#label_countersTypes::LabelCounters

Provides a breakdown of the number of data objects labeled by humans, the number of objects labeled by machine, the number of objects than couldn’t be labeled, and the total number of objects labeled.



20465
20466
20467
20468
20469
20470
20471
20472
20473
20474
20475
20476
20477
20478
20479
20480
20481
20482
20483
20484
20485
20486
# File 'lib/aws-sdk-sagemaker/types.rb', line 20465

class DescribeLabelingJobResponse < Struct.new(
  :labeling_job_status,
  :label_counters,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :job_reference_code,
  :labeling_job_name,
  :labeling_job_arn,
  :label_attribute_name,
  :input_config,
  :output_config,
  :role_arn,
  :label_category_config_s3_uri,
  :stopping_conditions,
  :labeling_job_algorithms_config,
  :human_task_config,
  :tags,
  :labeling_job_output)
  SENSITIVE = []
  include Aws::Structure
end

#labeling_job_algorithms_configTypes::LabelingJobAlgorithmsConfig

Configuration information for automated data labeling.



20465
20466
20467
20468
20469
20470
20471
20472
20473
20474
20475
20476
20477
20478
20479
20480
20481
20482
20483
20484
20485
20486
# File 'lib/aws-sdk-sagemaker/types.rb', line 20465

class DescribeLabelingJobResponse < Struct.new(
  :labeling_job_status,
  :label_counters,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :job_reference_code,
  :labeling_job_name,
  :labeling_job_arn,
  :label_attribute_name,
  :input_config,
  :output_config,
  :role_arn,
  :label_category_config_s3_uri,
  :stopping_conditions,
  :labeling_job_algorithms_config,
  :human_task_config,
  :tags,
  :labeling_job_output)
  SENSITIVE = []
  include Aws::Structure
end

#labeling_job_arnString

The Amazon Resource Name (ARN) of the labeling job.

Returns:

  • (String)


20465
20466
20467
20468
20469
20470
20471
20472
20473
20474
20475
20476
20477
20478
20479
20480
20481
20482
20483
20484
20485
20486
# File 'lib/aws-sdk-sagemaker/types.rb', line 20465

class DescribeLabelingJobResponse < Struct.new(
  :labeling_job_status,
  :label_counters,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :job_reference_code,
  :labeling_job_name,
  :labeling_job_arn,
  :label_attribute_name,
  :input_config,
  :output_config,
  :role_arn,
  :label_category_config_s3_uri,
  :stopping_conditions,
  :labeling_job_algorithms_config,
  :human_task_config,
  :tags,
  :labeling_job_output)
  SENSITIVE = []
  include Aws::Structure
end

#labeling_job_nameString

The name assigned to the labeling job when it was created.

Returns:

  • (String)


20465
20466
20467
20468
20469
20470
20471
20472
20473
20474
20475
20476
20477
20478
20479
20480
20481
20482
20483
20484
20485
20486
# File 'lib/aws-sdk-sagemaker/types.rb', line 20465

class DescribeLabelingJobResponse < Struct.new(
  :labeling_job_status,
  :label_counters,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :job_reference_code,
  :labeling_job_name,
  :labeling_job_arn,
  :label_attribute_name,
  :input_config,
  :output_config,
  :role_arn,
  :label_category_config_s3_uri,
  :stopping_conditions,
  :labeling_job_algorithms_config,
  :human_task_config,
  :tags,
  :labeling_job_output)
  SENSITIVE = []
  include Aws::Structure
end

#labeling_job_outputTypes::LabelingJobOutput

The location of the output produced by the labeling job.



20465
20466
20467
20468
20469
20470
20471
20472
20473
20474
20475
20476
20477
20478
20479
20480
20481
20482
20483
20484
20485
20486
# File 'lib/aws-sdk-sagemaker/types.rb', line 20465

class DescribeLabelingJobResponse < Struct.new(
  :labeling_job_status,
  :label_counters,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :job_reference_code,
  :labeling_job_name,
  :labeling_job_arn,
  :label_attribute_name,
  :input_config,
  :output_config,
  :role_arn,
  :label_category_config_s3_uri,
  :stopping_conditions,
  :labeling_job_algorithms_config,
  :human_task_config,
  :tags,
  :labeling_job_output)
  SENSITIVE = []
  include Aws::Structure
end

#labeling_job_statusString

The processing status of the labeling job.

Returns:

  • (String)


20465
20466
20467
20468
20469
20470
20471
20472
20473
20474
20475
20476
20477
20478
20479
20480
20481
20482
20483
20484
20485
20486
# File 'lib/aws-sdk-sagemaker/types.rb', line 20465

class DescribeLabelingJobResponse < Struct.new(
  :labeling_job_status,
  :label_counters,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :job_reference_code,
  :labeling_job_name,
  :labeling_job_arn,
  :label_attribute_name,
  :input_config,
  :output_config,
  :role_arn,
  :label_category_config_s3_uri,
  :stopping_conditions,
  :labeling_job_algorithms_config,
  :human_task_config,
  :tags,
  :labeling_job_output)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The date and time that the labeling job was last updated.

Returns:

  • (Time)


20465
20466
20467
20468
20469
20470
20471
20472
20473
20474
20475
20476
20477
20478
20479
20480
20481
20482
20483
20484
20485
20486
# File 'lib/aws-sdk-sagemaker/types.rb', line 20465

class DescribeLabelingJobResponse < Struct.new(
  :labeling_job_status,
  :label_counters,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :job_reference_code,
  :labeling_job_name,
  :labeling_job_arn,
  :label_attribute_name,
  :input_config,
  :output_config,
  :role_arn,
  :label_category_config_s3_uri,
  :stopping_conditions,
  :labeling_job_algorithms_config,
  :human_task_config,
  :tags,
  :labeling_job_output)
  SENSITIVE = []
  include Aws::Structure
end

#output_configTypes::LabelingJobOutputConfig

The location of the job’s output data and the Amazon Web Services Key Management Service key ID for the key used to encrypt the output data, if any.



20465
20466
20467
20468
20469
20470
20471
20472
20473
20474
20475
20476
20477
20478
20479
20480
20481
20482
20483
20484
20485
20486
# File 'lib/aws-sdk-sagemaker/types.rb', line 20465

class DescribeLabelingJobResponse < Struct.new(
  :labeling_job_status,
  :label_counters,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :job_reference_code,
  :labeling_job_name,
  :labeling_job_arn,
  :label_attribute_name,
  :input_config,
  :output_config,
  :role_arn,
  :label_category_config_s3_uri,
  :stopping_conditions,
  :labeling_job_algorithms_config,
  :human_task_config,
  :tags,
  :labeling_job_output)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) that SageMaker assumes to perform tasks on your behalf during data labeling.

Returns:

  • (String)


20465
20466
20467
20468
20469
20470
20471
20472
20473
20474
20475
20476
20477
20478
20479
20480
20481
20482
20483
20484
20485
20486
# File 'lib/aws-sdk-sagemaker/types.rb', line 20465

class DescribeLabelingJobResponse < Struct.new(
  :labeling_job_status,
  :label_counters,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :job_reference_code,
  :labeling_job_name,
  :labeling_job_arn,
  :label_attribute_name,
  :input_config,
  :output_config,
  :role_arn,
  :label_category_config_s3_uri,
  :stopping_conditions,
  :labeling_job_algorithms_config,
  :human_task_config,
  :tags,
  :labeling_job_output)
  SENSITIVE = []
  include Aws::Structure
end

#stopping_conditionsTypes::LabelingJobStoppingConditions

A set of conditions for stopping a labeling job. If any of the conditions are met, the job is automatically stopped.



20465
20466
20467
20468
20469
20470
20471
20472
20473
20474
20475
20476
20477
20478
20479
20480
20481
20482
20483
20484
20485
20486
# File 'lib/aws-sdk-sagemaker/types.rb', line 20465

class DescribeLabelingJobResponse < Struct.new(
  :labeling_job_status,
  :label_counters,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :job_reference_code,
  :labeling_job_name,
  :labeling_job_arn,
  :label_attribute_name,
  :input_config,
  :output_config,
  :role_arn,
  :label_category_config_s3_uri,
  :stopping_conditions,
  :labeling_job_algorithms_config,
  :human_task_config,
  :tags,
  :labeling_job_output)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

An array of key-value pairs. You can use tags to categorize your Amazon Web Services resources in different ways, for example, by purpose, owner, or environment. For more information, see [Tagging Amazon Web Services Resources].

[1]: docs.aws.amazon.com/general/latest/gr/aws_tagging.html

Returns:



20465
20466
20467
20468
20469
20470
20471
20472
20473
20474
20475
20476
20477
20478
20479
20480
20481
20482
20483
20484
20485
20486
# File 'lib/aws-sdk-sagemaker/types.rb', line 20465

class DescribeLabelingJobResponse < Struct.new(
  :labeling_job_status,
  :label_counters,
  :failure_reason,
  :creation_time,
  :last_modified_time,
  :job_reference_code,
  :labeling_job_name,
  :labeling_job_arn,
  :label_attribute_name,
  :input_config,
  :output_config,
  :role_arn,
  :label_category_config_s3_uri,
  :stopping_conditions,
  :labeling_job_algorithms_config,
  :human_task_config,
  :tags,
  :labeling_job_output)
  SENSITIVE = []
  include Aws::Structure
end