Class: Aws::SageMaker::Types::DescribeMlflowAppResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeMlflowAppResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_default_status ⇒ String
Indicates whether this MLflow app is the default for the entire account.
-
#arn ⇒ String
The ARN of the MLflow App.
-
#artifact_store_uri ⇒ String
The S3 URI of the general purpose bucket used as the MLflow App artifact store.
-
#created_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
-
#creation_time ⇒ Time
The timestamp when the MLflow App was created.
-
#default_domain_id_list ⇒ Array<String>
List of SageMaker Domain IDs for which this MLflow App is the default.
-
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
-
#last_modified_time ⇒ Time
The timestamp when the MLflow App was last modified.
-
#maintenance_status ⇒ String
Current maintenance status of the MLflow App.
-
#mlflow_version ⇒ String
The MLflow version used.
-
#model_registration_mode ⇒ String
Whether automatic registration of new MLflow models to the SageMaker Model Registry is enabled.
-
#name ⇒ String
The name of the MLflow App.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) for an IAM role in your account that the MLflow App uses to access the artifact store in Amazon S3.
-
#status ⇒ String
The current creation status of the described MLflow App.
-
#weekly_maintenance_window_start ⇒ String
The day and time of the week when weekly maintenance occurs.
Instance Attribute Details
#account_default_status ⇒ String
Indicates whether this MLflow app is the default for the entire account.
21022 21023 21024 21025 21026 21027 21028 21029 21030 21031 21032 21033 21034 21035 21036 21037 21038 21039 21040 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21022 class DescribeMlflowAppResponse < Struct.new( :arn, :name, :artifact_store_uri, :mlflow_version, :role_arn, :status, :model_registration_mode, :account_default_status, :default_domain_id_list, :creation_time, :created_by, :last_modified_time, :last_modified_by, :weekly_maintenance_window_start, :maintenance_status) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The ARN of the MLflow App.
21022 21023 21024 21025 21026 21027 21028 21029 21030 21031 21032 21033 21034 21035 21036 21037 21038 21039 21040 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21022 class DescribeMlflowAppResponse < Struct.new( :arn, :name, :artifact_store_uri, :mlflow_version, :role_arn, :status, :model_registration_mode, :account_default_status, :default_domain_id_list, :creation_time, :created_by, :last_modified_time, :last_modified_by, :weekly_maintenance_window_start, :maintenance_status) SENSITIVE = [] include Aws::Structure end |
#artifact_store_uri ⇒ String
The S3 URI of the general purpose bucket used as the MLflow App artifact store.
21022 21023 21024 21025 21026 21027 21028 21029 21030 21031 21032 21033 21034 21035 21036 21037 21038 21039 21040 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21022 class DescribeMlflowAppResponse < Struct.new( :arn, :name, :artifact_store_uri, :mlflow_version, :role_arn, :status, :model_registration_mode, :account_default_status, :default_domain_id_list, :creation_time, :created_by, :last_modified_time, :last_modified_by, :weekly_maintenance_window_start, :maintenance_status) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
21022 21023 21024 21025 21026 21027 21028 21029 21030 21031 21032 21033 21034 21035 21036 21037 21038 21039 21040 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21022 class DescribeMlflowAppResponse < Struct.new( :arn, :name, :artifact_store_uri, :mlflow_version, :role_arn, :status, :model_registration_mode, :account_default_status, :default_domain_id_list, :creation_time, :created_by, :last_modified_time, :last_modified_by, :weekly_maintenance_window_start, :maintenance_status) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The timestamp when the MLflow App was created.
21022 21023 21024 21025 21026 21027 21028 21029 21030 21031 21032 21033 21034 21035 21036 21037 21038 21039 21040 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21022 class DescribeMlflowAppResponse < Struct.new( :arn, :name, :artifact_store_uri, :mlflow_version, :role_arn, :status, :model_registration_mode, :account_default_status, :default_domain_id_list, :creation_time, :created_by, :last_modified_time, :last_modified_by, :weekly_maintenance_window_start, :maintenance_status) SENSITIVE = [] include Aws::Structure end |
#default_domain_id_list ⇒ Array<String>
List of SageMaker Domain IDs for which this MLflow App is the default.
21022 21023 21024 21025 21026 21027 21028 21029 21030 21031 21032 21033 21034 21035 21036 21037 21038 21039 21040 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21022 class DescribeMlflowAppResponse < Struct.new( :arn, :name, :artifact_store_uri, :mlflow_version, :role_arn, :status, :model_registration_mode, :account_default_status, :default_domain_id_list, :creation_time, :created_by, :last_modified_time, :last_modified_by, :weekly_maintenance_window_start, :maintenance_status) SENSITIVE = [] include Aws::Structure end |
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
21022 21023 21024 21025 21026 21027 21028 21029 21030 21031 21032 21033 21034 21035 21036 21037 21038 21039 21040 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21022 class DescribeMlflowAppResponse < Struct.new( :arn, :name, :artifact_store_uri, :mlflow_version, :role_arn, :status, :model_registration_mode, :account_default_status, :default_domain_id_list, :creation_time, :created_by, :last_modified_time, :last_modified_by, :weekly_maintenance_window_start, :maintenance_status) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp when the MLflow App was last modified.
21022 21023 21024 21025 21026 21027 21028 21029 21030 21031 21032 21033 21034 21035 21036 21037 21038 21039 21040 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21022 class DescribeMlflowAppResponse < Struct.new( :arn, :name, :artifact_store_uri, :mlflow_version, :role_arn, :status, :model_registration_mode, :account_default_status, :default_domain_id_list, :creation_time, :created_by, :last_modified_time, :last_modified_by, :weekly_maintenance_window_start, :maintenance_status) SENSITIVE = [] include Aws::Structure end |
#maintenance_status ⇒ String
Current maintenance status of the MLflow App.
21022 21023 21024 21025 21026 21027 21028 21029 21030 21031 21032 21033 21034 21035 21036 21037 21038 21039 21040 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21022 class DescribeMlflowAppResponse < Struct.new( :arn, :name, :artifact_store_uri, :mlflow_version, :role_arn, :status, :model_registration_mode, :account_default_status, :default_domain_id_list, :creation_time, :created_by, :last_modified_time, :last_modified_by, :weekly_maintenance_window_start, :maintenance_status) SENSITIVE = [] include Aws::Structure end |
#mlflow_version ⇒ String
The MLflow version used.
21022 21023 21024 21025 21026 21027 21028 21029 21030 21031 21032 21033 21034 21035 21036 21037 21038 21039 21040 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21022 class DescribeMlflowAppResponse < Struct.new( :arn, :name, :artifact_store_uri, :mlflow_version, :role_arn, :status, :model_registration_mode, :account_default_status, :default_domain_id_list, :creation_time, :created_by, :last_modified_time, :last_modified_by, :weekly_maintenance_window_start, :maintenance_status) SENSITIVE = [] include Aws::Structure end |
#model_registration_mode ⇒ String
Whether automatic registration of new MLflow models to the SageMaker Model Registry is enabled.
21022 21023 21024 21025 21026 21027 21028 21029 21030 21031 21032 21033 21034 21035 21036 21037 21038 21039 21040 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21022 class DescribeMlflowAppResponse < Struct.new( :arn, :name, :artifact_store_uri, :mlflow_version, :role_arn, :status, :model_registration_mode, :account_default_status, :default_domain_id_list, :creation_time, :created_by, :last_modified_time, :last_modified_by, :weekly_maintenance_window_start, :maintenance_status) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the MLflow App.
21022 21023 21024 21025 21026 21027 21028 21029 21030 21031 21032 21033 21034 21035 21036 21037 21038 21039 21040 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21022 class DescribeMlflowAppResponse < Struct.new( :arn, :name, :artifact_store_uri, :mlflow_version, :role_arn, :status, :model_registration_mode, :account_default_status, :default_domain_id_list, :creation_time, :created_by, :last_modified_time, :last_modified_by, :weekly_maintenance_window_start, :maintenance_status) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) for an IAM role in your account that the MLflow App uses to access the artifact store in Amazon S3.
21022 21023 21024 21025 21026 21027 21028 21029 21030 21031 21032 21033 21034 21035 21036 21037 21038 21039 21040 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21022 class DescribeMlflowAppResponse < Struct.new( :arn, :name, :artifact_store_uri, :mlflow_version, :role_arn, :status, :model_registration_mode, :account_default_status, :default_domain_id_list, :creation_time, :created_by, :last_modified_time, :last_modified_by, :weekly_maintenance_window_start, :maintenance_status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current creation status of the described MLflow App.
21022 21023 21024 21025 21026 21027 21028 21029 21030 21031 21032 21033 21034 21035 21036 21037 21038 21039 21040 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21022 class DescribeMlflowAppResponse < Struct.new( :arn, :name, :artifact_store_uri, :mlflow_version, :role_arn, :status, :model_registration_mode, :account_default_status, :default_domain_id_list, :creation_time, :created_by, :last_modified_time, :last_modified_by, :weekly_maintenance_window_start, :maintenance_status) SENSITIVE = [] include Aws::Structure end |
#weekly_maintenance_window_start ⇒ String
The day and time of the week when weekly maintenance occurs.
21022 21023 21024 21025 21026 21027 21028 21029 21030 21031 21032 21033 21034 21035 21036 21037 21038 21039 21040 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21022 class DescribeMlflowAppResponse < Struct.new( :arn, :name, :artifact_store_uri, :mlflow_version, :role_arn, :status, :model_registration_mode, :account_default_status, :default_domain_id_list, :creation_time, :created_by, :last_modified_time, :last_modified_by, :weekly_maintenance_window_start, :maintenance_status) SENSITIVE = [] include Aws::Structure end |