Class: Aws::SageMaker::Types::DescribeMlflowTrackingServerResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeMlflowTrackingServerResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#artifact_store_uri ⇒ String
The S3 URI of the general purpose bucket used as the MLflow Tracking Server artifact store.
-
#automatic_model_registration ⇒ Boolean
Whether automatic registration of new MLflow models to the SageMaker Model Registry is enabled.
-
#created_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
-
#creation_time ⇒ Time
The timestamp of when the described MLflow Tracking Server was created.
-
#is_active ⇒ String
Whether the described MLflow Tracking Server is currently active.
-
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
-
#last_modified_time ⇒ Time
The timestamp of when the described MLflow Tracking Server was last modified.
-
#mlflow_version ⇒ String
The MLflow version used for the described tracking server.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) for an IAM role in your account that the described MLflow Tracking Server uses to access the artifact store in Amazon S3.
-
#s3_bucket_owner_account_id ⇒ String
Expected Amazon Web Services account ID that owns the Amazon S3 bucket for artifact storage.
-
#s3_bucket_owner_verification ⇒ Boolean
Whether Amazon S3 Bucket Ownership checks are enabled whenever the tracking server interacts with Amazon Amazon S3.
-
#tracking_server_arn ⇒ String
The ARN of the described tracking server.
-
#tracking_server_maintenance_status ⇒ String
The current maintenance status of the described MLflow Tracking Server.
-
#tracking_server_name ⇒ String
The name of the described tracking server.
-
#tracking_server_size ⇒ String
The size of the described tracking server.
-
#tracking_server_status ⇒ String
The current creation status of the described MLflow Tracking Server.
-
#tracking_server_url ⇒ String
The URL to connect to the MLflow user interface for the described tracking server.
-
#weekly_maintenance_window_start ⇒ String
The day and time of the week when weekly maintenance occurs on the described tracking server.
Instance Attribute Details
#artifact_store_uri ⇒ String
The S3 URI of the general purpose bucket used as the MLflow Tracking Server artifact store.
19553 19554 19555 19556 19557 19558 19559 19560 19561 19562 19563 19564 19565 19566 19567 19568 19569 19570 19571 19572 19573 19574 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19553 class DescribeMlflowTrackingServerResponse < Struct.new( :tracking_server_arn, :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :tracking_server_status, :tracking_server_maintenance_status, :is_active, :tracking_server_url, :weekly_maintenance_window_start, :automatic_model_registration, :creation_time, :created_by, :last_modified_time, :last_modified_by, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#automatic_model_registration ⇒ Boolean
Whether automatic registration of new MLflow models to the SageMaker Model Registry is enabled.
19553 19554 19555 19556 19557 19558 19559 19560 19561 19562 19563 19564 19565 19566 19567 19568 19569 19570 19571 19572 19573 19574 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19553 class DescribeMlflowTrackingServerResponse < Struct.new( :tracking_server_arn, :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :tracking_server_status, :tracking_server_maintenance_status, :is_active, :tracking_server_url, :weekly_maintenance_window_start, :automatic_model_registration, :creation_time, :created_by, :last_modified_time, :last_modified_by, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
19553 19554 19555 19556 19557 19558 19559 19560 19561 19562 19563 19564 19565 19566 19567 19568 19569 19570 19571 19572 19573 19574 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19553 class DescribeMlflowTrackingServerResponse < Struct.new( :tracking_server_arn, :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :tracking_server_status, :tracking_server_maintenance_status, :is_active, :tracking_server_url, :weekly_maintenance_window_start, :automatic_model_registration, :creation_time, :created_by, :last_modified_time, :last_modified_by, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The timestamp of when the described MLflow Tracking Server was created.
19553 19554 19555 19556 19557 19558 19559 19560 19561 19562 19563 19564 19565 19566 19567 19568 19569 19570 19571 19572 19573 19574 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19553 class DescribeMlflowTrackingServerResponse < Struct.new( :tracking_server_arn, :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :tracking_server_status, :tracking_server_maintenance_status, :is_active, :tracking_server_url, :weekly_maintenance_window_start, :automatic_model_registration, :creation_time, :created_by, :last_modified_time, :last_modified_by, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#is_active ⇒ String
Whether the described MLflow Tracking Server is currently active.
19553 19554 19555 19556 19557 19558 19559 19560 19561 19562 19563 19564 19565 19566 19567 19568 19569 19570 19571 19572 19573 19574 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19553 class DescribeMlflowTrackingServerResponse < Struct.new( :tracking_server_arn, :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :tracking_server_status, :tracking_server_maintenance_status, :is_active, :tracking_server_url, :weekly_maintenance_window_start, :automatic_model_registration, :creation_time, :created_by, :last_modified_time, :last_modified_by, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
19553 19554 19555 19556 19557 19558 19559 19560 19561 19562 19563 19564 19565 19566 19567 19568 19569 19570 19571 19572 19573 19574 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19553 class DescribeMlflowTrackingServerResponse < Struct.new( :tracking_server_arn, :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :tracking_server_status, :tracking_server_maintenance_status, :is_active, :tracking_server_url, :weekly_maintenance_window_start, :automatic_model_registration, :creation_time, :created_by, :last_modified_time, :last_modified_by, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp of when the described MLflow Tracking Server was last modified.
19553 19554 19555 19556 19557 19558 19559 19560 19561 19562 19563 19564 19565 19566 19567 19568 19569 19570 19571 19572 19573 19574 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19553 class DescribeMlflowTrackingServerResponse < Struct.new( :tracking_server_arn, :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :tracking_server_status, :tracking_server_maintenance_status, :is_active, :tracking_server_url, :weekly_maintenance_window_start, :automatic_model_registration, :creation_time, :created_by, :last_modified_time, :last_modified_by, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#mlflow_version ⇒ String
The MLflow version used for the described tracking server.
19553 19554 19555 19556 19557 19558 19559 19560 19561 19562 19563 19564 19565 19566 19567 19568 19569 19570 19571 19572 19573 19574 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19553 class DescribeMlflowTrackingServerResponse < Struct.new( :tracking_server_arn, :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :tracking_server_status, :tracking_server_maintenance_status, :is_active, :tracking_server_url, :weekly_maintenance_window_start, :automatic_model_registration, :creation_time, :created_by, :last_modified_time, :last_modified_by, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) for an IAM role in your account that the described MLflow Tracking Server uses to access the artifact store in Amazon S3.
19553 19554 19555 19556 19557 19558 19559 19560 19561 19562 19563 19564 19565 19566 19567 19568 19569 19570 19571 19572 19573 19574 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19553 class DescribeMlflowTrackingServerResponse < Struct.new( :tracking_server_arn, :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :tracking_server_status, :tracking_server_maintenance_status, :is_active, :tracking_server_url, :weekly_maintenance_window_start, :automatic_model_registration, :creation_time, :created_by, :last_modified_time, :last_modified_by, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#s3_bucket_owner_account_id ⇒ String
Expected Amazon Web Services account ID that owns the Amazon S3 bucket for artifact storage.
19553 19554 19555 19556 19557 19558 19559 19560 19561 19562 19563 19564 19565 19566 19567 19568 19569 19570 19571 19572 19573 19574 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19553 class DescribeMlflowTrackingServerResponse < Struct.new( :tracking_server_arn, :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :tracking_server_status, :tracking_server_maintenance_status, :is_active, :tracking_server_url, :weekly_maintenance_window_start, :automatic_model_registration, :creation_time, :created_by, :last_modified_time, :last_modified_by, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#s3_bucket_owner_verification ⇒ Boolean
Whether Amazon S3 Bucket Ownership checks are enabled whenever the tracking server interacts with Amazon Amazon S3.
19553 19554 19555 19556 19557 19558 19559 19560 19561 19562 19563 19564 19565 19566 19567 19568 19569 19570 19571 19572 19573 19574 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19553 class DescribeMlflowTrackingServerResponse < Struct.new( :tracking_server_arn, :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :tracking_server_status, :tracking_server_maintenance_status, :is_active, :tracking_server_url, :weekly_maintenance_window_start, :automatic_model_registration, :creation_time, :created_by, :last_modified_time, :last_modified_by, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#tracking_server_arn ⇒ String
The ARN of the described tracking server.
19553 19554 19555 19556 19557 19558 19559 19560 19561 19562 19563 19564 19565 19566 19567 19568 19569 19570 19571 19572 19573 19574 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19553 class DescribeMlflowTrackingServerResponse < Struct.new( :tracking_server_arn, :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :tracking_server_status, :tracking_server_maintenance_status, :is_active, :tracking_server_url, :weekly_maintenance_window_start, :automatic_model_registration, :creation_time, :created_by, :last_modified_time, :last_modified_by, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#tracking_server_maintenance_status ⇒ String
The current maintenance status of the described MLflow Tracking Server.
19553 19554 19555 19556 19557 19558 19559 19560 19561 19562 19563 19564 19565 19566 19567 19568 19569 19570 19571 19572 19573 19574 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19553 class DescribeMlflowTrackingServerResponse < Struct.new( :tracking_server_arn, :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :tracking_server_status, :tracking_server_maintenance_status, :is_active, :tracking_server_url, :weekly_maintenance_window_start, :automatic_model_registration, :creation_time, :created_by, :last_modified_time, :last_modified_by, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#tracking_server_name ⇒ String
The name of the described tracking server.
19553 19554 19555 19556 19557 19558 19559 19560 19561 19562 19563 19564 19565 19566 19567 19568 19569 19570 19571 19572 19573 19574 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19553 class DescribeMlflowTrackingServerResponse < Struct.new( :tracking_server_arn, :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :tracking_server_status, :tracking_server_maintenance_status, :is_active, :tracking_server_url, :weekly_maintenance_window_start, :automatic_model_registration, :creation_time, :created_by, :last_modified_time, :last_modified_by, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#tracking_server_size ⇒ String
The size of the described tracking server.
19553 19554 19555 19556 19557 19558 19559 19560 19561 19562 19563 19564 19565 19566 19567 19568 19569 19570 19571 19572 19573 19574 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19553 class DescribeMlflowTrackingServerResponse < Struct.new( :tracking_server_arn, :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :tracking_server_status, :tracking_server_maintenance_status, :is_active, :tracking_server_url, :weekly_maintenance_window_start, :automatic_model_registration, :creation_time, :created_by, :last_modified_time, :last_modified_by, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#tracking_server_status ⇒ String
The current creation status of the described MLflow Tracking Server.
19553 19554 19555 19556 19557 19558 19559 19560 19561 19562 19563 19564 19565 19566 19567 19568 19569 19570 19571 19572 19573 19574 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19553 class DescribeMlflowTrackingServerResponse < Struct.new( :tracking_server_arn, :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :tracking_server_status, :tracking_server_maintenance_status, :is_active, :tracking_server_url, :weekly_maintenance_window_start, :automatic_model_registration, :creation_time, :created_by, :last_modified_time, :last_modified_by, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#tracking_server_url ⇒ String
The URL to connect to the MLflow user interface for the described tracking server.
19553 19554 19555 19556 19557 19558 19559 19560 19561 19562 19563 19564 19565 19566 19567 19568 19569 19570 19571 19572 19573 19574 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19553 class DescribeMlflowTrackingServerResponse < Struct.new( :tracking_server_arn, :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :tracking_server_status, :tracking_server_maintenance_status, :is_active, :tracking_server_url, :weekly_maintenance_window_start, :automatic_model_registration, :creation_time, :created_by, :last_modified_time, :last_modified_by, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |
#weekly_maintenance_window_start ⇒ String
The day and time of the week when weekly maintenance occurs on the described tracking server.
19553 19554 19555 19556 19557 19558 19559 19560 19561 19562 19563 19564 19565 19566 19567 19568 19569 19570 19571 19572 19573 19574 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 19553 class DescribeMlflowTrackingServerResponse < Struct.new( :tracking_server_arn, :tracking_server_name, :artifact_store_uri, :tracking_server_size, :mlflow_version, :role_arn, :tracking_server_status, :tracking_server_maintenance_status, :is_active, :tracking_server_url, :weekly_maintenance_window_start, :automatic_model_registration, :creation_time, :created_by, :last_modified_time, :last_modified_by, :s3_bucket_owner_account_id, :s3_bucket_owner_verification) SENSITIVE = [] include Aws::Structure end |