Class: Aws::SageMaker::Types::DescribeModelBiasJobDefinitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeModelBiasJobDefinitionRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_definition_name ⇒ String
The name of the model bias job definition.
Instance Attribute Details
#job_definition_name ⇒ String
The name of the model bias job definition. The name must be unique within an Amazon Web Services Region in the Amazon Web Services account.
20850 20851 20852 20853 20854 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20850 class DescribeModelBiasJobDefinitionRequest < Struct.new( :job_definition_name) SENSITIVE = [] include Aws::Structure end |