Class: Aws::SageMaker::Types::DescribeModelBiasJobDefinitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeModelBiasJobDefinitionRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_definition_name ⇒ String
The name of the model bias job definition.
Instance Attribute Details
#job_definition_name ⇒ String
The name of the model bias job definition. The name must be unique within an Amazon Web Services Region in the Amazon Web Services account.
20815 20816 20817 20818 20819 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20815 class DescribeModelBiasJobDefinitionRequest < Struct.new( :job_definition_name) SENSITIVE = [] include Aws::Structure end |