Class: Aws::SageMaker::Types::DescribeModelBiasJobDefinitionResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timeTime

The time at which the model bias job was created.

Returns:

  • (Time)


21666
21667
21668
21669
21670
21671
21672
21673
21674
21675
21676
21677
21678
21679
21680
# File 'lib/aws-sdk-sagemaker/types.rb', line 21666

class DescribeModelBiasJobDefinitionResponse < Struct.new(
  :job_definition_arn,
  :job_definition_name,
  :creation_time,
  :model_bias_baseline_config,
  :model_bias_app_specification,
  :model_bias_job_input,
  :model_bias_job_output_config,
  :job_resources,
  :network_config,
  :role_arn,
  :stopping_condition)
  SENSITIVE = []
  include Aws::Structure
end

#job_definition_arnString

The Amazon Resource Name (ARN) of the model bias job.

Returns:

  • (String)


21666
21667
21668
21669
21670
21671
21672
21673
21674
21675
21676
21677
21678
21679
21680
# File 'lib/aws-sdk-sagemaker/types.rb', line 21666

class DescribeModelBiasJobDefinitionResponse < Struct.new(
  :job_definition_arn,
  :job_definition_name,
  :creation_time,
  :model_bias_baseline_config,
  :model_bias_app_specification,
  :model_bias_job_input,
  :model_bias_job_output_config,
  :job_resources,
  :network_config,
  :role_arn,
  :stopping_condition)
  SENSITIVE = []
  include Aws::Structure
end

#job_definition_nameString

The name of the bias job definition. The name must be unique within an Amazon Web Services Region in the Amazon Web Services account.

Returns:

  • (String)


21666
21667
21668
21669
21670
21671
21672
21673
21674
21675
21676
21677
21678
21679
21680
# File 'lib/aws-sdk-sagemaker/types.rb', line 21666

class DescribeModelBiasJobDefinitionResponse < Struct.new(
  :job_definition_arn,
  :job_definition_name,
  :creation_time,
  :model_bias_baseline_config,
  :model_bias_app_specification,
  :model_bias_job_input,
  :model_bias_job_output_config,
  :job_resources,
  :network_config,
  :role_arn,
  :stopping_condition)
  SENSITIVE = []
  include Aws::Structure
end

#job_resourcesTypes::MonitoringResources

Identifies the resources to deploy for a monitoring job.



21666
21667
21668
21669
21670
21671
21672
21673
21674
21675
21676
21677
21678
21679
21680
# File 'lib/aws-sdk-sagemaker/types.rb', line 21666

class DescribeModelBiasJobDefinitionResponse < Struct.new(
  :job_definition_arn,
  :job_definition_name,
  :creation_time,
  :model_bias_baseline_config,
  :model_bias_app_specification,
  :model_bias_job_input,
  :model_bias_job_output_config,
  :job_resources,
  :network_config,
  :role_arn,
  :stopping_condition)
  SENSITIVE = []
  include Aws::Structure
end

#model_bias_app_specificationTypes::ModelBiasAppSpecification

Configures the model bias job to run a specified Docker container image.



21666
21667
21668
21669
21670
21671
21672
21673
21674
21675
21676
21677
21678
21679
21680
# File 'lib/aws-sdk-sagemaker/types.rb', line 21666

class DescribeModelBiasJobDefinitionResponse < Struct.new(
  :job_definition_arn,
  :job_definition_name,
  :creation_time,
  :model_bias_baseline_config,
  :model_bias_app_specification,
  :model_bias_job_input,
  :model_bias_job_output_config,
  :job_resources,
  :network_config,
  :role_arn,
  :stopping_condition)
  SENSITIVE = []
  include Aws::Structure
end

#model_bias_baseline_configTypes::ModelBiasBaselineConfig

The baseline configuration for a model bias job.



21666
21667
21668
21669
21670
21671
21672
21673
21674
21675
21676
21677
21678
21679
21680
# File 'lib/aws-sdk-sagemaker/types.rb', line 21666

class DescribeModelBiasJobDefinitionResponse < Struct.new(
  :job_definition_arn,
  :job_definition_name,
  :creation_time,
  :model_bias_baseline_config,
  :model_bias_app_specification,
  :model_bias_job_input,
  :model_bias_job_output_config,
  :job_resources,
  :network_config,
  :role_arn,
  :stopping_condition)
  SENSITIVE = []
  include Aws::Structure
end

#model_bias_job_inputTypes::ModelBiasJobInput

Inputs for the model bias job.



21666
21667
21668
21669
21670
21671
21672
21673
21674
21675
21676
21677
21678
21679
21680
# File 'lib/aws-sdk-sagemaker/types.rb', line 21666

class DescribeModelBiasJobDefinitionResponse < Struct.new(
  :job_definition_arn,
  :job_definition_name,
  :creation_time,
  :model_bias_baseline_config,
  :model_bias_app_specification,
  :model_bias_job_input,
  :model_bias_job_output_config,
  :job_resources,
  :network_config,
  :role_arn,
  :stopping_condition)
  SENSITIVE = []
  include Aws::Structure
end

#model_bias_job_output_configTypes::MonitoringOutputConfig

The output configuration for monitoring jobs.



21666
21667
21668
21669
21670
21671
21672
21673
21674
21675
21676
21677
21678
21679
21680
# File 'lib/aws-sdk-sagemaker/types.rb', line 21666

class DescribeModelBiasJobDefinitionResponse < Struct.new(
  :job_definition_arn,
  :job_definition_name,
  :creation_time,
  :model_bias_baseline_config,
  :model_bias_app_specification,
  :model_bias_job_input,
  :model_bias_job_output_config,
  :job_resources,
  :network_config,
  :role_arn,
  :stopping_condition)
  SENSITIVE = []
  include Aws::Structure
end

#network_configTypes::MonitoringNetworkConfig

Networking options for a model bias job.



21666
21667
21668
21669
21670
21671
21672
21673
21674
21675
21676
21677
21678
21679
21680
# File 'lib/aws-sdk-sagemaker/types.rb', line 21666

class DescribeModelBiasJobDefinitionResponse < Struct.new(
  :job_definition_arn,
  :job_definition_name,
  :creation_time,
  :model_bias_baseline_config,
  :model_bias_app_specification,
  :model_bias_job_input,
  :model_bias_job_output_config,
  :job_resources,
  :network_config,
  :role_arn,
  :stopping_condition)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of the IAM role that has read permission to the input data location and write permission to the output data location in Amazon S3.

Returns:

  • (String)


21666
21667
21668
21669
21670
21671
21672
21673
21674
21675
21676
21677
21678
21679
21680
# File 'lib/aws-sdk-sagemaker/types.rb', line 21666

class DescribeModelBiasJobDefinitionResponse < Struct.new(
  :job_definition_arn,
  :job_definition_name,
  :creation_time,
  :model_bias_baseline_config,
  :model_bias_app_specification,
  :model_bias_job_input,
  :model_bias_job_output_config,
  :job_resources,
  :network_config,
  :role_arn,
  :stopping_condition)
  SENSITIVE = []
  include Aws::Structure
end

#stopping_conditionTypes::MonitoringStoppingCondition

A time limit for how long the monitoring job is allowed to run before stopping.



21666
21667
21668
21669
21670
21671
21672
21673
21674
21675
21676
21677
21678
21679
21680
# File 'lib/aws-sdk-sagemaker/types.rb', line 21666

class DescribeModelBiasJobDefinitionResponse < Struct.new(
  :job_definition_arn,
  :job_definition_name,
  :creation_time,
  :model_bias_baseline_config,
  :model_bias_app_specification,
  :model_bias_job_input,
  :model_bias_job_output_config,
  :job_resources,
  :network_config,
  :role_arn,
  :stopping_condition)
  SENSITIVE = []
  include Aws::Structure
end