Class: Aws::SageMaker::Types::DescribeModelBiasJobDefinitionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeModelBiasJobDefinitionResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Time
The time at which the model bias job was created.
-
#job_definition_arn ⇒ String
The Amazon Resource Name (ARN) of the model bias job.
-
#job_definition_name ⇒ String
The name of the bias job definition.
-
#job_resources ⇒ Types::MonitoringResources
Identifies the resources to deploy for a monitoring job.
-
#model_bias_app_specification ⇒ Types::ModelBiasAppSpecification
Configures the model bias job to run a specified Docker container image.
-
#model_bias_baseline_config ⇒ Types::ModelBiasBaselineConfig
The baseline configuration for a model bias job.
-
#model_bias_job_input ⇒ Types::ModelBiasJobInput
Inputs for the model bias job.
-
#model_bias_job_output_config ⇒ Types::MonitoringOutputConfig
The output configuration for monitoring jobs.
-
#network_config ⇒ Types::MonitoringNetworkConfig
Networking options for a model bias job.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that has read permission to the input data location and write permission to the output data location in Amazon S3.
-
#stopping_condition ⇒ Types::MonitoringStoppingCondition
A time limit for how long the monitoring job is allowed to run before stopping.
Instance Attribute Details
#creation_time ⇒ Time
The time at which the model bias job was created.
20855 20856 20857 20858 20859 20860 20861 20862 20863 20864 20865 20866 20867 20868 20869 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20855 class DescribeModelBiasJobDefinitionResponse < Struct.new( :job_definition_arn, :job_definition_name, :creation_time, :model_bias_baseline_config, :model_bias_app_specification, :model_bias_job_input, :model_bias_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition) SENSITIVE = [] include Aws::Structure end |
#job_definition_arn ⇒ String
The Amazon Resource Name (ARN) of the model bias job.
20855 20856 20857 20858 20859 20860 20861 20862 20863 20864 20865 20866 20867 20868 20869 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20855 class DescribeModelBiasJobDefinitionResponse < Struct.new( :job_definition_arn, :job_definition_name, :creation_time, :model_bias_baseline_config, :model_bias_app_specification, :model_bias_job_input, :model_bias_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition) SENSITIVE = [] include Aws::Structure end |
#job_definition_name ⇒ String
The name of the bias job definition. The name must be unique within an Amazon Web Services Region in the Amazon Web Services account.
20855 20856 20857 20858 20859 20860 20861 20862 20863 20864 20865 20866 20867 20868 20869 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20855 class DescribeModelBiasJobDefinitionResponse < Struct.new( :job_definition_arn, :job_definition_name, :creation_time, :model_bias_baseline_config, :model_bias_app_specification, :model_bias_job_input, :model_bias_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition) SENSITIVE = [] include Aws::Structure end |
#job_resources ⇒ Types::MonitoringResources
Identifies the resources to deploy for a monitoring job.
20855 20856 20857 20858 20859 20860 20861 20862 20863 20864 20865 20866 20867 20868 20869 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20855 class DescribeModelBiasJobDefinitionResponse < Struct.new( :job_definition_arn, :job_definition_name, :creation_time, :model_bias_baseline_config, :model_bias_app_specification, :model_bias_job_input, :model_bias_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition) SENSITIVE = [] include Aws::Structure end |
#model_bias_app_specification ⇒ Types::ModelBiasAppSpecification
Configures the model bias job to run a specified Docker container image.
20855 20856 20857 20858 20859 20860 20861 20862 20863 20864 20865 20866 20867 20868 20869 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20855 class DescribeModelBiasJobDefinitionResponse < Struct.new( :job_definition_arn, :job_definition_name, :creation_time, :model_bias_baseline_config, :model_bias_app_specification, :model_bias_job_input, :model_bias_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition) SENSITIVE = [] include Aws::Structure end |
#model_bias_baseline_config ⇒ Types::ModelBiasBaselineConfig
The baseline configuration for a model bias job.
20855 20856 20857 20858 20859 20860 20861 20862 20863 20864 20865 20866 20867 20868 20869 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20855 class DescribeModelBiasJobDefinitionResponse < Struct.new( :job_definition_arn, :job_definition_name, :creation_time, :model_bias_baseline_config, :model_bias_app_specification, :model_bias_job_input, :model_bias_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition) SENSITIVE = [] include Aws::Structure end |
#model_bias_job_input ⇒ Types::ModelBiasJobInput
Inputs for the model bias job.
20855 20856 20857 20858 20859 20860 20861 20862 20863 20864 20865 20866 20867 20868 20869 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20855 class DescribeModelBiasJobDefinitionResponse < Struct.new( :job_definition_arn, :job_definition_name, :creation_time, :model_bias_baseline_config, :model_bias_app_specification, :model_bias_job_input, :model_bias_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition) SENSITIVE = [] include Aws::Structure end |
#model_bias_job_output_config ⇒ Types::MonitoringOutputConfig
The output configuration for monitoring jobs.
20855 20856 20857 20858 20859 20860 20861 20862 20863 20864 20865 20866 20867 20868 20869 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20855 class DescribeModelBiasJobDefinitionResponse < Struct.new( :job_definition_arn, :job_definition_name, :creation_time, :model_bias_baseline_config, :model_bias_app_specification, :model_bias_job_input, :model_bias_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition) SENSITIVE = [] include Aws::Structure end |
#network_config ⇒ Types::MonitoringNetworkConfig
Networking options for a model bias job.
20855 20856 20857 20858 20859 20860 20861 20862 20863 20864 20865 20866 20867 20868 20869 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20855 class DescribeModelBiasJobDefinitionResponse < Struct.new( :job_definition_arn, :job_definition_name, :creation_time, :model_bias_baseline_config, :model_bias_app_specification, :model_bias_job_input, :model_bias_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that has read permission to the input data location and write permission to the output data location in Amazon S3.
20855 20856 20857 20858 20859 20860 20861 20862 20863 20864 20865 20866 20867 20868 20869 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20855 class DescribeModelBiasJobDefinitionResponse < Struct.new( :job_definition_arn, :job_definition_name, :creation_time, :model_bias_baseline_config, :model_bias_app_specification, :model_bias_job_input, :model_bias_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition) SENSITIVE = [] include Aws::Structure end |
#stopping_condition ⇒ Types::MonitoringStoppingCondition
A time limit for how long the monitoring job is allowed to run before stopping.
20855 20856 20857 20858 20859 20860 20861 20862 20863 20864 20865 20866 20867 20868 20869 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 20855 class DescribeModelBiasJobDefinitionResponse < Struct.new( :job_definition_arn, :job_definition_name, :creation_time, :model_bias_baseline_config, :model_bias_app_specification, :model_bias_job_input, :model_bias_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition) SENSITIVE = [] include Aws::Structure end |