Class: Aws::SageMaker::Types::DescribeModelCardExportJobResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeModelCardExportJobResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The date and time that the model export job was created.
-
#export_artifacts ⇒ Types::ModelCardExportArtifacts
The exported model card artifacts.
-
#failure_reason ⇒ String
The failure reason if the model export job fails.
-
#last_modified_at ⇒ Time
The date and time that the model export job was last modified.
-
#model_card_export_job_arn ⇒ String
The Amazon Resource Name (ARN) of the model card export job.
-
#model_card_export_job_name ⇒ String
The name of the model card export job to describe.
-
#model_card_name ⇒ String
The name or Amazon Resource Name (ARN) of the model card that the model export job exports.
-
#model_card_version ⇒ Integer
The version of the model card that the model export job exports.
-
#output_config ⇒ Types::ModelCardExportOutputConfig
The export output details for the model card.
-
#status ⇒ String
The completion status of the model card export job.
Instance Attribute Details
#created_at ⇒ Time
The date and time that the model export job was created.
21746 21747 21748 21749 21750 21751 21752 21753 21754 21755 21756 21757 21758 21759 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21746 class DescribeModelCardExportJobResponse < Struct.new( :model_card_export_job_name, :model_card_export_job_arn, :status, :model_card_name, :model_card_version, :output_config, :created_at, :last_modified_at, :failure_reason, :export_artifacts) SENSITIVE = [] include Aws::Structure end |
#export_artifacts ⇒ Types::ModelCardExportArtifacts
The exported model card artifacts.
21746 21747 21748 21749 21750 21751 21752 21753 21754 21755 21756 21757 21758 21759 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21746 class DescribeModelCardExportJobResponse < Struct.new( :model_card_export_job_name, :model_card_export_job_arn, :status, :model_card_name, :model_card_version, :output_config, :created_at, :last_modified_at, :failure_reason, :export_artifacts) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
The failure reason if the model export job fails.
21746 21747 21748 21749 21750 21751 21752 21753 21754 21755 21756 21757 21758 21759 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21746 class DescribeModelCardExportJobResponse < Struct.new( :model_card_export_job_name, :model_card_export_job_arn, :status, :model_card_name, :model_card_version, :output_config, :created_at, :last_modified_at, :failure_reason, :export_artifacts) SENSITIVE = [] include Aws::Structure end |
#last_modified_at ⇒ Time
The date and time that the model export job was last modified.
21746 21747 21748 21749 21750 21751 21752 21753 21754 21755 21756 21757 21758 21759 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21746 class DescribeModelCardExportJobResponse < Struct.new( :model_card_export_job_name, :model_card_export_job_arn, :status, :model_card_name, :model_card_version, :output_config, :created_at, :last_modified_at, :failure_reason, :export_artifacts) SENSITIVE = [] include Aws::Structure end |
#model_card_export_job_arn ⇒ String
The Amazon Resource Name (ARN) of the model card export job.
21746 21747 21748 21749 21750 21751 21752 21753 21754 21755 21756 21757 21758 21759 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21746 class DescribeModelCardExportJobResponse < Struct.new( :model_card_export_job_name, :model_card_export_job_arn, :status, :model_card_name, :model_card_version, :output_config, :created_at, :last_modified_at, :failure_reason, :export_artifacts) SENSITIVE = [] include Aws::Structure end |
#model_card_export_job_name ⇒ String
The name of the model card export job to describe.
21746 21747 21748 21749 21750 21751 21752 21753 21754 21755 21756 21757 21758 21759 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21746 class DescribeModelCardExportJobResponse < Struct.new( :model_card_export_job_name, :model_card_export_job_arn, :status, :model_card_name, :model_card_version, :output_config, :created_at, :last_modified_at, :failure_reason, :export_artifacts) SENSITIVE = [] include Aws::Structure end |
#model_card_name ⇒ String
The name or Amazon Resource Name (ARN) of the model card that the model export job exports.
21746 21747 21748 21749 21750 21751 21752 21753 21754 21755 21756 21757 21758 21759 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21746 class DescribeModelCardExportJobResponse < Struct.new( :model_card_export_job_name, :model_card_export_job_arn, :status, :model_card_name, :model_card_version, :output_config, :created_at, :last_modified_at, :failure_reason, :export_artifacts) SENSITIVE = [] include Aws::Structure end |
#model_card_version ⇒ Integer
The version of the model card that the model export job exports.
21746 21747 21748 21749 21750 21751 21752 21753 21754 21755 21756 21757 21758 21759 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21746 class DescribeModelCardExportJobResponse < Struct.new( :model_card_export_job_name, :model_card_export_job_arn, :status, :model_card_name, :model_card_version, :output_config, :created_at, :last_modified_at, :failure_reason, :export_artifacts) SENSITIVE = [] include Aws::Structure end |
#output_config ⇒ Types::ModelCardExportOutputConfig
The export output details for the model card.
21746 21747 21748 21749 21750 21751 21752 21753 21754 21755 21756 21757 21758 21759 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21746 class DescribeModelCardExportJobResponse < Struct.new( :model_card_export_job_name, :model_card_export_job_arn, :status, :model_card_name, :model_card_version, :output_config, :created_at, :last_modified_at, :failure_reason, :export_artifacts) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The completion status of the model card export job.
-
InProgress: The model card export job is in progress. -
Completed: The model card export job is complete. -
Failed: The model card export job failed. To see the reason for the failure, see theFailureReasonfield in the response to aDescribeModelCardExportJobcall.
21746 21747 21748 21749 21750 21751 21752 21753 21754 21755 21756 21757 21758 21759 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21746 class DescribeModelCardExportJobResponse < Struct.new( :model_card_export_job_name, :model_card_export_job_arn, :status, :model_card_name, :model_card_version, :output_config, :created_at, :last_modified_at, :failure_reason, :export_artifacts) SENSITIVE = [] include Aws::Structure end |