Class: Aws::SageMaker::Types::DescribeModelCardRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeModelCardRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#included_data ⇒ String
Specifies the level of model card data to include in the response.
-
#model_card_name ⇒ String
The name or Amazon Resource Name (ARN) of the model card to describe.
-
#model_card_version ⇒ Integer
The version of the model card to describe.
Instance Attribute Details
#included_data ⇒ String
Specifies the level of model card data to include in the response. Use this parameter to call ‘DescribeModelCard` without requiring `kms:Decrypt` permission on the customer-managed Amazon Web Services KMS key.
-
‘AllData`: Returns the full model card `Content`. This option requires `kms:Decrypt` permission on the customer-managed key, if one is associated with the model card. This is the default.
-
‘MetadataOnly`: Returns the model card with sanitized `Content` that includes only a small set of unencrypted metadata fields. This option does not require `kms:Decrypt` permission. For the list of fields preserved in the response, see `Content`.
If you don’t specify a value, SageMaker returns ‘AllData`.
21354 21355 21356 21357 21358 21359 21360 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21354 class DescribeModelCardRequest < Struct.new( :model_card_name, :model_card_version, :included_data) SENSITIVE = [] include Aws::Structure end |
#model_card_name ⇒ String
The name or Amazon Resource Name (ARN) of the model card to describe.
21354 21355 21356 21357 21358 21359 21360 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21354 class DescribeModelCardRequest < Struct.new( :model_card_name, :model_card_version, :included_data) SENSITIVE = [] include Aws::Structure end |
#model_card_version ⇒ Integer
The version of the model card to describe. If a version is not provided, then the latest version of the model card is described.
21354 21355 21356 21357 21358 21359 21360 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21354 class DescribeModelCardRequest < Struct.new( :model_card_name, :model_card_version, :included_data) SENSITIVE = [] include Aws::Structure end |