Class: Aws::SageMaker::Types::DescribeModelCardResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeModelCardResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:content]
Instance Attribute Summary collapse
-
#content ⇒ String
The content of the model card.
-
#created_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
-
#creation_time ⇒ Time
The date and time the model card was created.
-
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
-
#last_modified_time ⇒ Time
The date and time the model card was last modified.
-
#model_card_arn ⇒ String
The Amazon Resource Name (ARN) of the model card.
-
#model_card_name ⇒ String
The name of the model card.
-
#model_card_processing_status ⇒ String
The processing status of model card deletion.
-
#model_card_status ⇒ String
The approval status of the model card within your organization.
-
#model_card_version ⇒ Integer
The version of the model card.
-
#security_config ⇒ Types::ModelCardSecurityConfig
The security configuration used to protect model card content.
Instance Attribute Details
#content ⇒ String
The content of the model card. Content is provided as a string in the [model card JSON schema].
When you set ‘IncludedData` to `MetadataOnly` in the request, SageMaker returns a sanitized version of `Content` that includes only the following JSON paths, when present in the model card:
-
‘model_overview.model_id`
-
‘model_overview.model_name`
-
‘intended_uses.risk_rating`
-
‘model_package_details.model_package_group_name`
-
‘model_package_details.model_package_arn`
All other fields are removed from ‘Content` when `IncludedData` is `MetadataOnly`, including model description, training details, evaluation details, business details, and additional information. To retrieve the complete `Content`, set `IncludedData` to `AllData` or omit the parameter.
[1]: docs.aws.amazon.com/sagemaker/latest/dg/model-cards.html#model-cards-json-schema
21541 21542 21543 21544 21545 21546 21547 21548 21549 21550 21551 21552 21553 21554 21555 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21541 class DescribeModelCardResponse < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :content, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :model_card_processing_status) SENSITIVE = [:content] include Aws::Structure end |
#created_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
21541 21542 21543 21544 21545 21546 21547 21548 21549 21550 21551 21552 21553 21554 21555 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21541 class DescribeModelCardResponse < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :content, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :model_card_processing_status) SENSITIVE = [:content] include Aws::Structure end |
#creation_time ⇒ Time
The date and time the model card was created.
21541 21542 21543 21544 21545 21546 21547 21548 21549 21550 21551 21552 21553 21554 21555 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21541 class DescribeModelCardResponse < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :content, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :model_card_processing_status) SENSITIVE = [:content] include Aws::Structure end |
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
21541 21542 21543 21544 21545 21546 21547 21548 21549 21550 21551 21552 21553 21554 21555 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21541 class DescribeModelCardResponse < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :content, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :model_card_processing_status) SENSITIVE = [:content] include Aws::Structure end |
#last_modified_time ⇒ Time
The date and time the model card was last modified.
21541 21542 21543 21544 21545 21546 21547 21548 21549 21550 21551 21552 21553 21554 21555 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21541 class DescribeModelCardResponse < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :content, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :model_card_processing_status) SENSITIVE = [:content] include Aws::Structure end |
#model_card_arn ⇒ String
The Amazon Resource Name (ARN) of the model card.
21541 21542 21543 21544 21545 21546 21547 21548 21549 21550 21551 21552 21553 21554 21555 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21541 class DescribeModelCardResponse < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :content, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :model_card_processing_status) SENSITIVE = [:content] include Aws::Structure end |
#model_card_name ⇒ String
The name of the model card.
21541 21542 21543 21544 21545 21546 21547 21548 21549 21550 21551 21552 21553 21554 21555 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21541 class DescribeModelCardResponse < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :content, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :model_card_processing_status) SENSITIVE = [:content] include Aws::Structure end |
#model_card_processing_status ⇒ String
The processing status of model card deletion. The ‘ModelCardProcessingStatus` updates throughout the different deletion steps.
-
‘DeletePending`: Model card deletion request received.
-
‘DeleteInProgress`: Model card deletion is in progress.
-
‘ContentDeleted`: Deleted model card content.
-
‘ExportJobsDeleted`: Deleted all export jobs associated with the model card.
-
‘DeleteCompleted`: Successfully deleted the model card.
-
‘DeleteFailed`: The model card failed to delete.
21541 21542 21543 21544 21545 21546 21547 21548 21549 21550 21551 21552 21553 21554 21555 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21541 class DescribeModelCardResponse < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :content, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :model_card_processing_status) SENSITIVE = [:content] include Aws::Structure end |
#model_card_status ⇒ String
The approval status of the model card within your organization. Different organizations might have different criteria for model card review and approval.
-
‘Draft`: The model card is a work in progress.
-
‘PendingReview`: The model card is pending review.
-
‘Approved`: The model card is approved.
-
‘Archived`: The model card is archived. No more updates should be made to the model card, but it can still be exported.
21541 21542 21543 21544 21545 21546 21547 21548 21549 21550 21551 21552 21553 21554 21555 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21541 class DescribeModelCardResponse < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :content, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :model_card_processing_status) SENSITIVE = [:content] include Aws::Structure end |
#model_card_version ⇒ Integer
The version of the model card.
21541 21542 21543 21544 21545 21546 21547 21548 21549 21550 21551 21552 21553 21554 21555 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21541 class DescribeModelCardResponse < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :content, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :model_card_processing_status) SENSITIVE = [:content] include Aws::Structure end |
#security_config ⇒ Types::ModelCardSecurityConfig
The security configuration used to protect model card content.
21541 21542 21543 21544 21545 21546 21547 21548 21549 21550 21551 21552 21553 21554 21555 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21541 class DescribeModelCardResponse < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :content, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :model_card_processing_status) SENSITIVE = [:content] include Aws::Structure end |