Class: Aws::SageMaker::Types::DescribeModelCardResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeModelCardResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:content]
Instance Attribute Summary collapse
-
#content ⇒ String
The content of the model card.
-
#created_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
-
#creation_time ⇒ Time
The date and time the model card was created.
-
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
-
#last_modified_time ⇒ Time
The date and time the model card was last modified.
-
#model_card_arn ⇒ String
The Amazon Resource Name (ARN) of the model card.
-
#model_card_name ⇒ String
The name of the model card.
-
#model_card_processing_status ⇒ String
The processing status of model card deletion.
-
#model_card_status ⇒ String
The approval status of the model card within your organization.
-
#model_card_version ⇒ Integer
The version of the model card.
-
#security_config ⇒ Types::ModelCardSecurityConfig
The security configuration used to protect model card content.
Instance Attribute Details
#content ⇒ String
The content of the model card.
21060 21061 21062 21063 21064 21065 21066 21067 21068 21069 21070 21071 21072 21073 21074 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21060 class DescribeModelCardResponse < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :content, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :model_card_processing_status) SENSITIVE = [:content] include Aws::Structure end |
#created_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
21060 21061 21062 21063 21064 21065 21066 21067 21068 21069 21070 21071 21072 21073 21074 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21060 class DescribeModelCardResponse < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :content, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :model_card_processing_status) SENSITIVE = [:content] include Aws::Structure end |
#creation_time ⇒ Time
The date and time the model card was created.
21060 21061 21062 21063 21064 21065 21066 21067 21068 21069 21070 21071 21072 21073 21074 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21060 class DescribeModelCardResponse < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :content, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :model_card_processing_status) SENSITIVE = [:content] include Aws::Structure end |
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
21060 21061 21062 21063 21064 21065 21066 21067 21068 21069 21070 21071 21072 21073 21074 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21060 class DescribeModelCardResponse < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :content, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :model_card_processing_status) SENSITIVE = [:content] include Aws::Structure end |
#last_modified_time ⇒ Time
The date and time the model card was last modified.
21060 21061 21062 21063 21064 21065 21066 21067 21068 21069 21070 21071 21072 21073 21074 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21060 class DescribeModelCardResponse < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :content, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :model_card_processing_status) SENSITIVE = [:content] include Aws::Structure end |
#model_card_arn ⇒ String
The Amazon Resource Name (ARN) of the model card.
21060 21061 21062 21063 21064 21065 21066 21067 21068 21069 21070 21071 21072 21073 21074 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21060 class DescribeModelCardResponse < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :content, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :model_card_processing_status) SENSITIVE = [:content] include Aws::Structure end |
#model_card_name ⇒ String
The name of the model card.
21060 21061 21062 21063 21064 21065 21066 21067 21068 21069 21070 21071 21072 21073 21074 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21060 class DescribeModelCardResponse < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :content, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :model_card_processing_status) SENSITIVE = [:content] include Aws::Structure end |
#model_card_processing_status ⇒ String
The processing status of model card deletion. The ‘ModelCardProcessingStatus` updates throughout the different deletion steps.
-
‘DeletePending`: Model card deletion request received.
-
‘DeleteInProgress`: Model card deletion is in progress.
-
‘ContentDeleted`: Deleted model card content.
-
‘ExportJobsDeleted`: Deleted all export jobs associated with the model card.
-
‘DeleteCompleted`: Successfully deleted the model card.
-
‘DeleteFailed`: The model card failed to delete.
21060 21061 21062 21063 21064 21065 21066 21067 21068 21069 21070 21071 21072 21073 21074 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21060 class DescribeModelCardResponse < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :content, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :model_card_processing_status) SENSITIVE = [:content] include Aws::Structure end |
#model_card_status ⇒ String
The approval status of the model card within your organization. Different organizations might have different criteria for model card review and approval.
-
‘Draft`: The model card is a work in progress.
-
‘PendingReview`: The model card is pending review.
-
‘Approved`: The model card is approved.
-
‘Archived`: The model card is archived. No more updates should be made to the model card, but it can still be exported.
21060 21061 21062 21063 21064 21065 21066 21067 21068 21069 21070 21071 21072 21073 21074 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21060 class DescribeModelCardResponse < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :content, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :model_card_processing_status) SENSITIVE = [:content] include Aws::Structure end |
#model_card_version ⇒ Integer
The version of the model card.
21060 21061 21062 21063 21064 21065 21066 21067 21068 21069 21070 21071 21072 21073 21074 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21060 class DescribeModelCardResponse < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :content, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :model_card_processing_status) SENSITIVE = [:content] include Aws::Structure end |
#security_config ⇒ Types::ModelCardSecurityConfig
The security configuration used to protect model card content.
21060 21061 21062 21063 21064 21065 21066 21067 21068 21069 21070 21071 21072 21073 21074 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21060 class DescribeModelCardResponse < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :content, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :model_card_processing_status) SENSITIVE = [:content] include Aws::Structure end |