Class: Aws::SageMaker::Types::DescribeModelExplainabilityJobDefinitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeModelExplainabilityJobDefinitionRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_definition_name ⇒ String
The name of the model explainability job definition.
Instance Attribute Details
#job_definition_name ⇒ String
The name of the model explainability job definition. The name must be unique within an Amazon Web Services Region in the Amazon Web Services account.
21893 21894 21895 21896 21897 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21893 class DescribeModelExplainabilityJobDefinitionRequest < Struct.new( :job_definition_name) SENSITIVE = [] include Aws::Structure end |