Class: Aws::SageMaker::Types::DescribeModelExplainabilityJobDefinitionRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#job_definition_nameString

The name of the model explainability job definition. The name must be unique within an Amazon Web Services Region in the Amazon Web Services account.



19646
19647
19648
19649
19650
# File 'lib/aws-sdk-sagemaker/types.rb', line 19646

class DescribeModelExplainabilityJobDefinitionRequest < Struct.new(
  :job_definition_name)
  SENSITIVE = []
  include Aws::Structure
end