Class: Aws::SageMaker::Types::DescribeModelExplainabilityJobDefinitionResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timeTime

The time at which the model explainability job was created.

Returns:

  • (Time)


21107
21108
21109
21110
21111
21112
21113
21114
21115
21116
21117
21118
21119
21120
21121
# File 'lib/aws-sdk-sagemaker/types.rb', line 21107

class DescribeModelExplainabilityJobDefinitionResponse < Struct.new(
  :job_definition_arn,
  :job_definition_name,
  :creation_time,
  :model_explainability_baseline_config,
  :model_explainability_app_specification,
  :model_explainability_job_input,
  :model_explainability_job_output_config,
  :job_resources,
  :network_config,
  :role_arn,
  :stopping_condition)
  SENSITIVE = []
  include Aws::Structure
end

#job_definition_arnString

The Amazon Resource Name (ARN) of the model explainability job.

Returns:

  • (String)


21107
21108
21109
21110
21111
21112
21113
21114
21115
21116
21117
21118
21119
21120
21121
# File 'lib/aws-sdk-sagemaker/types.rb', line 21107

class DescribeModelExplainabilityJobDefinitionResponse < Struct.new(
  :job_definition_arn,
  :job_definition_name,
  :creation_time,
  :model_explainability_baseline_config,
  :model_explainability_app_specification,
  :model_explainability_job_input,
  :model_explainability_job_output_config,
  :job_resources,
  :network_config,
  :role_arn,
  :stopping_condition)
  SENSITIVE = []
  include Aws::Structure
end

#job_definition_nameString

The name of the explainability job definition. The name must be unique within an Amazon Web Services Region in the Amazon Web Services account.

Returns:

  • (String)


21107
21108
21109
21110
21111
21112
21113
21114
21115
21116
21117
21118
21119
21120
21121
# File 'lib/aws-sdk-sagemaker/types.rb', line 21107

class DescribeModelExplainabilityJobDefinitionResponse < Struct.new(
  :job_definition_arn,
  :job_definition_name,
  :creation_time,
  :model_explainability_baseline_config,
  :model_explainability_app_specification,
  :model_explainability_job_input,
  :model_explainability_job_output_config,
  :job_resources,
  :network_config,
  :role_arn,
  :stopping_condition)
  SENSITIVE = []
  include Aws::Structure
end

#job_resourcesTypes::MonitoringResources

Identifies the resources to deploy for a monitoring job.



21107
21108
21109
21110
21111
21112
21113
21114
21115
21116
21117
21118
21119
21120
21121
# File 'lib/aws-sdk-sagemaker/types.rb', line 21107

class DescribeModelExplainabilityJobDefinitionResponse < Struct.new(
  :job_definition_arn,
  :job_definition_name,
  :creation_time,
  :model_explainability_baseline_config,
  :model_explainability_app_specification,
  :model_explainability_job_input,
  :model_explainability_job_output_config,
  :job_resources,
  :network_config,
  :role_arn,
  :stopping_condition)
  SENSITIVE = []
  include Aws::Structure
end

#model_explainability_app_specificationTypes::ModelExplainabilityAppSpecification

Configures the model explainability job to run a specified Docker container image.



21107
21108
21109
21110
21111
21112
21113
21114
21115
21116
21117
21118
21119
21120
21121
# File 'lib/aws-sdk-sagemaker/types.rb', line 21107

class DescribeModelExplainabilityJobDefinitionResponse < Struct.new(
  :job_definition_arn,
  :job_definition_name,
  :creation_time,
  :model_explainability_baseline_config,
  :model_explainability_app_specification,
  :model_explainability_job_input,
  :model_explainability_job_output_config,
  :job_resources,
  :network_config,
  :role_arn,
  :stopping_condition)
  SENSITIVE = []
  include Aws::Structure
end

#model_explainability_baseline_configTypes::ModelExplainabilityBaselineConfig

The baseline configuration for a model explainability job.



21107
21108
21109
21110
21111
21112
21113
21114
21115
21116
21117
21118
21119
21120
21121
# File 'lib/aws-sdk-sagemaker/types.rb', line 21107

class DescribeModelExplainabilityJobDefinitionResponse < Struct.new(
  :job_definition_arn,
  :job_definition_name,
  :creation_time,
  :model_explainability_baseline_config,
  :model_explainability_app_specification,
  :model_explainability_job_input,
  :model_explainability_job_output_config,
  :job_resources,
  :network_config,
  :role_arn,
  :stopping_condition)
  SENSITIVE = []
  include Aws::Structure
end

#model_explainability_job_inputTypes::ModelExplainabilityJobInput

Inputs for the model explainability job.



21107
21108
21109
21110
21111
21112
21113
21114
21115
21116
21117
21118
21119
21120
21121
# File 'lib/aws-sdk-sagemaker/types.rb', line 21107

class DescribeModelExplainabilityJobDefinitionResponse < Struct.new(
  :job_definition_arn,
  :job_definition_name,
  :creation_time,
  :model_explainability_baseline_config,
  :model_explainability_app_specification,
  :model_explainability_job_input,
  :model_explainability_job_output_config,
  :job_resources,
  :network_config,
  :role_arn,
  :stopping_condition)
  SENSITIVE = []
  include Aws::Structure
end

#model_explainability_job_output_configTypes::MonitoringOutputConfig

The output configuration for monitoring jobs.



21107
21108
21109
21110
21111
21112
21113
21114
21115
21116
21117
21118
21119
21120
21121
# File 'lib/aws-sdk-sagemaker/types.rb', line 21107

class DescribeModelExplainabilityJobDefinitionResponse < Struct.new(
  :job_definition_arn,
  :job_definition_name,
  :creation_time,
  :model_explainability_baseline_config,
  :model_explainability_app_specification,
  :model_explainability_job_input,
  :model_explainability_job_output_config,
  :job_resources,
  :network_config,
  :role_arn,
  :stopping_condition)
  SENSITIVE = []
  include Aws::Structure
end

#network_configTypes::MonitoringNetworkConfig

Networking options for a model explainability job.



21107
21108
21109
21110
21111
21112
21113
21114
21115
21116
21117
21118
21119
21120
21121
# File 'lib/aws-sdk-sagemaker/types.rb', line 21107

class DescribeModelExplainabilityJobDefinitionResponse < Struct.new(
  :job_definition_arn,
  :job_definition_name,
  :creation_time,
  :model_explainability_baseline_config,
  :model_explainability_app_specification,
  :model_explainability_job_input,
  :model_explainability_job_output_config,
  :job_resources,
  :network_config,
  :role_arn,
  :stopping_condition)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of the IAM role that has read permission to the input data location and write permission to the output data location in Amazon S3.

Returns:

  • (String)


21107
21108
21109
21110
21111
21112
21113
21114
21115
21116
21117
21118
21119
21120
21121
# File 'lib/aws-sdk-sagemaker/types.rb', line 21107

class DescribeModelExplainabilityJobDefinitionResponse < Struct.new(
  :job_definition_arn,
  :job_definition_name,
  :creation_time,
  :model_explainability_baseline_config,
  :model_explainability_app_specification,
  :model_explainability_job_input,
  :model_explainability_job_output_config,
  :job_resources,
  :network_config,
  :role_arn,
  :stopping_condition)
  SENSITIVE = []
  include Aws::Structure
end

#stopping_conditionTypes::MonitoringStoppingCondition

A time limit for how long the monitoring job is allowed to run before stopping.



21107
21108
21109
21110
21111
21112
21113
21114
21115
21116
21117
21118
21119
21120
21121
# File 'lib/aws-sdk-sagemaker/types.rb', line 21107

class DescribeModelExplainabilityJobDefinitionResponse < Struct.new(
  :job_definition_arn,
  :job_definition_name,
  :creation_time,
  :model_explainability_baseline_config,
  :model_explainability_app_specification,
  :model_explainability_job_input,
  :model_explainability_job_output_config,
  :job_resources,
  :network_config,
  :role_arn,
  :stopping_condition)
  SENSITIVE = []
  include Aws::Structure
end