Class: Aws::SageMaker::Types::DescribeModelExplainabilityJobDefinitionResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timeTime

The time at which the model explainability job was created.

Returns:

  • (Time)


19730
19731
19732
19733
19734
19735
19736
19737
19738
19739
19740
19741
19742
19743
19744
# File 'lib/aws-sdk-sagemaker/types.rb', line 19730

class DescribeModelExplainabilityJobDefinitionResponse < Struct.new(
  :job_definition_arn,
  :job_definition_name,
  :creation_time,
  :model_explainability_baseline_config,
  :model_explainability_app_specification,
  :model_explainability_job_input,
  :model_explainability_job_output_config,
  :job_resources,
  :network_config,
  :role_arn,
  :stopping_condition)
  SENSITIVE = []
  include Aws::Structure
end

#job_definition_arnString

The Amazon Resource Name (ARN) of the model explainability job.

Returns:

  • (String)


19730
19731
19732
19733
19734
19735
19736
19737
19738
19739
19740
19741
19742
19743
19744
# File 'lib/aws-sdk-sagemaker/types.rb', line 19730

class DescribeModelExplainabilityJobDefinitionResponse < Struct.new(
  :job_definition_arn,
  :job_definition_name,
  :creation_time,
  :model_explainability_baseline_config,
  :model_explainability_app_specification,
  :model_explainability_job_input,
  :model_explainability_job_output_config,
  :job_resources,
  :network_config,
  :role_arn,
  :stopping_condition)
  SENSITIVE = []
  include Aws::Structure
end

#job_definition_nameString

The name of the explainability job definition. The name must be unique within an Amazon Web Services Region in the Amazon Web Services account.

Returns:

  • (String)


19730
19731
19732
19733
19734
19735
19736
19737
19738
19739
19740
19741
19742
19743
19744
# File 'lib/aws-sdk-sagemaker/types.rb', line 19730

class DescribeModelExplainabilityJobDefinitionResponse < Struct.new(
  :job_definition_arn,
  :job_definition_name,
  :creation_time,
  :model_explainability_baseline_config,
  :model_explainability_app_specification,
  :model_explainability_job_input,
  :model_explainability_job_output_config,
  :job_resources,
  :network_config,
  :role_arn,
  :stopping_condition)
  SENSITIVE = []
  include Aws::Structure
end

#job_resourcesTypes::MonitoringResources

Identifies the resources to deploy for a monitoring job.



19730
19731
19732
19733
19734
19735
19736
19737
19738
19739
19740
19741
19742
19743
19744
# File 'lib/aws-sdk-sagemaker/types.rb', line 19730

class DescribeModelExplainabilityJobDefinitionResponse < Struct.new(
  :job_definition_arn,
  :job_definition_name,
  :creation_time,
  :model_explainability_baseline_config,
  :model_explainability_app_specification,
  :model_explainability_job_input,
  :model_explainability_job_output_config,
  :job_resources,
  :network_config,
  :role_arn,
  :stopping_condition)
  SENSITIVE = []
  include Aws::Structure
end

#model_explainability_app_specificationTypes::ModelExplainabilityAppSpecification

Configures the model explainability job to run a specified Docker container image.



19730
19731
19732
19733
19734
19735
19736
19737
19738
19739
19740
19741
19742
19743
19744
# File 'lib/aws-sdk-sagemaker/types.rb', line 19730

class DescribeModelExplainabilityJobDefinitionResponse < Struct.new(
  :job_definition_arn,
  :job_definition_name,
  :creation_time,
  :model_explainability_baseline_config,
  :model_explainability_app_specification,
  :model_explainability_job_input,
  :model_explainability_job_output_config,
  :job_resources,
  :network_config,
  :role_arn,
  :stopping_condition)
  SENSITIVE = []
  include Aws::Structure
end

#model_explainability_baseline_configTypes::ModelExplainabilityBaselineConfig

The baseline configuration for a model explainability job.



19730
19731
19732
19733
19734
19735
19736
19737
19738
19739
19740
19741
19742
19743
19744
# File 'lib/aws-sdk-sagemaker/types.rb', line 19730

class DescribeModelExplainabilityJobDefinitionResponse < Struct.new(
  :job_definition_arn,
  :job_definition_name,
  :creation_time,
  :model_explainability_baseline_config,
  :model_explainability_app_specification,
  :model_explainability_job_input,
  :model_explainability_job_output_config,
  :job_resources,
  :network_config,
  :role_arn,
  :stopping_condition)
  SENSITIVE = []
  include Aws::Structure
end

#model_explainability_job_inputTypes::ModelExplainabilityJobInput

Inputs for the model explainability job.



19730
19731
19732
19733
19734
19735
19736
19737
19738
19739
19740
19741
19742
19743
19744
# File 'lib/aws-sdk-sagemaker/types.rb', line 19730

class DescribeModelExplainabilityJobDefinitionResponse < Struct.new(
  :job_definition_arn,
  :job_definition_name,
  :creation_time,
  :model_explainability_baseline_config,
  :model_explainability_app_specification,
  :model_explainability_job_input,
  :model_explainability_job_output_config,
  :job_resources,
  :network_config,
  :role_arn,
  :stopping_condition)
  SENSITIVE = []
  include Aws::Structure
end

#model_explainability_job_output_configTypes::MonitoringOutputConfig

The output configuration for monitoring jobs.



19730
19731
19732
19733
19734
19735
19736
19737
19738
19739
19740
19741
19742
19743
19744
# File 'lib/aws-sdk-sagemaker/types.rb', line 19730

class DescribeModelExplainabilityJobDefinitionResponse < Struct.new(
  :job_definition_arn,
  :job_definition_name,
  :creation_time,
  :model_explainability_baseline_config,
  :model_explainability_app_specification,
  :model_explainability_job_input,
  :model_explainability_job_output_config,
  :job_resources,
  :network_config,
  :role_arn,
  :stopping_condition)
  SENSITIVE = []
  include Aws::Structure
end

#network_configTypes::MonitoringNetworkConfig

Networking options for a model explainability job.



19730
19731
19732
19733
19734
19735
19736
19737
19738
19739
19740
19741
19742
19743
19744
# File 'lib/aws-sdk-sagemaker/types.rb', line 19730

class DescribeModelExplainabilityJobDefinitionResponse < Struct.new(
  :job_definition_arn,
  :job_definition_name,
  :creation_time,
  :model_explainability_baseline_config,
  :model_explainability_app_specification,
  :model_explainability_job_input,
  :model_explainability_job_output_config,
  :job_resources,
  :network_config,
  :role_arn,
  :stopping_condition)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of the IAM role that has read permission to the input data location and write permission to the output data location in Amazon S3.

Returns:

  • (String)


19730
19731
19732
19733
19734
19735
19736
19737
19738
19739
19740
19741
19742
19743
19744
# File 'lib/aws-sdk-sagemaker/types.rb', line 19730

class DescribeModelExplainabilityJobDefinitionResponse < Struct.new(
  :job_definition_arn,
  :job_definition_name,
  :creation_time,
  :model_explainability_baseline_config,
  :model_explainability_app_specification,
  :model_explainability_job_input,
  :model_explainability_job_output_config,
  :job_resources,
  :network_config,
  :role_arn,
  :stopping_condition)
  SENSITIVE = []
  include Aws::Structure
end

#stopping_conditionTypes::MonitoringStoppingCondition

A time limit for how long the monitoring job is allowed to run before stopping.



19730
19731
19732
19733
19734
19735
19736
19737
19738
19739
19740
19741
19742
19743
19744
# File 'lib/aws-sdk-sagemaker/types.rb', line 19730

class DescribeModelExplainabilityJobDefinitionResponse < Struct.new(
  :job_definition_arn,
  :job_definition_name,
  :creation_time,
  :model_explainability_baseline_config,
  :model_explainability_app_specification,
  :model_explainability_job_input,
  :model_explainability_job_output_config,
  :job_resources,
  :network_config,
  :role_arn,
  :stopping_condition)
  SENSITIVE = []
  include Aws::Structure
end