Class: Aws::SageMaker::Types::DescribeModelOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#containersArray<Types::ContainerDefinition>

The containers in the inference pipeline.

Returns:



21246
21247
21248
21249
21250
21251
21252
21253
21254
21255
21256
21257
21258
21259
# File 'lib/aws-sdk-sagemaker/types.rb', line 21246

class DescribeModelOutput < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :deployment_recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

A timestamp that shows when the model was created.

Returns:

  • (Time)


21246
21247
21248
21249
21250
21251
21252
21253
21254
21255
21256
21257
21258
21259
# File 'lib/aws-sdk-sagemaker/types.rb', line 21246

class DescribeModelOutput < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :deployment_recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_recommendationTypes::DeploymentRecommendation

A set of recommended deployment configurations for the model.



21246
21247
21248
21249
21250
21251
21252
21253
21254
21255
21256
21257
21258
21259
# File 'lib/aws-sdk-sagemaker/types.rb', line 21246

class DescribeModelOutput < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :deployment_recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#enable_network_isolationBoolean

If ‘True`, no inbound or outbound network calls can be made to or from the model container.

Returns:

  • (Boolean)


21246
21247
21248
21249
21250
21251
21252
21253
21254
21255
21256
21257
21258
21259
# File 'lib/aws-sdk-sagemaker/types.rb', line 21246

class DescribeModelOutput < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :deployment_recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#execution_role_arnString

The Amazon Resource Name (ARN) of the IAM role that you specified for the model.

Returns:

  • (String)


21246
21247
21248
21249
21250
21251
21252
21253
21254
21255
21256
21257
21258
21259
# File 'lib/aws-sdk-sagemaker/types.rb', line 21246

class DescribeModelOutput < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :deployment_recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#inference_execution_configTypes::InferenceExecutionConfig

Specifies details of how containers in a multi-container endpoint are called.



21246
21247
21248
21249
21250
21251
21252
21253
21254
21255
21256
21257
21258
21259
# File 'lib/aws-sdk-sagemaker/types.rb', line 21246

class DescribeModelOutput < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :deployment_recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#model_arnString

The Amazon Resource Name (ARN) of the model.

Returns:

  • (String)


21246
21247
21248
21249
21250
21251
21252
21253
21254
21255
21256
21257
21258
21259
# File 'lib/aws-sdk-sagemaker/types.rb', line 21246

class DescribeModelOutput < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :deployment_recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#model_nameString

Name of the SageMaker model.

Returns:

  • (String)


21246
21247
21248
21249
21250
21251
21252
21253
21254
21255
21256
21257
21258
21259
# File 'lib/aws-sdk-sagemaker/types.rb', line 21246

class DescribeModelOutput < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :deployment_recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#primary_containerTypes::ContainerDefinition

The location of the primary inference code, associated artifacts, and custom environment map that the inference code uses when it is deployed in production.



21246
21247
21248
21249
21250
21251
21252
21253
21254
21255
21256
21257
21258
21259
# File 'lib/aws-sdk-sagemaker/types.rb', line 21246

class DescribeModelOutput < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :deployment_recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_configTypes::VpcConfig

A [VpcConfig] object that specifies the VPC that this model has access to. For more information, see [Protect Endpoints by Using an Amazon Virtual Private Cloud]

[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_VpcConfig.html [2]: docs.aws.amazon.com/sagemaker/latest/dg/host-vpc.html

Returns:



21246
21247
21248
21249
21250
21251
21252
21253
21254
21255
21256
21257
21258
21259
# File 'lib/aws-sdk-sagemaker/types.rb', line 21246

class DescribeModelOutput < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :deployment_recommendation)
  SENSITIVE = []
  include Aws::Structure
end