Class: Aws::SageMaker::Types::DescribeModelOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeModelOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#containers ⇒ Array<Types::ContainerDefinition>
The containers in the inference pipeline.
-
#creation_time ⇒ Time
A timestamp that shows when the model was created.
-
#deployment_recommendation ⇒ Types::DeploymentRecommendation
A set of recommended deployment configurations for the model.
-
#enable_network_isolation ⇒ Boolean
If ‘True`, no inbound or outbound network calls can be made to or from the model container.
-
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that you specified for the model.
-
#inference_execution_config ⇒ Types::InferenceExecutionConfig
Specifies details of how containers in a multi-container endpoint are called.
-
#model_arn ⇒ String
The Amazon Resource Name (ARN) of the model.
-
#model_name ⇒ String
Name of the SageMaker model.
-
#primary_container ⇒ Types::ContainerDefinition
The location of the primary inference code, associated artifacts, and custom environment map that the inference code uses when it is deployed in production.
-
#vpc_config ⇒ Types::VpcConfig
A [VpcConfig] object that specifies the VPC that this model has access to.
Instance Attribute Details
#containers ⇒ Array<Types::ContainerDefinition>
The containers in the inference pipeline.
21224 21225 21226 21227 21228 21229 21230 21231 21232 21233 21234 21235 21236 21237 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21224 class DescribeModelOutput < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :deployment_recommendation) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
A timestamp that shows when the model was created.
21224 21225 21226 21227 21228 21229 21230 21231 21232 21233 21234 21235 21236 21237 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21224 class DescribeModelOutput < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :deployment_recommendation) SENSITIVE = [] include Aws::Structure end |
#deployment_recommendation ⇒ Types::DeploymentRecommendation
A set of recommended deployment configurations for the model.
21224 21225 21226 21227 21228 21229 21230 21231 21232 21233 21234 21235 21236 21237 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21224 class DescribeModelOutput < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :deployment_recommendation) SENSITIVE = [] include Aws::Structure end |
#enable_network_isolation ⇒ Boolean
If ‘True`, no inbound or outbound network calls can be made to or from the model container.
21224 21225 21226 21227 21228 21229 21230 21231 21232 21233 21234 21235 21236 21237 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21224 class DescribeModelOutput < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :deployment_recommendation) SENSITIVE = [] include Aws::Structure end |
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that you specified for the model.
21224 21225 21226 21227 21228 21229 21230 21231 21232 21233 21234 21235 21236 21237 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21224 class DescribeModelOutput < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :deployment_recommendation) SENSITIVE = [] include Aws::Structure end |
#inference_execution_config ⇒ Types::InferenceExecutionConfig
Specifies details of how containers in a multi-container endpoint are called.
21224 21225 21226 21227 21228 21229 21230 21231 21232 21233 21234 21235 21236 21237 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21224 class DescribeModelOutput < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :deployment_recommendation) SENSITIVE = [] include Aws::Structure end |
#model_arn ⇒ String
The Amazon Resource Name (ARN) of the model.
21224 21225 21226 21227 21228 21229 21230 21231 21232 21233 21234 21235 21236 21237 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21224 class DescribeModelOutput < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :deployment_recommendation) SENSITIVE = [] include Aws::Structure end |
#model_name ⇒ String
Name of the SageMaker model.
21224 21225 21226 21227 21228 21229 21230 21231 21232 21233 21234 21235 21236 21237 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21224 class DescribeModelOutput < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :deployment_recommendation) SENSITIVE = [] include Aws::Structure end |
#primary_container ⇒ Types::ContainerDefinition
The location of the primary inference code, associated artifacts, and custom environment map that the inference code uses when it is deployed in production.
21224 21225 21226 21227 21228 21229 21230 21231 21232 21233 21234 21235 21236 21237 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21224 class DescribeModelOutput < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :deployment_recommendation) SENSITIVE = [] include Aws::Structure end |
#vpc_config ⇒ Types::VpcConfig
A [VpcConfig] object that specifies the VPC that this model has access to. For more information, see [Protect Endpoints by Using an Amazon Virtual Private Cloud]
[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_VpcConfig.html [2]: docs.aws.amazon.com/sagemaker/latest/dg/host-vpc.html
21224 21225 21226 21227 21228 21229 21230 21231 21232 21233 21234 21235 21236 21237 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21224 class DescribeModelOutput < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :deployment_recommendation) SENSITIVE = [] include Aws::Structure end |