Class: Aws::SageMaker::Types::DescribeModelOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#containersArray<Types::ContainerDefinition>

The containers in the inference pipeline.

Returns:



12989
12990
12991
12992
12993
12994
12995
12996
12997
12998
12999
13000
13001
# File 'lib/aws-sdk-sagemaker/types.rb', line 12989

class DescribeModelOutput < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

A timestamp that shows when the model was created.

Returns:



12989
12990
12991
12992
12993
12994
12995
12996
12997
12998
12999
13000
13001
# File 'lib/aws-sdk-sagemaker/types.rb', line 12989

class DescribeModelOutput < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation)
  SENSITIVE = []
  include Aws::Structure
end

#enable_network_isolationBoolean

If True, no inbound or outbound network calls can be made to or from the model container.

Returns:



12989
12990
12991
12992
12993
12994
12995
12996
12997
12998
12999
13000
13001
# File 'lib/aws-sdk-sagemaker/types.rb', line 12989

class DescribeModelOutput < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation)
  SENSITIVE = []
  include Aws::Structure
end

#execution_role_arnString

The Amazon Resource Name (ARN) of the IAM role that you specified for the model.

Returns:



12989
12990
12991
12992
12993
12994
12995
12996
12997
12998
12999
13000
13001
# File 'lib/aws-sdk-sagemaker/types.rb', line 12989

class DescribeModelOutput < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation)
  SENSITIVE = []
  include Aws::Structure
end

#inference_execution_configTypes::InferenceExecutionConfig

Specifies details of how containers in a multi-container endpoint are called.

Returns:



12989
12990
12991
12992
12993
12994
12995
12996
12997
12998
12999
13000
13001
# File 'lib/aws-sdk-sagemaker/types.rb', line 12989

class DescribeModelOutput < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation)
  SENSITIVE = []
  include Aws::Structure
end

#model_arnString

The Amazon Resource Name (ARN) of the model.

Returns:



12989
12990
12991
12992
12993
12994
12995
12996
12997
12998
12999
13000
13001
# File 'lib/aws-sdk-sagemaker/types.rb', line 12989

class DescribeModelOutput < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation)
  SENSITIVE = []
  include Aws::Structure
end

#model_nameString

Name of the SageMaker model.

Returns:



12989
12990
12991
12992
12993
12994
12995
12996
12997
12998
12999
13000
13001
# File 'lib/aws-sdk-sagemaker/types.rb', line 12989

class DescribeModelOutput < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation)
  SENSITIVE = []
  include Aws::Structure
end

#primary_containerTypes::ContainerDefinition

The location of the primary inference code, associated artifacts, and custom environment map that the inference code uses when it is deployed in production.

Returns:



12989
12990
12991
12992
12993
12994
12995
12996
12997
12998
12999
13000
13001
# File 'lib/aws-sdk-sagemaker/types.rb', line 12989

class DescribeModelOutput < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_configTypes::VpcConfig

A VpcConfig object that specifies the VPC that this model has access to. For more information, see [Protect Endpoints by Using an Amazon Virtual Private Cloud]

[1]: docs.aws.amazon.com/sagemaker/latest/dg/host-vpc.html

Returns:



12989
12990
12991
12992
12993
12994
12995
12996
12997
12998
12999
13000
13001
# File 'lib/aws-sdk-sagemaker/types.rb', line 12989

class DescribeModelOutput < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation)
  SENSITIVE = []
  include Aws::Structure
end