Class: Aws::SageMaker::Types::DescribeModelOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeModelOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#containers ⇒ Array<Types::ContainerDefinition>
The containers in the inference pipeline.
-
#creation_time ⇒ Time
A timestamp that shows when the model was created.
-
#enable_network_isolation ⇒ Boolean
If
True, no inbound or outbound network calls can be made to or from the model container. -
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that you specified for the model.
-
#inference_execution_config ⇒ Types::InferenceExecutionConfig
Specifies details of how containers in a multi-container endpoint are called.
-
#model_arn ⇒ String
The Amazon Resource Name (ARN) of the model.
-
#model_name ⇒ String
Name of the SageMaker model.
-
#primary_container ⇒ Types::ContainerDefinition
The location of the primary inference code, associated artifacts, and custom environment map that the inference code uses when it is deployed in production.
-
#vpc_config ⇒ Types::VpcConfig
A VpcConfig object that specifies the VPC that this model has access to.
Instance Attribute Details
#containers ⇒ Array<Types::ContainerDefinition>
The containers in the inference pipeline.
12989 12990 12991 12992 12993 12994 12995 12996 12997 12998 12999 13000 13001 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12989 class DescribeModelOutput < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
A timestamp that shows when the model was created.
12989 12990 12991 12992 12993 12994 12995 12996 12997 12998 12999 13000 13001 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12989 class DescribeModelOutput < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation) SENSITIVE = [] include Aws::Structure end |
#enable_network_isolation ⇒ Boolean
If True, no inbound or outbound network calls can be made to or from the model container.
12989 12990 12991 12992 12993 12994 12995 12996 12997 12998 12999 13000 13001 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12989 class DescribeModelOutput < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation) SENSITIVE = [] include Aws::Structure end |
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that you specified for the model.
12989 12990 12991 12992 12993 12994 12995 12996 12997 12998 12999 13000 13001 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12989 class DescribeModelOutput < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation) SENSITIVE = [] include Aws::Structure end |
#inference_execution_config ⇒ Types::InferenceExecutionConfig
Specifies details of how containers in a multi-container endpoint are called.
12989 12990 12991 12992 12993 12994 12995 12996 12997 12998 12999 13000 13001 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12989 class DescribeModelOutput < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation) SENSITIVE = [] include Aws::Structure end |
#model_arn ⇒ String
The Amazon Resource Name (ARN) of the model.
12989 12990 12991 12992 12993 12994 12995 12996 12997 12998 12999 13000 13001 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12989 class DescribeModelOutput < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation) SENSITIVE = [] include Aws::Structure end |
#model_name ⇒ String
Name of the SageMaker model.
12989 12990 12991 12992 12993 12994 12995 12996 12997 12998 12999 13000 13001 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12989 class DescribeModelOutput < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation) SENSITIVE = [] include Aws::Structure end |
#primary_container ⇒ Types::ContainerDefinition
The location of the primary inference code, associated artifacts, and custom environment map that the inference code uses when it is deployed in production.
12989 12990 12991 12992 12993 12994 12995 12996 12997 12998 12999 13000 13001 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12989 class DescribeModelOutput < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation) SENSITIVE = [] include Aws::Structure end |
#vpc_config ⇒ Types::VpcConfig
A VpcConfig object that specifies the VPC that this model has access to. For more information, see [Protect Endpoints by Using an Amazon Virtual Private Cloud]
12989 12990 12991 12992 12993 12994 12995 12996 12997 12998 12999 13000 13001 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 12989 class DescribeModelOutput < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation) SENSITIVE = [] include Aws::Structure end |