Class: Aws::SageMaker::Types::DescribeModelPackageOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeModelPackageOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_inference_specifications ⇒ Array<Types::AdditionalInferenceSpecificationDefinition>
An array of additional Inference Specification objects.
-
#approval_description ⇒ String
A description provided for the model approval.
-
#certify_for_marketplace ⇒ Boolean
Whether the model package is certified for listing on Amazon Web Services Marketplace.
-
#created_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
-
#creation_time ⇒ Time
A timestamp specifying when the model package was created.
-
#customer_metadata_properties ⇒ Hash<String,String>
The metadata properties associated with the model package versions.
-
#domain ⇒ String
The machine learning domain of the model package you specified.
-
#drift_check_baselines ⇒ Types::DriftCheckBaselines
Represents the drift check baselines that can be used when the model monitor is set using the model package.
-
#inference_specification ⇒ Types::InferenceSpecification
Details about inference jobs that you can run with models based on this model package.
-
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
-
#last_modified_time ⇒ Time
The last time that the model package was modified.
-
#managed_storage_type ⇒ String
The storage type of the model package.
-
#metadata_properties ⇒ Types::MetadataProperties
Metadata properties of the tracking entity, trial, or trial component.
-
#model_approval_status ⇒ String
The approval status of the model package.
-
#model_card ⇒ Types::ModelPackageModelCard
The model card associated with the model package.
-
#model_life_cycle ⇒ Types::ModelLifeCycle
A structure describing the current state of the model in its life cycle.
-
#model_metrics ⇒ Types::ModelMetrics
Metrics for the model.
-
#model_package_arn ⇒ String
The Amazon Resource Name (ARN) of the model package.
-
#model_package_description ⇒ String
A brief summary of the model package.
-
#model_package_group_name ⇒ String
If the model is a versioned model, the name of the model group that the versioned model belongs to.
-
#model_package_name ⇒ String
The name of the model package being described.
-
#model_package_registration_type ⇒ String
The package registration type of the model package output.
-
#model_package_status ⇒ String
The current status of the model package.
-
#model_package_status_details ⇒ Types::ModelPackageStatusDetails
Details about the current status of the model package.
-
#model_package_version ⇒ Integer
The version of the model package.
-
#sample_payload_url ⇒ String
The Amazon Simple Storage Service (Amazon S3) path where the sample payload are stored.
-
#security_config ⇒ Types::ModelPackageSecurityConfig
The KMS Key ID (‘KMSKeyId`) used for encryption of model package information.
-
#skip_model_validation ⇒ String
Indicates if you want to skip model validation.
-
#source_algorithm_specification ⇒ Types::SourceAlgorithmSpecification
Details about the algorithm that was used to create the model package.
-
#source_uri ⇒ String
The URI of the source for the model package.
-
#task ⇒ String
The machine learning task you specified that your model package accomplishes.
-
#validation_specification ⇒ Types::ModelPackageValidationSpecification
Configurations for one or more transform jobs that SageMaker runs to test the model package.
Instance Attribute Details
#additional_inference_specifications ⇒ Array<Types::AdditionalInferenceSpecificationDefinition>
An array of additional Inference Specification objects. Each additional Inference Specification specifies artifacts based on this model package that can be used on inference endpoints. Generally used with SageMaker Neo to store the compiled artifacts.
22013 22014 22015 22016 22017 22018 22019 22020 22021 22022 22023 22024 22025 22026 22027 22028 22029 22030 22031 22032 22033 22034 22035 22036 22037 22038 22039 22040 22041 22042 22043 22044 22045 22046 22047 22048 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22013 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :customer_metadata_properties, :drift_check_baselines, :additional_inference_specifications, :skip_model_validation, :source_uri, :security_config, :model_card, :model_life_cycle, :managed_storage_type) SENSITIVE = [] include Aws::Structure end |
#approval_description ⇒ String
A description provided for the model approval.
22013 22014 22015 22016 22017 22018 22019 22020 22021 22022 22023 22024 22025 22026 22027 22028 22029 22030 22031 22032 22033 22034 22035 22036 22037 22038 22039 22040 22041 22042 22043 22044 22045 22046 22047 22048 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22013 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :customer_metadata_properties, :drift_check_baselines, :additional_inference_specifications, :skip_model_validation, :source_uri, :security_config, :model_card, :model_life_cycle, :managed_storage_type) SENSITIVE = [] include Aws::Structure end |
#certify_for_marketplace ⇒ Boolean
Whether the model package is certified for listing on Amazon Web Services Marketplace.
22013 22014 22015 22016 22017 22018 22019 22020 22021 22022 22023 22024 22025 22026 22027 22028 22029 22030 22031 22032 22033 22034 22035 22036 22037 22038 22039 22040 22041 22042 22043 22044 22045 22046 22047 22048 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22013 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :customer_metadata_properties, :drift_check_baselines, :additional_inference_specifications, :skip_model_validation, :source_uri, :security_config, :model_card, :model_life_cycle, :managed_storage_type) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
22013 22014 22015 22016 22017 22018 22019 22020 22021 22022 22023 22024 22025 22026 22027 22028 22029 22030 22031 22032 22033 22034 22035 22036 22037 22038 22039 22040 22041 22042 22043 22044 22045 22046 22047 22048 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22013 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :customer_metadata_properties, :drift_check_baselines, :additional_inference_specifications, :skip_model_validation, :source_uri, :security_config, :model_card, :model_life_cycle, :managed_storage_type) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
A timestamp specifying when the model package was created.
22013 22014 22015 22016 22017 22018 22019 22020 22021 22022 22023 22024 22025 22026 22027 22028 22029 22030 22031 22032 22033 22034 22035 22036 22037 22038 22039 22040 22041 22042 22043 22044 22045 22046 22047 22048 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22013 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :customer_metadata_properties, :drift_check_baselines, :additional_inference_specifications, :skip_model_validation, :source_uri, :security_config, :model_card, :model_life_cycle, :managed_storage_type) SENSITIVE = [] include Aws::Structure end |
#customer_metadata_properties ⇒ Hash<String,String>
The metadata properties associated with the model package versions.
22013 22014 22015 22016 22017 22018 22019 22020 22021 22022 22023 22024 22025 22026 22027 22028 22029 22030 22031 22032 22033 22034 22035 22036 22037 22038 22039 22040 22041 22042 22043 22044 22045 22046 22047 22048 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22013 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :customer_metadata_properties, :drift_check_baselines, :additional_inference_specifications, :skip_model_validation, :source_uri, :security_config, :model_card, :model_life_cycle, :managed_storage_type) SENSITIVE = [] include Aws::Structure end |
#domain ⇒ String
The machine learning domain of the model package you specified. Common machine learning domains include computer vision and natural language processing.
22013 22014 22015 22016 22017 22018 22019 22020 22021 22022 22023 22024 22025 22026 22027 22028 22029 22030 22031 22032 22033 22034 22035 22036 22037 22038 22039 22040 22041 22042 22043 22044 22045 22046 22047 22048 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22013 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :customer_metadata_properties, :drift_check_baselines, :additional_inference_specifications, :skip_model_validation, :source_uri, :security_config, :model_card, :model_life_cycle, :managed_storage_type) SENSITIVE = [] include Aws::Structure end |
#drift_check_baselines ⇒ Types::DriftCheckBaselines
Represents the drift check baselines that can be used when the model monitor is set using the model package. For more information, see the topic on [Drift Detection against Previous Baselines in SageMaker Pipelines] in the *Amazon SageMaker Developer Guide*.
22013 22014 22015 22016 22017 22018 22019 22020 22021 22022 22023 22024 22025 22026 22027 22028 22029 22030 22031 22032 22033 22034 22035 22036 22037 22038 22039 22040 22041 22042 22043 22044 22045 22046 22047 22048 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22013 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :customer_metadata_properties, :drift_check_baselines, :additional_inference_specifications, :skip_model_validation, :source_uri, :security_config, :model_card, :model_life_cycle, :managed_storage_type) SENSITIVE = [] include Aws::Structure end |
#inference_specification ⇒ Types::InferenceSpecification
Details about inference jobs that you can run with models based on this model package.
22013 22014 22015 22016 22017 22018 22019 22020 22021 22022 22023 22024 22025 22026 22027 22028 22029 22030 22031 22032 22033 22034 22035 22036 22037 22038 22039 22040 22041 22042 22043 22044 22045 22046 22047 22048 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22013 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :customer_metadata_properties, :drift_check_baselines, :additional_inference_specifications, :skip_model_validation, :source_uri, :security_config, :model_card, :model_life_cycle, :managed_storage_type) SENSITIVE = [] include Aws::Structure end |
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
22013 22014 22015 22016 22017 22018 22019 22020 22021 22022 22023 22024 22025 22026 22027 22028 22029 22030 22031 22032 22033 22034 22035 22036 22037 22038 22039 22040 22041 22042 22043 22044 22045 22046 22047 22048 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22013 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :customer_metadata_properties, :drift_check_baselines, :additional_inference_specifications, :skip_model_validation, :source_uri, :security_config, :model_card, :model_life_cycle, :managed_storage_type) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The last time that the model package was modified.
22013 22014 22015 22016 22017 22018 22019 22020 22021 22022 22023 22024 22025 22026 22027 22028 22029 22030 22031 22032 22033 22034 22035 22036 22037 22038 22039 22040 22041 22042 22043 22044 22045 22046 22047 22048 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22013 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :customer_metadata_properties, :drift_check_baselines, :additional_inference_specifications, :skip_model_validation, :source_uri, :security_config, :model_card, :model_life_cycle, :managed_storage_type) SENSITIVE = [] include Aws::Structure end |
#managed_storage_type ⇒ String
The storage type of the model package.
22013 22014 22015 22016 22017 22018 22019 22020 22021 22022 22023 22024 22025 22026 22027 22028 22029 22030 22031 22032 22033 22034 22035 22036 22037 22038 22039 22040 22041 22042 22043 22044 22045 22046 22047 22048 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22013 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :customer_metadata_properties, :drift_check_baselines, :additional_inference_specifications, :skip_model_validation, :source_uri, :security_config, :model_card, :model_life_cycle, :managed_storage_type) SENSITIVE = [] include Aws::Structure end |
#metadata_properties ⇒ Types::MetadataProperties
Metadata properties of the tracking entity, trial, or trial component.
22013 22014 22015 22016 22017 22018 22019 22020 22021 22022 22023 22024 22025 22026 22027 22028 22029 22030 22031 22032 22033 22034 22035 22036 22037 22038 22039 22040 22041 22042 22043 22044 22045 22046 22047 22048 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22013 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :customer_metadata_properties, :drift_check_baselines, :additional_inference_specifications, :skip_model_validation, :source_uri, :security_config, :model_card, :model_life_cycle, :managed_storage_type) SENSITIVE = [] include Aws::Structure end |
#model_approval_status ⇒ String
The approval status of the model package.
22013 22014 22015 22016 22017 22018 22019 22020 22021 22022 22023 22024 22025 22026 22027 22028 22029 22030 22031 22032 22033 22034 22035 22036 22037 22038 22039 22040 22041 22042 22043 22044 22045 22046 22047 22048 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22013 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :customer_metadata_properties, :drift_check_baselines, :additional_inference_specifications, :skip_model_validation, :source_uri, :security_config, :model_card, :model_life_cycle, :managed_storage_type) SENSITIVE = [] include Aws::Structure end |
#model_card ⇒ Types::ModelPackageModelCard
The model card associated with the model package. Since ‘ModelPackageModelCard` is tied to a model package, it is a specific usage of a model card and its schema is simplified compared to the schema of `ModelCard`. The `ModelPackageModelCard` schema does not include `model_package_details`, and `model_overview` is composed of the `model_creator` and `model_artifact` properties. For more information about the model package model card schema, see [Model package model card schema]. For more information about the model card associated with the model package, see [View the Details of a Model Version].
When you set ‘IncludedData` to `MetadataOnly` in the request, `ModelCardStatus` is preserved and `ModelCardContent` is sanitized to include only the following JSON paths, when present in the model card:
-
‘model_overview.model_id`
-
‘model_overview.model_name`
-
‘intended_uses.risk_rating`
-
‘model_package_details.model_package_group_name`
-
‘model_package_details.model_package_arn`
Because the ‘ModelPackageModelCard` schema does not include `model_package_details` and limits `model_overview` to `model_creator` and `model_artifact`, the sanitized `ModelCardContent` for a model package typically contains only `intended_uses.risk_rating` if it was provided when the model card was created. To retrieve the complete `ModelCardContent`, set `IncludedData` to `AllData` or omit the parameter.
[1]: docs.aws.amazon.com/sagemaker/latest/dg/model-registry-details.html#model-card-schema [2]: docs.aws.amazon.com/sagemaker/latest/dg/model-registry-details.html
22013 22014 22015 22016 22017 22018 22019 22020 22021 22022 22023 22024 22025 22026 22027 22028 22029 22030 22031 22032 22033 22034 22035 22036 22037 22038 22039 22040 22041 22042 22043 22044 22045 22046 22047 22048 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22013 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :customer_metadata_properties, :drift_check_baselines, :additional_inference_specifications, :skip_model_validation, :source_uri, :security_config, :model_card, :model_life_cycle, :managed_storage_type) SENSITIVE = [] include Aws::Structure end |
#model_life_cycle ⇒ Types::ModelLifeCycle
A structure describing the current state of the model in its life cycle.
22013 22014 22015 22016 22017 22018 22019 22020 22021 22022 22023 22024 22025 22026 22027 22028 22029 22030 22031 22032 22033 22034 22035 22036 22037 22038 22039 22040 22041 22042 22043 22044 22045 22046 22047 22048 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22013 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :customer_metadata_properties, :drift_check_baselines, :additional_inference_specifications, :skip_model_validation, :source_uri, :security_config, :model_card, :model_life_cycle, :managed_storage_type) SENSITIVE = [] include Aws::Structure end |
#model_metrics ⇒ Types::ModelMetrics
Metrics for the model.
22013 22014 22015 22016 22017 22018 22019 22020 22021 22022 22023 22024 22025 22026 22027 22028 22029 22030 22031 22032 22033 22034 22035 22036 22037 22038 22039 22040 22041 22042 22043 22044 22045 22046 22047 22048 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22013 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :customer_metadata_properties, :drift_check_baselines, :additional_inference_specifications, :skip_model_validation, :source_uri, :security_config, :model_card, :model_life_cycle, :managed_storage_type) SENSITIVE = [] include Aws::Structure end |
#model_package_arn ⇒ String
The Amazon Resource Name (ARN) of the model package.
22013 22014 22015 22016 22017 22018 22019 22020 22021 22022 22023 22024 22025 22026 22027 22028 22029 22030 22031 22032 22033 22034 22035 22036 22037 22038 22039 22040 22041 22042 22043 22044 22045 22046 22047 22048 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22013 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :customer_metadata_properties, :drift_check_baselines, :additional_inference_specifications, :skip_model_validation, :source_uri, :security_config, :model_card, :model_life_cycle, :managed_storage_type) SENSITIVE = [] include Aws::Structure end |
#model_package_description ⇒ String
A brief summary of the model package.
22013 22014 22015 22016 22017 22018 22019 22020 22021 22022 22023 22024 22025 22026 22027 22028 22029 22030 22031 22032 22033 22034 22035 22036 22037 22038 22039 22040 22041 22042 22043 22044 22045 22046 22047 22048 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22013 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :customer_metadata_properties, :drift_check_baselines, :additional_inference_specifications, :skip_model_validation, :source_uri, :security_config, :model_card, :model_life_cycle, :managed_storage_type) SENSITIVE = [] include Aws::Structure end |
#model_package_group_name ⇒ String
If the model is a versioned model, the name of the model group that the versioned model belongs to.
22013 22014 22015 22016 22017 22018 22019 22020 22021 22022 22023 22024 22025 22026 22027 22028 22029 22030 22031 22032 22033 22034 22035 22036 22037 22038 22039 22040 22041 22042 22043 22044 22045 22046 22047 22048 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22013 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :customer_metadata_properties, :drift_check_baselines, :additional_inference_specifications, :skip_model_validation, :source_uri, :security_config, :model_card, :model_life_cycle, :managed_storage_type) SENSITIVE = [] include Aws::Structure end |
#model_package_name ⇒ String
The name of the model package being described.
22013 22014 22015 22016 22017 22018 22019 22020 22021 22022 22023 22024 22025 22026 22027 22028 22029 22030 22031 22032 22033 22034 22035 22036 22037 22038 22039 22040 22041 22042 22043 22044 22045 22046 22047 22048 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22013 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :customer_metadata_properties, :drift_check_baselines, :additional_inference_specifications, :skip_model_validation, :source_uri, :security_config, :model_card, :model_life_cycle, :managed_storage_type) SENSITIVE = [] include Aws::Structure end |
#model_package_registration_type ⇒ String
The package registration type of the model package output.
22013 22014 22015 22016 22017 22018 22019 22020 22021 22022 22023 22024 22025 22026 22027 22028 22029 22030 22031 22032 22033 22034 22035 22036 22037 22038 22039 22040 22041 22042 22043 22044 22045 22046 22047 22048 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22013 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :customer_metadata_properties, :drift_check_baselines, :additional_inference_specifications, :skip_model_validation, :source_uri, :security_config, :model_card, :model_life_cycle, :managed_storage_type) SENSITIVE = [] include Aws::Structure end |
#model_package_status ⇒ String
The current status of the model package.
22013 22014 22015 22016 22017 22018 22019 22020 22021 22022 22023 22024 22025 22026 22027 22028 22029 22030 22031 22032 22033 22034 22035 22036 22037 22038 22039 22040 22041 22042 22043 22044 22045 22046 22047 22048 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22013 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :customer_metadata_properties, :drift_check_baselines, :additional_inference_specifications, :skip_model_validation, :source_uri, :security_config, :model_card, :model_life_cycle, :managed_storage_type) SENSITIVE = [] include Aws::Structure end |
#model_package_status_details ⇒ Types::ModelPackageStatusDetails
Details about the current status of the model package.
22013 22014 22015 22016 22017 22018 22019 22020 22021 22022 22023 22024 22025 22026 22027 22028 22029 22030 22031 22032 22033 22034 22035 22036 22037 22038 22039 22040 22041 22042 22043 22044 22045 22046 22047 22048 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22013 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :customer_metadata_properties, :drift_check_baselines, :additional_inference_specifications, :skip_model_validation, :source_uri, :security_config, :model_card, :model_life_cycle, :managed_storage_type) SENSITIVE = [] include Aws::Structure end |
#model_package_version ⇒ Integer
The version of the model package.
22013 22014 22015 22016 22017 22018 22019 22020 22021 22022 22023 22024 22025 22026 22027 22028 22029 22030 22031 22032 22033 22034 22035 22036 22037 22038 22039 22040 22041 22042 22043 22044 22045 22046 22047 22048 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22013 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :customer_metadata_properties, :drift_check_baselines, :additional_inference_specifications, :skip_model_validation, :source_uri, :security_config, :model_card, :model_life_cycle, :managed_storage_type) SENSITIVE = [] include Aws::Structure end |
#sample_payload_url ⇒ String
The Amazon Simple Storage Service (Amazon S3) path where the sample payload are stored. This path points to a single gzip compressed tar archive (.tar.gz suffix).
22013 22014 22015 22016 22017 22018 22019 22020 22021 22022 22023 22024 22025 22026 22027 22028 22029 22030 22031 22032 22033 22034 22035 22036 22037 22038 22039 22040 22041 22042 22043 22044 22045 22046 22047 22048 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22013 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :customer_metadata_properties, :drift_check_baselines, :additional_inference_specifications, :skip_model_validation, :source_uri, :security_config, :model_card, :model_life_cycle, :managed_storage_type) SENSITIVE = [] include Aws::Structure end |
#security_config ⇒ Types::ModelPackageSecurityConfig
The KMS Key ID (‘KMSKeyId`) used for encryption of model package information.
22013 22014 22015 22016 22017 22018 22019 22020 22021 22022 22023 22024 22025 22026 22027 22028 22029 22030 22031 22032 22033 22034 22035 22036 22037 22038 22039 22040 22041 22042 22043 22044 22045 22046 22047 22048 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22013 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :customer_metadata_properties, :drift_check_baselines, :additional_inference_specifications, :skip_model_validation, :source_uri, :security_config, :model_card, :model_life_cycle, :managed_storage_type) SENSITIVE = [] include Aws::Structure end |
#skip_model_validation ⇒ String
Indicates if you want to skip model validation.
22013 22014 22015 22016 22017 22018 22019 22020 22021 22022 22023 22024 22025 22026 22027 22028 22029 22030 22031 22032 22033 22034 22035 22036 22037 22038 22039 22040 22041 22042 22043 22044 22045 22046 22047 22048 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22013 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :customer_metadata_properties, :drift_check_baselines, :additional_inference_specifications, :skip_model_validation, :source_uri, :security_config, :model_card, :model_life_cycle, :managed_storage_type) SENSITIVE = [] include Aws::Structure end |
#source_algorithm_specification ⇒ Types::SourceAlgorithmSpecification
Details about the algorithm that was used to create the model package.
22013 22014 22015 22016 22017 22018 22019 22020 22021 22022 22023 22024 22025 22026 22027 22028 22029 22030 22031 22032 22033 22034 22035 22036 22037 22038 22039 22040 22041 22042 22043 22044 22045 22046 22047 22048 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22013 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :customer_metadata_properties, :drift_check_baselines, :additional_inference_specifications, :skip_model_validation, :source_uri, :security_config, :model_card, :model_life_cycle, :managed_storage_type) SENSITIVE = [] include Aws::Structure end |
#source_uri ⇒ String
The URI of the source for the model package.
22013 22014 22015 22016 22017 22018 22019 22020 22021 22022 22023 22024 22025 22026 22027 22028 22029 22030 22031 22032 22033 22034 22035 22036 22037 22038 22039 22040 22041 22042 22043 22044 22045 22046 22047 22048 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22013 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :customer_metadata_properties, :drift_check_baselines, :additional_inference_specifications, :skip_model_validation, :source_uri, :security_config, :model_card, :model_life_cycle, :managed_storage_type) SENSITIVE = [] include Aws::Structure end |
#task ⇒ String
The machine learning task you specified that your model package accomplishes. Common machine learning tasks include object detection and image classification.
22013 22014 22015 22016 22017 22018 22019 22020 22021 22022 22023 22024 22025 22026 22027 22028 22029 22030 22031 22032 22033 22034 22035 22036 22037 22038 22039 22040 22041 22042 22043 22044 22045 22046 22047 22048 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22013 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :customer_metadata_properties, :drift_check_baselines, :additional_inference_specifications, :skip_model_validation, :source_uri, :security_config, :model_card, :model_life_cycle, :managed_storage_type) SENSITIVE = [] include Aws::Structure end |
#validation_specification ⇒ Types::ModelPackageValidationSpecification
Configurations for one or more transform jobs that SageMaker runs to test the model package.
22013 22014 22015 22016 22017 22018 22019 22020 22021 22022 22023 22024 22025 22026 22027 22028 22029 22030 22031 22032 22033 22034 22035 22036 22037 22038 22039 22040 22041 22042 22043 22044 22045 22046 22047 22048 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22013 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :customer_metadata_properties, :drift_check_baselines, :additional_inference_specifications, :skip_model_validation, :source_uri, :security_config, :model_card, :model_life_cycle, :managed_storage_type) SENSITIVE = [] include Aws::Structure end |