Class: Aws::SageMaker::Types::DescribeModelPackageOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_inference_specificationsArray<Types::AdditionalInferenceSpecificationDefinition>

An array of additional Inference Specification objects. Each additional Inference Specification specifies artifacts based on this model package that can be used on inference endpoints. Generally used with SageMaker Neo to store the compiled artifacts.



21981
21982
21983
21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
21996
21997
21998
21999
22000
22001
22002
22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
# File 'lib/aws-sdk-sagemaker/types.rb', line 21981

class DescribeModelPackageOutput < Struct.new(
  :model_package_name,
  :model_package_group_name,
  :model_package_version,
  :model_package_registration_type,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :source_algorithm_specification,
  :validation_specification,
  :model_package_status,
  :model_package_status_details,
  :certify_for_marketplace,
  :model_approval_status,
  :created_by,
  :metadata_properties,
  :model_metrics,
  :last_modified_time,
  :last_modified_by,
  :approval_description,
  :domain,
  :task,
  :sample_payload_url,
  :customer_metadata_properties,
  :drift_check_baselines,
  :additional_inference_specifications,
  :skip_model_validation,
  :source_uri,
  :security_config,
  :model_card,
  :model_life_cycle,
  :managed_storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#approval_descriptionString

A description provided for the model approval.

Returns:

  • (String)


21981
21982
21983
21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
21996
21997
21998
21999
22000
22001
22002
22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
# File 'lib/aws-sdk-sagemaker/types.rb', line 21981

class DescribeModelPackageOutput < Struct.new(
  :model_package_name,
  :model_package_group_name,
  :model_package_version,
  :model_package_registration_type,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :source_algorithm_specification,
  :validation_specification,
  :model_package_status,
  :model_package_status_details,
  :certify_for_marketplace,
  :model_approval_status,
  :created_by,
  :metadata_properties,
  :model_metrics,
  :last_modified_time,
  :last_modified_by,
  :approval_description,
  :domain,
  :task,
  :sample_payload_url,
  :customer_metadata_properties,
  :drift_check_baselines,
  :additional_inference_specifications,
  :skip_model_validation,
  :source_uri,
  :security_config,
  :model_card,
  :model_life_cycle,
  :managed_storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#certify_for_marketplaceBoolean

Whether the model package is certified for listing on Amazon Web Services Marketplace.

Returns:

  • (Boolean)


21981
21982
21983
21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
21996
21997
21998
21999
22000
22001
22002
22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
# File 'lib/aws-sdk-sagemaker/types.rb', line 21981

class DescribeModelPackageOutput < Struct.new(
  :model_package_name,
  :model_package_group_name,
  :model_package_version,
  :model_package_registration_type,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :source_algorithm_specification,
  :validation_specification,
  :model_package_status,
  :model_package_status_details,
  :certify_for_marketplace,
  :model_approval_status,
  :created_by,
  :metadata_properties,
  :model_metrics,
  :last_modified_time,
  :last_modified_by,
  :approval_description,
  :domain,
  :task,
  :sample_payload_url,
  :customer_metadata_properties,
  :drift_check_baselines,
  :additional_inference_specifications,
  :skip_model_validation,
  :source_uri,
  :security_config,
  :model_card,
  :model_life_cycle,
  :managed_storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#created_byTypes::UserContext

Information about the user who created or modified a SageMaker resource.

Returns:



21981
21982
21983
21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
21996
21997
21998
21999
22000
22001
22002
22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
# File 'lib/aws-sdk-sagemaker/types.rb', line 21981

class DescribeModelPackageOutput < Struct.new(
  :model_package_name,
  :model_package_group_name,
  :model_package_version,
  :model_package_registration_type,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :source_algorithm_specification,
  :validation_specification,
  :model_package_status,
  :model_package_status_details,
  :certify_for_marketplace,
  :model_approval_status,
  :created_by,
  :metadata_properties,
  :model_metrics,
  :last_modified_time,
  :last_modified_by,
  :approval_description,
  :domain,
  :task,
  :sample_payload_url,
  :customer_metadata_properties,
  :drift_check_baselines,
  :additional_inference_specifications,
  :skip_model_validation,
  :source_uri,
  :security_config,
  :model_card,
  :model_life_cycle,
  :managed_storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

A timestamp specifying when the model package was created.

Returns:

  • (Time)


21981
21982
21983
21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
21996
21997
21998
21999
22000
22001
22002
22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
# File 'lib/aws-sdk-sagemaker/types.rb', line 21981

class DescribeModelPackageOutput < Struct.new(
  :model_package_name,
  :model_package_group_name,
  :model_package_version,
  :model_package_registration_type,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :source_algorithm_specification,
  :validation_specification,
  :model_package_status,
  :model_package_status_details,
  :certify_for_marketplace,
  :model_approval_status,
  :created_by,
  :metadata_properties,
  :model_metrics,
  :last_modified_time,
  :last_modified_by,
  :approval_description,
  :domain,
  :task,
  :sample_payload_url,
  :customer_metadata_properties,
  :drift_check_baselines,
  :additional_inference_specifications,
  :skip_model_validation,
  :source_uri,
  :security_config,
  :model_card,
  :model_life_cycle,
  :managed_storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#customer_metadata_propertiesHash<String,String>

The metadata properties associated with the model package versions.

Returns:

  • (Hash<String,String>)


21981
21982
21983
21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
21996
21997
21998
21999
22000
22001
22002
22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
# File 'lib/aws-sdk-sagemaker/types.rb', line 21981

class DescribeModelPackageOutput < Struct.new(
  :model_package_name,
  :model_package_group_name,
  :model_package_version,
  :model_package_registration_type,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :source_algorithm_specification,
  :validation_specification,
  :model_package_status,
  :model_package_status_details,
  :certify_for_marketplace,
  :model_approval_status,
  :created_by,
  :metadata_properties,
  :model_metrics,
  :last_modified_time,
  :last_modified_by,
  :approval_description,
  :domain,
  :task,
  :sample_payload_url,
  :customer_metadata_properties,
  :drift_check_baselines,
  :additional_inference_specifications,
  :skip_model_validation,
  :source_uri,
  :security_config,
  :model_card,
  :model_life_cycle,
  :managed_storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#domainString

The machine learning domain of the model package you specified. Common machine learning domains include computer vision and natural language processing.

Returns:

  • (String)


21981
21982
21983
21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
21996
21997
21998
21999
22000
22001
22002
22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
# File 'lib/aws-sdk-sagemaker/types.rb', line 21981

class DescribeModelPackageOutput < Struct.new(
  :model_package_name,
  :model_package_group_name,
  :model_package_version,
  :model_package_registration_type,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :source_algorithm_specification,
  :validation_specification,
  :model_package_status,
  :model_package_status_details,
  :certify_for_marketplace,
  :model_approval_status,
  :created_by,
  :metadata_properties,
  :model_metrics,
  :last_modified_time,
  :last_modified_by,
  :approval_description,
  :domain,
  :task,
  :sample_payload_url,
  :customer_metadata_properties,
  :drift_check_baselines,
  :additional_inference_specifications,
  :skip_model_validation,
  :source_uri,
  :security_config,
  :model_card,
  :model_life_cycle,
  :managed_storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#drift_check_baselinesTypes::DriftCheckBaselines

Represents the drift check baselines that can be used when the model monitor is set using the model package. For more information, see the topic on [Drift Detection against Previous Baselines in SageMaker Pipelines] in the *Amazon SageMaker Developer Guide*.

[1]: docs.aws.amazon.com/sagemaker/latest/dg/pipelines-quality-clarify-baseline-lifecycle.html#pipelines-quality-clarify-baseline-drift-detection



21981
21982
21983
21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
21996
21997
21998
21999
22000
22001
22002
22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
# File 'lib/aws-sdk-sagemaker/types.rb', line 21981

class DescribeModelPackageOutput < Struct.new(
  :model_package_name,
  :model_package_group_name,
  :model_package_version,
  :model_package_registration_type,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :source_algorithm_specification,
  :validation_specification,
  :model_package_status,
  :model_package_status_details,
  :certify_for_marketplace,
  :model_approval_status,
  :created_by,
  :metadata_properties,
  :model_metrics,
  :last_modified_time,
  :last_modified_by,
  :approval_description,
  :domain,
  :task,
  :sample_payload_url,
  :customer_metadata_properties,
  :drift_check_baselines,
  :additional_inference_specifications,
  :skip_model_validation,
  :source_uri,
  :security_config,
  :model_card,
  :model_life_cycle,
  :managed_storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#inference_specificationTypes::InferenceSpecification

Details about inference jobs that you can run with models based on this model package.



21981
21982
21983
21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
21996
21997
21998
21999
22000
22001
22002
22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
# File 'lib/aws-sdk-sagemaker/types.rb', line 21981

class DescribeModelPackageOutput < Struct.new(
  :model_package_name,
  :model_package_group_name,
  :model_package_version,
  :model_package_registration_type,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :source_algorithm_specification,
  :validation_specification,
  :model_package_status,
  :model_package_status_details,
  :certify_for_marketplace,
  :model_approval_status,
  :created_by,
  :metadata_properties,
  :model_metrics,
  :last_modified_time,
  :last_modified_by,
  :approval_description,
  :domain,
  :task,
  :sample_payload_url,
  :customer_metadata_properties,
  :drift_check_baselines,
  :additional_inference_specifications,
  :skip_model_validation,
  :source_uri,
  :security_config,
  :model_card,
  :model_life_cycle,
  :managed_storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_byTypes::UserContext

Information about the user who created or modified a SageMaker resource.

Returns:



21981
21982
21983
21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
21996
21997
21998
21999
22000
22001
22002
22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
# File 'lib/aws-sdk-sagemaker/types.rb', line 21981

class DescribeModelPackageOutput < Struct.new(
  :model_package_name,
  :model_package_group_name,
  :model_package_version,
  :model_package_registration_type,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :source_algorithm_specification,
  :validation_specification,
  :model_package_status,
  :model_package_status_details,
  :certify_for_marketplace,
  :model_approval_status,
  :created_by,
  :metadata_properties,
  :model_metrics,
  :last_modified_time,
  :last_modified_by,
  :approval_description,
  :domain,
  :task,
  :sample_payload_url,
  :customer_metadata_properties,
  :drift_check_baselines,
  :additional_inference_specifications,
  :skip_model_validation,
  :source_uri,
  :security_config,
  :model_card,
  :model_life_cycle,
  :managed_storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The last time that the model package was modified.

Returns:

  • (Time)


21981
21982
21983
21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
21996
21997
21998
21999
22000
22001
22002
22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
# File 'lib/aws-sdk-sagemaker/types.rb', line 21981

class DescribeModelPackageOutput < Struct.new(
  :model_package_name,
  :model_package_group_name,
  :model_package_version,
  :model_package_registration_type,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :source_algorithm_specification,
  :validation_specification,
  :model_package_status,
  :model_package_status_details,
  :certify_for_marketplace,
  :model_approval_status,
  :created_by,
  :metadata_properties,
  :model_metrics,
  :last_modified_time,
  :last_modified_by,
  :approval_description,
  :domain,
  :task,
  :sample_payload_url,
  :customer_metadata_properties,
  :drift_check_baselines,
  :additional_inference_specifications,
  :skip_model_validation,
  :source_uri,
  :security_config,
  :model_card,
  :model_life_cycle,
  :managed_storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#managed_storage_typeString

The storage type of the model package.

Returns:

  • (String)


21981
21982
21983
21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
21996
21997
21998
21999
22000
22001
22002
22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
# File 'lib/aws-sdk-sagemaker/types.rb', line 21981

class DescribeModelPackageOutput < Struct.new(
  :model_package_name,
  :model_package_group_name,
  :model_package_version,
  :model_package_registration_type,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :source_algorithm_specification,
  :validation_specification,
  :model_package_status,
  :model_package_status_details,
  :certify_for_marketplace,
  :model_approval_status,
  :created_by,
  :metadata_properties,
  :model_metrics,
  :last_modified_time,
  :last_modified_by,
  :approval_description,
  :domain,
  :task,
  :sample_payload_url,
  :customer_metadata_properties,
  :drift_check_baselines,
  :additional_inference_specifications,
  :skip_model_validation,
  :source_uri,
  :security_config,
  :model_card,
  :model_life_cycle,
  :managed_storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#metadata_propertiesTypes::MetadataProperties

Metadata properties of the tracking entity, trial, or trial component.



21981
21982
21983
21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
21996
21997
21998
21999
22000
22001
22002
22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
# File 'lib/aws-sdk-sagemaker/types.rb', line 21981

class DescribeModelPackageOutput < Struct.new(
  :model_package_name,
  :model_package_group_name,
  :model_package_version,
  :model_package_registration_type,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :source_algorithm_specification,
  :validation_specification,
  :model_package_status,
  :model_package_status_details,
  :certify_for_marketplace,
  :model_approval_status,
  :created_by,
  :metadata_properties,
  :model_metrics,
  :last_modified_time,
  :last_modified_by,
  :approval_description,
  :domain,
  :task,
  :sample_payload_url,
  :customer_metadata_properties,
  :drift_check_baselines,
  :additional_inference_specifications,
  :skip_model_validation,
  :source_uri,
  :security_config,
  :model_card,
  :model_life_cycle,
  :managed_storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#model_approval_statusString

The approval status of the model package.

Returns:

  • (String)


21981
21982
21983
21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
21996
21997
21998
21999
22000
22001
22002
22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
# File 'lib/aws-sdk-sagemaker/types.rb', line 21981

class DescribeModelPackageOutput < Struct.new(
  :model_package_name,
  :model_package_group_name,
  :model_package_version,
  :model_package_registration_type,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :source_algorithm_specification,
  :validation_specification,
  :model_package_status,
  :model_package_status_details,
  :certify_for_marketplace,
  :model_approval_status,
  :created_by,
  :metadata_properties,
  :model_metrics,
  :last_modified_time,
  :last_modified_by,
  :approval_description,
  :domain,
  :task,
  :sample_payload_url,
  :customer_metadata_properties,
  :drift_check_baselines,
  :additional_inference_specifications,
  :skip_model_validation,
  :source_uri,
  :security_config,
  :model_card,
  :model_life_cycle,
  :managed_storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#model_cardTypes::ModelPackageModelCard

The model card associated with the model package. Since ‘ModelPackageModelCard` is tied to a model package, it is a specific usage of a model card and its schema is simplified compared to the schema of `ModelCard`. The `ModelPackageModelCard` schema does not include `model_package_details`, and `model_overview` is composed of the `model_creator` and `model_artifact` properties. For more information about the model package model card schema, see [Model package model card schema]. For more information about the model card associated with the model package, see [View the Details of a Model Version].

When you set ‘IncludedData` to `MetadataOnly` in the request, `ModelCardStatus` is preserved and `ModelCardContent` is sanitized to include only the following JSON paths, when present in the model card:

  • ‘model_overview.model_id`

  • ‘model_overview.model_name`

  • ‘intended_uses.risk_rating`

  • ‘model_package_details.model_package_group_name`

  • ‘model_package_details.model_package_arn`

Because the ‘ModelPackageModelCard` schema does not include `model_package_details` and limits `model_overview` to `model_creator` and `model_artifact`, the sanitized `ModelCardContent` for a model package typically contains only `intended_uses.risk_rating` if it was provided when the model card was created. To retrieve the complete `ModelCardContent`, set `IncludedData` to `AllData` or omit the parameter.

[1]: docs.aws.amazon.com/sagemaker/latest/dg/model-registry-details.html#model-card-schema [2]: docs.aws.amazon.com/sagemaker/latest/dg/model-registry-details.html



21981
21982
21983
21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
21996
21997
21998
21999
22000
22001
22002
22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
# File 'lib/aws-sdk-sagemaker/types.rb', line 21981

class DescribeModelPackageOutput < Struct.new(
  :model_package_name,
  :model_package_group_name,
  :model_package_version,
  :model_package_registration_type,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :source_algorithm_specification,
  :validation_specification,
  :model_package_status,
  :model_package_status_details,
  :certify_for_marketplace,
  :model_approval_status,
  :created_by,
  :metadata_properties,
  :model_metrics,
  :last_modified_time,
  :last_modified_by,
  :approval_description,
  :domain,
  :task,
  :sample_payload_url,
  :customer_metadata_properties,
  :drift_check_baselines,
  :additional_inference_specifications,
  :skip_model_validation,
  :source_uri,
  :security_config,
  :model_card,
  :model_life_cycle,
  :managed_storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#model_life_cycleTypes::ModelLifeCycle

A structure describing the current state of the model in its life cycle.



21981
21982
21983
21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
21996
21997
21998
21999
22000
22001
22002
22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
# File 'lib/aws-sdk-sagemaker/types.rb', line 21981

class DescribeModelPackageOutput < Struct.new(
  :model_package_name,
  :model_package_group_name,
  :model_package_version,
  :model_package_registration_type,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :source_algorithm_specification,
  :validation_specification,
  :model_package_status,
  :model_package_status_details,
  :certify_for_marketplace,
  :model_approval_status,
  :created_by,
  :metadata_properties,
  :model_metrics,
  :last_modified_time,
  :last_modified_by,
  :approval_description,
  :domain,
  :task,
  :sample_payload_url,
  :customer_metadata_properties,
  :drift_check_baselines,
  :additional_inference_specifications,
  :skip_model_validation,
  :source_uri,
  :security_config,
  :model_card,
  :model_life_cycle,
  :managed_storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#model_metricsTypes::ModelMetrics

Metrics for the model.

Returns:



21981
21982
21983
21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
21996
21997
21998
21999
22000
22001
22002
22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
# File 'lib/aws-sdk-sagemaker/types.rb', line 21981

class DescribeModelPackageOutput < Struct.new(
  :model_package_name,
  :model_package_group_name,
  :model_package_version,
  :model_package_registration_type,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :source_algorithm_specification,
  :validation_specification,
  :model_package_status,
  :model_package_status_details,
  :certify_for_marketplace,
  :model_approval_status,
  :created_by,
  :metadata_properties,
  :model_metrics,
  :last_modified_time,
  :last_modified_by,
  :approval_description,
  :domain,
  :task,
  :sample_payload_url,
  :customer_metadata_properties,
  :drift_check_baselines,
  :additional_inference_specifications,
  :skip_model_validation,
  :source_uri,
  :security_config,
  :model_card,
  :model_life_cycle,
  :managed_storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#model_package_arnString

The Amazon Resource Name (ARN) of the model package.

Returns:

  • (String)


21981
21982
21983
21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
21996
21997
21998
21999
22000
22001
22002
22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
# File 'lib/aws-sdk-sagemaker/types.rb', line 21981

class DescribeModelPackageOutput < Struct.new(
  :model_package_name,
  :model_package_group_name,
  :model_package_version,
  :model_package_registration_type,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :source_algorithm_specification,
  :validation_specification,
  :model_package_status,
  :model_package_status_details,
  :certify_for_marketplace,
  :model_approval_status,
  :created_by,
  :metadata_properties,
  :model_metrics,
  :last_modified_time,
  :last_modified_by,
  :approval_description,
  :domain,
  :task,
  :sample_payload_url,
  :customer_metadata_properties,
  :drift_check_baselines,
  :additional_inference_specifications,
  :skip_model_validation,
  :source_uri,
  :security_config,
  :model_card,
  :model_life_cycle,
  :managed_storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#model_package_descriptionString

A brief summary of the model package.

Returns:

  • (String)


21981
21982
21983
21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
21996
21997
21998
21999
22000
22001
22002
22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
# File 'lib/aws-sdk-sagemaker/types.rb', line 21981

class DescribeModelPackageOutput < Struct.new(
  :model_package_name,
  :model_package_group_name,
  :model_package_version,
  :model_package_registration_type,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :source_algorithm_specification,
  :validation_specification,
  :model_package_status,
  :model_package_status_details,
  :certify_for_marketplace,
  :model_approval_status,
  :created_by,
  :metadata_properties,
  :model_metrics,
  :last_modified_time,
  :last_modified_by,
  :approval_description,
  :domain,
  :task,
  :sample_payload_url,
  :customer_metadata_properties,
  :drift_check_baselines,
  :additional_inference_specifications,
  :skip_model_validation,
  :source_uri,
  :security_config,
  :model_card,
  :model_life_cycle,
  :managed_storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#model_package_group_nameString

If the model is a versioned model, the name of the model group that the versioned model belongs to.

Returns:

  • (String)


21981
21982
21983
21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
21996
21997
21998
21999
22000
22001
22002
22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
# File 'lib/aws-sdk-sagemaker/types.rb', line 21981

class DescribeModelPackageOutput < Struct.new(
  :model_package_name,
  :model_package_group_name,
  :model_package_version,
  :model_package_registration_type,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :source_algorithm_specification,
  :validation_specification,
  :model_package_status,
  :model_package_status_details,
  :certify_for_marketplace,
  :model_approval_status,
  :created_by,
  :metadata_properties,
  :model_metrics,
  :last_modified_time,
  :last_modified_by,
  :approval_description,
  :domain,
  :task,
  :sample_payload_url,
  :customer_metadata_properties,
  :drift_check_baselines,
  :additional_inference_specifications,
  :skip_model_validation,
  :source_uri,
  :security_config,
  :model_card,
  :model_life_cycle,
  :managed_storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#model_package_nameString

The name of the model package being described.

Returns:

  • (String)


21981
21982
21983
21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
21996
21997
21998
21999
22000
22001
22002
22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
# File 'lib/aws-sdk-sagemaker/types.rb', line 21981

class DescribeModelPackageOutput < Struct.new(
  :model_package_name,
  :model_package_group_name,
  :model_package_version,
  :model_package_registration_type,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :source_algorithm_specification,
  :validation_specification,
  :model_package_status,
  :model_package_status_details,
  :certify_for_marketplace,
  :model_approval_status,
  :created_by,
  :metadata_properties,
  :model_metrics,
  :last_modified_time,
  :last_modified_by,
  :approval_description,
  :domain,
  :task,
  :sample_payload_url,
  :customer_metadata_properties,
  :drift_check_baselines,
  :additional_inference_specifications,
  :skip_model_validation,
  :source_uri,
  :security_config,
  :model_card,
  :model_life_cycle,
  :managed_storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#model_package_registration_typeString

The package registration type of the model package output.

Returns:

  • (String)


21981
21982
21983
21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
21996
21997
21998
21999
22000
22001
22002
22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
# File 'lib/aws-sdk-sagemaker/types.rb', line 21981

class DescribeModelPackageOutput < Struct.new(
  :model_package_name,
  :model_package_group_name,
  :model_package_version,
  :model_package_registration_type,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :source_algorithm_specification,
  :validation_specification,
  :model_package_status,
  :model_package_status_details,
  :certify_for_marketplace,
  :model_approval_status,
  :created_by,
  :metadata_properties,
  :model_metrics,
  :last_modified_time,
  :last_modified_by,
  :approval_description,
  :domain,
  :task,
  :sample_payload_url,
  :customer_metadata_properties,
  :drift_check_baselines,
  :additional_inference_specifications,
  :skip_model_validation,
  :source_uri,
  :security_config,
  :model_card,
  :model_life_cycle,
  :managed_storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#model_package_statusString

The current status of the model package.

Returns:

  • (String)


21981
21982
21983
21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
21996
21997
21998
21999
22000
22001
22002
22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
# File 'lib/aws-sdk-sagemaker/types.rb', line 21981

class DescribeModelPackageOutput < Struct.new(
  :model_package_name,
  :model_package_group_name,
  :model_package_version,
  :model_package_registration_type,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :source_algorithm_specification,
  :validation_specification,
  :model_package_status,
  :model_package_status_details,
  :certify_for_marketplace,
  :model_approval_status,
  :created_by,
  :metadata_properties,
  :model_metrics,
  :last_modified_time,
  :last_modified_by,
  :approval_description,
  :domain,
  :task,
  :sample_payload_url,
  :customer_metadata_properties,
  :drift_check_baselines,
  :additional_inference_specifications,
  :skip_model_validation,
  :source_uri,
  :security_config,
  :model_card,
  :model_life_cycle,
  :managed_storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#model_package_status_detailsTypes::ModelPackageStatusDetails

Details about the current status of the model package.



21981
21982
21983
21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
21996
21997
21998
21999
22000
22001
22002
22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
# File 'lib/aws-sdk-sagemaker/types.rb', line 21981

class DescribeModelPackageOutput < Struct.new(
  :model_package_name,
  :model_package_group_name,
  :model_package_version,
  :model_package_registration_type,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :source_algorithm_specification,
  :validation_specification,
  :model_package_status,
  :model_package_status_details,
  :certify_for_marketplace,
  :model_approval_status,
  :created_by,
  :metadata_properties,
  :model_metrics,
  :last_modified_time,
  :last_modified_by,
  :approval_description,
  :domain,
  :task,
  :sample_payload_url,
  :customer_metadata_properties,
  :drift_check_baselines,
  :additional_inference_specifications,
  :skip_model_validation,
  :source_uri,
  :security_config,
  :model_card,
  :model_life_cycle,
  :managed_storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#model_package_versionInteger

The version of the model package.

Returns:

  • (Integer)


21981
21982
21983
21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
21996
21997
21998
21999
22000
22001
22002
22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
# File 'lib/aws-sdk-sagemaker/types.rb', line 21981

class DescribeModelPackageOutput < Struct.new(
  :model_package_name,
  :model_package_group_name,
  :model_package_version,
  :model_package_registration_type,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :source_algorithm_specification,
  :validation_specification,
  :model_package_status,
  :model_package_status_details,
  :certify_for_marketplace,
  :model_approval_status,
  :created_by,
  :metadata_properties,
  :model_metrics,
  :last_modified_time,
  :last_modified_by,
  :approval_description,
  :domain,
  :task,
  :sample_payload_url,
  :customer_metadata_properties,
  :drift_check_baselines,
  :additional_inference_specifications,
  :skip_model_validation,
  :source_uri,
  :security_config,
  :model_card,
  :model_life_cycle,
  :managed_storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#sample_payload_urlString

The Amazon Simple Storage Service (Amazon S3) path where the sample payload are stored. This path points to a single gzip compressed tar archive (.tar.gz suffix).

Returns:

  • (String)


21981
21982
21983
21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
21996
21997
21998
21999
22000
22001
22002
22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
# File 'lib/aws-sdk-sagemaker/types.rb', line 21981

class DescribeModelPackageOutput < Struct.new(
  :model_package_name,
  :model_package_group_name,
  :model_package_version,
  :model_package_registration_type,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :source_algorithm_specification,
  :validation_specification,
  :model_package_status,
  :model_package_status_details,
  :certify_for_marketplace,
  :model_approval_status,
  :created_by,
  :metadata_properties,
  :model_metrics,
  :last_modified_time,
  :last_modified_by,
  :approval_description,
  :domain,
  :task,
  :sample_payload_url,
  :customer_metadata_properties,
  :drift_check_baselines,
  :additional_inference_specifications,
  :skip_model_validation,
  :source_uri,
  :security_config,
  :model_card,
  :model_life_cycle,
  :managed_storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#security_configTypes::ModelPackageSecurityConfig

The KMS Key ID (‘KMSKeyId`) used for encryption of model package information.



21981
21982
21983
21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
21996
21997
21998
21999
22000
22001
22002
22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
# File 'lib/aws-sdk-sagemaker/types.rb', line 21981

class DescribeModelPackageOutput < Struct.new(
  :model_package_name,
  :model_package_group_name,
  :model_package_version,
  :model_package_registration_type,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :source_algorithm_specification,
  :validation_specification,
  :model_package_status,
  :model_package_status_details,
  :certify_for_marketplace,
  :model_approval_status,
  :created_by,
  :metadata_properties,
  :model_metrics,
  :last_modified_time,
  :last_modified_by,
  :approval_description,
  :domain,
  :task,
  :sample_payload_url,
  :customer_metadata_properties,
  :drift_check_baselines,
  :additional_inference_specifications,
  :skip_model_validation,
  :source_uri,
  :security_config,
  :model_card,
  :model_life_cycle,
  :managed_storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#skip_model_validationString

Indicates if you want to skip model validation.

Returns:

  • (String)


21981
21982
21983
21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
21996
21997
21998
21999
22000
22001
22002
22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
# File 'lib/aws-sdk-sagemaker/types.rb', line 21981

class DescribeModelPackageOutput < Struct.new(
  :model_package_name,
  :model_package_group_name,
  :model_package_version,
  :model_package_registration_type,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :source_algorithm_specification,
  :validation_specification,
  :model_package_status,
  :model_package_status_details,
  :certify_for_marketplace,
  :model_approval_status,
  :created_by,
  :metadata_properties,
  :model_metrics,
  :last_modified_time,
  :last_modified_by,
  :approval_description,
  :domain,
  :task,
  :sample_payload_url,
  :customer_metadata_properties,
  :drift_check_baselines,
  :additional_inference_specifications,
  :skip_model_validation,
  :source_uri,
  :security_config,
  :model_card,
  :model_life_cycle,
  :managed_storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#source_algorithm_specificationTypes::SourceAlgorithmSpecification

Details about the algorithm that was used to create the model package.



21981
21982
21983
21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
21996
21997
21998
21999
22000
22001
22002
22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
# File 'lib/aws-sdk-sagemaker/types.rb', line 21981

class DescribeModelPackageOutput < Struct.new(
  :model_package_name,
  :model_package_group_name,
  :model_package_version,
  :model_package_registration_type,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :source_algorithm_specification,
  :validation_specification,
  :model_package_status,
  :model_package_status_details,
  :certify_for_marketplace,
  :model_approval_status,
  :created_by,
  :metadata_properties,
  :model_metrics,
  :last_modified_time,
  :last_modified_by,
  :approval_description,
  :domain,
  :task,
  :sample_payload_url,
  :customer_metadata_properties,
  :drift_check_baselines,
  :additional_inference_specifications,
  :skip_model_validation,
  :source_uri,
  :security_config,
  :model_card,
  :model_life_cycle,
  :managed_storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#source_uriString

The URI of the source for the model package.

Returns:

  • (String)


21981
21982
21983
21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
21996
21997
21998
21999
22000
22001
22002
22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
# File 'lib/aws-sdk-sagemaker/types.rb', line 21981

class DescribeModelPackageOutput < Struct.new(
  :model_package_name,
  :model_package_group_name,
  :model_package_version,
  :model_package_registration_type,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :source_algorithm_specification,
  :validation_specification,
  :model_package_status,
  :model_package_status_details,
  :certify_for_marketplace,
  :model_approval_status,
  :created_by,
  :metadata_properties,
  :model_metrics,
  :last_modified_time,
  :last_modified_by,
  :approval_description,
  :domain,
  :task,
  :sample_payload_url,
  :customer_metadata_properties,
  :drift_check_baselines,
  :additional_inference_specifications,
  :skip_model_validation,
  :source_uri,
  :security_config,
  :model_card,
  :model_life_cycle,
  :managed_storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#taskString

The machine learning task you specified that your model package accomplishes. Common machine learning tasks include object detection and image classification.

Returns:

  • (String)


21981
21982
21983
21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
21996
21997
21998
21999
22000
22001
22002
22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
# File 'lib/aws-sdk-sagemaker/types.rb', line 21981

class DescribeModelPackageOutput < Struct.new(
  :model_package_name,
  :model_package_group_name,
  :model_package_version,
  :model_package_registration_type,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :source_algorithm_specification,
  :validation_specification,
  :model_package_status,
  :model_package_status_details,
  :certify_for_marketplace,
  :model_approval_status,
  :created_by,
  :metadata_properties,
  :model_metrics,
  :last_modified_time,
  :last_modified_by,
  :approval_description,
  :domain,
  :task,
  :sample_payload_url,
  :customer_metadata_properties,
  :drift_check_baselines,
  :additional_inference_specifications,
  :skip_model_validation,
  :source_uri,
  :security_config,
  :model_card,
  :model_life_cycle,
  :managed_storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#validation_specificationTypes::ModelPackageValidationSpecification

Configurations for one or more transform jobs that SageMaker runs to test the model package.



21981
21982
21983
21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
21996
21997
21998
21999
22000
22001
22002
22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
# File 'lib/aws-sdk-sagemaker/types.rb', line 21981

class DescribeModelPackageOutput < Struct.new(
  :model_package_name,
  :model_package_group_name,
  :model_package_version,
  :model_package_registration_type,
  :model_package_arn,
  :model_package_description,
  :creation_time,
  :inference_specification,
  :source_algorithm_specification,
  :validation_specification,
  :model_package_status,
  :model_package_status_details,
  :certify_for_marketplace,
  :model_approval_status,
  :created_by,
  :metadata_properties,
  :model_metrics,
  :last_modified_time,
  :last_modified_by,
  :approval_description,
  :domain,
  :task,
  :sample_payload_url,
  :customer_metadata_properties,
  :drift_check_baselines,
  :additional_inference_specifications,
  :skip_model_validation,
  :source_uri,
  :security_config,
  :model_card,
  :model_life_cycle,
  :managed_storage_type)
  SENSITIVE = []
  include Aws::Structure
end