Class: Aws::SageMaker::Types::DescribeModelPackageOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeModelPackageOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_inference_specifications ⇒ Array<Types::AdditionalInferenceSpecificationDefinition>
An array of additional Inference Specification objects.
-
#approval_description ⇒ String
A description provided for the model approval.
-
#certify_for_marketplace ⇒ Boolean
Whether the model package is certified for listing on Amazon Web Services Marketplace.
-
#created_by ⇒ Types::UserContext
Information about the user who created or modified an experiment, trial, trial component, lineage group, project, or model card.
-
#creation_time ⇒ Time
A timestamp specifying when the model package was created.
-
#customer_metadata_properties ⇒ Hash<String,String>
The metadata properties associated with the model package versions.
-
#domain ⇒ String
The machine learning domain of the model package you specified.
-
#drift_check_baselines ⇒ Types::DriftCheckBaselines
Represents the drift check baselines that can be used when the model monitor is set using the model package.
-
#inference_specification ⇒ Types::InferenceSpecification
Details about inference jobs that can be run with models based on this model package.
-
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified an experiment, trial, trial component, lineage group, project, or model card.
-
#last_modified_time ⇒ Time
The last time that the model package was modified.
-
#metadata_properties ⇒ Types::MetadataProperties
Metadata properties of the tracking entity, trial, or trial component.
-
#model_approval_status ⇒ String
The approval status of the model package.
-
#model_metrics ⇒ Types::ModelMetrics
Metrics for the model.
-
#model_package_arn ⇒ String
The Amazon Resource Name (ARN) of the model package.
-
#model_package_description ⇒ String
A brief summary of the model package.
-
#model_package_group_name ⇒ String
If the model is a versioned model, the name of the model group that the versioned model belongs to.
-
#model_package_name ⇒ String
The name of the model package being described.
-
#model_package_status ⇒ String
The current status of the model package.
-
#model_package_status_details ⇒ Types::ModelPackageStatusDetails
Details about the current status of the model package.
-
#model_package_version ⇒ Integer
The version of the model package.
-
#sample_payload_url ⇒ String
The Amazon Simple Storage Service (Amazon S3) path where the sample payload are stored.
-
#source_algorithm_specification ⇒ Types::SourceAlgorithmSpecification
Details about the algorithm that was used to create the model package.
-
#task ⇒ String
The machine learning task you specified that your model package accomplishes.
-
#validation_specification ⇒ Types::ModelPackageValidationSpecification
Configurations for one or more transform jobs that SageMaker runs to test the model package.
Instance Attribute Details
#additional_inference_specifications ⇒ Array<Types::AdditionalInferenceSpecificationDefinition>
An array of additional Inference Specification objects. Each additional Inference Specification specifies artifacts based on this model package that can be used on inference endpoints. Generally used with SageMaker Neo to store the compiled artifacts.
13195 13196 13197 13198 13199 13200 13201 13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13195 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#approval_description ⇒ String
A description provided for the model approval.
13195 13196 13197 13198 13199 13200 13201 13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13195 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#certify_for_marketplace ⇒ Boolean
Whether the model package is certified for listing on Amazon Web Services Marketplace.
13195 13196 13197 13198 13199 13200 13201 13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13195 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ Types::UserContext
Information about the user who created or modified an experiment, trial, trial component, lineage group, project, or model card.
13195 13196 13197 13198 13199 13200 13201 13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13195 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
A timestamp specifying when the model package was created.
13195 13196 13197 13198 13199 13200 13201 13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13195 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#customer_metadata_properties ⇒ Hash<String,String>
The metadata properties associated with the model package versions.
13195 13196 13197 13198 13199 13200 13201 13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13195 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#domain ⇒ String
The machine learning domain of the model package you specified. Common machine learning domains include computer vision and natural language processing.
13195 13196 13197 13198 13199 13200 13201 13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13195 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#drift_check_baselines ⇒ Types::DriftCheckBaselines
Represents the drift check baselines that can be used when the model monitor is set using the model package. For more information, see the topic on [Drift Detection against Previous Baselines in SageMaker Pipelines] in the *Amazon SageMaker Developer Guide*.
13195 13196 13197 13198 13199 13200 13201 13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13195 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#inference_specification ⇒ Types::InferenceSpecification
Details about inference jobs that can be run with models based on this model package.
13195 13196 13197 13198 13199 13200 13201 13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13195 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified an experiment, trial, trial component, lineage group, project, or model card.
13195 13196 13197 13198 13199 13200 13201 13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13195 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The last time that the model package was modified.
13195 13196 13197 13198 13199 13200 13201 13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13195 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#metadata_properties ⇒ Types::MetadataProperties
Metadata properties of the tracking entity, trial, or trial component.
13195 13196 13197 13198 13199 13200 13201 13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13195 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#model_approval_status ⇒ String
The approval status of the model package.
13195 13196 13197 13198 13199 13200 13201 13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13195 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#model_metrics ⇒ Types::ModelMetrics
Metrics for the model.
13195 13196 13197 13198 13199 13200 13201 13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13195 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#model_package_arn ⇒ String
The Amazon Resource Name (ARN) of the model package.
13195 13196 13197 13198 13199 13200 13201 13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13195 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#model_package_description ⇒ String
A brief summary of the model package.
13195 13196 13197 13198 13199 13200 13201 13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13195 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#model_package_group_name ⇒ String
If the model is a versioned model, the name of the model group that the versioned model belongs to.
13195 13196 13197 13198 13199 13200 13201 13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13195 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#model_package_name ⇒ String
The name of the model package being described.
13195 13196 13197 13198 13199 13200 13201 13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13195 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#model_package_status ⇒ String
The current status of the model package.
13195 13196 13197 13198 13199 13200 13201 13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13195 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#model_package_status_details ⇒ Types::ModelPackageStatusDetails
Details about the current status of the model package.
13195 13196 13197 13198 13199 13200 13201 13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13195 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#model_package_version ⇒ Integer
The version of the model package.
13195 13196 13197 13198 13199 13200 13201 13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13195 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#sample_payload_url ⇒ String
The Amazon Simple Storage Service (Amazon S3) path where the sample payload are stored. This path points to a single gzip compressed tar archive (.tar.gz suffix).
13195 13196 13197 13198 13199 13200 13201 13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13195 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#source_algorithm_specification ⇒ Types::SourceAlgorithmSpecification
Details about the algorithm that was used to create the model package.
13195 13196 13197 13198 13199 13200 13201 13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13195 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#task ⇒ String
The machine learning task you specified that your model package accomplishes. Common machine learning tasks include object detection and image classification.
13195 13196 13197 13198 13199 13200 13201 13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13195 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |
#validation_specification ⇒ Types::ModelPackageValidationSpecification
Configurations for one or more transform jobs that SageMaker runs to test the model package.
13195 13196 13197 13198 13199 13200 13201 13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 13195 class DescribeModelPackageOutput < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :customer_metadata_properties, :drift_check_baselines, :domain, :task, :sample_payload_url, :additional_inference_specifications) SENSITIVE = [] include Aws::Structure end |