Class: Aws::SageMaker::Types::DescribeModelQualityJobDefinitionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeModelQualityJobDefinitionResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Time
The time at which the model quality job was created.
-
#job_definition_arn ⇒ String
The Amazon Resource Name (ARN) of the model quality job.
-
#job_definition_name ⇒ String
The name of the quality job definition.
-
#job_resources ⇒ Types::MonitoringResources
Identifies the resources to deploy for a monitoring job.
-
#model_quality_app_specification ⇒ Types::ModelQualityAppSpecification
Configures the model quality job to run a specified Docker container image.
-
#model_quality_baseline_config ⇒ Types::ModelQualityBaselineConfig
The baseline configuration for a model quality job.
-
#model_quality_job_input ⇒ Types::ModelQualityJobInput
Inputs for the model quality job.
-
#model_quality_job_output_config ⇒ Types::MonitoringOutputConfig
The output configuration for monitoring jobs.
-
#network_config ⇒ Types::MonitoringNetworkConfig
Networking options for a model quality job.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker AI can assume to perform tasks on your behalf.
-
#stopping_condition ⇒ Types::MonitoringStoppingCondition
A time limit for how long the monitoring job is allowed to run before stopping.
Instance Attribute Details
#creation_time ⇒ Time
The time at which the model quality job was created.
21616 21617 21618 21619 21620 21621 21622 21623 21624 21625 21626 21627 21628 21629 21630 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21616 class DescribeModelQualityJobDefinitionResponse < Struct.new( :job_definition_arn, :job_definition_name, :creation_time, :model_quality_baseline_config, :model_quality_app_specification, :model_quality_job_input, :model_quality_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition) SENSITIVE = [] include Aws::Structure end |
#job_definition_arn ⇒ String
The Amazon Resource Name (ARN) of the model quality job.
21616 21617 21618 21619 21620 21621 21622 21623 21624 21625 21626 21627 21628 21629 21630 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21616 class DescribeModelQualityJobDefinitionResponse < Struct.new( :job_definition_arn, :job_definition_name, :creation_time, :model_quality_baseline_config, :model_quality_app_specification, :model_quality_job_input, :model_quality_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition) SENSITIVE = [] include Aws::Structure end |
#job_definition_name ⇒ String
The name of the quality job definition. The name must be unique within an Amazon Web Services Region in the Amazon Web Services account.
21616 21617 21618 21619 21620 21621 21622 21623 21624 21625 21626 21627 21628 21629 21630 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21616 class DescribeModelQualityJobDefinitionResponse < Struct.new( :job_definition_arn, :job_definition_name, :creation_time, :model_quality_baseline_config, :model_quality_app_specification, :model_quality_job_input, :model_quality_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition) SENSITIVE = [] include Aws::Structure end |
#job_resources ⇒ Types::MonitoringResources
Identifies the resources to deploy for a monitoring job.
21616 21617 21618 21619 21620 21621 21622 21623 21624 21625 21626 21627 21628 21629 21630 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21616 class DescribeModelQualityJobDefinitionResponse < Struct.new( :job_definition_arn, :job_definition_name, :creation_time, :model_quality_baseline_config, :model_quality_app_specification, :model_quality_job_input, :model_quality_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition) SENSITIVE = [] include Aws::Structure end |
#model_quality_app_specification ⇒ Types::ModelQualityAppSpecification
Configures the model quality job to run a specified Docker container image.
21616 21617 21618 21619 21620 21621 21622 21623 21624 21625 21626 21627 21628 21629 21630 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21616 class DescribeModelQualityJobDefinitionResponse < Struct.new( :job_definition_arn, :job_definition_name, :creation_time, :model_quality_baseline_config, :model_quality_app_specification, :model_quality_job_input, :model_quality_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition) SENSITIVE = [] include Aws::Structure end |
#model_quality_baseline_config ⇒ Types::ModelQualityBaselineConfig
The baseline configuration for a model quality job.
21616 21617 21618 21619 21620 21621 21622 21623 21624 21625 21626 21627 21628 21629 21630 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21616 class DescribeModelQualityJobDefinitionResponse < Struct.new( :job_definition_arn, :job_definition_name, :creation_time, :model_quality_baseline_config, :model_quality_app_specification, :model_quality_job_input, :model_quality_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition) SENSITIVE = [] include Aws::Structure end |
#model_quality_job_input ⇒ Types::ModelQualityJobInput
Inputs for the model quality job.
21616 21617 21618 21619 21620 21621 21622 21623 21624 21625 21626 21627 21628 21629 21630 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21616 class DescribeModelQualityJobDefinitionResponse < Struct.new( :job_definition_arn, :job_definition_name, :creation_time, :model_quality_baseline_config, :model_quality_app_specification, :model_quality_job_input, :model_quality_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition) SENSITIVE = [] include Aws::Structure end |
#model_quality_job_output_config ⇒ Types::MonitoringOutputConfig
The output configuration for monitoring jobs.
21616 21617 21618 21619 21620 21621 21622 21623 21624 21625 21626 21627 21628 21629 21630 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21616 class DescribeModelQualityJobDefinitionResponse < Struct.new( :job_definition_arn, :job_definition_name, :creation_time, :model_quality_baseline_config, :model_quality_app_specification, :model_quality_job_input, :model_quality_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition) SENSITIVE = [] include Aws::Structure end |
#network_config ⇒ Types::MonitoringNetworkConfig
Networking options for a model quality job.
21616 21617 21618 21619 21620 21621 21622 21623 21624 21625 21626 21627 21628 21629 21630 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21616 class DescribeModelQualityJobDefinitionResponse < Struct.new( :job_definition_arn, :job_definition_name, :creation_time, :model_quality_baseline_config, :model_quality_app_specification, :model_quality_job_input, :model_quality_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker AI can assume to perform tasks on your behalf.
21616 21617 21618 21619 21620 21621 21622 21623 21624 21625 21626 21627 21628 21629 21630 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21616 class DescribeModelQualityJobDefinitionResponse < Struct.new( :job_definition_arn, :job_definition_name, :creation_time, :model_quality_baseline_config, :model_quality_app_specification, :model_quality_job_input, :model_quality_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition) SENSITIVE = [] include Aws::Structure end |
#stopping_condition ⇒ Types::MonitoringStoppingCondition
A time limit for how long the monitoring job is allowed to run before stopping.
21616 21617 21618 21619 21620 21621 21622 21623 21624 21625 21626 21627 21628 21629 21630 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21616 class DescribeModelQualityJobDefinitionResponse < Struct.new( :job_definition_arn, :job_definition_name, :creation_time, :model_quality_baseline_config, :model_quality_app_specification, :model_quality_job_input, :model_quality_job_output_config, :job_resources, :network_config, :role_arn, :stopping_condition) SENSITIVE = [] include Aws::Structure end |