Class: Aws::SageMaker::Types::DescribePipelineResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribePipelineResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
-
#creation_time ⇒ Time
The time when the pipeline was created.
-
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
-
#last_modified_time ⇒ Time
The time when the pipeline was last modified.
-
#last_run_time ⇒ Time
The time when the pipeline was last run.
-
#parallelism_configuration ⇒ Types::ParallelismConfiguration
Lists the parallelism configuration applied to the pipeline.
-
#pipeline_arn ⇒ String
The Amazon Resource Name (ARN) of the pipeline.
-
#pipeline_definition ⇒ String
The JSON pipeline definition.
-
#pipeline_description ⇒ String
The description of the pipeline.
-
#pipeline_display_name ⇒ String
The display name of the pipeline.
-
#pipeline_name ⇒ String
The name of the pipeline.
-
#pipeline_status ⇒ String
The status of the pipeline execution.
-
#pipeline_version_description ⇒ String
The description of the pipeline version.
-
#pipeline_version_display_name ⇒ String
The display name of the pipeline version.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) that the pipeline uses to execute.
Instance Attribute Details
#created_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
22416 22417 22418 22419 22420 22421 22422 22423 22424 22425 22426 22427 22428 22429 22430 22431 22432 22433 22434 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22416 class DescribePipelineResponse < Struct.new( :pipeline_arn, :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_description, :role_arn, :pipeline_status, :creation_time, :last_modified_time, :last_run_time, :created_by, :last_modified_by, :parallelism_configuration, :pipeline_version_display_name, :pipeline_version_description) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The time when the pipeline was created.
22416 22417 22418 22419 22420 22421 22422 22423 22424 22425 22426 22427 22428 22429 22430 22431 22432 22433 22434 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22416 class DescribePipelineResponse < Struct.new( :pipeline_arn, :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_description, :role_arn, :pipeline_status, :creation_time, :last_modified_time, :last_run_time, :created_by, :last_modified_by, :parallelism_configuration, :pipeline_version_display_name, :pipeline_version_description) SENSITIVE = [] include Aws::Structure end |
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
22416 22417 22418 22419 22420 22421 22422 22423 22424 22425 22426 22427 22428 22429 22430 22431 22432 22433 22434 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22416 class DescribePipelineResponse < Struct.new( :pipeline_arn, :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_description, :role_arn, :pipeline_status, :creation_time, :last_modified_time, :last_run_time, :created_by, :last_modified_by, :parallelism_configuration, :pipeline_version_display_name, :pipeline_version_description) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The time when the pipeline was last modified.
22416 22417 22418 22419 22420 22421 22422 22423 22424 22425 22426 22427 22428 22429 22430 22431 22432 22433 22434 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22416 class DescribePipelineResponse < Struct.new( :pipeline_arn, :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_description, :role_arn, :pipeline_status, :creation_time, :last_modified_time, :last_run_time, :created_by, :last_modified_by, :parallelism_configuration, :pipeline_version_display_name, :pipeline_version_description) SENSITIVE = [] include Aws::Structure end |
#last_run_time ⇒ Time
The time when the pipeline was last run.
22416 22417 22418 22419 22420 22421 22422 22423 22424 22425 22426 22427 22428 22429 22430 22431 22432 22433 22434 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22416 class DescribePipelineResponse < Struct.new( :pipeline_arn, :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_description, :role_arn, :pipeline_status, :creation_time, :last_modified_time, :last_run_time, :created_by, :last_modified_by, :parallelism_configuration, :pipeline_version_display_name, :pipeline_version_description) SENSITIVE = [] include Aws::Structure end |
#parallelism_configuration ⇒ Types::ParallelismConfiguration
Lists the parallelism configuration applied to the pipeline.
22416 22417 22418 22419 22420 22421 22422 22423 22424 22425 22426 22427 22428 22429 22430 22431 22432 22433 22434 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22416 class DescribePipelineResponse < Struct.new( :pipeline_arn, :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_description, :role_arn, :pipeline_status, :creation_time, :last_modified_time, :last_run_time, :created_by, :last_modified_by, :parallelism_configuration, :pipeline_version_display_name, :pipeline_version_description) SENSITIVE = [] include Aws::Structure end |
#pipeline_arn ⇒ String
The Amazon Resource Name (ARN) of the pipeline.
22416 22417 22418 22419 22420 22421 22422 22423 22424 22425 22426 22427 22428 22429 22430 22431 22432 22433 22434 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22416 class DescribePipelineResponse < Struct.new( :pipeline_arn, :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_description, :role_arn, :pipeline_status, :creation_time, :last_modified_time, :last_run_time, :created_by, :last_modified_by, :parallelism_configuration, :pipeline_version_display_name, :pipeline_version_description) SENSITIVE = [] include Aws::Structure end |
#pipeline_definition ⇒ String
The JSON pipeline definition.
22416 22417 22418 22419 22420 22421 22422 22423 22424 22425 22426 22427 22428 22429 22430 22431 22432 22433 22434 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22416 class DescribePipelineResponse < Struct.new( :pipeline_arn, :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_description, :role_arn, :pipeline_status, :creation_time, :last_modified_time, :last_run_time, :created_by, :last_modified_by, :parallelism_configuration, :pipeline_version_display_name, :pipeline_version_description) SENSITIVE = [] include Aws::Structure end |
#pipeline_description ⇒ String
The description of the pipeline.
22416 22417 22418 22419 22420 22421 22422 22423 22424 22425 22426 22427 22428 22429 22430 22431 22432 22433 22434 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22416 class DescribePipelineResponse < Struct.new( :pipeline_arn, :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_description, :role_arn, :pipeline_status, :creation_time, :last_modified_time, :last_run_time, :created_by, :last_modified_by, :parallelism_configuration, :pipeline_version_display_name, :pipeline_version_description) SENSITIVE = [] include Aws::Structure end |
#pipeline_display_name ⇒ String
The display name of the pipeline.
22416 22417 22418 22419 22420 22421 22422 22423 22424 22425 22426 22427 22428 22429 22430 22431 22432 22433 22434 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22416 class DescribePipelineResponse < Struct.new( :pipeline_arn, :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_description, :role_arn, :pipeline_status, :creation_time, :last_modified_time, :last_run_time, :created_by, :last_modified_by, :parallelism_configuration, :pipeline_version_display_name, :pipeline_version_description) SENSITIVE = [] include Aws::Structure end |
#pipeline_name ⇒ String
The name of the pipeline.
22416 22417 22418 22419 22420 22421 22422 22423 22424 22425 22426 22427 22428 22429 22430 22431 22432 22433 22434 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22416 class DescribePipelineResponse < Struct.new( :pipeline_arn, :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_description, :role_arn, :pipeline_status, :creation_time, :last_modified_time, :last_run_time, :created_by, :last_modified_by, :parallelism_configuration, :pipeline_version_display_name, :pipeline_version_description) SENSITIVE = [] include Aws::Structure end |
#pipeline_status ⇒ String
The status of the pipeline execution.
22416 22417 22418 22419 22420 22421 22422 22423 22424 22425 22426 22427 22428 22429 22430 22431 22432 22433 22434 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22416 class DescribePipelineResponse < Struct.new( :pipeline_arn, :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_description, :role_arn, :pipeline_status, :creation_time, :last_modified_time, :last_run_time, :created_by, :last_modified_by, :parallelism_configuration, :pipeline_version_display_name, :pipeline_version_description) SENSITIVE = [] include Aws::Structure end |
#pipeline_version_description ⇒ String
The description of the pipeline version.
22416 22417 22418 22419 22420 22421 22422 22423 22424 22425 22426 22427 22428 22429 22430 22431 22432 22433 22434 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22416 class DescribePipelineResponse < Struct.new( :pipeline_arn, :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_description, :role_arn, :pipeline_status, :creation_time, :last_modified_time, :last_run_time, :created_by, :last_modified_by, :parallelism_configuration, :pipeline_version_display_name, :pipeline_version_description) SENSITIVE = [] include Aws::Structure end |
#pipeline_version_display_name ⇒ String
The display name of the pipeline version.
22416 22417 22418 22419 22420 22421 22422 22423 22424 22425 22426 22427 22428 22429 22430 22431 22432 22433 22434 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22416 class DescribePipelineResponse < Struct.new( :pipeline_arn, :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_description, :role_arn, :pipeline_status, :creation_time, :last_modified_time, :last_run_time, :created_by, :last_modified_by, :parallelism_configuration, :pipeline_version_display_name, :pipeline_version_description) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) that the pipeline uses to execute.
22416 22417 22418 22419 22420 22421 22422 22423 22424 22425 22426 22427 22428 22429 22430 22431 22432 22433 22434 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22416 class DescribePipelineResponse < Struct.new( :pipeline_arn, :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_description, :role_arn, :pipeline_status, :creation_time, :last_modified_time, :last_run_time, :created_by, :last_modified_by, :parallelism_configuration, :pipeline_version_display_name, :pipeline_version_description) SENSITIVE = [] include Aws::Structure end |