Class: Aws::SageMaker::Types::DescribePipelineResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribePipelineResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
-
#creation_time ⇒ Time
The time when the pipeline was created.
-
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
-
#last_modified_time ⇒ Time
The time when the pipeline was last modified.
-
#last_run_time ⇒ Time
The time when the pipeline was last run.
-
#parallelism_configuration ⇒ Types::ParallelismConfiguration
Lists the parallelism configuration applied to the pipeline.
-
#pipeline_arn ⇒ String
The Amazon Resource Name (ARN) of the pipeline.
-
#pipeline_definition ⇒ String
The JSON pipeline definition.
-
#pipeline_description ⇒ String
The description of the pipeline.
-
#pipeline_display_name ⇒ String
The display name of the pipeline.
-
#pipeline_name ⇒ String
The name of the pipeline.
-
#pipeline_status ⇒ String
The status of the pipeline execution.
-
#pipeline_version_description ⇒ String
The description of the pipeline version.
-
#pipeline_version_display_name ⇒ String
The display name of the pipeline version.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) that the pipeline uses to execute.
Instance Attribute Details
#created_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
22381 22382 22383 22384 22385 22386 22387 22388 22389 22390 22391 22392 22393 22394 22395 22396 22397 22398 22399 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22381 class DescribePipelineResponse < Struct.new( :pipeline_arn, :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_description, :role_arn, :pipeline_status, :creation_time, :last_modified_time, :last_run_time, :created_by, :last_modified_by, :parallelism_configuration, :pipeline_version_display_name, :pipeline_version_description) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The time when the pipeline was created.
22381 22382 22383 22384 22385 22386 22387 22388 22389 22390 22391 22392 22393 22394 22395 22396 22397 22398 22399 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22381 class DescribePipelineResponse < Struct.new( :pipeline_arn, :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_description, :role_arn, :pipeline_status, :creation_time, :last_modified_time, :last_run_time, :created_by, :last_modified_by, :parallelism_configuration, :pipeline_version_display_name, :pipeline_version_description) SENSITIVE = [] include Aws::Structure end |
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
22381 22382 22383 22384 22385 22386 22387 22388 22389 22390 22391 22392 22393 22394 22395 22396 22397 22398 22399 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22381 class DescribePipelineResponse < Struct.new( :pipeline_arn, :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_description, :role_arn, :pipeline_status, :creation_time, :last_modified_time, :last_run_time, :created_by, :last_modified_by, :parallelism_configuration, :pipeline_version_display_name, :pipeline_version_description) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The time when the pipeline was last modified.
22381 22382 22383 22384 22385 22386 22387 22388 22389 22390 22391 22392 22393 22394 22395 22396 22397 22398 22399 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22381 class DescribePipelineResponse < Struct.new( :pipeline_arn, :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_description, :role_arn, :pipeline_status, :creation_time, :last_modified_time, :last_run_time, :created_by, :last_modified_by, :parallelism_configuration, :pipeline_version_display_name, :pipeline_version_description) SENSITIVE = [] include Aws::Structure end |
#last_run_time ⇒ Time
The time when the pipeline was last run.
22381 22382 22383 22384 22385 22386 22387 22388 22389 22390 22391 22392 22393 22394 22395 22396 22397 22398 22399 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22381 class DescribePipelineResponse < Struct.new( :pipeline_arn, :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_description, :role_arn, :pipeline_status, :creation_time, :last_modified_time, :last_run_time, :created_by, :last_modified_by, :parallelism_configuration, :pipeline_version_display_name, :pipeline_version_description) SENSITIVE = [] include Aws::Structure end |
#parallelism_configuration ⇒ Types::ParallelismConfiguration
Lists the parallelism configuration applied to the pipeline.
22381 22382 22383 22384 22385 22386 22387 22388 22389 22390 22391 22392 22393 22394 22395 22396 22397 22398 22399 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22381 class DescribePipelineResponse < Struct.new( :pipeline_arn, :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_description, :role_arn, :pipeline_status, :creation_time, :last_modified_time, :last_run_time, :created_by, :last_modified_by, :parallelism_configuration, :pipeline_version_display_name, :pipeline_version_description) SENSITIVE = [] include Aws::Structure end |
#pipeline_arn ⇒ String
The Amazon Resource Name (ARN) of the pipeline.
22381 22382 22383 22384 22385 22386 22387 22388 22389 22390 22391 22392 22393 22394 22395 22396 22397 22398 22399 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22381 class DescribePipelineResponse < Struct.new( :pipeline_arn, :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_description, :role_arn, :pipeline_status, :creation_time, :last_modified_time, :last_run_time, :created_by, :last_modified_by, :parallelism_configuration, :pipeline_version_display_name, :pipeline_version_description) SENSITIVE = [] include Aws::Structure end |
#pipeline_definition ⇒ String
The JSON pipeline definition.
22381 22382 22383 22384 22385 22386 22387 22388 22389 22390 22391 22392 22393 22394 22395 22396 22397 22398 22399 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22381 class DescribePipelineResponse < Struct.new( :pipeline_arn, :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_description, :role_arn, :pipeline_status, :creation_time, :last_modified_time, :last_run_time, :created_by, :last_modified_by, :parallelism_configuration, :pipeline_version_display_name, :pipeline_version_description) SENSITIVE = [] include Aws::Structure end |
#pipeline_description ⇒ String
The description of the pipeline.
22381 22382 22383 22384 22385 22386 22387 22388 22389 22390 22391 22392 22393 22394 22395 22396 22397 22398 22399 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22381 class DescribePipelineResponse < Struct.new( :pipeline_arn, :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_description, :role_arn, :pipeline_status, :creation_time, :last_modified_time, :last_run_time, :created_by, :last_modified_by, :parallelism_configuration, :pipeline_version_display_name, :pipeline_version_description) SENSITIVE = [] include Aws::Structure end |
#pipeline_display_name ⇒ String
The display name of the pipeline.
22381 22382 22383 22384 22385 22386 22387 22388 22389 22390 22391 22392 22393 22394 22395 22396 22397 22398 22399 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22381 class DescribePipelineResponse < Struct.new( :pipeline_arn, :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_description, :role_arn, :pipeline_status, :creation_time, :last_modified_time, :last_run_time, :created_by, :last_modified_by, :parallelism_configuration, :pipeline_version_display_name, :pipeline_version_description) SENSITIVE = [] include Aws::Structure end |
#pipeline_name ⇒ String
The name of the pipeline.
22381 22382 22383 22384 22385 22386 22387 22388 22389 22390 22391 22392 22393 22394 22395 22396 22397 22398 22399 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22381 class DescribePipelineResponse < Struct.new( :pipeline_arn, :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_description, :role_arn, :pipeline_status, :creation_time, :last_modified_time, :last_run_time, :created_by, :last_modified_by, :parallelism_configuration, :pipeline_version_display_name, :pipeline_version_description) SENSITIVE = [] include Aws::Structure end |
#pipeline_status ⇒ String
The status of the pipeline execution.
22381 22382 22383 22384 22385 22386 22387 22388 22389 22390 22391 22392 22393 22394 22395 22396 22397 22398 22399 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22381 class DescribePipelineResponse < Struct.new( :pipeline_arn, :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_description, :role_arn, :pipeline_status, :creation_time, :last_modified_time, :last_run_time, :created_by, :last_modified_by, :parallelism_configuration, :pipeline_version_display_name, :pipeline_version_description) SENSITIVE = [] include Aws::Structure end |
#pipeline_version_description ⇒ String
The description of the pipeline version.
22381 22382 22383 22384 22385 22386 22387 22388 22389 22390 22391 22392 22393 22394 22395 22396 22397 22398 22399 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22381 class DescribePipelineResponse < Struct.new( :pipeline_arn, :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_description, :role_arn, :pipeline_status, :creation_time, :last_modified_time, :last_run_time, :created_by, :last_modified_by, :parallelism_configuration, :pipeline_version_display_name, :pipeline_version_description) SENSITIVE = [] include Aws::Structure end |
#pipeline_version_display_name ⇒ String
The display name of the pipeline version.
22381 22382 22383 22384 22385 22386 22387 22388 22389 22390 22391 22392 22393 22394 22395 22396 22397 22398 22399 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22381 class DescribePipelineResponse < Struct.new( :pipeline_arn, :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_description, :role_arn, :pipeline_status, :creation_time, :last_modified_time, :last_run_time, :created_by, :last_modified_by, :parallelism_configuration, :pipeline_version_display_name, :pipeline_version_description) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) that the pipeline uses to execute.
22381 22382 22383 22384 22385 22386 22387 22388 22389 22390 22391 22392 22393 22394 22395 22396 22397 22398 22399 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22381 class DescribePipelineResponse < Struct.new( :pipeline_arn, :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_description, :role_arn, :pipeline_status, :creation_time, :last_modified_time, :last_run_time, :created_by, :last_modified_by, :parallelism_configuration, :pipeline_version_display_name, :pipeline_version_description) SENSITIVE = [] include Aws::Structure end |