Class: Aws::SageMaker::Types::DescribeProcessingJobResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeProcessingJobResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#app_specification ⇒ Types::AppSpecification
Configures the processing job to run a specified container image.
-
#auto_ml_job_arn ⇒ String
The ARN of an AutoML job associated with this processing job.
-
#creation_time ⇒ Time
The time at which the processing job was created.
-
#environment ⇒ Hash<String,String>
The environment variables set in the Docker container.
-
#exit_message ⇒ String
An optional string, up to one KB in size, that contains metadata from the processing container when the processing job exits.
-
#experiment_config ⇒ Types::ExperimentConfig
The configuration information used to create an experiment.
-
#failure_reason ⇒ String
A string, up to one KB in size, that contains the reason a processing job failed, if it failed.
-
#last_modified_time ⇒ Time
The time at which the processing job was last modified.
-
#monitoring_schedule_arn ⇒ String
The ARN of a monitoring schedule for an endpoint associated with this processing job.
-
#network_config ⇒ Types::NetworkConfig
Networking options for a processing job.
-
#processing_end_time ⇒ Time
The time at which the processing job completed.
-
#processing_inputs ⇒ Array<Types::ProcessingInput>
The inputs for a processing job.
-
#processing_job_arn ⇒ String
The Amazon Resource Name (ARN) of the processing job.
-
#processing_job_name ⇒ String
The name of the processing job.
-
#processing_job_status ⇒ String
Provides the status of a processing job.
-
#processing_output_config ⇒ Types::ProcessingOutputConfig
Output configuration for the processing job.
-
#processing_resources ⇒ Types::ProcessingResources
Identifies the resources, ML compute instances, and ML storage volumes to deploy for a processing job.
-
#processing_start_time ⇒ Time
The time at which the processing job started.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker can assume to perform tasks on your behalf.
-
#stopping_condition ⇒ Types::ProcessingStoppingCondition
The time limit for how long the processing job is allowed to run.
-
#training_job_arn ⇒ String
The ARN of a training job associated with this processing job.
Instance Attribute Details
#app_specification ⇒ Types::AppSpecification
Configures the processing job to run a specified container image.
23053 23054 23055 23056 23057 23058 23059 23060 23061 23062 23063 23064 23065 23066 23067 23068 23069 23070 23071 23072 23073 23074 23075 23076 23077 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23053 class DescribeProcessingJobResponse < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn) SENSITIVE = [] include Aws::Structure end |
#auto_ml_job_arn ⇒ String
The ARN of an AutoML job associated with this processing job.
23053 23054 23055 23056 23057 23058 23059 23060 23061 23062 23063 23064 23065 23066 23067 23068 23069 23070 23071 23072 23073 23074 23075 23076 23077 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23053 class DescribeProcessingJobResponse < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The time at which the processing job was created.
23053 23054 23055 23056 23057 23058 23059 23060 23061 23062 23063 23064 23065 23066 23067 23068 23069 23070 23071 23072 23073 23074 23075 23076 23077 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23053 class DescribeProcessingJobResponse < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn) SENSITIVE = [] include Aws::Structure end |
#environment ⇒ Hash<String,String>
The environment variables set in the Docker container.
23053 23054 23055 23056 23057 23058 23059 23060 23061 23062 23063 23064 23065 23066 23067 23068 23069 23070 23071 23072 23073 23074 23075 23076 23077 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23053 class DescribeProcessingJobResponse < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn) SENSITIVE = [] include Aws::Structure end |
#exit_message ⇒ String
An optional string, up to one KB in size, that contains metadata from the processing container when the processing job exits.
23053 23054 23055 23056 23057 23058 23059 23060 23061 23062 23063 23064 23065 23066 23067 23068 23069 23070 23071 23072 23073 23074 23075 23076 23077 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23053 class DescribeProcessingJobResponse < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn) SENSITIVE = [] include Aws::Structure end |
#experiment_config ⇒ Types::ExperimentConfig
The configuration information used to create an experiment.
23053 23054 23055 23056 23057 23058 23059 23060 23061 23062 23063 23064 23065 23066 23067 23068 23069 23070 23071 23072 23073 23074 23075 23076 23077 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23053 class DescribeProcessingJobResponse < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
A string, up to one KB in size, that contains the reason a processing job failed, if it failed.
23053 23054 23055 23056 23057 23058 23059 23060 23061 23062 23063 23064 23065 23066 23067 23068 23069 23070 23071 23072 23073 23074 23075 23076 23077 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23053 class DescribeProcessingJobResponse < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The time at which the processing job was last modified.
23053 23054 23055 23056 23057 23058 23059 23060 23061 23062 23063 23064 23065 23066 23067 23068 23069 23070 23071 23072 23073 23074 23075 23076 23077 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23053 class DescribeProcessingJobResponse < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn) SENSITIVE = [] include Aws::Structure end |
#monitoring_schedule_arn ⇒ String
The ARN of a monitoring schedule for an endpoint associated with this processing job.
23053 23054 23055 23056 23057 23058 23059 23060 23061 23062 23063 23064 23065 23066 23067 23068 23069 23070 23071 23072 23073 23074 23075 23076 23077 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23053 class DescribeProcessingJobResponse < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn) SENSITIVE = [] include Aws::Structure end |
#network_config ⇒ Types::NetworkConfig
Networking options for a processing job.
23053 23054 23055 23056 23057 23058 23059 23060 23061 23062 23063 23064 23065 23066 23067 23068 23069 23070 23071 23072 23073 23074 23075 23076 23077 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23053 class DescribeProcessingJobResponse < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn) SENSITIVE = [] include Aws::Structure end |
#processing_end_time ⇒ Time
The time at which the processing job completed.
23053 23054 23055 23056 23057 23058 23059 23060 23061 23062 23063 23064 23065 23066 23067 23068 23069 23070 23071 23072 23073 23074 23075 23076 23077 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23053 class DescribeProcessingJobResponse < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn) SENSITIVE = [] include Aws::Structure end |
#processing_inputs ⇒ Array<Types::ProcessingInput>
The inputs for a processing job.
23053 23054 23055 23056 23057 23058 23059 23060 23061 23062 23063 23064 23065 23066 23067 23068 23069 23070 23071 23072 23073 23074 23075 23076 23077 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23053 class DescribeProcessingJobResponse < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn) SENSITIVE = [] include Aws::Structure end |
#processing_job_arn ⇒ String
The Amazon Resource Name (ARN) of the processing job.
23053 23054 23055 23056 23057 23058 23059 23060 23061 23062 23063 23064 23065 23066 23067 23068 23069 23070 23071 23072 23073 23074 23075 23076 23077 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23053 class DescribeProcessingJobResponse < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn) SENSITIVE = [] include Aws::Structure end |
#processing_job_name ⇒ String
The name of the processing job. The name must be unique within an Amazon Web Services Region in the Amazon Web Services account.
23053 23054 23055 23056 23057 23058 23059 23060 23061 23062 23063 23064 23065 23066 23067 23068 23069 23070 23071 23072 23073 23074 23075 23076 23077 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23053 class DescribeProcessingJobResponse < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn) SENSITIVE = [] include Aws::Structure end |
#processing_job_status ⇒ String
Provides the status of a processing job.
23053 23054 23055 23056 23057 23058 23059 23060 23061 23062 23063 23064 23065 23066 23067 23068 23069 23070 23071 23072 23073 23074 23075 23076 23077 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23053 class DescribeProcessingJobResponse < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn) SENSITIVE = [] include Aws::Structure end |
#processing_output_config ⇒ Types::ProcessingOutputConfig
Output configuration for the processing job.
23053 23054 23055 23056 23057 23058 23059 23060 23061 23062 23063 23064 23065 23066 23067 23068 23069 23070 23071 23072 23073 23074 23075 23076 23077 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23053 class DescribeProcessingJobResponse < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn) SENSITIVE = [] include Aws::Structure end |
#processing_resources ⇒ Types::ProcessingResources
Identifies the resources, ML compute instances, and ML storage volumes to deploy for a processing job. In distributed training, you specify more than one instance.
23053 23054 23055 23056 23057 23058 23059 23060 23061 23062 23063 23064 23065 23066 23067 23068 23069 23070 23071 23072 23073 23074 23075 23076 23077 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23053 class DescribeProcessingJobResponse < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn) SENSITIVE = [] include Aws::Structure end |
#processing_start_time ⇒ Time
The time at which the processing job started.
23053 23054 23055 23056 23057 23058 23059 23060 23061 23062 23063 23064 23065 23066 23067 23068 23069 23070 23071 23072 23073 23074 23075 23076 23077 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23053 class DescribeProcessingJobResponse < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker can assume to perform tasks on your behalf.
23053 23054 23055 23056 23057 23058 23059 23060 23061 23062 23063 23064 23065 23066 23067 23068 23069 23070 23071 23072 23073 23074 23075 23076 23077 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23053 class DescribeProcessingJobResponse < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn) SENSITIVE = [] include Aws::Structure end |
#stopping_condition ⇒ Types::ProcessingStoppingCondition
The time limit for how long the processing job is allowed to run.
23053 23054 23055 23056 23057 23058 23059 23060 23061 23062 23063 23064 23065 23066 23067 23068 23069 23070 23071 23072 23073 23074 23075 23076 23077 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23053 class DescribeProcessingJobResponse < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn) SENSITIVE = [] include Aws::Structure end |
#training_job_arn ⇒ String
The ARN of a training job associated with this processing job.
23053 23054 23055 23056 23057 23058 23059 23060 23061 23062 23063 23064 23065 23066 23067 23068 23069 23070 23071 23072 23073 23074 23075 23076 23077 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23053 class DescribeProcessingJobResponse < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn) SENSITIVE = [] include Aws::Structure end |