Class: Aws::SageMaker::Types::DescribeProcessingJobResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#app_specificationTypes::AppSpecification

Configures the processing job to run a specified container image.



22587
22588
22589
22590
22591
22592
22593
22594
22595
22596
22597
22598
22599
22600
22601
22602
22603
22604
22605
22606
22607
22608
22609
22610
22611
# File 'lib/aws-sdk-sagemaker/types.rb', line 22587

class DescribeProcessingJobResponse < Struct.new(
  :processing_inputs,
  :processing_output_config,
  :processing_job_name,
  :processing_resources,
  :stopping_condition,
  :app_specification,
  :environment,
  :network_config,
  :role_arn,
  :experiment_config,
  :processing_job_arn,
  :processing_job_status,
  :exit_message,
  :failure_reason,
  :processing_end_time,
  :processing_start_time,
  :last_modified_time,
  :creation_time,
  :monitoring_schedule_arn,
  :auto_ml_job_arn,
  :training_job_arn)
  SENSITIVE = []
  include Aws::Structure
end

#auto_ml_job_arnString

The ARN of an AutoML job associated with this processing job.

Returns:

  • (String)


22587
22588
22589
22590
22591
22592
22593
22594
22595
22596
22597
22598
22599
22600
22601
22602
22603
22604
22605
22606
22607
22608
22609
22610
22611
# File 'lib/aws-sdk-sagemaker/types.rb', line 22587

class DescribeProcessingJobResponse < Struct.new(
  :processing_inputs,
  :processing_output_config,
  :processing_job_name,
  :processing_resources,
  :stopping_condition,
  :app_specification,
  :environment,
  :network_config,
  :role_arn,
  :experiment_config,
  :processing_job_arn,
  :processing_job_status,
  :exit_message,
  :failure_reason,
  :processing_end_time,
  :processing_start_time,
  :last_modified_time,
  :creation_time,
  :monitoring_schedule_arn,
  :auto_ml_job_arn,
  :training_job_arn)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

The time at which the processing job was created.

Returns:

  • (Time)


22587
22588
22589
22590
22591
22592
22593
22594
22595
22596
22597
22598
22599
22600
22601
22602
22603
22604
22605
22606
22607
22608
22609
22610
22611
# File 'lib/aws-sdk-sagemaker/types.rb', line 22587

class DescribeProcessingJobResponse < Struct.new(
  :processing_inputs,
  :processing_output_config,
  :processing_job_name,
  :processing_resources,
  :stopping_condition,
  :app_specification,
  :environment,
  :network_config,
  :role_arn,
  :experiment_config,
  :processing_job_arn,
  :processing_job_status,
  :exit_message,
  :failure_reason,
  :processing_end_time,
  :processing_start_time,
  :last_modified_time,
  :creation_time,
  :monitoring_schedule_arn,
  :auto_ml_job_arn,
  :training_job_arn)
  SENSITIVE = []
  include Aws::Structure
end

#environmentHash<String,String>

The environment variables set in the Docker container.

Returns:

  • (Hash<String,String>)


22587
22588
22589
22590
22591
22592
22593
22594
22595
22596
22597
22598
22599
22600
22601
22602
22603
22604
22605
22606
22607
22608
22609
22610
22611
# File 'lib/aws-sdk-sagemaker/types.rb', line 22587

class DescribeProcessingJobResponse < Struct.new(
  :processing_inputs,
  :processing_output_config,
  :processing_job_name,
  :processing_resources,
  :stopping_condition,
  :app_specification,
  :environment,
  :network_config,
  :role_arn,
  :experiment_config,
  :processing_job_arn,
  :processing_job_status,
  :exit_message,
  :failure_reason,
  :processing_end_time,
  :processing_start_time,
  :last_modified_time,
  :creation_time,
  :monitoring_schedule_arn,
  :auto_ml_job_arn,
  :training_job_arn)
  SENSITIVE = []
  include Aws::Structure
end

#exit_messageString

An optional string, up to one KB in size, that contains metadata from the processing container when the processing job exits.

Returns:

  • (String)


22587
22588
22589
22590
22591
22592
22593
22594
22595
22596
22597
22598
22599
22600
22601
22602
22603
22604
22605
22606
22607
22608
22609
22610
22611
# File 'lib/aws-sdk-sagemaker/types.rb', line 22587

class DescribeProcessingJobResponse < Struct.new(
  :processing_inputs,
  :processing_output_config,
  :processing_job_name,
  :processing_resources,
  :stopping_condition,
  :app_specification,
  :environment,
  :network_config,
  :role_arn,
  :experiment_config,
  :processing_job_arn,
  :processing_job_status,
  :exit_message,
  :failure_reason,
  :processing_end_time,
  :processing_start_time,
  :last_modified_time,
  :creation_time,
  :monitoring_schedule_arn,
  :auto_ml_job_arn,
  :training_job_arn)
  SENSITIVE = []
  include Aws::Structure
end

#experiment_configTypes::ExperimentConfig

The configuration information used to create an experiment.



22587
22588
22589
22590
22591
22592
22593
22594
22595
22596
22597
22598
22599
22600
22601
22602
22603
22604
22605
22606
22607
22608
22609
22610
22611
# File 'lib/aws-sdk-sagemaker/types.rb', line 22587

class DescribeProcessingJobResponse < Struct.new(
  :processing_inputs,
  :processing_output_config,
  :processing_job_name,
  :processing_resources,
  :stopping_condition,
  :app_specification,
  :environment,
  :network_config,
  :role_arn,
  :experiment_config,
  :processing_job_arn,
  :processing_job_status,
  :exit_message,
  :failure_reason,
  :processing_end_time,
  :processing_start_time,
  :last_modified_time,
  :creation_time,
  :monitoring_schedule_arn,
  :auto_ml_job_arn,
  :training_job_arn)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

A string, up to one KB in size, that contains the reason a processing job failed, if it failed.

Returns:

  • (String)


22587
22588
22589
22590
22591
22592
22593
22594
22595
22596
22597
22598
22599
22600
22601
22602
22603
22604
22605
22606
22607
22608
22609
22610
22611
# File 'lib/aws-sdk-sagemaker/types.rb', line 22587

class DescribeProcessingJobResponse < Struct.new(
  :processing_inputs,
  :processing_output_config,
  :processing_job_name,
  :processing_resources,
  :stopping_condition,
  :app_specification,
  :environment,
  :network_config,
  :role_arn,
  :experiment_config,
  :processing_job_arn,
  :processing_job_status,
  :exit_message,
  :failure_reason,
  :processing_end_time,
  :processing_start_time,
  :last_modified_time,
  :creation_time,
  :monitoring_schedule_arn,
  :auto_ml_job_arn,
  :training_job_arn)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The time at which the processing job was last modified.

Returns:

  • (Time)


22587
22588
22589
22590
22591
22592
22593
22594
22595
22596
22597
22598
22599
22600
22601
22602
22603
22604
22605
22606
22607
22608
22609
22610
22611
# File 'lib/aws-sdk-sagemaker/types.rb', line 22587

class DescribeProcessingJobResponse < Struct.new(
  :processing_inputs,
  :processing_output_config,
  :processing_job_name,
  :processing_resources,
  :stopping_condition,
  :app_specification,
  :environment,
  :network_config,
  :role_arn,
  :experiment_config,
  :processing_job_arn,
  :processing_job_status,
  :exit_message,
  :failure_reason,
  :processing_end_time,
  :processing_start_time,
  :last_modified_time,
  :creation_time,
  :monitoring_schedule_arn,
  :auto_ml_job_arn,
  :training_job_arn)
  SENSITIVE = []
  include Aws::Structure
end

#monitoring_schedule_arnString

The ARN of a monitoring schedule for an endpoint associated with this processing job.

Returns:

  • (String)


22587
22588
22589
22590
22591
22592
22593
22594
22595
22596
22597
22598
22599
22600
22601
22602
22603
22604
22605
22606
22607
22608
22609
22610
22611
# File 'lib/aws-sdk-sagemaker/types.rb', line 22587

class DescribeProcessingJobResponse < Struct.new(
  :processing_inputs,
  :processing_output_config,
  :processing_job_name,
  :processing_resources,
  :stopping_condition,
  :app_specification,
  :environment,
  :network_config,
  :role_arn,
  :experiment_config,
  :processing_job_arn,
  :processing_job_status,
  :exit_message,
  :failure_reason,
  :processing_end_time,
  :processing_start_time,
  :last_modified_time,
  :creation_time,
  :monitoring_schedule_arn,
  :auto_ml_job_arn,
  :training_job_arn)
  SENSITIVE = []
  include Aws::Structure
end

#network_configTypes::NetworkConfig

Networking options for a processing job.



22587
22588
22589
22590
22591
22592
22593
22594
22595
22596
22597
22598
22599
22600
22601
22602
22603
22604
22605
22606
22607
22608
22609
22610
22611
# File 'lib/aws-sdk-sagemaker/types.rb', line 22587

class DescribeProcessingJobResponse < Struct.new(
  :processing_inputs,
  :processing_output_config,
  :processing_job_name,
  :processing_resources,
  :stopping_condition,
  :app_specification,
  :environment,
  :network_config,
  :role_arn,
  :experiment_config,
  :processing_job_arn,
  :processing_job_status,
  :exit_message,
  :failure_reason,
  :processing_end_time,
  :processing_start_time,
  :last_modified_time,
  :creation_time,
  :monitoring_schedule_arn,
  :auto_ml_job_arn,
  :training_job_arn)
  SENSITIVE = []
  include Aws::Structure
end

#processing_end_timeTime

The time at which the processing job completed.

Returns:

  • (Time)


22587
22588
22589
22590
22591
22592
22593
22594
22595
22596
22597
22598
22599
22600
22601
22602
22603
22604
22605
22606
22607
22608
22609
22610
22611
# File 'lib/aws-sdk-sagemaker/types.rb', line 22587

class DescribeProcessingJobResponse < Struct.new(
  :processing_inputs,
  :processing_output_config,
  :processing_job_name,
  :processing_resources,
  :stopping_condition,
  :app_specification,
  :environment,
  :network_config,
  :role_arn,
  :experiment_config,
  :processing_job_arn,
  :processing_job_status,
  :exit_message,
  :failure_reason,
  :processing_end_time,
  :processing_start_time,
  :last_modified_time,
  :creation_time,
  :monitoring_schedule_arn,
  :auto_ml_job_arn,
  :training_job_arn)
  SENSITIVE = []
  include Aws::Structure
end

#processing_inputsArray<Types::ProcessingInput>

The inputs for a processing job.

Returns:



22587
22588
22589
22590
22591
22592
22593
22594
22595
22596
22597
22598
22599
22600
22601
22602
22603
22604
22605
22606
22607
22608
22609
22610
22611
# File 'lib/aws-sdk-sagemaker/types.rb', line 22587

class DescribeProcessingJobResponse < Struct.new(
  :processing_inputs,
  :processing_output_config,
  :processing_job_name,
  :processing_resources,
  :stopping_condition,
  :app_specification,
  :environment,
  :network_config,
  :role_arn,
  :experiment_config,
  :processing_job_arn,
  :processing_job_status,
  :exit_message,
  :failure_reason,
  :processing_end_time,
  :processing_start_time,
  :last_modified_time,
  :creation_time,
  :monitoring_schedule_arn,
  :auto_ml_job_arn,
  :training_job_arn)
  SENSITIVE = []
  include Aws::Structure
end

#processing_job_arnString

The Amazon Resource Name (ARN) of the processing job.

Returns:

  • (String)


22587
22588
22589
22590
22591
22592
22593
22594
22595
22596
22597
22598
22599
22600
22601
22602
22603
22604
22605
22606
22607
22608
22609
22610
22611
# File 'lib/aws-sdk-sagemaker/types.rb', line 22587

class DescribeProcessingJobResponse < Struct.new(
  :processing_inputs,
  :processing_output_config,
  :processing_job_name,
  :processing_resources,
  :stopping_condition,
  :app_specification,
  :environment,
  :network_config,
  :role_arn,
  :experiment_config,
  :processing_job_arn,
  :processing_job_status,
  :exit_message,
  :failure_reason,
  :processing_end_time,
  :processing_start_time,
  :last_modified_time,
  :creation_time,
  :monitoring_schedule_arn,
  :auto_ml_job_arn,
  :training_job_arn)
  SENSITIVE = []
  include Aws::Structure
end

#processing_job_nameString

The name of the processing job. The name must be unique within an Amazon Web Services Region in the Amazon Web Services account.

Returns:

  • (String)


22587
22588
22589
22590
22591
22592
22593
22594
22595
22596
22597
22598
22599
22600
22601
22602
22603
22604
22605
22606
22607
22608
22609
22610
22611
# File 'lib/aws-sdk-sagemaker/types.rb', line 22587

class DescribeProcessingJobResponse < Struct.new(
  :processing_inputs,
  :processing_output_config,
  :processing_job_name,
  :processing_resources,
  :stopping_condition,
  :app_specification,
  :environment,
  :network_config,
  :role_arn,
  :experiment_config,
  :processing_job_arn,
  :processing_job_status,
  :exit_message,
  :failure_reason,
  :processing_end_time,
  :processing_start_time,
  :last_modified_time,
  :creation_time,
  :monitoring_schedule_arn,
  :auto_ml_job_arn,
  :training_job_arn)
  SENSITIVE = []
  include Aws::Structure
end

#processing_job_statusString

Provides the status of a processing job.

Returns:

  • (String)


22587
22588
22589
22590
22591
22592
22593
22594
22595
22596
22597
22598
22599
22600
22601
22602
22603
22604
22605
22606
22607
22608
22609
22610
22611
# File 'lib/aws-sdk-sagemaker/types.rb', line 22587

class DescribeProcessingJobResponse < Struct.new(
  :processing_inputs,
  :processing_output_config,
  :processing_job_name,
  :processing_resources,
  :stopping_condition,
  :app_specification,
  :environment,
  :network_config,
  :role_arn,
  :experiment_config,
  :processing_job_arn,
  :processing_job_status,
  :exit_message,
  :failure_reason,
  :processing_end_time,
  :processing_start_time,
  :last_modified_time,
  :creation_time,
  :monitoring_schedule_arn,
  :auto_ml_job_arn,
  :training_job_arn)
  SENSITIVE = []
  include Aws::Structure
end

#processing_output_configTypes::ProcessingOutputConfig

Output configuration for the processing job.



22587
22588
22589
22590
22591
22592
22593
22594
22595
22596
22597
22598
22599
22600
22601
22602
22603
22604
22605
22606
22607
22608
22609
22610
22611
# File 'lib/aws-sdk-sagemaker/types.rb', line 22587

class DescribeProcessingJobResponse < Struct.new(
  :processing_inputs,
  :processing_output_config,
  :processing_job_name,
  :processing_resources,
  :stopping_condition,
  :app_specification,
  :environment,
  :network_config,
  :role_arn,
  :experiment_config,
  :processing_job_arn,
  :processing_job_status,
  :exit_message,
  :failure_reason,
  :processing_end_time,
  :processing_start_time,
  :last_modified_time,
  :creation_time,
  :monitoring_schedule_arn,
  :auto_ml_job_arn,
  :training_job_arn)
  SENSITIVE = []
  include Aws::Structure
end

#processing_resourcesTypes::ProcessingResources

Identifies the resources, ML compute instances, and ML storage volumes to deploy for a processing job. In distributed training, you specify more than one instance.



22587
22588
22589
22590
22591
22592
22593
22594
22595
22596
22597
22598
22599
22600
22601
22602
22603
22604
22605
22606
22607
22608
22609
22610
22611
# File 'lib/aws-sdk-sagemaker/types.rb', line 22587

class DescribeProcessingJobResponse < Struct.new(
  :processing_inputs,
  :processing_output_config,
  :processing_job_name,
  :processing_resources,
  :stopping_condition,
  :app_specification,
  :environment,
  :network_config,
  :role_arn,
  :experiment_config,
  :processing_job_arn,
  :processing_job_status,
  :exit_message,
  :failure_reason,
  :processing_end_time,
  :processing_start_time,
  :last_modified_time,
  :creation_time,
  :monitoring_schedule_arn,
  :auto_ml_job_arn,
  :training_job_arn)
  SENSITIVE = []
  include Aws::Structure
end

#processing_start_timeTime

The time at which the processing job started.

Returns:

  • (Time)


22587
22588
22589
22590
22591
22592
22593
22594
22595
22596
22597
22598
22599
22600
22601
22602
22603
22604
22605
22606
22607
22608
22609
22610
22611
# File 'lib/aws-sdk-sagemaker/types.rb', line 22587

class DescribeProcessingJobResponse < Struct.new(
  :processing_inputs,
  :processing_output_config,
  :processing_job_name,
  :processing_resources,
  :stopping_condition,
  :app_specification,
  :environment,
  :network_config,
  :role_arn,
  :experiment_config,
  :processing_job_arn,
  :processing_job_status,
  :exit_message,
  :failure_reason,
  :processing_end_time,
  :processing_start_time,
  :last_modified_time,
  :creation_time,
  :monitoring_schedule_arn,
  :auto_ml_job_arn,
  :training_job_arn)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker can assume to perform tasks on your behalf.

Returns:

  • (String)


22587
22588
22589
22590
22591
22592
22593
22594
22595
22596
22597
22598
22599
22600
22601
22602
22603
22604
22605
22606
22607
22608
22609
22610
22611
# File 'lib/aws-sdk-sagemaker/types.rb', line 22587

class DescribeProcessingJobResponse < Struct.new(
  :processing_inputs,
  :processing_output_config,
  :processing_job_name,
  :processing_resources,
  :stopping_condition,
  :app_specification,
  :environment,
  :network_config,
  :role_arn,
  :experiment_config,
  :processing_job_arn,
  :processing_job_status,
  :exit_message,
  :failure_reason,
  :processing_end_time,
  :processing_start_time,
  :last_modified_time,
  :creation_time,
  :monitoring_schedule_arn,
  :auto_ml_job_arn,
  :training_job_arn)
  SENSITIVE = []
  include Aws::Structure
end

#stopping_conditionTypes::ProcessingStoppingCondition

The time limit for how long the processing job is allowed to run.



22587
22588
22589
22590
22591
22592
22593
22594
22595
22596
22597
22598
22599
22600
22601
22602
22603
22604
22605
22606
22607
22608
22609
22610
22611
# File 'lib/aws-sdk-sagemaker/types.rb', line 22587

class DescribeProcessingJobResponse < Struct.new(
  :processing_inputs,
  :processing_output_config,
  :processing_job_name,
  :processing_resources,
  :stopping_condition,
  :app_specification,
  :environment,
  :network_config,
  :role_arn,
  :experiment_config,
  :processing_job_arn,
  :processing_job_status,
  :exit_message,
  :failure_reason,
  :processing_end_time,
  :processing_start_time,
  :last_modified_time,
  :creation_time,
  :monitoring_schedule_arn,
  :auto_ml_job_arn,
  :training_job_arn)
  SENSITIVE = []
  include Aws::Structure
end

#training_job_arnString

The ARN of a training job associated with this processing job.

Returns:

  • (String)


22587
22588
22589
22590
22591
22592
22593
22594
22595
22596
22597
22598
22599
22600
22601
22602
22603
22604
22605
22606
22607
22608
22609
22610
22611
# File 'lib/aws-sdk-sagemaker/types.rb', line 22587

class DescribeProcessingJobResponse < Struct.new(
  :processing_inputs,
  :processing_output_config,
  :processing_job_name,
  :processing_resources,
  :stopping_condition,
  :app_specification,
  :environment,
  :network_config,
  :role_arn,
  :experiment_config,
  :processing_job_arn,
  :processing_job_status,
  :exit_message,
  :failure_reason,
  :processing_end_time,
  :processing_start_time,
  :last_modified_time,
  :creation_time,
  :monitoring_schedule_arn,
  :auto_ml_job_arn,
  :training_job_arn)
  SENSITIVE = []
  include Aws::Structure
end