Class: Aws::SageMaker::Types::DescribeSpaceResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeSpaceResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Time
The creation time.
-
#domain_id ⇒ String
The ID of the associated domain.
-
#failure_reason ⇒ String
The failure reason.
-
#home_efs_file_system_uid ⇒ String
The ID of the space's profile in the Amazon EFS volume.
-
#last_modified_time ⇒ Time
The last modified time.
-
#ownership_settings ⇒ Types::OwnershipSettings
The collection of ownership settings for a space.
-
#space_arn ⇒ String
The space's Amazon Resource Name (ARN).
-
#space_display_name ⇒ String
The name of the space that appears in the Amazon SageMaker Studio UI.
-
#space_name ⇒ String
The name of the space.
-
#space_settings ⇒ Types::SpaceSettings
A collection of space settings.
-
#space_sharing_settings ⇒ Types::SpaceSharingSettings
The collection of space sharing settings for a space.
-
#status ⇒ String
The status.
-
#url ⇒ String
Returns the URL of the space.
Instance Attribute Details
#creation_time ⇒ Time
The creation time.
23708 23709 23710 23711 23712 23713 23714 23715 23716 23717 23718 23719 23720 23721 23722 23723 23724 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23708 class DescribeSpaceResponse < Struct.new( :domain_id, :space_arn, :space_name, :home_efs_file_system_uid, :status, :last_modified_time, :creation_time, :failure_reason, :space_settings, :ownership_settings, :space_sharing_settings, :space_display_name, :url) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
The ID of the associated domain.
23708 23709 23710 23711 23712 23713 23714 23715 23716 23717 23718 23719 23720 23721 23722 23723 23724 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23708 class DescribeSpaceResponse < Struct.new( :domain_id, :space_arn, :space_name, :home_efs_file_system_uid, :status, :last_modified_time, :creation_time, :failure_reason, :space_settings, :ownership_settings, :space_sharing_settings, :space_display_name, :url) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
The failure reason.
23708 23709 23710 23711 23712 23713 23714 23715 23716 23717 23718 23719 23720 23721 23722 23723 23724 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23708 class DescribeSpaceResponse < Struct.new( :domain_id, :space_arn, :space_name, :home_efs_file_system_uid, :status, :last_modified_time, :creation_time, :failure_reason, :space_settings, :ownership_settings, :space_sharing_settings, :space_display_name, :url) SENSITIVE = [] include Aws::Structure end |
#home_efs_file_system_uid ⇒ String
The ID of the space's profile in the Amazon EFS volume.
23708 23709 23710 23711 23712 23713 23714 23715 23716 23717 23718 23719 23720 23721 23722 23723 23724 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23708 class DescribeSpaceResponse < Struct.new( :domain_id, :space_arn, :space_name, :home_efs_file_system_uid, :status, :last_modified_time, :creation_time, :failure_reason, :space_settings, :ownership_settings, :space_sharing_settings, :space_display_name, :url) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The last modified time.
23708 23709 23710 23711 23712 23713 23714 23715 23716 23717 23718 23719 23720 23721 23722 23723 23724 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23708 class DescribeSpaceResponse < Struct.new( :domain_id, :space_arn, :space_name, :home_efs_file_system_uid, :status, :last_modified_time, :creation_time, :failure_reason, :space_settings, :ownership_settings, :space_sharing_settings, :space_display_name, :url) SENSITIVE = [] include Aws::Structure end |
#ownership_settings ⇒ Types::OwnershipSettings
The collection of ownership settings for a space.
23708 23709 23710 23711 23712 23713 23714 23715 23716 23717 23718 23719 23720 23721 23722 23723 23724 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23708 class DescribeSpaceResponse < Struct.new( :domain_id, :space_arn, :space_name, :home_efs_file_system_uid, :status, :last_modified_time, :creation_time, :failure_reason, :space_settings, :ownership_settings, :space_sharing_settings, :space_display_name, :url) SENSITIVE = [] include Aws::Structure end |
#space_arn ⇒ String
The space's Amazon Resource Name (ARN).
23708 23709 23710 23711 23712 23713 23714 23715 23716 23717 23718 23719 23720 23721 23722 23723 23724 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23708 class DescribeSpaceResponse < Struct.new( :domain_id, :space_arn, :space_name, :home_efs_file_system_uid, :status, :last_modified_time, :creation_time, :failure_reason, :space_settings, :ownership_settings, :space_sharing_settings, :space_display_name, :url) SENSITIVE = [] include Aws::Structure end |
#space_display_name ⇒ String
The name of the space that appears in the Amazon SageMaker Studio UI.
23708 23709 23710 23711 23712 23713 23714 23715 23716 23717 23718 23719 23720 23721 23722 23723 23724 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23708 class DescribeSpaceResponse < Struct.new( :domain_id, :space_arn, :space_name, :home_efs_file_system_uid, :status, :last_modified_time, :creation_time, :failure_reason, :space_settings, :ownership_settings, :space_sharing_settings, :space_display_name, :url) SENSITIVE = [] include Aws::Structure end |
#space_name ⇒ String
The name of the space.
23708 23709 23710 23711 23712 23713 23714 23715 23716 23717 23718 23719 23720 23721 23722 23723 23724 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23708 class DescribeSpaceResponse < Struct.new( :domain_id, :space_arn, :space_name, :home_efs_file_system_uid, :status, :last_modified_time, :creation_time, :failure_reason, :space_settings, :ownership_settings, :space_sharing_settings, :space_display_name, :url) SENSITIVE = [] include Aws::Structure end |
#space_settings ⇒ Types::SpaceSettings
A collection of space settings.
23708 23709 23710 23711 23712 23713 23714 23715 23716 23717 23718 23719 23720 23721 23722 23723 23724 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23708 class DescribeSpaceResponse < Struct.new( :domain_id, :space_arn, :space_name, :home_efs_file_system_uid, :status, :last_modified_time, :creation_time, :failure_reason, :space_settings, :ownership_settings, :space_sharing_settings, :space_display_name, :url) SENSITIVE = [] include Aws::Structure end |
#space_sharing_settings ⇒ Types::SpaceSharingSettings
The collection of space sharing settings for a space.
23708 23709 23710 23711 23712 23713 23714 23715 23716 23717 23718 23719 23720 23721 23722 23723 23724 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23708 class DescribeSpaceResponse < Struct.new( :domain_id, :space_arn, :space_name, :home_efs_file_system_uid, :status, :last_modified_time, :creation_time, :failure_reason, :space_settings, :ownership_settings, :space_sharing_settings, :space_display_name, :url) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status.
23708 23709 23710 23711 23712 23713 23714 23715 23716 23717 23718 23719 23720 23721 23722 23723 23724 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23708 class DescribeSpaceResponse < Struct.new( :domain_id, :space_arn, :space_name, :home_efs_file_system_uid, :status, :last_modified_time, :creation_time, :failure_reason, :space_settings, :ownership_settings, :space_sharing_settings, :space_display_name, :url) SENSITIVE = [] include Aws::Structure end |
#url ⇒ String
Returns the URL of the space. If the space is created with Amazon Web Services IAM Identity Center (Successor to Amazon Web Services Single Sign-On) authentication, users can navigate to the URL after appending the respective redirect parameter for the application type to be federated through Amazon Web Services IAM Identity Center.
The following application types are supported:
-
Studio Classic:
&redirect=JupyterServer -
JupyterLab:
&redirect=JupyterLab -
Code Editor, based on Code-OSS, Visual Studio Code - Open Source:
&redirect=CodeEditor
23708 23709 23710 23711 23712 23713 23714 23715 23716 23717 23718 23719 23720 23721 23722 23723 23724 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23708 class DescribeSpaceResponse < Struct.new( :domain_id, :space_arn, :space_name, :home_efs_file_system_uid, :status, :last_modified_time, :creation_time, :failure_reason, :space_settings, :ownership_settings, :space_sharing_settings, :space_display_name, :url) SENSITIVE = [] include Aws::Structure end |