Class: Aws::SageMaker::Types::DescribeSpaceResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timeTime

The creation time.

Returns:

  • (Time)


22972
22973
22974
22975
22976
22977
22978
22979
22980
22981
22982
22983
22984
22985
22986
22987
22988
# File 'lib/aws-sdk-sagemaker/types.rb', line 22972

class DescribeSpaceResponse < Struct.new(
  :domain_id,
  :space_arn,
  :space_name,
  :home_efs_file_system_uid,
  :status,
  :last_modified_time,
  :creation_time,
  :failure_reason,
  :space_settings,
  :ownership_settings,
  :space_sharing_settings,
  :space_display_name,
  :url)
  SENSITIVE = []
  include Aws::Structure
end

#domain_idString

The ID of the associated domain.

Returns:

  • (String)


22972
22973
22974
22975
22976
22977
22978
22979
22980
22981
22982
22983
22984
22985
22986
22987
22988
# File 'lib/aws-sdk-sagemaker/types.rb', line 22972

class DescribeSpaceResponse < Struct.new(
  :domain_id,
  :space_arn,
  :space_name,
  :home_efs_file_system_uid,
  :status,
  :last_modified_time,
  :creation_time,
  :failure_reason,
  :space_settings,
  :ownership_settings,
  :space_sharing_settings,
  :space_display_name,
  :url)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

The failure reason.

Returns:

  • (String)


22972
22973
22974
22975
22976
22977
22978
22979
22980
22981
22982
22983
22984
22985
22986
22987
22988
# File 'lib/aws-sdk-sagemaker/types.rb', line 22972

class DescribeSpaceResponse < Struct.new(
  :domain_id,
  :space_arn,
  :space_name,
  :home_efs_file_system_uid,
  :status,
  :last_modified_time,
  :creation_time,
  :failure_reason,
  :space_settings,
  :ownership_settings,
  :space_sharing_settings,
  :space_display_name,
  :url)
  SENSITIVE = []
  include Aws::Structure
end

#home_efs_file_system_uidString

The ID of the space’s profile in the Amazon EFS volume.

Returns:

  • (String)


22972
22973
22974
22975
22976
22977
22978
22979
22980
22981
22982
22983
22984
22985
22986
22987
22988
# File 'lib/aws-sdk-sagemaker/types.rb', line 22972

class DescribeSpaceResponse < Struct.new(
  :domain_id,
  :space_arn,
  :space_name,
  :home_efs_file_system_uid,
  :status,
  :last_modified_time,
  :creation_time,
  :failure_reason,
  :space_settings,
  :ownership_settings,
  :space_sharing_settings,
  :space_display_name,
  :url)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The last modified time.

Returns:

  • (Time)


22972
22973
22974
22975
22976
22977
22978
22979
22980
22981
22982
22983
22984
22985
22986
22987
22988
# File 'lib/aws-sdk-sagemaker/types.rb', line 22972

class DescribeSpaceResponse < Struct.new(
  :domain_id,
  :space_arn,
  :space_name,
  :home_efs_file_system_uid,
  :status,
  :last_modified_time,
  :creation_time,
  :failure_reason,
  :space_settings,
  :ownership_settings,
  :space_sharing_settings,
  :space_display_name,
  :url)
  SENSITIVE = []
  include Aws::Structure
end

#ownership_settingsTypes::OwnershipSettings

The collection of ownership settings for a space.



22972
22973
22974
22975
22976
22977
22978
22979
22980
22981
22982
22983
22984
22985
22986
22987
22988
# File 'lib/aws-sdk-sagemaker/types.rb', line 22972

class DescribeSpaceResponse < Struct.new(
  :domain_id,
  :space_arn,
  :space_name,
  :home_efs_file_system_uid,
  :status,
  :last_modified_time,
  :creation_time,
  :failure_reason,
  :space_settings,
  :ownership_settings,
  :space_sharing_settings,
  :space_display_name,
  :url)
  SENSITIVE = []
  include Aws::Structure
end

#space_arnString

The space’s Amazon Resource Name (ARN).

Returns:

  • (String)


22972
22973
22974
22975
22976
22977
22978
22979
22980
22981
22982
22983
22984
22985
22986
22987
22988
# File 'lib/aws-sdk-sagemaker/types.rb', line 22972

class DescribeSpaceResponse < Struct.new(
  :domain_id,
  :space_arn,
  :space_name,
  :home_efs_file_system_uid,
  :status,
  :last_modified_time,
  :creation_time,
  :failure_reason,
  :space_settings,
  :ownership_settings,
  :space_sharing_settings,
  :space_display_name,
  :url)
  SENSITIVE = []
  include Aws::Structure
end

#space_display_nameString

The name of the space that appears in the Amazon SageMaker Studio UI.

Returns:

  • (String)


22972
22973
22974
22975
22976
22977
22978
22979
22980
22981
22982
22983
22984
22985
22986
22987
22988
# File 'lib/aws-sdk-sagemaker/types.rb', line 22972

class DescribeSpaceResponse < Struct.new(
  :domain_id,
  :space_arn,
  :space_name,
  :home_efs_file_system_uid,
  :status,
  :last_modified_time,
  :creation_time,
  :failure_reason,
  :space_settings,
  :ownership_settings,
  :space_sharing_settings,
  :space_display_name,
  :url)
  SENSITIVE = []
  include Aws::Structure
end

#space_nameString

The name of the space.

Returns:

  • (String)


22972
22973
22974
22975
22976
22977
22978
22979
22980
22981
22982
22983
22984
22985
22986
22987
22988
# File 'lib/aws-sdk-sagemaker/types.rb', line 22972

class DescribeSpaceResponse < Struct.new(
  :domain_id,
  :space_arn,
  :space_name,
  :home_efs_file_system_uid,
  :status,
  :last_modified_time,
  :creation_time,
  :failure_reason,
  :space_settings,
  :ownership_settings,
  :space_sharing_settings,
  :space_display_name,
  :url)
  SENSITIVE = []
  include Aws::Structure
end

#space_settingsTypes::SpaceSettings

A collection of space settings.



22972
22973
22974
22975
22976
22977
22978
22979
22980
22981
22982
22983
22984
22985
22986
22987
22988
# File 'lib/aws-sdk-sagemaker/types.rb', line 22972

class DescribeSpaceResponse < Struct.new(
  :domain_id,
  :space_arn,
  :space_name,
  :home_efs_file_system_uid,
  :status,
  :last_modified_time,
  :creation_time,
  :failure_reason,
  :space_settings,
  :ownership_settings,
  :space_sharing_settings,
  :space_display_name,
  :url)
  SENSITIVE = []
  include Aws::Structure
end

#space_sharing_settingsTypes::SpaceSharingSettings

The collection of space sharing settings for a space.



22972
22973
22974
22975
22976
22977
22978
22979
22980
22981
22982
22983
22984
22985
22986
22987
22988
# File 'lib/aws-sdk-sagemaker/types.rb', line 22972

class DescribeSpaceResponse < Struct.new(
  :domain_id,
  :space_arn,
  :space_name,
  :home_efs_file_system_uid,
  :status,
  :last_modified_time,
  :creation_time,
  :failure_reason,
  :space_settings,
  :ownership_settings,
  :space_sharing_settings,
  :space_display_name,
  :url)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status.

Returns:

  • (String)


22972
22973
22974
22975
22976
22977
22978
22979
22980
22981
22982
22983
22984
22985
22986
22987
22988
# File 'lib/aws-sdk-sagemaker/types.rb', line 22972

class DescribeSpaceResponse < Struct.new(
  :domain_id,
  :space_arn,
  :space_name,
  :home_efs_file_system_uid,
  :status,
  :last_modified_time,
  :creation_time,
  :failure_reason,
  :space_settings,
  :ownership_settings,
  :space_sharing_settings,
  :space_display_name,
  :url)
  SENSITIVE = []
  include Aws::Structure
end

#urlString

Returns the URL of the space. If the space is created with Amazon Web Services IAM Identity Center (Successor to Amazon Web Services Single Sign-On) authentication, users can navigate to the URL after appending the respective redirect parameter for the application type to be federated through Amazon Web Services IAM Identity Center.

The following application types are supported:

  • Studio Classic: ‘&redirect=JupyterServer`

  • JupyterLab: ‘&redirect=JupyterLab`

  • Code Editor, based on Code-OSS, Visual Studio Code - Open Source: ‘&redirect=CodeEditor`

Returns:

  • (String)


22972
22973
22974
22975
22976
22977
22978
22979
22980
22981
22982
22983
22984
22985
22986
22987
22988
# File 'lib/aws-sdk-sagemaker/types.rb', line 22972

class DescribeSpaceResponse < Struct.new(
  :domain_id,
  :space_arn,
  :space_name,
  :home_efs_file_system_uid,
  :status,
  :last_modified_time,
  :creation_time,
  :failure_reason,
  :space_settings,
  :ownership_settings,
  :space_sharing_settings,
  :space_display_name,
  :url)
  SENSITIVE = []
  include Aws::Structure
end