Class: Aws::SageMaker::Types::DescribeTrainingPlanExtensionHistoryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeTrainingPlanExtensionHistoryRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of extensions to return in the response.
-
#next_token ⇒ String
A token to continue pagination if more results are available.
-
#training_plan_arn ⇒ String
The Amazon Resource Name (ARN); of the training plan to retrieve extension history for.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of extensions to return in the response.
21980 21981 21982 21983 21984 21985 21986 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21980 class DescribeTrainingPlanExtensionHistoryRequest < Struct.new( :training_plan_arn, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token to continue pagination if more results are available.
21980 21981 21982 21983 21984 21985 21986 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21980 class DescribeTrainingPlanExtensionHistoryRequest < Struct.new( :training_plan_arn, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#training_plan_arn ⇒ String
The Amazon Resource Name (ARN); of the training plan to retrieve extension history for.
21980 21981 21982 21983 21984 21985 21986 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21980 class DescribeTrainingPlanExtensionHistoryRequest < Struct.new( :training_plan_arn, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |