Class: Aws::SageMaker::Types::DescribeTrainingPlanExtensionHistoryResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

A token to continue pagination if more results are available.

Returns:

  • (String)


22179
22180
22181
22182
22183
22184
# File 'lib/aws-sdk-sagemaker/types.rb', line 22179

class DescribeTrainingPlanExtensionHistoryResponse < Struct.new(
  :training_plan_extensions,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#training_plan_extensionsArray<Types::TrainingPlanExtension>

A list of extensions for the specified training plan.

Returns:



22179
22180
22181
22182
22183
22184
# File 'lib/aws-sdk-sagemaker/types.rb', line 22179

class DescribeTrainingPlanExtensionHistoryResponse < Struct.new(
  :training_plan_extensions,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end