Class: Aws::SageMaker::Types::DescribeTrainingPlanExtensionHistoryResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeTrainingPlanExtensionHistoryResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A token to continue pagination if more results are available.
-
#training_plan_extensions ⇒ Array<Types::TrainingPlanExtension>
A list of extensions for the specified training plan.
Instance Attribute Details
#next_token ⇒ String
A token to continue pagination if more results are available.
22179 22180 22181 22182 22183 22184 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22179 class DescribeTrainingPlanExtensionHistoryResponse < Struct.new( :training_plan_extensions, :next_token) SENSITIVE = [] include Aws::Structure end |
#training_plan_extensions ⇒ Array<Types::TrainingPlanExtension>
A list of extensions for the specified training plan.
22179 22180 22181 22182 22183 22184 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 22179 class DescribeTrainingPlanExtensionHistoryResponse < Struct.new( :training_plan_extensions, :next_token) SENSITIVE = [] include Aws::Structure end |