Class: Aws::SageMaker::Types::DescribeTrainingPlanExtensionHistoryResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeTrainingPlanExtensionHistoryResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A token to continue pagination if more results are available.
-
#training_plan_extensions ⇒ Array<Types::TrainingPlanExtension>
A list of extensions for the specified training plan.
Instance Attribute Details
#next_token ⇒ String
A token to continue pagination if more results are available.
21998 21999 22000 22001 22002 22003 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21998 class DescribeTrainingPlanExtensionHistoryResponse < Struct.new( :training_plan_extensions, :next_token) SENSITIVE = [] include Aws::Structure end |
#training_plan_extensions ⇒ Array<Types::TrainingPlanExtension>
A list of extensions for the specified training plan.
21998 21999 22000 22001 22002 22003 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 21998 class DescribeTrainingPlanExtensionHistoryResponse < Struct.new( :training_plan_extensions, :next_token) SENSITIVE = [] include Aws::Structure end |