Class: Aws::SageMaker::Types::DescribeTrainingPlanResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeTrainingPlanResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#available_instance_count ⇒ Integer
The number of instances currently available for use in this training plan.
-
#available_spare_instance_count ⇒ Integer
The number of available spare instances in the training plan.
-
#currency_code ⇒ String
The currency code for the upfront fee (e.g., USD).
-
#duration_hours ⇒ Integer
The number of whole hours in the total duration for this training plan.
-
#duration_minutes ⇒ Integer
The additional minutes beyond whole hours in the total duration for this training plan.
-
#end_time ⇒ Time
The end time of the training plan.
-
#in_use_instance_count ⇒ Integer
The number of instances currently in use from this training plan.
-
#reserved_capacity_summaries ⇒ Array<Types::ReservedCapacitySummary>
The list of Reserved Capacity providing the underlying compute resources of the plan.
-
#start_time ⇒ Time
The start time of the training plan.
-
#status ⇒ String
The current status of the training plan (e.g., Pending, Active, Expired).
-
#status_message ⇒ String
A message providing additional information about the current status of the training plan.
-
#target_resources ⇒ Array<String>
The target resources (e.g., SageMaker Training Jobs, SageMaker HyperPod, SageMaker Endpoints, Studio apps) that can use this training plan.
-
#total_instance_count ⇒ Integer
The total number of instances reserved in this training plan.
-
#total_ultra_server_count ⇒ Integer
The total number of UltraServers reserved to this training plan.
-
#training_plan_arn ⇒ String
The Amazon Resource Name (ARN); of the training plan.
-
#training_plan_name ⇒ String
The name of the training plan.
-
#unhealthy_instance_count ⇒ Integer
The number of instances in the training plan that are currently in an unhealthy state.
-
#upfront_fee ⇒ String
The upfront fee for the training plan.
Instance Attribute Details
#available_instance_count ⇒ Integer
The number of instances currently available for use in this training plan.
23992 23993 23994 23995 23996 23997 23998 23999 24000 24001 24002 24003 24004 24005 24006 24007 24008 24009 24010 24011 24012 24013 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23992 class DescribeTrainingPlanResponse < Struct.new( :training_plan_arn, :training_plan_name, :status, :status_message, :duration_hours, :duration_minutes, :start_time, :end_time, :upfront_fee, :currency_code, :total_instance_count, :available_instance_count, :in_use_instance_count, :unhealthy_instance_count, :available_spare_instance_count, :total_ultra_server_count, :target_resources, :reserved_capacity_summaries) SENSITIVE = [] include Aws::Structure end |
#available_spare_instance_count ⇒ Integer
The number of available spare instances in the training plan.
23992 23993 23994 23995 23996 23997 23998 23999 24000 24001 24002 24003 24004 24005 24006 24007 24008 24009 24010 24011 24012 24013 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23992 class DescribeTrainingPlanResponse < Struct.new( :training_plan_arn, :training_plan_name, :status, :status_message, :duration_hours, :duration_minutes, :start_time, :end_time, :upfront_fee, :currency_code, :total_instance_count, :available_instance_count, :in_use_instance_count, :unhealthy_instance_count, :available_spare_instance_count, :total_ultra_server_count, :target_resources, :reserved_capacity_summaries) SENSITIVE = [] include Aws::Structure end |
#currency_code ⇒ String
The currency code for the upfront fee (e.g., USD).
23992 23993 23994 23995 23996 23997 23998 23999 24000 24001 24002 24003 24004 24005 24006 24007 24008 24009 24010 24011 24012 24013 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23992 class DescribeTrainingPlanResponse < Struct.new( :training_plan_arn, :training_plan_name, :status, :status_message, :duration_hours, :duration_minutes, :start_time, :end_time, :upfront_fee, :currency_code, :total_instance_count, :available_instance_count, :in_use_instance_count, :unhealthy_instance_count, :available_spare_instance_count, :total_ultra_server_count, :target_resources, :reserved_capacity_summaries) SENSITIVE = [] include Aws::Structure end |
#duration_hours ⇒ Integer
The number of whole hours in the total duration for this training plan.
23992 23993 23994 23995 23996 23997 23998 23999 24000 24001 24002 24003 24004 24005 24006 24007 24008 24009 24010 24011 24012 24013 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23992 class DescribeTrainingPlanResponse < Struct.new( :training_plan_arn, :training_plan_name, :status, :status_message, :duration_hours, :duration_minutes, :start_time, :end_time, :upfront_fee, :currency_code, :total_instance_count, :available_instance_count, :in_use_instance_count, :unhealthy_instance_count, :available_spare_instance_count, :total_ultra_server_count, :target_resources, :reserved_capacity_summaries) SENSITIVE = [] include Aws::Structure end |
#duration_minutes ⇒ Integer
The additional minutes beyond whole hours in the total duration for this training plan.
23992 23993 23994 23995 23996 23997 23998 23999 24000 24001 24002 24003 24004 24005 24006 24007 24008 24009 24010 24011 24012 24013 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23992 class DescribeTrainingPlanResponse < Struct.new( :training_plan_arn, :training_plan_name, :status, :status_message, :duration_hours, :duration_minutes, :start_time, :end_time, :upfront_fee, :currency_code, :total_instance_count, :available_instance_count, :in_use_instance_count, :unhealthy_instance_count, :available_spare_instance_count, :total_ultra_server_count, :target_resources, :reserved_capacity_summaries) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
The end time of the training plan.
23992 23993 23994 23995 23996 23997 23998 23999 24000 24001 24002 24003 24004 24005 24006 24007 24008 24009 24010 24011 24012 24013 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23992 class DescribeTrainingPlanResponse < Struct.new( :training_plan_arn, :training_plan_name, :status, :status_message, :duration_hours, :duration_minutes, :start_time, :end_time, :upfront_fee, :currency_code, :total_instance_count, :available_instance_count, :in_use_instance_count, :unhealthy_instance_count, :available_spare_instance_count, :total_ultra_server_count, :target_resources, :reserved_capacity_summaries) SENSITIVE = [] include Aws::Structure end |
#in_use_instance_count ⇒ Integer
The number of instances currently in use from this training plan.
23992 23993 23994 23995 23996 23997 23998 23999 24000 24001 24002 24003 24004 24005 24006 24007 24008 24009 24010 24011 24012 24013 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23992 class DescribeTrainingPlanResponse < Struct.new( :training_plan_arn, :training_plan_name, :status, :status_message, :duration_hours, :duration_minutes, :start_time, :end_time, :upfront_fee, :currency_code, :total_instance_count, :available_instance_count, :in_use_instance_count, :unhealthy_instance_count, :available_spare_instance_count, :total_ultra_server_count, :target_resources, :reserved_capacity_summaries) SENSITIVE = [] include Aws::Structure end |
#reserved_capacity_summaries ⇒ Array<Types::ReservedCapacitySummary>
The list of Reserved Capacity providing the underlying compute resources of the plan.
23992 23993 23994 23995 23996 23997 23998 23999 24000 24001 24002 24003 24004 24005 24006 24007 24008 24009 24010 24011 24012 24013 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23992 class DescribeTrainingPlanResponse < Struct.new( :training_plan_arn, :training_plan_name, :status, :status_message, :duration_hours, :duration_minutes, :start_time, :end_time, :upfront_fee, :currency_code, :total_instance_count, :available_instance_count, :in_use_instance_count, :unhealthy_instance_count, :available_spare_instance_count, :total_ultra_server_count, :target_resources, :reserved_capacity_summaries) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The start time of the training plan.
23992 23993 23994 23995 23996 23997 23998 23999 24000 24001 24002 24003 24004 24005 24006 24007 24008 24009 24010 24011 24012 24013 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23992 class DescribeTrainingPlanResponse < Struct.new( :training_plan_arn, :training_plan_name, :status, :status_message, :duration_hours, :duration_minutes, :start_time, :end_time, :upfront_fee, :currency_code, :total_instance_count, :available_instance_count, :in_use_instance_count, :unhealthy_instance_count, :available_spare_instance_count, :total_ultra_server_count, :target_resources, :reserved_capacity_summaries) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the training plan (e.g., Pending, Active, Expired). To see the complete list of status values available for a training plan, refer to the ‘Status` attribute within the ` TrainingPlanSummary ` object.
23992 23993 23994 23995 23996 23997 23998 23999 24000 24001 24002 24003 24004 24005 24006 24007 24008 24009 24010 24011 24012 24013 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23992 class DescribeTrainingPlanResponse < Struct.new( :training_plan_arn, :training_plan_name, :status, :status_message, :duration_hours, :duration_minutes, :start_time, :end_time, :upfront_fee, :currency_code, :total_instance_count, :available_instance_count, :in_use_instance_count, :unhealthy_instance_count, :available_spare_instance_count, :total_ultra_server_count, :target_resources, :reserved_capacity_summaries) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
A message providing additional information about the current status of the training plan.
23992 23993 23994 23995 23996 23997 23998 23999 24000 24001 24002 24003 24004 24005 24006 24007 24008 24009 24010 24011 24012 24013 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23992 class DescribeTrainingPlanResponse < Struct.new( :training_plan_arn, :training_plan_name, :status, :status_message, :duration_hours, :duration_minutes, :start_time, :end_time, :upfront_fee, :currency_code, :total_instance_count, :available_instance_count, :in_use_instance_count, :unhealthy_instance_count, :available_spare_instance_count, :total_ultra_server_count, :target_resources, :reserved_capacity_summaries) SENSITIVE = [] include Aws::Structure end |
#target_resources ⇒ Array<String>
The target resources (e.g., SageMaker Training Jobs, SageMaker HyperPod, SageMaker Endpoints, Studio apps) that can use this training plan.
Training plans are specific to their target resource.
-
A training plan designed for SageMaker training jobs can only be used to schedule and run training jobs.
-
A training plan for HyperPod clusters can be used exclusively to provide compute resources to a cluster’s instance group.
-
A training plan for SageMaker endpoints can be used exclusively to provide compute resources to SageMaker endpoints for model deployment.
-
A training plan for Studio apps can be used to launch JupyterLab and Code Editor apps on reserved training plan capacity.
23992 23993 23994 23995 23996 23997 23998 23999 24000 24001 24002 24003 24004 24005 24006 24007 24008 24009 24010 24011 24012 24013 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23992 class DescribeTrainingPlanResponse < Struct.new( :training_plan_arn, :training_plan_name, :status, :status_message, :duration_hours, :duration_minutes, :start_time, :end_time, :upfront_fee, :currency_code, :total_instance_count, :available_instance_count, :in_use_instance_count, :unhealthy_instance_count, :available_spare_instance_count, :total_ultra_server_count, :target_resources, :reserved_capacity_summaries) SENSITIVE = [] include Aws::Structure end |
#total_instance_count ⇒ Integer
The total number of instances reserved in this training plan.
23992 23993 23994 23995 23996 23997 23998 23999 24000 24001 24002 24003 24004 24005 24006 24007 24008 24009 24010 24011 24012 24013 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23992 class DescribeTrainingPlanResponse < Struct.new( :training_plan_arn, :training_plan_name, :status, :status_message, :duration_hours, :duration_minutes, :start_time, :end_time, :upfront_fee, :currency_code, :total_instance_count, :available_instance_count, :in_use_instance_count, :unhealthy_instance_count, :available_spare_instance_count, :total_ultra_server_count, :target_resources, :reserved_capacity_summaries) SENSITIVE = [] include Aws::Structure end |
#total_ultra_server_count ⇒ Integer
The total number of UltraServers reserved to this training plan.
23992 23993 23994 23995 23996 23997 23998 23999 24000 24001 24002 24003 24004 24005 24006 24007 24008 24009 24010 24011 24012 24013 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23992 class DescribeTrainingPlanResponse < Struct.new( :training_plan_arn, :training_plan_name, :status, :status_message, :duration_hours, :duration_minutes, :start_time, :end_time, :upfront_fee, :currency_code, :total_instance_count, :available_instance_count, :in_use_instance_count, :unhealthy_instance_count, :available_spare_instance_count, :total_ultra_server_count, :target_resources, :reserved_capacity_summaries) SENSITIVE = [] include Aws::Structure end |
#training_plan_arn ⇒ String
The Amazon Resource Name (ARN); of the training plan.
23992 23993 23994 23995 23996 23997 23998 23999 24000 24001 24002 24003 24004 24005 24006 24007 24008 24009 24010 24011 24012 24013 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23992 class DescribeTrainingPlanResponse < Struct.new( :training_plan_arn, :training_plan_name, :status, :status_message, :duration_hours, :duration_minutes, :start_time, :end_time, :upfront_fee, :currency_code, :total_instance_count, :available_instance_count, :in_use_instance_count, :unhealthy_instance_count, :available_spare_instance_count, :total_ultra_server_count, :target_resources, :reserved_capacity_summaries) SENSITIVE = [] include Aws::Structure end |
#training_plan_name ⇒ String
The name of the training plan.
23992 23993 23994 23995 23996 23997 23998 23999 24000 24001 24002 24003 24004 24005 24006 24007 24008 24009 24010 24011 24012 24013 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23992 class DescribeTrainingPlanResponse < Struct.new( :training_plan_arn, :training_plan_name, :status, :status_message, :duration_hours, :duration_minutes, :start_time, :end_time, :upfront_fee, :currency_code, :total_instance_count, :available_instance_count, :in_use_instance_count, :unhealthy_instance_count, :available_spare_instance_count, :total_ultra_server_count, :target_resources, :reserved_capacity_summaries) SENSITIVE = [] include Aws::Structure end |
#unhealthy_instance_count ⇒ Integer
The number of instances in the training plan that are currently in an unhealthy state.
23992 23993 23994 23995 23996 23997 23998 23999 24000 24001 24002 24003 24004 24005 24006 24007 24008 24009 24010 24011 24012 24013 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23992 class DescribeTrainingPlanResponse < Struct.new( :training_plan_arn, :training_plan_name, :status, :status_message, :duration_hours, :duration_minutes, :start_time, :end_time, :upfront_fee, :currency_code, :total_instance_count, :available_instance_count, :in_use_instance_count, :unhealthy_instance_count, :available_spare_instance_count, :total_ultra_server_count, :target_resources, :reserved_capacity_summaries) SENSITIVE = [] include Aws::Structure end |
#upfront_fee ⇒ String
The upfront fee for the training plan.
23992 23993 23994 23995 23996 23997 23998 23999 24000 24001 24002 24003 24004 24005 24006 24007 24008 24009 24010 24011 24012 24013 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23992 class DescribeTrainingPlanResponse < Struct.new( :training_plan_arn, :training_plan_name, :status, :status_message, :duration_hours, :duration_minutes, :start_time, :end_time, :upfront_fee, :currency_code, :total_instance_count, :available_instance_count, :in_use_instance_count, :unhealthy_instance_count, :available_spare_instance_count, :total_ultra_server_count, :target_resources, :reserved_capacity_summaries) SENSITIVE = [] include Aws::Structure end |