Class: Aws::SageMaker::Types::DescribeTrialComponentResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_byTypes::UserContext

Who created the trial component.

Returns:



24333
24334
24335
24336
24337
24338
24339
24340
24341
24342
24343
24344
24345
24346
24347
24348
24349
24350
24351
24352
24353
24354
# File 'lib/aws-sdk-sagemaker/types.rb', line 24333

class DescribeTrialComponentResponse < Struct.new(
  :trial_component_name,
  :trial_component_arn,
  :display_name,
  :source,
  :status,
  :start_time,
  :end_time,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :parameters,
  :input_artifacts,
  :output_artifacts,
  :metadata_properties,
  :metrics,
  :lineage_group_arn,
  :sources)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

When the component was created.

Returns:

  • (Time)


24333
24334
24335
24336
24337
24338
24339
24340
24341
24342
24343
24344
24345
24346
24347
24348
24349
24350
24351
24352
24353
24354
# File 'lib/aws-sdk-sagemaker/types.rb', line 24333

class DescribeTrialComponentResponse < Struct.new(
  :trial_component_name,
  :trial_component_arn,
  :display_name,
  :source,
  :status,
  :start_time,
  :end_time,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :parameters,
  :input_artifacts,
  :output_artifacts,
  :metadata_properties,
  :metrics,
  :lineage_group_arn,
  :sources)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

The name of the component as displayed. If ‘DisplayName` isn’t specified, ‘TrialComponentName` is displayed.

Returns:

  • (String)


24333
24334
24335
24336
24337
24338
24339
24340
24341
24342
24343
24344
24345
24346
24347
24348
24349
24350
24351
24352
24353
24354
# File 'lib/aws-sdk-sagemaker/types.rb', line 24333

class DescribeTrialComponentResponse < Struct.new(
  :trial_component_name,
  :trial_component_arn,
  :display_name,
  :source,
  :status,
  :start_time,
  :end_time,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :parameters,
  :input_artifacts,
  :output_artifacts,
  :metadata_properties,
  :metrics,
  :lineage_group_arn,
  :sources)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

When the component ended.

Returns:

  • (Time)


24333
24334
24335
24336
24337
24338
24339
24340
24341
24342
24343
24344
24345
24346
24347
24348
24349
24350
24351
24352
24353
24354
# File 'lib/aws-sdk-sagemaker/types.rb', line 24333

class DescribeTrialComponentResponse < Struct.new(
  :trial_component_name,
  :trial_component_arn,
  :display_name,
  :source,
  :status,
  :start_time,
  :end_time,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :parameters,
  :input_artifacts,
  :output_artifacts,
  :metadata_properties,
  :metrics,
  :lineage_group_arn,
  :sources)
  SENSITIVE = []
  include Aws::Structure
end

#input_artifactsHash<String,Types::TrialComponentArtifact>

The input artifacts of the component.

Returns:



24333
24334
24335
24336
24337
24338
24339
24340
24341
24342
24343
24344
24345
24346
24347
24348
24349
24350
24351
24352
24353
24354
# File 'lib/aws-sdk-sagemaker/types.rb', line 24333

class DescribeTrialComponentResponse < Struct.new(
  :trial_component_name,
  :trial_component_arn,
  :display_name,
  :source,
  :status,
  :start_time,
  :end_time,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :parameters,
  :input_artifacts,
  :output_artifacts,
  :metadata_properties,
  :metrics,
  :lineage_group_arn,
  :sources)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_byTypes::UserContext

Who last modified the component.

Returns:



24333
24334
24335
24336
24337
24338
24339
24340
24341
24342
24343
24344
24345
24346
24347
24348
24349
24350
24351
24352
24353
24354
# File 'lib/aws-sdk-sagemaker/types.rb', line 24333

class DescribeTrialComponentResponse < Struct.new(
  :trial_component_name,
  :trial_component_arn,
  :display_name,
  :source,
  :status,
  :start_time,
  :end_time,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :parameters,
  :input_artifacts,
  :output_artifacts,
  :metadata_properties,
  :metrics,
  :lineage_group_arn,
  :sources)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

When the component was last modified.

Returns:

  • (Time)


24333
24334
24335
24336
24337
24338
24339
24340
24341
24342
24343
24344
24345
24346
24347
24348
24349
24350
24351
24352
24353
24354
# File 'lib/aws-sdk-sagemaker/types.rb', line 24333

class DescribeTrialComponentResponse < Struct.new(
  :trial_component_name,
  :trial_component_arn,
  :display_name,
  :source,
  :status,
  :start_time,
  :end_time,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :parameters,
  :input_artifacts,
  :output_artifacts,
  :metadata_properties,
  :metrics,
  :lineage_group_arn,
  :sources)
  SENSITIVE = []
  include Aws::Structure
end

#lineage_group_arnString

The Amazon Resource Name (ARN) of the lineage group.

Returns:

  • (String)


24333
24334
24335
24336
24337
24338
24339
24340
24341
24342
24343
24344
24345
24346
24347
24348
24349
24350
24351
24352
24353
24354
# File 'lib/aws-sdk-sagemaker/types.rb', line 24333

class DescribeTrialComponentResponse < Struct.new(
  :trial_component_name,
  :trial_component_arn,
  :display_name,
  :source,
  :status,
  :start_time,
  :end_time,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :parameters,
  :input_artifacts,
  :output_artifacts,
  :metadata_properties,
  :metrics,
  :lineage_group_arn,
  :sources)
  SENSITIVE = []
  include Aws::Structure
end

#metadata_propertiesTypes::MetadataProperties

Metadata properties of the tracking entity, trial, or trial component.



24333
24334
24335
24336
24337
24338
24339
24340
24341
24342
24343
24344
24345
24346
24347
24348
24349
24350
24351
24352
24353
24354
# File 'lib/aws-sdk-sagemaker/types.rb', line 24333

class DescribeTrialComponentResponse < Struct.new(
  :trial_component_name,
  :trial_component_arn,
  :display_name,
  :source,
  :status,
  :start_time,
  :end_time,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :parameters,
  :input_artifacts,
  :output_artifacts,
  :metadata_properties,
  :metrics,
  :lineage_group_arn,
  :sources)
  SENSITIVE = []
  include Aws::Structure
end

#metricsArray<Types::TrialComponentMetricSummary>

The metrics for the component.



24333
24334
24335
24336
24337
24338
24339
24340
24341
24342
24343
24344
24345
24346
24347
24348
24349
24350
24351
24352
24353
24354
# File 'lib/aws-sdk-sagemaker/types.rb', line 24333

class DescribeTrialComponentResponse < Struct.new(
  :trial_component_name,
  :trial_component_arn,
  :display_name,
  :source,
  :status,
  :start_time,
  :end_time,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :parameters,
  :input_artifacts,
  :output_artifacts,
  :metadata_properties,
  :metrics,
  :lineage_group_arn,
  :sources)
  SENSITIVE = []
  include Aws::Structure
end

#output_artifactsHash<String,Types::TrialComponentArtifact>

The output artifacts of the component.

Returns:



24333
24334
24335
24336
24337
24338
24339
24340
24341
24342
24343
24344
24345
24346
24347
24348
24349
24350
24351
24352
24353
24354
# File 'lib/aws-sdk-sagemaker/types.rb', line 24333

class DescribeTrialComponentResponse < Struct.new(
  :trial_component_name,
  :trial_component_arn,
  :display_name,
  :source,
  :status,
  :start_time,
  :end_time,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :parameters,
  :input_artifacts,
  :output_artifacts,
  :metadata_properties,
  :metrics,
  :lineage_group_arn,
  :sources)
  SENSITIVE = []
  include Aws::Structure
end

#parametersHash<String,Types::TrialComponentParameterValue>

The hyperparameters of the component.

Returns:



24333
24334
24335
24336
24337
24338
24339
24340
24341
24342
24343
24344
24345
24346
24347
24348
24349
24350
24351
24352
24353
24354
# File 'lib/aws-sdk-sagemaker/types.rb', line 24333

class DescribeTrialComponentResponse < Struct.new(
  :trial_component_name,
  :trial_component_arn,
  :display_name,
  :source,
  :status,
  :start_time,
  :end_time,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :parameters,
  :input_artifacts,
  :output_artifacts,
  :metadata_properties,
  :metrics,
  :lineage_group_arn,
  :sources)
  SENSITIVE = []
  include Aws::Structure
end

#sourceTypes::TrialComponentSource

The Amazon Resource Name (ARN) of the source and, optionally, the job type.



24333
24334
24335
24336
24337
24338
24339
24340
24341
24342
24343
24344
24345
24346
24347
24348
24349
24350
24351
24352
24353
24354
# File 'lib/aws-sdk-sagemaker/types.rb', line 24333

class DescribeTrialComponentResponse < Struct.new(
  :trial_component_name,
  :trial_component_arn,
  :display_name,
  :source,
  :status,
  :start_time,
  :end_time,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :parameters,
  :input_artifacts,
  :output_artifacts,
  :metadata_properties,
  :metrics,
  :lineage_group_arn,
  :sources)
  SENSITIVE = []
  include Aws::Structure
end

#sourcesArray<Types::TrialComponentSource>

A list of ARNs and, if applicable, job types for multiple sources of an experiment run.

Returns:



24333
24334
24335
24336
24337
24338
24339
24340
24341
24342
24343
24344
24345
24346
24347
24348
24349
24350
24351
24352
24353
24354
# File 'lib/aws-sdk-sagemaker/types.rb', line 24333

class DescribeTrialComponentResponse < Struct.new(
  :trial_component_name,
  :trial_component_arn,
  :display_name,
  :source,
  :status,
  :start_time,
  :end_time,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :parameters,
  :input_artifacts,
  :output_artifacts,
  :metadata_properties,
  :metrics,
  :lineage_group_arn,
  :sources)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

When the component started.

Returns:

  • (Time)


24333
24334
24335
24336
24337
24338
24339
24340
24341
24342
24343
24344
24345
24346
24347
24348
24349
24350
24351
24352
24353
24354
# File 'lib/aws-sdk-sagemaker/types.rb', line 24333

class DescribeTrialComponentResponse < Struct.new(
  :trial_component_name,
  :trial_component_arn,
  :display_name,
  :source,
  :status,
  :start_time,
  :end_time,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :parameters,
  :input_artifacts,
  :output_artifacts,
  :metadata_properties,
  :metrics,
  :lineage_group_arn,
  :sources)
  SENSITIVE = []
  include Aws::Structure
end

#statusTypes::TrialComponentStatus

The status of the component. States include:

  • InProgress

  • Completed

  • Failed



24333
24334
24335
24336
24337
24338
24339
24340
24341
24342
24343
24344
24345
24346
24347
24348
24349
24350
24351
24352
24353
24354
# File 'lib/aws-sdk-sagemaker/types.rb', line 24333

class DescribeTrialComponentResponse < Struct.new(
  :trial_component_name,
  :trial_component_arn,
  :display_name,
  :source,
  :status,
  :start_time,
  :end_time,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :parameters,
  :input_artifacts,
  :output_artifacts,
  :metadata_properties,
  :metrics,
  :lineage_group_arn,
  :sources)
  SENSITIVE = []
  include Aws::Structure
end

#trial_component_arnString

The Amazon Resource Name (ARN) of the trial component.

Returns:

  • (String)


24333
24334
24335
24336
24337
24338
24339
24340
24341
24342
24343
24344
24345
24346
24347
24348
24349
24350
24351
24352
24353
24354
# File 'lib/aws-sdk-sagemaker/types.rb', line 24333

class DescribeTrialComponentResponse < Struct.new(
  :trial_component_name,
  :trial_component_arn,
  :display_name,
  :source,
  :status,
  :start_time,
  :end_time,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :parameters,
  :input_artifacts,
  :output_artifacts,
  :metadata_properties,
  :metrics,
  :lineage_group_arn,
  :sources)
  SENSITIVE = []
  include Aws::Structure
end

#trial_component_nameString

The name of the trial component.

Returns:

  • (String)


24333
24334
24335
24336
24337
24338
24339
24340
24341
24342
24343
24344
24345
24346
24347
24348
24349
24350
24351
24352
24353
24354
# File 'lib/aws-sdk-sagemaker/types.rb', line 24333

class DescribeTrialComponentResponse < Struct.new(
  :trial_component_name,
  :trial_component_arn,
  :display_name,
  :source,
  :status,
  :start_time,
  :end_time,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :parameters,
  :input_artifacts,
  :output_artifacts,
  :metadata_properties,
  :metrics,
  :lineage_group_arn,
  :sources)
  SENSITIVE = []
  include Aws::Structure
end