Class: Aws::SageMaker::Types::DescribeTrialComponentResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DescribeTrialComponentResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_by ⇒ Types::UserContext
Who created the trial component.
-
#creation_time ⇒ Time
When the component was created.
-
#display_name ⇒ String
The name of the component as displayed.
-
#end_time ⇒ Time
When the component ended.
-
#input_artifacts ⇒ Hash<String,Types::TrialComponentArtifact>
The input artifacts of the component.
-
#last_modified_by ⇒ Types::UserContext
Who last modified the component.
-
#last_modified_time ⇒ Time
When the component was last modified.
-
#lineage_group_arn ⇒ String
The Amazon Resource Name (ARN) of the lineage group.
-
#metadata_properties ⇒ Types::MetadataProperties
Metadata properties of the tracking entity, trial, or trial component.
-
#metrics ⇒ Array<Types::TrialComponentMetricSummary>
The metrics for the component.
-
#output_artifacts ⇒ Hash<String,Types::TrialComponentArtifact>
The output artifacts of the component.
-
#parameters ⇒ Hash<String,Types::TrialComponentParameterValue>
The hyperparameters of the component.
-
#source ⇒ Types::TrialComponentSource
The Amazon Resource Name (ARN) of the source and, optionally, the job type.
-
#sources ⇒ Array<Types::TrialComponentSource>
A list of ARNs and, if applicable, job types for multiple sources of an experiment run.
-
#start_time ⇒ Time
When the component started.
-
#status ⇒ Types::TrialComponentStatus
The status of the component.
-
#trial_component_arn ⇒ String
The Amazon Resource Name (ARN) of the trial component.
-
#trial_component_name ⇒ String
The name of the trial component.
Instance Attribute Details
#created_by ⇒ Types::UserContext
Who created the trial component.
23783 23784 23785 23786 23787 23788 23789 23790 23791 23792 23793 23794 23795 23796 23797 23798 23799 23800 23801 23802 23803 23804 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23783 class DescribeTrialComponentResponse < Struct.new( :trial_component_name, :trial_component_arn, :display_name, :source, :status, :start_time, :end_time, :creation_time, :created_by, :last_modified_time, :last_modified_by, :parameters, :input_artifacts, :output_artifacts, :metadata_properties, :metrics, :lineage_group_arn, :sources) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
When the component was created.
23783 23784 23785 23786 23787 23788 23789 23790 23791 23792 23793 23794 23795 23796 23797 23798 23799 23800 23801 23802 23803 23804 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23783 class DescribeTrialComponentResponse < Struct.new( :trial_component_name, :trial_component_arn, :display_name, :source, :status, :start_time, :end_time, :creation_time, :created_by, :last_modified_time, :last_modified_by, :parameters, :input_artifacts, :output_artifacts, :metadata_properties, :metrics, :lineage_group_arn, :sources) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The name of the component as displayed. If ‘DisplayName` isn’t specified, ‘TrialComponentName` is displayed.
23783 23784 23785 23786 23787 23788 23789 23790 23791 23792 23793 23794 23795 23796 23797 23798 23799 23800 23801 23802 23803 23804 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23783 class DescribeTrialComponentResponse < Struct.new( :trial_component_name, :trial_component_arn, :display_name, :source, :status, :start_time, :end_time, :creation_time, :created_by, :last_modified_time, :last_modified_by, :parameters, :input_artifacts, :output_artifacts, :metadata_properties, :metrics, :lineage_group_arn, :sources) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
When the component ended.
23783 23784 23785 23786 23787 23788 23789 23790 23791 23792 23793 23794 23795 23796 23797 23798 23799 23800 23801 23802 23803 23804 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23783 class DescribeTrialComponentResponse < Struct.new( :trial_component_name, :trial_component_arn, :display_name, :source, :status, :start_time, :end_time, :creation_time, :created_by, :last_modified_time, :last_modified_by, :parameters, :input_artifacts, :output_artifacts, :metadata_properties, :metrics, :lineage_group_arn, :sources) SENSITIVE = [] include Aws::Structure end |
#input_artifacts ⇒ Hash<String,Types::TrialComponentArtifact>
The input artifacts of the component.
23783 23784 23785 23786 23787 23788 23789 23790 23791 23792 23793 23794 23795 23796 23797 23798 23799 23800 23801 23802 23803 23804 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23783 class DescribeTrialComponentResponse < Struct.new( :trial_component_name, :trial_component_arn, :display_name, :source, :status, :start_time, :end_time, :creation_time, :created_by, :last_modified_time, :last_modified_by, :parameters, :input_artifacts, :output_artifacts, :metadata_properties, :metrics, :lineage_group_arn, :sources) SENSITIVE = [] include Aws::Structure end |
#last_modified_by ⇒ Types::UserContext
Who last modified the component.
23783 23784 23785 23786 23787 23788 23789 23790 23791 23792 23793 23794 23795 23796 23797 23798 23799 23800 23801 23802 23803 23804 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23783 class DescribeTrialComponentResponse < Struct.new( :trial_component_name, :trial_component_arn, :display_name, :source, :status, :start_time, :end_time, :creation_time, :created_by, :last_modified_time, :last_modified_by, :parameters, :input_artifacts, :output_artifacts, :metadata_properties, :metrics, :lineage_group_arn, :sources) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
When the component was last modified.
23783 23784 23785 23786 23787 23788 23789 23790 23791 23792 23793 23794 23795 23796 23797 23798 23799 23800 23801 23802 23803 23804 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23783 class DescribeTrialComponentResponse < Struct.new( :trial_component_name, :trial_component_arn, :display_name, :source, :status, :start_time, :end_time, :creation_time, :created_by, :last_modified_time, :last_modified_by, :parameters, :input_artifacts, :output_artifacts, :metadata_properties, :metrics, :lineage_group_arn, :sources) SENSITIVE = [] include Aws::Structure end |
#lineage_group_arn ⇒ String
The Amazon Resource Name (ARN) of the lineage group.
23783 23784 23785 23786 23787 23788 23789 23790 23791 23792 23793 23794 23795 23796 23797 23798 23799 23800 23801 23802 23803 23804 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23783 class DescribeTrialComponentResponse < Struct.new( :trial_component_name, :trial_component_arn, :display_name, :source, :status, :start_time, :end_time, :creation_time, :created_by, :last_modified_time, :last_modified_by, :parameters, :input_artifacts, :output_artifacts, :metadata_properties, :metrics, :lineage_group_arn, :sources) SENSITIVE = [] include Aws::Structure end |
#metadata_properties ⇒ Types::MetadataProperties
Metadata properties of the tracking entity, trial, or trial component.
23783 23784 23785 23786 23787 23788 23789 23790 23791 23792 23793 23794 23795 23796 23797 23798 23799 23800 23801 23802 23803 23804 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23783 class DescribeTrialComponentResponse < Struct.new( :trial_component_name, :trial_component_arn, :display_name, :source, :status, :start_time, :end_time, :creation_time, :created_by, :last_modified_time, :last_modified_by, :parameters, :input_artifacts, :output_artifacts, :metadata_properties, :metrics, :lineage_group_arn, :sources) SENSITIVE = [] include Aws::Structure end |
#metrics ⇒ Array<Types::TrialComponentMetricSummary>
The metrics for the component.
23783 23784 23785 23786 23787 23788 23789 23790 23791 23792 23793 23794 23795 23796 23797 23798 23799 23800 23801 23802 23803 23804 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23783 class DescribeTrialComponentResponse < Struct.new( :trial_component_name, :trial_component_arn, :display_name, :source, :status, :start_time, :end_time, :creation_time, :created_by, :last_modified_time, :last_modified_by, :parameters, :input_artifacts, :output_artifacts, :metadata_properties, :metrics, :lineage_group_arn, :sources) SENSITIVE = [] include Aws::Structure end |
#output_artifacts ⇒ Hash<String,Types::TrialComponentArtifact>
The output artifacts of the component.
23783 23784 23785 23786 23787 23788 23789 23790 23791 23792 23793 23794 23795 23796 23797 23798 23799 23800 23801 23802 23803 23804 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23783 class DescribeTrialComponentResponse < Struct.new( :trial_component_name, :trial_component_arn, :display_name, :source, :status, :start_time, :end_time, :creation_time, :created_by, :last_modified_time, :last_modified_by, :parameters, :input_artifacts, :output_artifacts, :metadata_properties, :metrics, :lineage_group_arn, :sources) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Hash<String,Types::TrialComponentParameterValue>
The hyperparameters of the component.
23783 23784 23785 23786 23787 23788 23789 23790 23791 23792 23793 23794 23795 23796 23797 23798 23799 23800 23801 23802 23803 23804 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23783 class DescribeTrialComponentResponse < Struct.new( :trial_component_name, :trial_component_arn, :display_name, :source, :status, :start_time, :end_time, :creation_time, :created_by, :last_modified_time, :last_modified_by, :parameters, :input_artifacts, :output_artifacts, :metadata_properties, :metrics, :lineage_group_arn, :sources) SENSITIVE = [] include Aws::Structure end |
#source ⇒ Types::TrialComponentSource
The Amazon Resource Name (ARN) of the source and, optionally, the job type.
23783 23784 23785 23786 23787 23788 23789 23790 23791 23792 23793 23794 23795 23796 23797 23798 23799 23800 23801 23802 23803 23804 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23783 class DescribeTrialComponentResponse < Struct.new( :trial_component_name, :trial_component_arn, :display_name, :source, :status, :start_time, :end_time, :creation_time, :created_by, :last_modified_time, :last_modified_by, :parameters, :input_artifacts, :output_artifacts, :metadata_properties, :metrics, :lineage_group_arn, :sources) SENSITIVE = [] include Aws::Structure end |
#sources ⇒ Array<Types::TrialComponentSource>
A list of ARNs and, if applicable, job types for multiple sources of an experiment run.
23783 23784 23785 23786 23787 23788 23789 23790 23791 23792 23793 23794 23795 23796 23797 23798 23799 23800 23801 23802 23803 23804 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23783 class DescribeTrialComponentResponse < Struct.new( :trial_component_name, :trial_component_arn, :display_name, :source, :status, :start_time, :end_time, :creation_time, :created_by, :last_modified_time, :last_modified_by, :parameters, :input_artifacts, :output_artifacts, :metadata_properties, :metrics, :lineage_group_arn, :sources) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
When the component started.
23783 23784 23785 23786 23787 23788 23789 23790 23791 23792 23793 23794 23795 23796 23797 23798 23799 23800 23801 23802 23803 23804 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23783 class DescribeTrialComponentResponse < Struct.new( :trial_component_name, :trial_component_arn, :display_name, :source, :status, :start_time, :end_time, :creation_time, :created_by, :last_modified_time, :last_modified_by, :parameters, :input_artifacts, :output_artifacts, :metadata_properties, :metrics, :lineage_group_arn, :sources) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::TrialComponentStatus
The status of the component. States include:
-
InProgress
-
Completed
-
Failed
23783 23784 23785 23786 23787 23788 23789 23790 23791 23792 23793 23794 23795 23796 23797 23798 23799 23800 23801 23802 23803 23804 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23783 class DescribeTrialComponentResponse < Struct.new( :trial_component_name, :trial_component_arn, :display_name, :source, :status, :start_time, :end_time, :creation_time, :created_by, :last_modified_time, :last_modified_by, :parameters, :input_artifacts, :output_artifacts, :metadata_properties, :metrics, :lineage_group_arn, :sources) SENSITIVE = [] include Aws::Structure end |
#trial_component_arn ⇒ String
The Amazon Resource Name (ARN) of the trial component.
23783 23784 23785 23786 23787 23788 23789 23790 23791 23792 23793 23794 23795 23796 23797 23798 23799 23800 23801 23802 23803 23804 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23783 class DescribeTrialComponentResponse < Struct.new( :trial_component_name, :trial_component_arn, :display_name, :source, :status, :start_time, :end_time, :creation_time, :created_by, :last_modified_time, :last_modified_by, :parameters, :input_artifacts, :output_artifacts, :metadata_properties, :metrics, :lineage_group_arn, :sources) SENSITIVE = [] include Aws::Structure end |
#trial_component_name ⇒ String
The name of the trial component.
23783 23784 23785 23786 23787 23788 23789 23790 23791 23792 23793 23794 23795 23796 23797 23798 23799 23800 23801 23802 23803 23804 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23783 class DescribeTrialComponentResponse < Struct.new( :trial_component_name, :trial_component_arn, :display_name, :source, :status, :start_time, :end_time, :creation_time, :created_by, :last_modified_time, :last_modified_by, :parameters, :input_artifacts, :output_artifacts, :metadata_properties, :metrics, :lineage_group_arn, :sources) SENSITIVE = [] include Aws::Structure end |