Class: Aws::SageMaker::Types::DescribeTrialResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_byTypes::UserContext

Who created the trial.

Returns:



23898
23899
23900
23901
23902
23903
23904
23905
23906
23907
23908
23909
23910
23911
# File 'lib/aws-sdk-sagemaker/types.rb', line 23898

class DescribeTrialResponse < Struct.new(
  :trial_name,
  :trial_arn,
  :display_name,
  :experiment_name,
  :source,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :metadata_properties)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

When the trial was created.

Returns:

  • (Time)


23898
23899
23900
23901
23902
23903
23904
23905
23906
23907
23908
23909
23910
23911
# File 'lib/aws-sdk-sagemaker/types.rb', line 23898

class DescribeTrialResponse < Struct.new(
  :trial_name,
  :trial_arn,
  :display_name,
  :experiment_name,
  :source,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :metadata_properties)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

The name of the trial as displayed. If ‘DisplayName` isn’t specified, ‘TrialName` is displayed.

Returns:

  • (String)


23898
23899
23900
23901
23902
23903
23904
23905
23906
23907
23908
23909
23910
23911
# File 'lib/aws-sdk-sagemaker/types.rb', line 23898

class DescribeTrialResponse < Struct.new(
  :trial_name,
  :trial_arn,
  :display_name,
  :experiment_name,
  :source,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :metadata_properties)
  SENSITIVE = []
  include Aws::Structure
end

#experiment_nameString

The name of the experiment the trial is part of.

Returns:

  • (String)


23898
23899
23900
23901
23902
23903
23904
23905
23906
23907
23908
23909
23910
23911
# File 'lib/aws-sdk-sagemaker/types.rb', line 23898

class DescribeTrialResponse < Struct.new(
  :trial_name,
  :trial_arn,
  :display_name,
  :experiment_name,
  :source,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :metadata_properties)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_byTypes::UserContext

Who last modified the trial.

Returns:



23898
23899
23900
23901
23902
23903
23904
23905
23906
23907
23908
23909
23910
23911
# File 'lib/aws-sdk-sagemaker/types.rb', line 23898

class DescribeTrialResponse < Struct.new(
  :trial_name,
  :trial_arn,
  :display_name,
  :experiment_name,
  :source,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :metadata_properties)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

When the trial was last modified.

Returns:

  • (Time)


23898
23899
23900
23901
23902
23903
23904
23905
23906
23907
23908
23909
23910
23911
# File 'lib/aws-sdk-sagemaker/types.rb', line 23898

class DescribeTrialResponse < Struct.new(
  :trial_name,
  :trial_arn,
  :display_name,
  :experiment_name,
  :source,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :metadata_properties)
  SENSITIVE = []
  include Aws::Structure
end

#metadata_propertiesTypes::MetadataProperties

Metadata properties of the tracking entity, trial, or trial component.



23898
23899
23900
23901
23902
23903
23904
23905
23906
23907
23908
23909
23910
23911
# File 'lib/aws-sdk-sagemaker/types.rb', line 23898

class DescribeTrialResponse < Struct.new(
  :trial_name,
  :trial_arn,
  :display_name,
  :experiment_name,
  :source,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :metadata_properties)
  SENSITIVE = []
  include Aws::Structure
end

#sourceTypes::TrialSource

The Amazon Resource Name (ARN) of the source and, optionally, the job type.

Returns:



23898
23899
23900
23901
23902
23903
23904
23905
23906
23907
23908
23909
23910
23911
# File 'lib/aws-sdk-sagemaker/types.rb', line 23898

class DescribeTrialResponse < Struct.new(
  :trial_name,
  :trial_arn,
  :display_name,
  :experiment_name,
  :source,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :metadata_properties)
  SENSITIVE = []
  include Aws::Structure
end

#trial_arnString

The Amazon Resource Name (ARN) of the trial.

Returns:

  • (String)


23898
23899
23900
23901
23902
23903
23904
23905
23906
23907
23908
23909
23910
23911
# File 'lib/aws-sdk-sagemaker/types.rb', line 23898

class DescribeTrialResponse < Struct.new(
  :trial_name,
  :trial_arn,
  :display_name,
  :experiment_name,
  :source,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :metadata_properties)
  SENSITIVE = []
  include Aws::Structure
end

#trial_nameString

The name of the trial.

Returns:

  • (String)


23898
23899
23900
23901
23902
23903
23904
23905
23906
23907
23908
23909
23910
23911
# File 'lib/aws-sdk-sagemaker/types.rb', line 23898

class DescribeTrialResponse < Struct.new(
  :trial_name,
  :trial_arn,
  :display_name,
  :experiment_name,
  :source,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :metadata_properties)
  SENSITIVE = []
  include Aws::Structure
end