Class: Aws::SageMaker::Types::DirectDeploySettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DirectDeploySettings
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The model deployment settings for the SageMaker Canvas application.
AmazonSageMakerCanvasDirectDeployAccess policy
attached. You can also turn on model deployment permissions through
the SageMaker Domain's or user profile's settings in the SageMaker
console.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#status ⇒ String
Describes whether model deployment permissions are enabled or disabled in the Canvas application.
Instance Attribute Details
#status ⇒ String
Describes whether model deployment permissions are enabled or disabled in the Canvas application.
25272 25273 25274 25275 25276 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 25272 class DirectDeploySettings < Struct.new( :status) SENSITIVE = [] include Aws::Structure end |