Class: Aws::SageMaker::Types::DomainSettingsForUpdate
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DomainSettingsForUpdate
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
A collection of ‘Domain` configuration settings to update.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#amazon_q_settings ⇒ Types::AmazonQSettings
A collection of settings that configure the Amazon Q experience within the domain.
-
#docker_settings ⇒ Types::DockerSettings
A collection of settings that configure the domain’s Docker interaction.
-
#execution_role_identity_config ⇒ String
The configuration for attaching a SageMaker AI user profile name to the execution role as a [sts:SourceIdentity key].
-
#ip_address_type ⇒ String
The IP address type for the domain.
-
#r_studio_server_pro_domain_settings_for_update ⇒ Types::RStudioServerProDomainSettingsForUpdate
A collection of ‘RStudioServerPro` Domain-level app settings to update.
-
#security_group_ids ⇒ Array<String>
The security groups for the Amazon Virtual Private Cloud that the ‘Domain` uses for communication between Domain-level apps and user apps.
-
#trusted_identity_propagation_settings ⇒ Types::TrustedIdentityPropagationSettings
The Trusted Identity Propagation (TIP) settings for the SageMaker domain.
-
#unified_studio_settings ⇒ Types::UnifiedStudioSettings
The settings that apply to an SageMaker AI domain when you use it in Amazon SageMaker Unified Studio.
Instance Attribute Details
#amazon_q_settings ⇒ Types::AmazonQSettings
A collection of settings that configure the Amazon Q experience within the domain.
25146 25147 25148 25149 25150 25151 25152 25153 25154 25155 25156 25157 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 25146 class DomainSettingsForUpdate < Struct.new( :r_studio_server_pro_domain_settings_for_update, :execution_role_identity_config, :security_group_ids, :trusted_identity_propagation_settings, :docker_settings, :amazon_q_settings, :unified_studio_settings, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#docker_settings ⇒ Types::DockerSettings
A collection of settings that configure the domain’s Docker interaction.
25146 25147 25148 25149 25150 25151 25152 25153 25154 25155 25156 25157 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 25146 class DomainSettingsForUpdate < Struct.new( :r_studio_server_pro_domain_settings_for_update, :execution_role_identity_config, :security_group_ids, :trusted_identity_propagation_settings, :docker_settings, :amazon_q_settings, :unified_studio_settings, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#execution_role_identity_config ⇒ String
The configuration for attaching a SageMaker AI user profile name to the execution role as a [sts:SourceIdentity key]. This configuration can only be modified if there are no apps in the ‘InService` or `Pending` state.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_control-access_monitor.html
25146 25147 25148 25149 25150 25151 25152 25153 25154 25155 25156 25157 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 25146 class DomainSettingsForUpdate < Struct.new( :r_studio_server_pro_domain_settings_for_update, :execution_role_identity_config, :security_group_ids, :trusted_identity_propagation_settings, :docker_settings, :amazon_q_settings, :unified_studio_settings, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#ip_address_type ⇒ String
The IP address type for the domain. Specify ‘ipv4` for IPv4-only connectivity or `dualstack` for both IPv4 and IPv6 connectivity. When you specify `dualstack`, the subnet must support IPv6 CIDR blocks.
25146 25147 25148 25149 25150 25151 25152 25153 25154 25155 25156 25157 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 25146 class DomainSettingsForUpdate < Struct.new( :r_studio_server_pro_domain_settings_for_update, :execution_role_identity_config, :security_group_ids, :trusted_identity_propagation_settings, :docker_settings, :amazon_q_settings, :unified_studio_settings, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#r_studio_server_pro_domain_settings_for_update ⇒ Types::RStudioServerProDomainSettingsForUpdate
A collection of ‘RStudioServerPro` Domain-level app settings to update. A single `RStudioServerPro` application is created for a domain.
25146 25147 25148 25149 25150 25151 25152 25153 25154 25155 25156 25157 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 25146 class DomainSettingsForUpdate < Struct.new( :r_studio_server_pro_domain_settings_for_update, :execution_role_identity_config, :security_group_ids, :trusted_identity_propagation_settings, :docker_settings, :amazon_q_settings, :unified_studio_settings, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#security_group_ids ⇒ Array<String>
The security groups for the Amazon Virtual Private Cloud that the ‘Domain` uses for communication between Domain-level apps and user apps.
25146 25147 25148 25149 25150 25151 25152 25153 25154 25155 25156 25157 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 25146 class DomainSettingsForUpdate < Struct.new( :r_studio_server_pro_domain_settings_for_update, :execution_role_identity_config, :security_group_ids, :trusted_identity_propagation_settings, :docker_settings, :amazon_q_settings, :unified_studio_settings, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#trusted_identity_propagation_settings ⇒ Types::TrustedIdentityPropagationSettings
The Trusted Identity Propagation (TIP) settings for the SageMaker domain. These settings determine how user identities from IAM Identity Center are propagated through the domain to TIP enabled Amazon Web Services services.
25146 25147 25148 25149 25150 25151 25152 25153 25154 25155 25156 25157 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 25146 class DomainSettingsForUpdate < Struct.new( :r_studio_server_pro_domain_settings_for_update, :execution_role_identity_config, :security_group_ids, :trusted_identity_propagation_settings, :docker_settings, :amazon_q_settings, :unified_studio_settings, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#unified_studio_settings ⇒ Types::UnifiedStudioSettings
The settings that apply to an SageMaker AI domain when you use it in Amazon SageMaker Unified Studio.
25146 25147 25148 25149 25150 25151 25152 25153 25154 25155 25156 25157 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 25146 class DomainSettingsForUpdate < Struct.new( :r_studio_server_pro_domain_settings_for_update, :execution_role_identity_config, :security_group_ids, :trusted_identity_propagation_settings, :docker_settings, :amazon_q_settings, :unified_studio_settings, :ip_address_type) SENSITIVE = [] include Aws::Structure end |