Class: Aws::SageMaker::Types::DomainSettingsForUpdate

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

A collection of Domain configuration settings to update.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#execution_role_identity_configString

The configuration for attaching a SageMaker user profile name to the execution role as a [sts:SourceIdentity key]. This configuration can only be modified if there are no apps in the InService or Pending state.

[1]: docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_control-access_monitor.html

Returns:

  • (String)


15454
15455
15456
15457
15458
15459
15460
# File 'lib/aws-sdk-sagemaker/types.rb', line 15454

class DomainSettingsForUpdate < Struct.new(
  :r_studio_server_pro_domain_settings_for_update,
  :execution_role_identity_config,
  :security_group_ids)
  SENSITIVE = []
  include Aws::Structure
end

#r_studio_server_pro_domain_settings_for_updateTypes::RStudioServerProDomainSettingsForUpdate

A collection of RStudioServerPro Domain-level app settings to update.



15454
15455
15456
15457
15458
15459
15460
# File 'lib/aws-sdk-sagemaker/types.rb', line 15454

class DomainSettingsForUpdate < Struct.new(
  :r_studio_server_pro_domain_settings_for_update,
  :execution_role_identity_config,
  :security_group_ids)
  SENSITIVE = []
  include Aws::Structure
end

#security_group_idsArray<String>

The security groups for the Amazon Virtual Private Cloud that the Domain uses for communication between Domain-level apps and user apps.

Returns:

  • (Array<String>)


15454
15455
15456
15457
15458
15459
15460
# File 'lib/aws-sdk-sagemaker/types.rb', line 15454

class DomainSettingsForUpdate < Struct.new(
  :r_studio_server_pro_domain_settings_for_update,
  :execution_role_identity_config,
  :security_group_ids)
  SENSITIVE = []
  include Aws::Structure
end