Class: Aws::SageMaker::Types::DriftCheckBaselines

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Represents the drift check baselines that can be used when the model monitor is set using the model package.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#biasTypes::DriftCheckBias

Represents the drift check bias baselines that can be used when the model monitor is set using the model package.



25216
25217
25218
25219
25220
25221
25222
25223
# File 'lib/aws-sdk-sagemaker/types.rb', line 25216

class DriftCheckBaselines < Struct.new(
  :bias,
  :explainability,
  :model_quality,
  :model_data_quality)
  SENSITIVE = []
  include Aws::Structure
end

#explainabilityTypes::DriftCheckExplainability

Represents the drift check explainability baselines that can be used when the model monitor is set using the model package.



25216
25217
25218
25219
25220
25221
25222
25223
# File 'lib/aws-sdk-sagemaker/types.rb', line 25216

class DriftCheckBaselines < Struct.new(
  :bias,
  :explainability,
  :model_quality,
  :model_data_quality)
  SENSITIVE = []
  include Aws::Structure
end

#model_data_qualityTypes::DriftCheckModelDataQuality

Represents the drift check model data quality baselines that can be used when the model monitor is set using the model package.



25216
25217
25218
25219
25220
25221
25222
25223
# File 'lib/aws-sdk-sagemaker/types.rb', line 25216

class DriftCheckBaselines < Struct.new(
  :bias,
  :explainability,
  :model_quality,
  :model_data_quality)
  SENSITIVE = []
  include Aws::Structure
end

#model_qualityTypes::DriftCheckModelQuality

Represents the drift check model quality baselines that can be used when the model monitor is set using the model package.



25216
25217
25218
25219
25220
25221
25222
25223
# File 'lib/aws-sdk-sagemaker/types.rb', line 25216

class DriftCheckBaselines < Struct.new(
  :bias,
  :explainability,
  :model_quality,
  :model_data_quality)
  SENSITIVE = []
  include Aws::Structure
end