Class: Aws::SageMaker::Types::DriftCheckBaselines
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::DriftCheckBaselines
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Represents the drift check baselines that can be used when the model monitor is set using the model package.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bias ⇒ Types::DriftCheckBias
Represents the drift check bias baselines that can be used when the model monitor is set using the model package.
-
#explainability ⇒ Types::DriftCheckExplainability
Represents the drift check explainability baselines that can be used when the model monitor is set using the model package.
-
#model_data_quality ⇒ Types::DriftCheckModelDataQuality
Represents the drift check model data quality baselines that can be used when the model monitor is set using the model package.
-
#model_quality ⇒ Types::DriftCheckModelQuality
Represents the drift check model quality baselines that can be used when the model monitor is set using the model package.
Instance Attribute Details
#bias ⇒ Types::DriftCheckBias
Represents the drift check bias baselines that can be used when the model monitor is set using the model package.
25184 25185 25186 25187 25188 25189 25190 25191 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 25184 class DriftCheckBaselines < Struct.new( :bias, :explainability, :model_quality, :model_data_quality) SENSITIVE = [] include Aws::Structure end |
#explainability ⇒ Types::DriftCheckExplainability
Represents the drift check explainability baselines that can be used when the model monitor is set using the model package.
25184 25185 25186 25187 25188 25189 25190 25191 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 25184 class DriftCheckBaselines < Struct.new( :bias, :explainability, :model_quality, :model_data_quality) SENSITIVE = [] include Aws::Structure end |
#model_data_quality ⇒ Types::DriftCheckModelDataQuality
Represents the drift check model data quality baselines that can be used when the model monitor is set using the model package.
25184 25185 25186 25187 25188 25189 25190 25191 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 25184 class DriftCheckBaselines < Struct.new( :bias, :explainability, :model_quality, :model_data_quality) SENSITIVE = [] include Aws::Structure end |
#model_quality ⇒ Types::DriftCheckModelQuality
Represents the drift check model quality baselines that can be used when the model monitor is set using the model package.
25184 25185 25186 25187 25188 25189 25190 25191 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 25184 class DriftCheckBaselines < Struct.new( :bias, :explainability, :model_quality, :model_data_quality) SENSITIVE = [] include Aws::Structure end |