Class: Aws::SageMaker::Types::DriftCheckBaselines

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Represents the drift check baselines that can be used when the model monitor is set using the model package.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#biasTypes::DriftCheckBias

Represents the drift check bias baselines that can be used when the model monitor is set using the model package.



24669
24670
24671
24672
24673
24674
24675
24676
# File 'lib/aws-sdk-sagemaker/types.rb', line 24669

class DriftCheckBaselines < Struct.new(
  :bias,
  :explainability,
  :model_quality,
  :model_data_quality)
  SENSITIVE = []
  include Aws::Structure
end

#explainabilityTypes::DriftCheckExplainability

Represents the drift check explainability baselines that can be used when the model monitor is set using the model package.



24669
24670
24671
24672
24673
24674
24675
24676
# File 'lib/aws-sdk-sagemaker/types.rb', line 24669

class DriftCheckBaselines < Struct.new(
  :bias,
  :explainability,
  :model_quality,
  :model_data_quality)
  SENSITIVE = []
  include Aws::Structure
end

#model_data_qualityTypes::DriftCheckModelDataQuality

Represents the drift check model data quality baselines that can be used when the model monitor is set using the model package.



24669
24670
24671
24672
24673
24674
24675
24676
# File 'lib/aws-sdk-sagemaker/types.rb', line 24669

class DriftCheckBaselines < Struct.new(
  :bias,
  :explainability,
  :model_quality,
  :model_data_quality)
  SENSITIVE = []
  include Aws::Structure
end

#model_qualityTypes::DriftCheckModelQuality

Represents the drift check model quality baselines that can be used when the model monitor is set using the model package.



24669
24670
24671
24672
24673
24674
24675
24676
# File 'lib/aws-sdk-sagemaker/types.rb', line 24669

class DriftCheckBaselines < Struct.new(
  :bias,
  :explainability,
  :model_quality,
  :model_data_quality)
  SENSITIVE = []
  include Aws::Structure
end