Class: Aws::SageMaker::Types::EFSFileSystemConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::EFSFileSystemConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The settings for assigning a custom Amazon EFS file system to a user profile or space for an Amazon SageMaker AI Domain.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#file_system_id ⇒ String
The ID of your Amazon EFS file system.
-
#file_system_path ⇒ String
The path to the file system directory that is accessible in Amazon SageMaker AI Studio.
Instance Attribute Details
#file_system_id ⇒ String
The ID of your Amazon EFS file system.
25202 25203 25204 25205 25206 25207 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 25202 class EFSFileSystemConfig < Struct.new( :file_system_id, :file_system_path) SENSITIVE = [] include Aws::Structure end |
#file_system_path ⇒ String
The path to the file system directory that is accessible in Amazon SageMaker AI Studio. Permitted users can access only this directory and below.
25202 25203 25204 25205 25206 25207 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 25202 class EFSFileSystemConfig < Struct.new( :file_system_id, :file_system_path) SENSITIVE = [] include Aws::Structure end |