Class: Aws::SageMaker::Types::EdgeDeploymentConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Contains information about the configuration of a deployment.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#failure_handling_policyString

Toggle that determines whether to rollback to previous configuration if the current deployment fails. By default this is turned on. You may turn this off if you want to investigate the errors yourself.

Returns:

  • (String)


24920
24921
24922
24923
24924
# File 'lib/aws-sdk-sagemaker/types.rb', line 24920

class EdgeDeploymentConfig < Struct.new(
  :failure_handling_policy)
  SENSITIVE = []
  include Aws::Structure
end