Class: Aws::SageMaker::Types::EdgeDeploymentConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::EdgeDeploymentConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Contains information about the configuration of a deployment.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#failure_handling_policy ⇒ String
Toggle that determines whether to rollback to previous configuration if the current deployment fails.
Instance Attribute Details
#failure_handling_policy ⇒ String
Toggle that determines whether to rollback to previous configuration if the current deployment fails. By default this is turned on. You may turn this off if you want to investigate the errors yourself.
23503 23504 23505 23506 23507 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 23503 class EdgeDeploymentConfig < Struct.new( :failure_handling_policy) SENSITIVE = [] include Aws::Structure end |