Class: Aws::SageMaker::Types::EmrServerlessSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::EmrServerlessSettings
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The settings for running Amazon EMR Serverless jobs in SageMaker Canvas.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Web Services IAM role that is assumed for running Amazon EMR Serverless jobs in SageMaker Canvas.
-
#status ⇒ String
Describes whether Amazon EMR Serverless job capabilities are enabled or disabled in the SageMaker Canvas application.
Instance Attribute Details
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Web Services IAM role that is assumed for running Amazon EMR Serverless jobs in SageMaker Canvas. This role should have the necessary permissions to read and write data attached and a trust relationship with EMR Serverless.
26290 26291 26292 26293 26294 26295 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26290 class EmrServerlessSettings < Struct.new( :execution_role_arn, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Describes whether Amazon EMR Serverless job capabilities are enabled or disabled in the SageMaker Canvas application.
26290 26291 26292 26293 26294 26295 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26290 class EmrServerlessSettings < Struct.new( :execution_role_arn, :status) SENSITIVE = [] include Aws::Structure end |