Class: Aws::SageMaker::Types::EmrServerlessSettings

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The settings for running Amazon EMR Serverless jobs in SageMaker Canvas.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#execution_role_arnString

The Amazon Resource Name (ARN) of the Amazon Web Services IAM role that is assumed for running Amazon EMR Serverless jobs in SageMaker Canvas. This role should have the necessary permissions to read and write data attached and a trust relationship with EMR Serverless.

Returns:

  • (String)


25878
25879
25880
25881
25882
25883
# File 'lib/aws-sdk-sagemaker/types.rb', line 25878

class EmrServerlessSettings < Struct.new(
  :execution_role_arn,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

Describes whether Amazon EMR Serverless job capabilities are enabled or disabled in the SageMaker Canvas application.

Returns:

  • (String)


25878
25879
25880
25881
25882
25883
# File 'lib/aws-sdk-sagemaker/types.rb', line 25878

class EmrServerlessSettings < Struct.new(
  :execution_role_arn,
  :status)
  SENSITIVE = []
  include Aws::Structure
end