Class: Aws::SageMaker::Types::EmrServerlessSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::EmrServerlessSettings
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The settings for running Amazon EMR Serverless jobs in SageMaker Canvas.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Web Services IAM role that is assumed for running Amazon EMR Serverless jobs in SageMaker Canvas.
-
#status ⇒ String
Describes whether Amazon EMR Serverless job capabilities are enabled or disabled in the SageMaker Canvas application.
Instance Attribute Details
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Web Services IAM role that is assumed for running Amazon EMR Serverless jobs in SageMaker Canvas. This role should have the necessary permissions to read and write data attached and a trust relationship with EMR Serverless.
24132 24133 24134 24135 24136 24137 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 24132 class EmrServerlessSettings < Struct.new( :execution_role_arn, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Describes whether Amazon EMR Serverless job capabilities are enabled or disabled in the SageMaker Canvas application.
24132 24133 24134 24135 24136 24137 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 24132 class EmrServerlessSettings < Struct.new( :execution_role_arn, :status) SENSITIVE = [] include Aws::Structure end |