Class: Aws::SageMaker::Types::Endpoint
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::Endpoint
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
A hosted endpoint for real-time inference.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Time
The time that the endpoint was created.
-
#data_capture_config ⇒ Types::DataCaptureConfigSummary
The currently active data capture configuration used by your Endpoint.
-
#endpoint_arn ⇒ String
The Amazon Resource Name (ARN) of the endpoint.
-
#endpoint_config_name ⇒ String
The endpoint configuration associated with the endpoint.
-
#endpoint_name ⇒ String
The name of the endpoint.
-
#endpoint_status ⇒ String
The status of the endpoint.
-
#failure_reason ⇒ String
If the endpoint failed, the reason it failed.
-
#last_modified_time ⇒ Time
The last time the endpoint was modified.
-
#monitoring_schedules ⇒ Array<Types::MonitoringSchedule>
A list of monitoring schedules for the endpoint.
-
#production_variants ⇒ Array<Types::ProductionVariantSummary>
A list of the production variants hosted on the endpoint.
-
#shadow_production_variants ⇒ Array<Types::ProductionVariantSummary>
A list of the shadow variants hosted on the endpoint.
-
#tags ⇒ Array<Types::Tag>
A list of the tags associated with the endpoint.
Instance Attribute Details
#creation_time ⇒ Time
The time that the endpoint was created.
26370 26371 26372 26373 26374 26375 26376 26377 26378 26379 26380 26381 26382 26383 26384 26385 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26370 class Endpoint < Struct.new( :endpoint_name, :endpoint_arn, :endpoint_config_name, :production_variants, :data_capture_config, :endpoint_status, :failure_reason, :creation_time, :last_modified_time, :monitoring_schedules, :tags, :shadow_production_variants) SENSITIVE = [] include Aws::Structure end |
#data_capture_config ⇒ Types::DataCaptureConfigSummary
The currently active data capture configuration used by your Endpoint.
26370 26371 26372 26373 26374 26375 26376 26377 26378 26379 26380 26381 26382 26383 26384 26385 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26370 class Endpoint < Struct.new( :endpoint_name, :endpoint_arn, :endpoint_config_name, :production_variants, :data_capture_config, :endpoint_status, :failure_reason, :creation_time, :last_modified_time, :monitoring_schedules, :tags, :shadow_production_variants) SENSITIVE = [] include Aws::Structure end |
#endpoint_arn ⇒ String
The Amazon Resource Name (ARN) of the endpoint.
26370 26371 26372 26373 26374 26375 26376 26377 26378 26379 26380 26381 26382 26383 26384 26385 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26370 class Endpoint < Struct.new( :endpoint_name, :endpoint_arn, :endpoint_config_name, :production_variants, :data_capture_config, :endpoint_status, :failure_reason, :creation_time, :last_modified_time, :monitoring_schedules, :tags, :shadow_production_variants) SENSITIVE = [] include Aws::Structure end |
#endpoint_config_name ⇒ String
The endpoint configuration associated with the endpoint.
26370 26371 26372 26373 26374 26375 26376 26377 26378 26379 26380 26381 26382 26383 26384 26385 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26370 class Endpoint < Struct.new( :endpoint_name, :endpoint_arn, :endpoint_config_name, :production_variants, :data_capture_config, :endpoint_status, :failure_reason, :creation_time, :last_modified_time, :monitoring_schedules, :tags, :shadow_production_variants) SENSITIVE = [] include Aws::Structure end |
#endpoint_name ⇒ String
The name of the endpoint.
26370 26371 26372 26373 26374 26375 26376 26377 26378 26379 26380 26381 26382 26383 26384 26385 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26370 class Endpoint < Struct.new( :endpoint_name, :endpoint_arn, :endpoint_config_name, :production_variants, :data_capture_config, :endpoint_status, :failure_reason, :creation_time, :last_modified_time, :monitoring_schedules, :tags, :shadow_production_variants) SENSITIVE = [] include Aws::Structure end |
#endpoint_status ⇒ String
The status of the endpoint.
26370 26371 26372 26373 26374 26375 26376 26377 26378 26379 26380 26381 26382 26383 26384 26385 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26370 class Endpoint < Struct.new( :endpoint_name, :endpoint_arn, :endpoint_config_name, :production_variants, :data_capture_config, :endpoint_status, :failure_reason, :creation_time, :last_modified_time, :monitoring_schedules, :tags, :shadow_production_variants) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
If the endpoint failed, the reason it failed.
26370 26371 26372 26373 26374 26375 26376 26377 26378 26379 26380 26381 26382 26383 26384 26385 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26370 class Endpoint < Struct.new( :endpoint_name, :endpoint_arn, :endpoint_config_name, :production_variants, :data_capture_config, :endpoint_status, :failure_reason, :creation_time, :last_modified_time, :monitoring_schedules, :tags, :shadow_production_variants) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The last time the endpoint was modified.
26370 26371 26372 26373 26374 26375 26376 26377 26378 26379 26380 26381 26382 26383 26384 26385 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26370 class Endpoint < Struct.new( :endpoint_name, :endpoint_arn, :endpoint_config_name, :production_variants, :data_capture_config, :endpoint_status, :failure_reason, :creation_time, :last_modified_time, :monitoring_schedules, :tags, :shadow_production_variants) SENSITIVE = [] include Aws::Structure end |
#monitoring_schedules ⇒ Array<Types::MonitoringSchedule>
A list of monitoring schedules for the endpoint. For information about model monitoring, see Amazon SageMaker Model Monitor.
26370 26371 26372 26373 26374 26375 26376 26377 26378 26379 26380 26381 26382 26383 26384 26385 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26370 class Endpoint < Struct.new( :endpoint_name, :endpoint_arn, :endpoint_config_name, :production_variants, :data_capture_config, :endpoint_status, :failure_reason, :creation_time, :last_modified_time, :monitoring_schedules, :tags, :shadow_production_variants) SENSITIVE = [] include Aws::Structure end |
#production_variants ⇒ Array<Types::ProductionVariantSummary>
A list of the production variants hosted on the endpoint. Each production variant is a model.
26370 26371 26372 26373 26374 26375 26376 26377 26378 26379 26380 26381 26382 26383 26384 26385 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26370 class Endpoint < Struct.new( :endpoint_name, :endpoint_arn, :endpoint_config_name, :production_variants, :data_capture_config, :endpoint_status, :failure_reason, :creation_time, :last_modified_time, :monitoring_schedules, :tags, :shadow_production_variants) SENSITIVE = [] include Aws::Structure end |
#shadow_production_variants ⇒ Array<Types::ProductionVariantSummary>
A list of the shadow variants hosted on the endpoint. Each shadow variant is a model in shadow mode with production traffic replicated from the production variant.
26370 26371 26372 26373 26374 26375 26376 26377 26378 26379 26380 26381 26382 26383 26384 26385 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26370 class Endpoint < Struct.new( :endpoint_name, :endpoint_arn, :endpoint_config_name, :production_variants, :data_capture_config, :endpoint_status, :failure_reason, :creation_time, :last_modified_time, :monitoring_schedules, :tags, :shadow_production_variants) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of the tags associated with the endpoint. For more information, see Tagging Amazon Web Services resources in the Amazon Web Services General Reference Guide.
26370 26371 26372 26373 26374 26375 26376 26377 26378 26379 26380 26381 26382 26383 26384 26385 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26370 class Endpoint < Struct.new( :endpoint_name, :endpoint_arn, :endpoint_config_name, :production_variants, :data_capture_config, :endpoint_status, :failure_reason, :creation_time, :last_modified_time, :monitoring_schedules, :tags, :shadow_production_variants) SENSITIVE = [] include Aws::Structure end |