Class: Aws::SageMaker::Types::EndpointInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::EndpointInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Input object for the endpoint
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end_time_offset ⇒ String
If specified, monitoring jobs substract this time from the end time.
-
#endpoint_name ⇒ String
An endpoint in customer's account which has enabled
DataCaptureConfigenabled. -
#exclude_features_attribute ⇒ String
The attributes of the input data to exclude from the analysis.
-
#features_attribute ⇒ String
The attributes of the input data that are the input features.
-
#inference_attribute ⇒ String
The attribute of the input data that represents the ground truth label.
-
#local_path ⇒ String
Path to the filesystem where the endpoint data is available to the container.
-
#probability_attribute ⇒ String
In a classification problem, the attribute that represents the class probability.
-
#probability_threshold_attribute ⇒ Float
The threshold for the class probability to be evaluated as a positive result.
-
#s3_data_distribution_type ⇒ String
Whether input data distributed in Amazon S3 is fully replicated or sharded by an Amazon S3 key.
-
#s3_input_mode ⇒ String
Whether the
PipeorFileis used as the input mode for transferring data for the monitoring job. -
#start_time_offset ⇒ String
If specified, monitoring jobs substract this time from the start time.
Instance Attribute Details
#end_time_offset ⇒ String
If specified, monitoring jobs substract this time from the end time. For information about using offsets for scheduling monitoring jobs, see Schedule Model Quality Monitoring Jobs.
26552 26553 26554 26555 26556 26557 26558 26559 26560 26561 26562 26563 26564 26565 26566 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26552 class EndpointInput < Struct.new( :endpoint_name, :local_path, :s3_input_mode, :s3_data_distribution_type, :features_attribute, :inference_attribute, :probability_attribute, :probability_threshold_attribute, :start_time_offset, :end_time_offset, :exclude_features_attribute) SENSITIVE = [] include Aws::Structure end |
#endpoint_name ⇒ String
An endpoint in customer's account which has enabled
DataCaptureConfig enabled.
26552 26553 26554 26555 26556 26557 26558 26559 26560 26561 26562 26563 26564 26565 26566 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26552 class EndpointInput < Struct.new( :endpoint_name, :local_path, :s3_input_mode, :s3_data_distribution_type, :features_attribute, :inference_attribute, :probability_attribute, :probability_threshold_attribute, :start_time_offset, :end_time_offset, :exclude_features_attribute) SENSITIVE = [] include Aws::Structure end |
#exclude_features_attribute ⇒ String
The attributes of the input data to exclude from the analysis.
26552 26553 26554 26555 26556 26557 26558 26559 26560 26561 26562 26563 26564 26565 26566 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26552 class EndpointInput < Struct.new( :endpoint_name, :local_path, :s3_input_mode, :s3_data_distribution_type, :features_attribute, :inference_attribute, :probability_attribute, :probability_threshold_attribute, :start_time_offset, :end_time_offset, :exclude_features_attribute) SENSITIVE = [] include Aws::Structure end |
#features_attribute ⇒ String
The attributes of the input data that are the input features.
26552 26553 26554 26555 26556 26557 26558 26559 26560 26561 26562 26563 26564 26565 26566 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26552 class EndpointInput < Struct.new( :endpoint_name, :local_path, :s3_input_mode, :s3_data_distribution_type, :features_attribute, :inference_attribute, :probability_attribute, :probability_threshold_attribute, :start_time_offset, :end_time_offset, :exclude_features_attribute) SENSITIVE = [] include Aws::Structure end |
#inference_attribute ⇒ String
The attribute of the input data that represents the ground truth label.
26552 26553 26554 26555 26556 26557 26558 26559 26560 26561 26562 26563 26564 26565 26566 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26552 class EndpointInput < Struct.new( :endpoint_name, :local_path, :s3_input_mode, :s3_data_distribution_type, :features_attribute, :inference_attribute, :probability_attribute, :probability_threshold_attribute, :start_time_offset, :end_time_offset, :exclude_features_attribute) SENSITIVE = [] include Aws::Structure end |
#local_path ⇒ String
Path to the filesystem where the endpoint data is available to the container.
26552 26553 26554 26555 26556 26557 26558 26559 26560 26561 26562 26563 26564 26565 26566 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26552 class EndpointInput < Struct.new( :endpoint_name, :local_path, :s3_input_mode, :s3_data_distribution_type, :features_attribute, :inference_attribute, :probability_attribute, :probability_threshold_attribute, :start_time_offset, :end_time_offset, :exclude_features_attribute) SENSITIVE = [] include Aws::Structure end |
#probability_attribute ⇒ String
In a classification problem, the attribute that represents the class probability.
26552 26553 26554 26555 26556 26557 26558 26559 26560 26561 26562 26563 26564 26565 26566 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26552 class EndpointInput < Struct.new( :endpoint_name, :local_path, :s3_input_mode, :s3_data_distribution_type, :features_attribute, :inference_attribute, :probability_attribute, :probability_threshold_attribute, :start_time_offset, :end_time_offset, :exclude_features_attribute) SENSITIVE = [] include Aws::Structure end |
#probability_threshold_attribute ⇒ Float
The threshold for the class probability to be evaluated as a positive result.
26552 26553 26554 26555 26556 26557 26558 26559 26560 26561 26562 26563 26564 26565 26566 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26552 class EndpointInput < Struct.new( :endpoint_name, :local_path, :s3_input_mode, :s3_data_distribution_type, :features_attribute, :inference_attribute, :probability_attribute, :probability_threshold_attribute, :start_time_offset, :end_time_offset, :exclude_features_attribute) SENSITIVE = [] include Aws::Structure end |
#s3_data_distribution_type ⇒ String
Whether input data distributed in Amazon S3 is fully replicated or
sharded by an Amazon S3 key. Defaults to FullyReplicated
26552 26553 26554 26555 26556 26557 26558 26559 26560 26561 26562 26563 26564 26565 26566 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26552 class EndpointInput < Struct.new( :endpoint_name, :local_path, :s3_input_mode, :s3_data_distribution_type, :features_attribute, :inference_attribute, :probability_attribute, :probability_threshold_attribute, :start_time_offset, :end_time_offset, :exclude_features_attribute) SENSITIVE = [] include Aws::Structure end |
#s3_input_mode ⇒ String
Whether the Pipe or File is used as the input mode for
transferring data for the monitoring job. Pipe mode is recommended
for large datasets. File mode is useful for small files that fit
in memory. Defaults to File.
26552 26553 26554 26555 26556 26557 26558 26559 26560 26561 26562 26563 26564 26565 26566 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26552 class EndpointInput < Struct.new( :endpoint_name, :local_path, :s3_input_mode, :s3_data_distribution_type, :features_attribute, :inference_attribute, :probability_attribute, :probability_threshold_attribute, :start_time_offset, :end_time_offset, :exclude_features_attribute) SENSITIVE = [] include Aws::Structure end |
#start_time_offset ⇒ String
If specified, monitoring jobs substract this time from the start time. For information about using offsets for scheduling monitoring jobs, see Schedule Model Quality Monitoring Jobs.
26552 26553 26554 26555 26556 26557 26558 26559 26560 26561 26562 26563 26564 26565 26566 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26552 class EndpointInput < Struct.new( :endpoint_name, :local_path, :s3_input_mode, :s3_data_distribution_type, :features_attribute, :inference_attribute, :probability_attribute, :probability_threshold_attribute, :start_time_offset, :end_time_offset, :exclude_features_attribute) SENSITIVE = [] include Aws::Structure end |