Class: Aws::SageMaker::Types::EndpointMetadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::EndpointMetadata
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The metadata of the endpoint.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#endpoint_config_name ⇒ String
The name of the endpoint configuration.
-
#endpoint_name ⇒ String
The name of the endpoint.
-
#endpoint_status ⇒ String
The status of the endpoint.
-
#failure_reason ⇒ String
If the status of the endpoint is
Failed, or the status isInServicebut update operation fails, this provides the reason why it failed.
Instance Attribute Details
#endpoint_config_name ⇒ String
The name of the endpoint configuration.
26580 26581 26582 26583 26584 26585 26586 26587 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26580 class EndpointMetadata < Struct.new( :endpoint_name, :endpoint_config_name, :endpoint_status, :failure_reason) SENSITIVE = [] include Aws::Structure end |
#endpoint_name ⇒ String
The name of the endpoint.
26580 26581 26582 26583 26584 26585 26586 26587 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26580 class EndpointMetadata < Struct.new( :endpoint_name, :endpoint_config_name, :endpoint_status, :failure_reason) SENSITIVE = [] include Aws::Structure end |
#endpoint_status ⇒ String
The status of the endpoint. For possible values of the status of an endpoint, see EndpointSummary.
26580 26581 26582 26583 26584 26585 26586 26587 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26580 class EndpointMetadata < Struct.new( :endpoint_name, :endpoint_config_name, :endpoint_status, :failure_reason) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
If the status of the endpoint is Failed, or the status is
InService but update operation fails, this provides the reason why
it failed.
26580 26581 26582 26583 26584 26585 26586 26587 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26580 class EndpointMetadata < Struct.new( :endpoint_name, :endpoint_config_name, :endpoint_status, :failure_reason) SENSITIVE = [] include Aws::Structure end |