Class: Aws::SageMaker::Types::FeatureGroup
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::FeatureGroup
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Amazon SageMaker Feature Store stores features in a collection called Feature Group. A Feature Group can be visualized as a table which has rows, with a unique identifier for each row where each column in the table is a feature. In principle, a Feature Group is composed of features and values per features.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Time
The time a ‘FeatureGroup` was created.
-
#description ⇒ String
A free form description of a ‘FeatureGroup`.
-
#event_time_feature_name ⇒ String
The name of the feature that stores the ‘EventTime` of a Record in a `FeatureGroup`.
-
#failure_reason ⇒ String
The reason that the ‘FeatureGroup` failed to be replicated in the `OfflineStore`.
-
#feature_definitions ⇒ Array<Types::FeatureDefinition>
A list of ‘Feature`s.
-
#feature_group_arn ⇒ String
The Amazon Resource Name (ARN) of a ‘FeatureGroup`.
-
#feature_group_name ⇒ String
The name of the ‘FeatureGroup`.
-
#feature_group_status ⇒ String
A ‘FeatureGroup` status.
-
#last_modified_time ⇒ Time
A timestamp indicating the last time you updated the feature group.
-
#last_update_status ⇒ Types::LastUpdateStatus
A value that indicates whether the feature group was updated successfully.
-
#offline_store_config ⇒ Types::OfflineStoreConfig
The configuration of an ‘OfflineStore`.
-
#offline_store_status ⇒ Types::OfflineStoreStatus
The status of ‘OfflineStore`.
-
#online_store_config ⇒ Types::OnlineStoreConfig
Use this to specify the Amazon Web Services Key Management Service (KMS) Key ID, or ‘KMSKeyId`, for at rest data encryption.
-
#record_identifier_feature_name ⇒ String
The name of the ‘Feature` whose value uniquely identifies a `Record` defined in the `FeatureGroup` `FeatureDefinitions`.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM execution role used to create the feature group.
-
#tags ⇒ Array<Types::Tag>
Tags used to define a ‘FeatureGroup`.
Instance Attribute Details
#creation_time ⇒ Time
The time a ‘FeatureGroup` was created.
26477 26478 26479 26480 26481 26482 26483 26484 26485 26486 26487 26488 26489 26490 26491 26492 26493 26494 26495 26496 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26477 class FeatureGroup < Struct.new( :feature_group_arn, :feature_group_name, :record_identifier_feature_name, :event_time_feature_name, :feature_definitions, :creation_time, :last_modified_time, :online_store_config, :offline_store_config, :role_arn, :feature_group_status, :offline_store_status, :last_update_status, :failure_reason, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A free form description of a ‘FeatureGroup`.
26477 26478 26479 26480 26481 26482 26483 26484 26485 26486 26487 26488 26489 26490 26491 26492 26493 26494 26495 26496 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26477 class FeatureGroup < Struct.new( :feature_group_arn, :feature_group_name, :record_identifier_feature_name, :event_time_feature_name, :feature_definitions, :creation_time, :last_modified_time, :online_store_config, :offline_store_config, :role_arn, :feature_group_status, :offline_store_status, :last_update_status, :failure_reason, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#event_time_feature_name ⇒ String
The name of the feature that stores the ‘EventTime` of a Record in a `FeatureGroup`.
A ‘EventTime` is point in time when a new event occurs that corresponds to the creation or update of a `Record` in `FeatureGroup`. All `Records` in the `FeatureGroup` must have a corresponding `EventTime`.
26477 26478 26479 26480 26481 26482 26483 26484 26485 26486 26487 26488 26489 26490 26491 26492 26493 26494 26495 26496 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26477 class FeatureGroup < Struct.new( :feature_group_arn, :feature_group_name, :record_identifier_feature_name, :event_time_feature_name, :feature_definitions, :creation_time, :last_modified_time, :online_store_config, :offline_store_config, :role_arn, :feature_group_status, :offline_store_status, :last_update_status, :failure_reason, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
The reason that the ‘FeatureGroup` failed to be replicated in the `OfflineStore`. This is failure may be due to a failure to create a `FeatureGroup` in or delete a `FeatureGroup` from the `OfflineStore`.
26477 26478 26479 26480 26481 26482 26483 26484 26485 26486 26487 26488 26489 26490 26491 26492 26493 26494 26495 26496 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26477 class FeatureGroup < Struct.new( :feature_group_arn, :feature_group_name, :record_identifier_feature_name, :event_time_feature_name, :feature_definitions, :creation_time, :last_modified_time, :online_store_config, :offline_store_config, :role_arn, :feature_group_status, :offline_store_status, :last_update_status, :failure_reason, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#feature_definitions ⇒ Array<Types::FeatureDefinition>
A list of ‘Feature`s. Each `Feature` must include a `FeatureName` and a `FeatureType`.
Valid ‘FeatureType`s are `Integral`, `Fractional` and `String`.
‘FeatureName`s cannot be any of the following: `is_deleted`, `write_time`, `api_invocation_time`.
You can create up to 2,500 ‘FeatureDefinition`s per `FeatureGroup`.
26477 26478 26479 26480 26481 26482 26483 26484 26485 26486 26487 26488 26489 26490 26491 26492 26493 26494 26495 26496 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26477 class FeatureGroup < Struct.new( :feature_group_arn, :feature_group_name, :record_identifier_feature_name, :event_time_feature_name, :feature_definitions, :creation_time, :last_modified_time, :online_store_config, :offline_store_config, :role_arn, :feature_group_status, :offline_store_status, :last_update_status, :failure_reason, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#feature_group_arn ⇒ String
The Amazon Resource Name (ARN) of a ‘FeatureGroup`.
26477 26478 26479 26480 26481 26482 26483 26484 26485 26486 26487 26488 26489 26490 26491 26492 26493 26494 26495 26496 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26477 class FeatureGroup < Struct.new( :feature_group_arn, :feature_group_name, :record_identifier_feature_name, :event_time_feature_name, :feature_definitions, :creation_time, :last_modified_time, :online_store_config, :offline_store_config, :role_arn, :feature_group_status, :offline_store_status, :last_update_status, :failure_reason, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#feature_group_name ⇒ String
The name of the ‘FeatureGroup`.
26477 26478 26479 26480 26481 26482 26483 26484 26485 26486 26487 26488 26489 26490 26491 26492 26493 26494 26495 26496 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26477 class FeatureGroup < Struct.new( :feature_group_arn, :feature_group_name, :record_identifier_feature_name, :event_time_feature_name, :feature_definitions, :creation_time, :last_modified_time, :online_store_config, :offline_store_config, :role_arn, :feature_group_status, :offline_store_status, :last_update_status, :failure_reason, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#feature_group_status ⇒ String
A ‘FeatureGroup` status.
26477 26478 26479 26480 26481 26482 26483 26484 26485 26486 26487 26488 26489 26490 26491 26492 26493 26494 26495 26496 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26477 class FeatureGroup < Struct.new( :feature_group_arn, :feature_group_name, :record_identifier_feature_name, :event_time_feature_name, :feature_definitions, :creation_time, :last_modified_time, :online_store_config, :offline_store_config, :role_arn, :feature_group_status, :offline_store_status, :last_update_status, :failure_reason, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
A timestamp indicating the last time you updated the feature group.
26477 26478 26479 26480 26481 26482 26483 26484 26485 26486 26487 26488 26489 26490 26491 26492 26493 26494 26495 26496 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26477 class FeatureGroup < Struct.new( :feature_group_arn, :feature_group_name, :record_identifier_feature_name, :event_time_feature_name, :feature_definitions, :creation_time, :last_modified_time, :online_store_config, :offline_store_config, :role_arn, :feature_group_status, :offline_store_status, :last_update_status, :failure_reason, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#last_update_status ⇒ Types::LastUpdateStatus
A value that indicates whether the feature group was updated successfully.
26477 26478 26479 26480 26481 26482 26483 26484 26485 26486 26487 26488 26489 26490 26491 26492 26493 26494 26495 26496 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26477 class FeatureGroup < Struct.new( :feature_group_arn, :feature_group_name, :record_identifier_feature_name, :event_time_feature_name, :feature_definitions, :creation_time, :last_modified_time, :online_store_config, :offline_store_config, :role_arn, :feature_group_status, :offline_store_status, :last_update_status, :failure_reason, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#offline_store_config ⇒ Types::OfflineStoreConfig
The configuration of an ‘OfflineStore`.
Provide an ‘OfflineStoreConfig` in a request to `CreateFeatureGroup` to create an `OfflineStore`.
To encrypt an ‘OfflineStore` using at rest data encryption, specify Amazon Web Services Key Management Service (KMS) key ID, or `KMSKeyId`, in `S3StorageConfig`.
26477 26478 26479 26480 26481 26482 26483 26484 26485 26486 26487 26488 26489 26490 26491 26492 26493 26494 26495 26496 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26477 class FeatureGroup < Struct.new( :feature_group_arn, :feature_group_name, :record_identifier_feature_name, :event_time_feature_name, :feature_definitions, :creation_time, :last_modified_time, :online_store_config, :offline_store_config, :role_arn, :feature_group_status, :offline_store_status, :last_update_status, :failure_reason, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#offline_store_status ⇒ Types::OfflineStoreStatus
The status of ‘OfflineStore`.
26477 26478 26479 26480 26481 26482 26483 26484 26485 26486 26487 26488 26489 26490 26491 26492 26493 26494 26495 26496 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26477 class FeatureGroup < Struct.new( :feature_group_arn, :feature_group_name, :record_identifier_feature_name, :event_time_feature_name, :feature_definitions, :creation_time, :last_modified_time, :online_store_config, :offline_store_config, :role_arn, :feature_group_status, :offline_store_status, :last_update_status, :failure_reason, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#online_store_config ⇒ Types::OnlineStoreConfig
Use this to specify the Amazon Web Services Key Management Service (KMS) Key ID, or ‘KMSKeyId`, for at rest data encryption. You can turn `OnlineStore` on or off by specifying the `EnableOnlineStore` flag at General Assembly.
The default value is ‘False`.
26477 26478 26479 26480 26481 26482 26483 26484 26485 26486 26487 26488 26489 26490 26491 26492 26493 26494 26495 26496 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26477 class FeatureGroup < Struct.new( :feature_group_arn, :feature_group_name, :record_identifier_feature_name, :event_time_feature_name, :feature_definitions, :creation_time, :last_modified_time, :online_store_config, :offline_store_config, :role_arn, :feature_group_status, :offline_store_status, :last_update_status, :failure_reason, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#record_identifier_feature_name ⇒ String
The name of the ‘Feature` whose value uniquely identifies a `Record` defined in the `FeatureGroup` `FeatureDefinitions`.
26477 26478 26479 26480 26481 26482 26483 26484 26485 26486 26487 26488 26489 26490 26491 26492 26493 26494 26495 26496 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26477 class FeatureGroup < Struct.new( :feature_group_arn, :feature_group_name, :record_identifier_feature_name, :event_time_feature_name, :feature_definitions, :creation_time, :last_modified_time, :online_store_config, :offline_store_config, :role_arn, :feature_group_status, :offline_store_status, :last_update_status, :failure_reason, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM execution role used to create the feature group.
26477 26478 26479 26480 26481 26482 26483 26484 26485 26486 26487 26488 26489 26490 26491 26492 26493 26494 26495 26496 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26477 class FeatureGroup < Struct.new( :feature_group_arn, :feature_group_name, :record_identifier_feature_name, :event_time_feature_name, :feature_definitions, :creation_time, :last_modified_time, :online_store_config, :offline_store_config, :role_arn, :feature_group_status, :offline_store_status, :last_update_status, :failure_reason, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Tags used to define a ‘FeatureGroup`.
26477 26478 26479 26480 26481 26482 26483 26484 26485 26486 26487 26488 26489 26490 26491 26492 26493 26494 26495 26496 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26477 class FeatureGroup < Struct.new( :feature_group_arn, :feature_group_name, :record_identifier_feature_name, :event_time_feature_name, :feature_definitions, :creation_time, :last_modified_time, :online_store_config, :offline_store_config, :role_arn, :feature_group_status, :offline_store_status, :last_update_status, :failure_reason, :description, :tags) SENSITIVE = [] include Aws::Structure end |