Method: Aws::SageMaker::Types::FinalAutoMLJobObjectiveMetric#metric_name
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
#metric_name ⇒ String
The name of the metric with the best result. For a description of the possible objective metrics, see [AutoMLJobObjective$MetricName].
[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_AutoMLJobObjective.html
25410 25411 25412 25413 25414 25415 25416 25417 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 25410 class FinalAutoMLJobObjectiveMetric < Struct.new( :type, :metric_name, :value, :standard_metric_name) SENSITIVE = [] include Aws::Structure end |