Class: Aws::SageMaker::Types::HolidayConfigAttributes

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Stores the holiday featurization attributes applicable to each item of time-series datasets during the training of a forecasting model. This allows the model to identify patterns associated with specific holidays.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#country_codeString

The country code for the holiday calendar.

For the list of public holiday calendars supported by AutoML job V2, see Country Codes. Use the country code corresponding to the country of your choice.

Returns:

  • (String)


28258
28259
28260
28261
28262
# File 'lib/aws-sdk-sagemaker/types.rb', line 28258

class HolidayConfigAttributes < Struct.new(
  :country_code)
  SENSITIVE = []
  include Aws::Structure
end