Class: Aws::SageMaker::Types::HubContentInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::HubContentInfo
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Information about hub content.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Time
The date and time that the hub content was created.
-
#document_schema_version ⇒ String
The version of the hub content document schema.
-
#hub_content_arn ⇒ String
The Amazon Resource Name (ARN) of the hub content.
-
#hub_content_description ⇒ String
A description of the hub content.
-
#hub_content_display_name ⇒ String
The display name of the hub content.
-
#hub_content_name ⇒ String
The name of the hub content.
-
#hub_content_search_keywords ⇒ Array<String>
The searchable keywords for the hub content.
-
#hub_content_status ⇒ String
The status of the hub content.
-
#hub_content_type ⇒ String
The type of hub content.
-
#hub_content_version ⇒ String
The version of the hub content.
-
#original_creation_time ⇒ Time
The date and time when the hub content was originally created, before any updates or revisions.
-
#sage_maker_public_hub_content_arn ⇒ String
The ARN of the public hub content.
-
#support_status ⇒ String
The support status of the hub content.
Instance Attribute Details
#creation_time ⇒ Time
The date and time that the hub content was created.
27851 27852 27853 27854 27855 27856 27857 27858 27859 27860 27861 27862 27863 27864 27865 27866 27867 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27851 class HubContentInfo < Struct.new( :hub_content_name, :hub_content_arn, :sage_maker_public_hub_content_arn, :hub_content_version, :hub_content_type, :document_schema_version, :hub_content_display_name, :hub_content_description, :support_status, :hub_content_search_keywords, :hub_content_status, :creation_time, :original_creation_time) SENSITIVE = [] include Aws::Structure end |
#document_schema_version ⇒ String
The version of the hub content document schema.
27851 27852 27853 27854 27855 27856 27857 27858 27859 27860 27861 27862 27863 27864 27865 27866 27867 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27851 class HubContentInfo < Struct.new( :hub_content_name, :hub_content_arn, :sage_maker_public_hub_content_arn, :hub_content_version, :hub_content_type, :document_schema_version, :hub_content_display_name, :hub_content_description, :support_status, :hub_content_search_keywords, :hub_content_status, :creation_time, :original_creation_time) SENSITIVE = [] include Aws::Structure end |
#hub_content_arn ⇒ String
The Amazon Resource Name (ARN) of the hub content.
27851 27852 27853 27854 27855 27856 27857 27858 27859 27860 27861 27862 27863 27864 27865 27866 27867 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27851 class HubContentInfo < Struct.new( :hub_content_name, :hub_content_arn, :sage_maker_public_hub_content_arn, :hub_content_version, :hub_content_type, :document_schema_version, :hub_content_display_name, :hub_content_description, :support_status, :hub_content_search_keywords, :hub_content_status, :creation_time, :original_creation_time) SENSITIVE = [] include Aws::Structure end |
#hub_content_description ⇒ String
A description of the hub content.
27851 27852 27853 27854 27855 27856 27857 27858 27859 27860 27861 27862 27863 27864 27865 27866 27867 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27851 class HubContentInfo < Struct.new( :hub_content_name, :hub_content_arn, :sage_maker_public_hub_content_arn, :hub_content_version, :hub_content_type, :document_schema_version, :hub_content_display_name, :hub_content_description, :support_status, :hub_content_search_keywords, :hub_content_status, :creation_time, :original_creation_time) SENSITIVE = [] include Aws::Structure end |
#hub_content_display_name ⇒ String
The display name of the hub content.
27851 27852 27853 27854 27855 27856 27857 27858 27859 27860 27861 27862 27863 27864 27865 27866 27867 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27851 class HubContentInfo < Struct.new( :hub_content_name, :hub_content_arn, :sage_maker_public_hub_content_arn, :hub_content_version, :hub_content_type, :document_schema_version, :hub_content_display_name, :hub_content_description, :support_status, :hub_content_search_keywords, :hub_content_status, :creation_time, :original_creation_time) SENSITIVE = [] include Aws::Structure end |
#hub_content_name ⇒ String
The name of the hub content.
27851 27852 27853 27854 27855 27856 27857 27858 27859 27860 27861 27862 27863 27864 27865 27866 27867 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27851 class HubContentInfo < Struct.new( :hub_content_name, :hub_content_arn, :sage_maker_public_hub_content_arn, :hub_content_version, :hub_content_type, :document_schema_version, :hub_content_display_name, :hub_content_description, :support_status, :hub_content_search_keywords, :hub_content_status, :creation_time, :original_creation_time) SENSITIVE = [] include Aws::Structure end |
#hub_content_search_keywords ⇒ Array<String>
The searchable keywords for the hub content.
27851 27852 27853 27854 27855 27856 27857 27858 27859 27860 27861 27862 27863 27864 27865 27866 27867 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27851 class HubContentInfo < Struct.new( :hub_content_name, :hub_content_arn, :sage_maker_public_hub_content_arn, :hub_content_version, :hub_content_type, :document_schema_version, :hub_content_display_name, :hub_content_description, :support_status, :hub_content_search_keywords, :hub_content_status, :creation_time, :original_creation_time) SENSITIVE = [] include Aws::Structure end |
#hub_content_status ⇒ String
The status of the hub content.
27851 27852 27853 27854 27855 27856 27857 27858 27859 27860 27861 27862 27863 27864 27865 27866 27867 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27851 class HubContentInfo < Struct.new( :hub_content_name, :hub_content_arn, :sage_maker_public_hub_content_arn, :hub_content_version, :hub_content_type, :document_schema_version, :hub_content_display_name, :hub_content_description, :support_status, :hub_content_search_keywords, :hub_content_status, :creation_time, :original_creation_time) SENSITIVE = [] include Aws::Structure end |
#hub_content_type ⇒ String
The type of hub content.
27851 27852 27853 27854 27855 27856 27857 27858 27859 27860 27861 27862 27863 27864 27865 27866 27867 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27851 class HubContentInfo < Struct.new( :hub_content_name, :hub_content_arn, :sage_maker_public_hub_content_arn, :hub_content_version, :hub_content_type, :document_schema_version, :hub_content_display_name, :hub_content_description, :support_status, :hub_content_search_keywords, :hub_content_status, :creation_time, :original_creation_time) SENSITIVE = [] include Aws::Structure end |
#hub_content_version ⇒ String
The version of the hub content.
27851 27852 27853 27854 27855 27856 27857 27858 27859 27860 27861 27862 27863 27864 27865 27866 27867 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27851 class HubContentInfo < Struct.new( :hub_content_name, :hub_content_arn, :sage_maker_public_hub_content_arn, :hub_content_version, :hub_content_type, :document_schema_version, :hub_content_display_name, :hub_content_description, :support_status, :hub_content_search_keywords, :hub_content_status, :creation_time, :original_creation_time) SENSITIVE = [] include Aws::Structure end |
#original_creation_time ⇒ Time
The date and time when the hub content was originally created, before any updates or revisions.
27851 27852 27853 27854 27855 27856 27857 27858 27859 27860 27861 27862 27863 27864 27865 27866 27867 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27851 class HubContentInfo < Struct.new( :hub_content_name, :hub_content_arn, :sage_maker_public_hub_content_arn, :hub_content_version, :hub_content_type, :document_schema_version, :hub_content_display_name, :hub_content_description, :support_status, :hub_content_search_keywords, :hub_content_status, :creation_time, :original_creation_time) SENSITIVE = [] include Aws::Structure end |
#sage_maker_public_hub_content_arn ⇒ String
The ARN of the public hub content.
27851 27852 27853 27854 27855 27856 27857 27858 27859 27860 27861 27862 27863 27864 27865 27866 27867 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27851 class HubContentInfo < Struct.new( :hub_content_name, :hub_content_arn, :sage_maker_public_hub_content_arn, :hub_content_version, :hub_content_type, :document_schema_version, :hub_content_display_name, :hub_content_description, :support_status, :hub_content_search_keywords, :hub_content_status, :creation_time, :original_creation_time) SENSITIVE = [] include Aws::Structure end |
#support_status ⇒ String
The support status of the hub content.
27851 27852 27853 27854 27855 27856 27857 27858 27859 27860 27861 27862 27863 27864 27865 27866 27867 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27851 class HubContentInfo < Struct.new( :hub_content_name, :hub_content_arn, :sage_maker_public_hub_content_arn, :hub_content_version, :hub_content_type, :document_schema_version, :hub_content_display_name, :hub_content_description, :support_status, :hub_content_search_keywords, :hub_content_status, :creation_time, :original_creation_time) SENSITIVE = [] include Aws::Structure end |