Class: Aws::SageMaker::Types::HumanLoopRequestSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::HumanLoopRequestSource
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Container for configuring the source of human task requests.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_managed_human_loop_request_source ⇒ String
Specifies whether Amazon Rekognition or Amazon Textract are used as the integration source.
Instance Attribute Details
#aws_managed_human_loop_request_source ⇒ String
Specifies whether Amazon Rekognition or Amazon Textract are used as the integration source. The default field settings and JSON parsing rules are different based on the integration source. Valid values:
28057 28058 28059 28060 28061 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 28057 class HumanLoopRequestSource < Struct.new( :aws_managed_human_loop_request_source) SENSITIVE = [] include Aws::Structure end |