Class: Aws::SageMaker::Types::HumanLoopRequestSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::HumanLoopRequestSource
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Container for configuring the source of human task requests.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_managed_human_loop_request_source ⇒ String
Specifies whether Amazon Rekognition or Amazon Textract are used as the integration source.
Instance Attribute Details
#aws_managed_human_loop_request_source ⇒ String
Specifies whether Amazon Rekognition or Amazon Textract are used as the integration source. The default field settings and JSON parsing rules are different based on the integration source. Valid values:
27908 27909 27910 27911 27912 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27908 class HumanLoopRequestSource < Struct.new( :aws_managed_human_loop_request_source) SENSITIVE = [] include Aws::Structure end |