Class: Aws::SageMaker::Types::HumanLoopRequestSource

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Container for configuring the source of human task requests.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_managed_human_loop_request_sourceString

Specifies whether Amazon Rekognition or Amazon Textract are used as the integration source. The default field settings and JSON parsing rules are different based on the integration source. Valid values:

Returns:

  • (String)


27873
27874
27875
27876
27877
# File 'lib/aws-sdk-sagemaker/types.rb', line 27873

class HumanLoopRequestSource < Struct.new(
  :aws_managed_human_loop_request_source)
  SENSITIVE = []
  include Aws::Structure
end