Class: Aws::SageMaker::Types::HyperParameterTuningJobSummary

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Provides summary information about a hyperparameter tuning job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timeTime

The date and time that the tuning job was created.

Returns:

  • (Time)


30478
30479
30480
30481
30482
30483
30484
30485
30486
30487
30488
30489
30490
30491
# File 'lib/aws-sdk-sagemaker/types.rb', line 30478

class HyperParameterTuningJobSummary < Struct.new(
  :hyper_parameter_tuning_job_name,
  :hyper_parameter_tuning_job_arn,
  :hyper_parameter_tuning_job_status,
  :strategy,
  :creation_time,
  :hyper_parameter_tuning_end_time,
  :last_modified_time,
  :training_job_status_counters,
  :objective_status_counters,
  :resource_limits)
  SENSITIVE = []
  include Aws::Structure
end

#hyper_parameter_tuning_end_timeTime

The date and time that the tuning job ended.

Returns:

  • (Time)


30478
30479
30480
30481
30482
30483
30484
30485
30486
30487
30488
30489
30490
30491
# File 'lib/aws-sdk-sagemaker/types.rb', line 30478

class HyperParameterTuningJobSummary < Struct.new(
  :hyper_parameter_tuning_job_name,
  :hyper_parameter_tuning_job_arn,
  :hyper_parameter_tuning_job_status,
  :strategy,
  :creation_time,
  :hyper_parameter_tuning_end_time,
  :last_modified_time,
  :training_job_status_counters,
  :objective_status_counters,
  :resource_limits)
  SENSITIVE = []
  include Aws::Structure
end

#hyper_parameter_tuning_job_arnString

The Amazon Resource Name (ARN) of the tuning job.

Returns:

  • (String)


30478
30479
30480
30481
30482
30483
30484
30485
30486
30487
30488
30489
30490
30491
# File 'lib/aws-sdk-sagemaker/types.rb', line 30478

class HyperParameterTuningJobSummary < Struct.new(
  :hyper_parameter_tuning_job_name,
  :hyper_parameter_tuning_job_arn,
  :hyper_parameter_tuning_job_status,
  :strategy,
  :creation_time,
  :hyper_parameter_tuning_end_time,
  :last_modified_time,
  :training_job_status_counters,
  :objective_status_counters,
  :resource_limits)
  SENSITIVE = []
  include Aws::Structure
end

#hyper_parameter_tuning_job_nameString

The name of the tuning job.

Returns:

  • (String)


30478
30479
30480
30481
30482
30483
30484
30485
30486
30487
30488
30489
30490
30491
# File 'lib/aws-sdk-sagemaker/types.rb', line 30478

class HyperParameterTuningJobSummary < Struct.new(
  :hyper_parameter_tuning_job_name,
  :hyper_parameter_tuning_job_arn,
  :hyper_parameter_tuning_job_status,
  :strategy,
  :creation_time,
  :hyper_parameter_tuning_end_time,
  :last_modified_time,
  :training_job_status_counters,
  :objective_status_counters,
  :resource_limits)
  SENSITIVE = []
  include Aws::Structure
end

#hyper_parameter_tuning_job_statusString

The status of the tuning job.

Returns:

  • (String)


30478
30479
30480
30481
30482
30483
30484
30485
30486
30487
30488
30489
30490
30491
# File 'lib/aws-sdk-sagemaker/types.rb', line 30478

class HyperParameterTuningJobSummary < Struct.new(
  :hyper_parameter_tuning_job_name,
  :hyper_parameter_tuning_job_arn,
  :hyper_parameter_tuning_job_status,
  :strategy,
  :creation_time,
  :hyper_parameter_tuning_end_time,
  :last_modified_time,
  :training_job_status_counters,
  :objective_status_counters,
  :resource_limits)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The date and time that the tuning job was modified.

Returns:

  • (Time)


30478
30479
30480
30481
30482
30483
30484
30485
30486
30487
30488
30489
30490
30491
# File 'lib/aws-sdk-sagemaker/types.rb', line 30478

class HyperParameterTuningJobSummary < Struct.new(
  :hyper_parameter_tuning_job_name,
  :hyper_parameter_tuning_job_arn,
  :hyper_parameter_tuning_job_status,
  :strategy,
  :creation_time,
  :hyper_parameter_tuning_end_time,
  :last_modified_time,
  :training_job_status_counters,
  :objective_status_counters,
  :resource_limits)
  SENSITIVE = []
  include Aws::Structure
end

#objective_status_countersTypes::ObjectiveStatusCounters

The ObjectiveStatusCounters object that specifies the numbers of training jobs, categorized by objective metric status, that this tuning job launched.



30478
30479
30480
30481
30482
30483
30484
30485
30486
30487
30488
30489
30490
30491
# File 'lib/aws-sdk-sagemaker/types.rb', line 30478

class HyperParameterTuningJobSummary < Struct.new(
  :hyper_parameter_tuning_job_name,
  :hyper_parameter_tuning_job_arn,
  :hyper_parameter_tuning_job_status,
  :strategy,
  :creation_time,
  :hyper_parameter_tuning_end_time,
  :last_modified_time,
  :training_job_status_counters,
  :objective_status_counters,
  :resource_limits)
  SENSITIVE = []
  include Aws::Structure
end

#resource_limitsTypes::ResourceLimits

The ResourceLimits object that specifies the maximum number of training jobs and parallel training jobs allowed for this tuning job.



30478
30479
30480
30481
30482
30483
30484
30485
30486
30487
30488
30489
30490
30491
# File 'lib/aws-sdk-sagemaker/types.rb', line 30478

class HyperParameterTuningJobSummary < Struct.new(
  :hyper_parameter_tuning_job_name,
  :hyper_parameter_tuning_job_arn,
  :hyper_parameter_tuning_job_status,
  :strategy,
  :creation_time,
  :hyper_parameter_tuning_end_time,
  :last_modified_time,
  :training_job_status_counters,
  :objective_status_counters,
  :resource_limits)
  SENSITIVE = []
  include Aws::Structure
end

#strategyString

Specifies the search strategy hyperparameter tuning uses to choose which hyperparameters to evaluate at each iteration.

Returns:

  • (String)


30478
30479
30480
30481
30482
30483
30484
30485
30486
30487
30488
30489
30490
30491
# File 'lib/aws-sdk-sagemaker/types.rb', line 30478

class HyperParameterTuningJobSummary < Struct.new(
  :hyper_parameter_tuning_job_name,
  :hyper_parameter_tuning_job_arn,
  :hyper_parameter_tuning_job_status,
  :strategy,
  :creation_time,
  :hyper_parameter_tuning_end_time,
  :last_modified_time,
  :training_job_status_counters,
  :objective_status_counters,
  :resource_limits)
  SENSITIVE = []
  include Aws::Structure
end

#training_job_status_countersTypes::TrainingJobStatusCounters

The TrainingJobStatusCounters object that specifies the numbers of training jobs, categorized by status, that this tuning job launched.



30478
30479
30480
30481
30482
30483
30484
30485
30486
30487
30488
30489
30490
30491
# File 'lib/aws-sdk-sagemaker/types.rb', line 30478

class HyperParameterTuningJobSummary < Struct.new(
  :hyper_parameter_tuning_job_name,
  :hyper_parameter_tuning_job_arn,
  :hyper_parameter_tuning_job_status,
  :strategy,
  :creation_time,
  :hyper_parameter_tuning_end_time,
  :last_modified_time,
  :training_job_status_counters,
  :objective_status_counters,
  :resource_limits)
  SENSITIVE = []
  include Aws::Structure
end