Class: Aws::SageMaker::Types::HyperParameterTuningJobSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::HyperParameterTuningJobSummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Provides summary information about a hyperparameter tuning job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Time
The date and time that the tuning job was created.
-
#hyper_parameter_tuning_end_time ⇒ Time
The date and time that the tuning job ended.
-
#hyper_parameter_tuning_job_arn ⇒ String
The Amazon Resource Name (ARN) of the tuning job.
-
#hyper_parameter_tuning_job_name ⇒ String
The name of the tuning job.
-
#hyper_parameter_tuning_job_status ⇒ String
The status of the tuning job.
-
#last_modified_time ⇒ Time
The date and time that the tuning job was modified.
-
#objective_status_counters ⇒ Types::ObjectiveStatusCounters
The [ObjectiveStatusCounters] object that specifies the numbers of training jobs, categorized by objective metric status, that this tuning job launched.
-
#resource_limits ⇒ Types::ResourceLimits
The [ResourceLimits] object that specifies the maximum number of training jobs and parallel training jobs allowed for this tuning job.
-
#strategy ⇒ String
Specifies the search strategy hyperparameter tuning uses to choose which hyperparameters to evaluate at each iteration.
-
#training_job_status_counters ⇒ Types::TrainingJobStatusCounters
The [TrainingJobStatusCounters] object that specifies the numbers of training jobs, categorized by status, that this tuning job launched.
Instance Attribute Details
#creation_time ⇒ Time
The date and time that the tuning job was created.
30108 30109 30110 30111 30112 30113 30114 30115 30116 30117 30118 30119 30120 30121 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30108 class HyperParameterTuningJobSummary < Struct.new( :hyper_parameter_tuning_job_name, :hyper_parameter_tuning_job_arn, :hyper_parameter_tuning_job_status, :strategy, :creation_time, :hyper_parameter_tuning_end_time, :last_modified_time, :training_job_status_counters, :objective_status_counters, :resource_limits) SENSITIVE = [] include Aws::Structure end |
#hyper_parameter_tuning_end_time ⇒ Time
The date and time that the tuning job ended.
30108 30109 30110 30111 30112 30113 30114 30115 30116 30117 30118 30119 30120 30121 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30108 class HyperParameterTuningJobSummary < Struct.new( :hyper_parameter_tuning_job_name, :hyper_parameter_tuning_job_arn, :hyper_parameter_tuning_job_status, :strategy, :creation_time, :hyper_parameter_tuning_end_time, :last_modified_time, :training_job_status_counters, :objective_status_counters, :resource_limits) SENSITIVE = [] include Aws::Structure end |
#hyper_parameter_tuning_job_arn ⇒ String
The Amazon Resource Name (ARN) of the tuning job.
30108 30109 30110 30111 30112 30113 30114 30115 30116 30117 30118 30119 30120 30121 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30108 class HyperParameterTuningJobSummary < Struct.new( :hyper_parameter_tuning_job_name, :hyper_parameter_tuning_job_arn, :hyper_parameter_tuning_job_status, :strategy, :creation_time, :hyper_parameter_tuning_end_time, :last_modified_time, :training_job_status_counters, :objective_status_counters, :resource_limits) SENSITIVE = [] include Aws::Structure end |
#hyper_parameter_tuning_job_name ⇒ String
The name of the tuning job.
30108 30109 30110 30111 30112 30113 30114 30115 30116 30117 30118 30119 30120 30121 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30108 class HyperParameterTuningJobSummary < Struct.new( :hyper_parameter_tuning_job_name, :hyper_parameter_tuning_job_arn, :hyper_parameter_tuning_job_status, :strategy, :creation_time, :hyper_parameter_tuning_end_time, :last_modified_time, :training_job_status_counters, :objective_status_counters, :resource_limits) SENSITIVE = [] include Aws::Structure end |
#hyper_parameter_tuning_job_status ⇒ String
The status of the tuning job.
30108 30109 30110 30111 30112 30113 30114 30115 30116 30117 30118 30119 30120 30121 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30108 class HyperParameterTuningJobSummary < Struct.new( :hyper_parameter_tuning_job_name, :hyper_parameter_tuning_job_arn, :hyper_parameter_tuning_job_status, :strategy, :creation_time, :hyper_parameter_tuning_end_time, :last_modified_time, :training_job_status_counters, :objective_status_counters, :resource_limits) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The date and time that the tuning job was modified.
30108 30109 30110 30111 30112 30113 30114 30115 30116 30117 30118 30119 30120 30121 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30108 class HyperParameterTuningJobSummary < Struct.new( :hyper_parameter_tuning_job_name, :hyper_parameter_tuning_job_arn, :hyper_parameter_tuning_job_status, :strategy, :creation_time, :hyper_parameter_tuning_end_time, :last_modified_time, :training_job_status_counters, :objective_status_counters, :resource_limits) SENSITIVE = [] include Aws::Structure end |
#objective_status_counters ⇒ Types::ObjectiveStatusCounters
The [ObjectiveStatusCounters] object that specifies the numbers of training jobs, categorized by objective metric status, that this tuning job launched.
[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_ObjectiveStatusCounters.html
30108 30109 30110 30111 30112 30113 30114 30115 30116 30117 30118 30119 30120 30121 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30108 class HyperParameterTuningJobSummary < Struct.new( :hyper_parameter_tuning_job_name, :hyper_parameter_tuning_job_arn, :hyper_parameter_tuning_job_status, :strategy, :creation_time, :hyper_parameter_tuning_end_time, :last_modified_time, :training_job_status_counters, :objective_status_counters, :resource_limits) SENSITIVE = [] include Aws::Structure end |
#resource_limits ⇒ Types::ResourceLimits
The [ResourceLimits] object that specifies the maximum number of training jobs and parallel training jobs allowed for this tuning job.
[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_ResourceLimits.html
30108 30109 30110 30111 30112 30113 30114 30115 30116 30117 30118 30119 30120 30121 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30108 class HyperParameterTuningJobSummary < Struct.new( :hyper_parameter_tuning_job_name, :hyper_parameter_tuning_job_arn, :hyper_parameter_tuning_job_status, :strategy, :creation_time, :hyper_parameter_tuning_end_time, :last_modified_time, :training_job_status_counters, :objective_status_counters, :resource_limits) SENSITIVE = [] include Aws::Structure end |
#strategy ⇒ String
Specifies the search strategy hyperparameter tuning uses to choose which hyperparameters to evaluate at each iteration.
30108 30109 30110 30111 30112 30113 30114 30115 30116 30117 30118 30119 30120 30121 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30108 class HyperParameterTuningJobSummary < Struct.new( :hyper_parameter_tuning_job_name, :hyper_parameter_tuning_job_arn, :hyper_parameter_tuning_job_status, :strategy, :creation_time, :hyper_parameter_tuning_end_time, :last_modified_time, :training_job_status_counters, :objective_status_counters, :resource_limits) SENSITIVE = [] include Aws::Structure end |
#training_job_status_counters ⇒ Types::TrainingJobStatusCounters
The [TrainingJobStatusCounters] object that specifies the numbers of training jobs, categorized by status, that this tuning job launched.
[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_TrainingJobStatusCounters.html
30108 30109 30110 30111 30112 30113 30114 30115 30116 30117 30118 30119 30120 30121 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30108 class HyperParameterTuningJobSummary < Struct.new( :hyper_parameter_tuning_job_name, :hyper_parameter_tuning_job_arn, :hyper_parameter_tuning_job_status, :strategy, :creation_time, :hyper_parameter_tuning_end_time, :last_modified_time, :training_job_status_counters, :objective_status_counters, :resource_limits) SENSITIVE = [] include Aws::Structure end |