Class: Aws::SageMaker::Types::IdentityProviderOAuthSetting
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::IdentityProviderOAuthSetting
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The Amazon SageMaker Canvas application setting where you configure OAuth for connecting to an external data source, such as Snowflake.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_source_name ⇒ String
The name of the data source that you’re connecting to.
-
#secret_arn ⇒ String
The ARN of an Amazon Web Services Secrets Manager secret that stores the credentials from your identity provider, such as the client ID and secret, authorization URL, and token URL.
-
#status ⇒ String
Describes whether OAuth for a data source is enabled or disabled in the Canvas application.
Instance Attribute Details
#data_source_name ⇒ String
The name of the data source that you’re connecting to. Canvas currently supports OAuth for Snowflake and Salesforce Data Cloud.
30092 30093 30094 30095 30096 30097 30098 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30092 class IdentityProviderOAuthSetting < Struct.new( :data_source_name, :status, :secret_arn) SENSITIVE = [] include Aws::Structure end |
#secret_arn ⇒ String
The ARN of an Amazon Web Services Secrets Manager secret that stores the credentials from your identity provider, such as the client ID and secret, authorization URL, and token URL.
30092 30093 30094 30095 30096 30097 30098 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30092 class IdentityProviderOAuthSetting < Struct.new( :data_source_name, :status, :secret_arn) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Describes whether OAuth for a data source is enabled or disabled in the Canvas application.
30092 30093 30094 30095 30096 30097 30098 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30092 class IdentityProviderOAuthSetting < Struct.new( :data_source_name, :status, :secret_arn) SENSITIVE = [] include Aws::Structure end |