Class: Aws::SageMaker::Types::IdentityProviderOAuthSetting

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The Amazon SageMaker Canvas application setting where you configure OAuth for connecting to an external data source, such as Snowflake.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#data_source_nameString

The name of the data source that you’re connecting to. Canvas currently supports OAuth for Snowflake and Salesforce Data Cloud.

Returns:

  • (String)


29926
29927
29928
29929
29930
29931
29932
# File 'lib/aws-sdk-sagemaker/types.rb', line 29926

class IdentityProviderOAuthSetting < Struct.new(
  :data_source_name,
  :status,
  :secret_arn)
  SENSITIVE = []
  include Aws::Structure
end

#secret_arnString

The ARN of an Amazon Web Services Secrets Manager secret that stores the credentials from your identity provider, such as the client ID and secret, authorization URL, and token URL.

Returns:

  • (String)


29926
29927
29928
29929
29930
29931
29932
# File 'lib/aws-sdk-sagemaker/types.rb', line 29926

class IdentityProviderOAuthSetting < Struct.new(
  :data_source_name,
  :status,
  :secret_arn)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

Describes whether OAuth for a data source is enabled or disabled in the Canvas application.

Returns:

  • (String)


29926
29927
29928
29929
29930
29931
29932
# File 'lib/aws-sdk-sagemaker/types.rb', line 29926

class IdentityProviderOAuthSetting < Struct.new(
  :data_source_name,
  :status,
  :secret_arn)
  SENSITIVE = []
  include Aws::Structure
end