Class: Aws::SageMaker::Types::ImageConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ImageConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Specifies whether the model container is in Amazon ECR or a private Docker registry accessible from your Amazon Virtual Private Cloud (VPC).
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#repository_access_mode ⇒ String
Set this to one of the following values:.
-
#repository_auth_config ⇒ Types::RepositoryAuthConfig
(Optional) Specifies an authentication configuration for the private docker registry where your model image is hosted.
Instance Attribute Details
#repository_access_mode ⇒ String
Set this to one of the following values:
-
Platform- The model image is hosted in Amazon ECR. -
Vpc- The model image is hosted in a private Docker registry in your VPC.
28597 28598 28599 28600 28601 28602 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 28597 class ImageConfig < Struct.new( :repository_access_mode, :repository_auth_config) SENSITIVE = [] include Aws::Structure end |
#repository_auth_config ⇒ Types::RepositoryAuthConfig
(Optional) Specifies an authentication configuration for the private docker registry where your model image is hosted. Specify a value for this property only if you specified Vpc as the value for the RepositoryAccessMode field, and the private Docker registry where the model image is hosted requires authentication.
28597 28598 28599 28600 28601 28602 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 28597 class ImageConfig < Struct.new( :repository_access_mode, :repository_auth_config) SENSITIVE = [] include Aws::Structure end |