Class: Aws::SageMaker::Types::ImportHubContentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ImportHubContentRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#document_schema_version ⇒ String
The version of the hub content schema to import.
-
#hub_content_description ⇒ String
A description of the hub content to import.
-
#hub_content_display_name ⇒ String
The display name of the hub content to import.
-
#hub_content_document ⇒ String
The hub content document that describes information about the hub content such as type, associated containers, scripts, and more.
-
#hub_content_markdown ⇒ String
A string that provides a description of the hub content.
-
#hub_content_name ⇒ String
The name of the hub content to import.
-
#hub_content_search_keywords ⇒ Array<String>
The searchable keywords of the hub content.
-
#hub_content_type ⇒ String
The type of hub content to import.
-
#hub_content_version ⇒ String
The version of the hub content to import.
-
#hub_name ⇒ String
The name of the hub to import content into.
-
#support_status ⇒ String
The status of the hub content resource.
-
#tags ⇒ Array<Types::Tag>
Any tags associated with the hub content.
Instance Attribute Details
#document_schema_version ⇒ String
The version of the hub content schema to import.
28949 28950 28951 28952 28953 28954 28955 28956 28957 28958 28959 28960 28961 28962 28963 28964 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 28949 class ImportHubContentRequest < Struct.new( :hub_content_name, :hub_content_version, :hub_content_type, :document_schema_version, :hub_name, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_document, :support_status, :hub_content_search_keywords, :tags) SENSITIVE = [] include Aws::Structure end |
#hub_content_description ⇒ String
A description of the hub content to import.
28949 28950 28951 28952 28953 28954 28955 28956 28957 28958 28959 28960 28961 28962 28963 28964 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 28949 class ImportHubContentRequest < Struct.new( :hub_content_name, :hub_content_version, :hub_content_type, :document_schema_version, :hub_name, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_document, :support_status, :hub_content_search_keywords, :tags) SENSITIVE = [] include Aws::Structure end |
#hub_content_display_name ⇒ String
The display name of the hub content to import.
28949 28950 28951 28952 28953 28954 28955 28956 28957 28958 28959 28960 28961 28962 28963 28964 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 28949 class ImportHubContentRequest < Struct.new( :hub_content_name, :hub_content_version, :hub_content_type, :document_schema_version, :hub_name, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_document, :support_status, :hub_content_search_keywords, :tags) SENSITIVE = [] include Aws::Structure end |
#hub_content_document ⇒ String
The hub content document that describes information about the hub content such as type, associated containers, scripts, and more.
28949 28950 28951 28952 28953 28954 28955 28956 28957 28958 28959 28960 28961 28962 28963 28964 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 28949 class ImportHubContentRequest < Struct.new( :hub_content_name, :hub_content_version, :hub_content_type, :document_schema_version, :hub_name, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_document, :support_status, :hub_content_search_keywords, :tags) SENSITIVE = [] include Aws::Structure end |
#hub_content_markdown ⇒ String
A string that provides a description of the hub content. This string can include links, tables, and standard markdown formating.
28949 28950 28951 28952 28953 28954 28955 28956 28957 28958 28959 28960 28961 28962 28963 28964 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 28949 class ImportHubContentRequest < Struct.new( :hub_content_name, :hub_content_version, :hub_content_type, :document_schema_version, :hub_name, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_document, :support_status, :hub_content_search_keywords, :tags) SENSITIVE = [] include Aws::Structure end |
#hub_content_name ⇒ String
The name of the hub content to import.
28949 28950 28951 28952 28953 28954 28955 28956 28957 28958 28959 28960 28961 28962 28963 28964 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 28949 class ImportHubContentRequest < Struct.new( :hub_content_name, :hub_content_version, :hub_content_type, :document_schema_version, :hub_name, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_document, :support_status, :hub_content_search_keywords, :tags) SENSITIVE = [] include Aws::Structure end |
#hub_content_search_keywords ⇒ Array<String>
The searchable keywords of the hub content.
28949 28950 28951 28952 28953 28954 28955 28956 28957 28958 28959 28960 28961 28962 28963 28964 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 28949 class ImportHubContentRequest < Struct.new( :hub_content_name, :hub_content_version, :hub_content_type, :document_schema_version, :hub_name, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_document, :support_status, :hub_content_search_keywords, :tags) SENSITIVE = [] include Aws::Structure end |
#hub_content_type ⇒ String
The type of hub content to import.
28949 28950 28951 28952 28953 28954 28955 28956 28957 28958 28959 28960 28961 28962 28963 28964 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 28949 class ImportHubContentRequest < Struct.new( :hub_content_name, :hub_content_version, :hub_content_type, :document_schema_version, :hub_name, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_document, :support_status, :hub_content_search_keywords, :tags) SENSITIVE = [] include Aws::Structure end |
#hub_content_version ⇒ String
The version of the hub content to import.
28949 28950 28951 28952 28953 28954 28955 28956 28957 28958 28959 28960 28961 28962 28963 28964 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 28949 class ImportHubContentRequest < Struct.new( :hub_content_name, :hub_content_version, :hub_content_type, :document_schema_version, :hub_name, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_document, :support_status, :hub_content_search_keywords, :tags) SENSITIVE = [] include Aws::Structure end |
#hub_name ⇒ String
The name of the hub to import content into.
28949 28950 28951 28952 28953 28954 28955 28956 28957 28958 28959 28960 28961 28962 28963 28964 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 28949 class ImportHubContentRequest < Struct.new( :hub_content_name, :hub_content_version, :hub_content_type, :document_schema_version, :hub_name, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_document, :support_status, :hub_content_search_keywords, :tags) SENSITIVE = [] include Aws::Structure end |
#support_status ⇒ String
The status of the hub content resource.
28949 28950 28951 28952 28953 28954 28955 28956 28957 28958 28959 28960 28961 28962 28963 28964 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 28949 class ImportHubContentRequest < Struct.new( :hub_content_name, :hub_content_version, :hub_content_type, :document_schema_version, :hub_name, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_document, :support_status, :hub_content_search_keywords, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Any tags associated with the hub content.
28949 28950 28951 28952 28953 28954 28955 28956 28957 28958 28959 28960 28961 28962 28963 28964 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 28949 class ImportHubContentRequest < Struct.new( :hub_content_name, :hub_content_version, :hub_content_type, :document_schema_version, :hub_name, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_document, :support_status, :hub_content_search_keywords, :tags) SENSITIVE = [] include Aws::Structure end |