Class: Aws::SageMaker::Types::ImportHubContentRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#document_schema_versionString

The version of the hub content schema to import.



28675
28676
28677
28678
28679
28680
28681
28682
28683
28684
28685
28686
28687
28688
28689
28690
# File 'lib/aws-sdk-sagemaker/types.rb', line 28675

class ImportHubContentRequest < Struct.new(
  :hub_content_name,
  :hub_content_version,
  :hub_content_type,
  :document_schema_version,
  :hub_name,
  :hub_content_display_name,
  :hub_content_description,
  :hub_content_markdown,
  :hub_content_document,
  :support_status,
  :hub_content_search_keywords,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#hub_content_descriptionString

A description of the hub content to import.



28675
28676
28677
28678
28679
28680
28681
28682
28683
28684
28685
28686
28687
28688
28689
28690
# File 'lib/aws-sdk-sagemaker/types.rb', line 28675

class ImportHubContentRequest < Struct.new(
  :hub_content_name,
  :hub_content_version,
  :hub_content_type,
  :document_schema_version,
  :hub_name,
  :hub_content_display_name,
  :hub_content_description,
  :hub_content_markdown,
  :hub_content_document,
  :support_status,
  :hub_content_search_keywords,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#hub_content_display_nameString

The display name of the hub content to import.



28675
28676
28677
28678
28679
28680
28681
28682
28683
28684
28685
28686
28687
28688
28689
28690
# File 'lib/aws-sdk-sagemaker/types.rb', line 28675

class ImportHubContentRequest < Struct.new(
  :hub_content_name,
  :hub_content_version,
  :hub_content_type,
  :document_schema_version,
  :hub_name,
  :hub_content_display_name,
  :hub_content_description,
  :hub_content_markdown,
  :hub_content_document,
  :support_status,
  :hub_content_search_keywords,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#hub_content_documentString

The hub content document that describes information about the hub content such as type, associated containers, scripts, and more.



28675
28676
28677
28678
28679
28680
28681
28682
28683
28684
28685
28686
28687
28688
28689
28690
# File 'lib/aws-sdk-sagemaker/types.rb', line 28675

class ImportHubContentRequest < Struct.new(
  :hub_content_name,
  :hub_content_version,
  :hub_content_type,
  :document_schema_version,
  :hub_name,
  :hub_content_display_name,
  :hub_content_description,
  :hub_content_markdown,
  :hub_content_document,
  :support_status,
  :hub_content_search_keywords,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#hub_content_markdownString

A string that provides a description of the hub content. This string can include links, tables, and standard markdown formating.



28675
28676
28677
28678
28679
28680
28681
28682
28683
28684
28685
28686
28687
28688
28689
28690
# File 'lib/aws-sdk-sagemaker/types.rb', line 28675

class ImportHubContentRequest < Struct.new(
  :hub_content_name,
  :hub_content_version,
  :hub_content_type,
  :document_schema_version,
  :hub_name,
  :hub_content_display_name,
  :hub_content_description,
  :hub_content_markdown,
  :hub_content_document,
  :support_status,
  :hub_content_search_keywords,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#hub_content_nameString

The name of the hub content to import.



28675
28676
28677
28678
28679
28680
28681
28682
28683
28684
28685
28686
28687
28688
28689
28690
# File 'lib/aws-sdk-sagemaker/types.rb', line 28675

class ImportHubContentRequest < Struct.new(
  :hub_content_name,
  :hub_content_version,
  :hub_content_type,
  :document_schema_version,
  :hub_name,
  :hub_content_display_name,
  :hub_content_description,
  :hub_content_markdown,
  :hub_content_document,
  :support_status,
  :hub_content_search_keywords,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#hub_content_search_keywordsArray<String>

The searchable keywords of the hub content.



28675
28676
28677
28678
28679
28680
28681
28682
28683
28684
28685
28686
28687
28688
28689
28690
# File 'lib/aws-sdk-sagemaker/types.rb', line 28675

class ImportHubContentRequest < Struct.new(
  :hub_content_name,
  :hub_content_version,
  :hub_content_type,
  :document_schema_version,
  :hub_name,
  :hub_content_display_name,
  :hub_content_description,
  :hub_content_markdown,
  :hub_content_document,
  :support_status,
  :hub_content_search_keywords,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#hub_content_typeString

The type of hub content to import.



28675
28676
28677
28678
28679
28680
28681
28682
28683
28684
28685
28686
28687
28688
28689
28690
# File 'lib/aws-sdk-sagemaker/types.rb', line 28675

class ImportHubContentRequest < Struct.new(
  :hub_content_name,
  :hub_content_version,
  :hub_content_type,
  :document_schema_version,
  :hub_name,
  :hub_content_display_name,
  :hub_content_description,
  :hub_content_markdown,
  :hub_content_document,
  :support_status,
  :hub_content_search_keywords,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#hub_content_versionString

The version of the hub content to import.



28675
28676
28677
28678
28679
28680
28681
28682
28683
28684
28685
28686
28687
28688
28689
28690
# File 'lib/aws-sdk-sagemaker/types.rb', line 28675

class ImportHubContentRequest < Struct.new(
  :hub_content_name,
  :hub_content_version,
  :hub_content_type,
  :document_schema_version,
  :hub_name,
  :hub_content_display_name,
  :hub_content_description,
  :hub_content_markdown,
  :hub_content_document,
  :support_status,
  :hub_content_search_keywords,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#hub_nameString

The name of the hub to import content into.



28675
28676
28677
28678
28679
28680
28681
28682
28683
28684
28685
28686
28687
28688
28689
28690
# File 'lib/aws-sdk-sagemaker/types.rb', line 28675

class ImportHubContentRequest < Struct.new(
  :hub_content_name,
  :hub_content_version,
  :hub_content_type,
  :document_schema_version,
  :hub_name,
  :hub_content_display_name,
  :hub_content_description,
  :hub_content_markdown,
  :hub_content_document,
  :support_status,
  :hub_content_search_keywords,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#support_statusString

The status of the hub content resource.



28675
28676
28677
28678
28679
28680
28681
28682
28683
28684
28685
28686
28687
28688
28689
28690
# File 'lib/aws-sdk-sagemaker/types.rb', line 28675

class ImportHubContentRequest < Struct.new(
  :hub_content_name,
  :hub_content_version,
  :hub_content_type,
  :document_schema_version,
  :hub_name,
  :hub_content_display_name,
  :hub_content_description,
  :hub_content_markdown,
  :hub_content_document,
  :support_status,
  :hub_content_search_keywords,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Any tags associated with the hub content.



28675
28676
28677
28678
28679
28680
28681
28682
28683
28684
28685
28686
28687
28688
28689
28690
# File 'lib/aws-sdk-sagemaker/types.rb', line 28675

class ImportHubContentRequest < Struct.new(
  :hub_content_name,
  :hub_content_version,
  :hub_content_type,
  :document_schema_version,
  :hub_name,
  :hub_content_display_name,
  :hub_content_description,
  :hub_content_markdown,
  :hub_content_document,
  :support_status,
  :hub_content_search_keywords,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end