Class: Aws::SageMaker::Types::InferenceComponentDataCacheConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::InferenceComponentDataCacheConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Settings that affect how the inference component caches data.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enable_caching ⇒ Boolean
Sets whether the endpoint that hosts the inference component caches the model artifacts and container image.
Instance Attribute Details
#enable_caching ⇒ Boolean
Sets whether the endpoint that hosts the inference component caches the model artifacts and container image.
With caching enabled, the endpoint caches this data in each instance that it provisions for the inference component. That way, the inference component deploys faster during the auto scaling process. If caching isn't enabled, the inference component takes longer to deploy because of the time it spends downloading the data.
31148 31149 31150 31151 31152 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31148 class InferenceComponentDataCacheConfig < Struct.new( :enable_caching) SENSITIVE = [] include Aws::Structure end |