Class: Aws::SageMaker::Types::InferenceComponentDataCacheConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Settings that affect how the inference component caches data.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enable_cachingBoolean

Sets whether the endpoint that hosts the inference component caches the model artifacts and container image.

With caching enabled, the endpoint caches this data in each instance that it provisions for the inference component. That way, the inference component deploys faster during the auto scaling process. If caching isn’t enabled, the inference component takes longer to deploy because of the time it spends downloading the data.

Returns:

  • (Boolean)


29178
29179
29180
29181
29182
# File 'lib/aws-sdk-sagemaker/types.rb', line 29178

class InferenceComponentDataCacheConfig < Struct.new(
  :enable_caching)
  SENSITIVE = []
  include Aws::Structure
end