Class: Aws::SageMaker::Types::InferenceComponentSpecificationSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::InferenceComponentSpecificationSummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Details about the resources that are deployed with this inference component.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#base_inference_component_name ⇒ String
The name of the base inference component that contains this inference component.
-
#compute_resource_requirements ⇒ Types::InferenceComponentComputeResourceRequirements
The compute resources allocated to run the model, plus any adapter models, that you assign to the inference component.
-
#container ⇒ Types::InferenceComponentContainerSpecificationSummary
Details about the container that provides the runtime environment for the model that is deployed with the inference component.
-
#data_cache_config ⇒ Types::InferenceComponentDataCacheConfigSummary
Settings that affect how the inference component caches data.
-
#instance_type ⇒ String
The ML compute instance type associated with this inference component specification.
-
#model_name ⇒ String
The name of the SageMaker AI model object that is deployed with the inference component.
-
#scheduling_config ⇒ Types::InferenceComponentSchedulingConfig
The scheduling configuration that determines how inference component copies are placed across available instances when copies are added or removed.
-
#startup_parameters ⇒ Types::InferenceComponentStartupParameters
Settings that take effect while the model container starts up.
Instance Attribute Details
#base_inference_component_name ⇒ String
The name of the base inference component that contains this inference component.
31637 31638 31639 31640 31641 31642 31643 31644 31645 31646 31647 31648 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31637 class InferenceComponentSpecificationSummary < Struct.new( :instance_type, :model_name, :container, :startup_parameters, :compute_resource_requirements, :base_inference_component_name, :data_cache_config, :scheduling_config) SENSITIVE = [] include Aws::Structure end |
#compute_resource_requirements ⇒ Types::InferenceComponentComputeResourceRequirements
The compute resources allocated to run the model, plus any adapter models, that you assign to the inference component.
31637 31638 31639 31640 31641 31642 31643 31644 31645 31646 31647 31648 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31637 class InferenceComponentSpecificationSummary < Struct.new( :instance_type, :model_name, :container, :startup_parameters, :compute_resource_requirements, :base_inference_component_name, :data_cache_config, :scheduling_config) SENSITIVE = [] include Aws::Structure end |
#container ⇒ Types::InferenceComponentContainerSpecificationSummary
Details about the container that provides the runtime environment for the model that is deployed with the inference component.
31637 31638 31639 31640 31641 31642 31643 31644 31645 31646 31647 31648 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31637 class InferenceComponentSpecificationSummary < Struct.new( :instance_type, :model_name, :container, :startup_parameters, :compute_resource_requirements, :base_inference_component_name, :data_cache_config, :scheduling_config) SENSITIVE = [] include Aws::Structure end |
#data_cache_config ⇒ Types::InferenceComponentDataCacheConfigSummary
Settings that affect how the inference component caches data.
31637 31638 31639 31640 31641 31642 31643 31644 31645 31646 31647 31648 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31637 class InferenceComponentSpecificationSummary < Struct.new( :instance_type, :model_name, :container, :startup_parameters, :compute_resource_requirements, :base_inference_component_name, :data_cache_config, :scheduling_config) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The ML compute instance type associated with this inference component specification.
31637 31638 31639 31640 31641 31642 31643 31644 31645 31646 31647 31648 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31637 class InferenceComponentSpecificationSummary < Struct.new( :instance_type, :model_name, :container, :startup_parameters, :compute_resource_requirements, :base_inference_component_name, :data_cache_config, :scheduling_config) SENSITIVE = [] include Aws::Structure end |
#model_name ⇒ String
The name of the SageMaker AI model object that is deployed with the inference component.
31637 31638 31639 31640 31641 31642 31643 31644 31645 31646 31647 31648 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31637 class InferenceComponentSpecificationSummary < Struct.new( :instance_type, :model_name, :container, :startup_parameters, :compute_resource_requirements, :base_inference_component_name, :data_cache_config, :scheduling_config) SENSITIVE = [] include Aws::Structure end |
#scheduling_config ⇒ Types::InferenceComponentSchedulingConfig
The scheduling configuration that determines how inference component copies are placed across available instances when copies are added or removed.
31637 31638 31639 31640 31641 31642 31643 31644 31645 31646 31647 31648 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31637 class InferenceComponentSpecificationSummary < Struct.new( :instance_type, :model_name, :container, :startup_parameters, :compute_resource_requirements, :base_inference_component_name, :data_cache_config, :scheduling_config) SENSITIVE = [] include Aws::Structure end |
#startup_parameters ⇒ Types::InferenceComponentStartupParameters
Settings that take effect while the model container starts up.
31637 31638 31639 31640 31641 31642 31643 31644 31645 31646 31647 31648 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31637 class InferenceComponentSpecificationSummary < Struct.new( :instance_type, :model_name, :container, :startup_parameters, :compute_resource_requirements, :base_inference_component_name, :data_cache_config, :scheduling_config) SENSITIVE = [] include Aws::Structure end |