Class: Aws::SageMaker::Types::InferenceComponentStartupParameters
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::InferenceComponentStartupParameters
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Settings that take effect while the model container starts up.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#container_startup_health_check_timeout_in_seconds ⇒ Integer
The timeout value, in seconds, for your inference container to pass health check by Amazon S3 Hosting.
-
#model_data_download_timeout_in_seconds ⇒ Integer
The timeout value, in seconds, to download and extract the model that you want to host from Amazon S3 to the individual inference instance associated with this inference component.
Instance Attribute Details
#container_startup_health_check_timeout_in_seconds ⇒ Integer
The timeout value, in seconds, for your inference container to pass health check by Amazon S3 Hosting. For more information about health check, see [How Your Container Should Respond to Health Check (Ping) Requests].
31280 31281 31282 31283 31284 31285 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31280 class InferenceComponentStartupParameters < Struct.new( :model_data_download_timeout_in_seconds, :container_startup_health_check_timeout_in_seconds) SENSITIVE = [] include Aws::Structure end |
#model_data_download_timeout_in_seconds ⇒ Integer
The timeout value, in seconds, to download and extract the model that you want to host from Amazon S3 to the individual inference instance associated with this inference component.
31280 31281 31282 31283 31284 31285 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31280 class InferenceComponentStartupParameters < Struct.new( :model_data_download_timeout_in_seconds, :container_startup_health_check_timeout_in_seconds) SENSITIVE = [] include Aws::Structure end |