Class: Aws::SageMaker::Types::InferenceExperimentDataStorageConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::InferenceExperimentDataStorageConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The Amazon S3 location and configuration for storing inference request and response data.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#content_type ⇒ Types::CaptureContentTypeHeader
Configuration specifying how to treat different headers.
-
#destination ⇒ String
The Amazon S3 bucket where the inference request and response data is stored.
-
#kms_key ⇒ String
The Amazon Web Services Key Management Service key that Amazon SageMaker uses to encrypt captured data at rest using Amazon S3 server-side encryption.
Instance Attribute Details
#content_type ⇒ Types::CaptureContentTypeHeader
Configuration specifying how to treat different headers. If no headers are specified Amazon SageMaker AI will by default base64 encode when capturing the data.
31581 31582 31583 31584 31585 31586 31587 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31581 class InferenceExperimentDataStorageConfig < Struct.new( :destination, :kms_key, :content_type) SENSITIVE = [] include Aws::Structure end |
#destination ⇒ String
The Amazon S3 bucket where the inference request and response data is stored.
31581 31582 31583 31584 31585 31586 31587 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31581 class InferenceExperimentDataStorageConfig < Struct.new( :destination, :kms_key, :content_type) SENSITIVE = [] include Aws::Structure end |
#kms_key ⇒ String
The Amazon Web Services Key Management Service key that Amazon SageMaker uses to encrypt captured data at rest using Amazon S3 server-side encryption.
31581 31582 31583 31584 31585 31586 31587 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31581 class InferenceExperimentDataStorageConfig < Struct.new( :destination, :kms_key, :content_type) SENSITIVE = [] include Aws::Structure end |