Class: Aws::SageMaker::Types::InferenceExperimentDataStorageConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The Amazon S3 location and configuration for storing inference request and response data.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#content_typeTypes::CaptureContentTypeHeader

Configuration specifying how to treat different headers. If no headers are specified Amazon SageMaker AI will by default base64 encode when capturing the data.



31335
31336
31337
31338
31339
31340
31341
# File 'lib/aws-sdk-sagemaker/types.rb', line 31335

class InferenceExperimentDataStorageConfig < Struct.new(
  :destination,
  :kms_key,
  :content_type)
  SENSITIVE = []
  include Aws::Structure
end

#destinationString

The Amazon S3 bucket where the inference request and response data is stored.

Returns:

  • (String)


31335
31336
31337
31338
31339
31340
31341
# File 'lib/aws-sdk-sagemaker/types.rb', line 31335

class InferenceExperimentDataStorageConfig < Struct.new(
  :destination,
  :kms_key,
  :content_type)
  SENSITIVE = []
  include Aws::Structure
end

#kms_keyString

The Amazon Web Services Key Management Service key that Amazon SageMaker uses to encrypt captured data at rest using Amazon S3 server-side encryption.

Returns:

  • (String)


31335
31336
31337
31338
31339
31340
31341
# File 'lib/aws-sdk-sagemaker/types.rb', line 31335

class InferenceExperimentDataStorageConfig < Struct.new(
  :destination,
  :kms_key,
  :content_type)
  SENSITIVE = []
  include Aws::Structure
end