Class: Aws::SageMaker::Types::InferenceExperimentSummary

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Lists a summary of properties of an inference experiment.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#completion_timeTime

The timestamp at which the inference experiment was completed.

Returns:

  • (Time)


31661
31662
31663
31664
31665
31666
31667
31668
31669
31670
31671
31672
31673
31674
# File 'lib/aws-sdk-sagemaker/types.rb', line 31661

class InferenceExperimentSummary < Struct.new(
  :name,
  :type,
  :schedule,
  :status,
  :status_reason,
  :description,
  :creation_time,
  :completion_time,
  :last_modified_time,
  :role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

The timestamp at which the inference experiment was created.

Returns:

  • (Time)


31661
31662
31663
31664
31665
31666
31667
31668
31669
31670
31671
31672
31673
31674
# File 'lib/aws-sdk-sagemaker/types.rb', line 31661

class InferenceExperimentSummary < Struct.new(
  :name,
  :type,
  :schedule,
  :status,
  :status_reason,
  :description,
  :creation_time,
  :completion_time,
  :last_modified_time,
  :role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the inference experiment.

Returns:

  • (String)


31661
31662
31663
31664
31665
31666
31667
31668
31669
31670
31671
31672
31673
31674
# File 'lib/aws-sdk-sagemaker/types.rb', line 31661

class InferenceExperimentSummary < Struct.new(
  :name,
  :type,
  :schedule,
  :status,
  :status_reason,
  :description,
  :creation_time,
  :completion_time,
  :last_modified_time,
  :role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The timestamp when you last modified the inference experiment.

Returns:

  • (Time)


31661
31662
31663
31664
31665
31666
31667
31668
31669
31670
31671
31672
31673
31674
# File 'lib/aws-sdk-sagemaker/types.rb', line 31661

class InferenceExperimentSummary < Struct.new(
  :name,
  :type,
  :schedule,
  :status,
  :status_reason,
  :description,
  :creation_time,
  :completion_time,
  :last_modified_time,
  :role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the inference experiment.

Returns:

  • (String)


31661
31662
31663
31664
31665
31666
31667
31668
31669
31670
31671
31672
31673
31674
# File 'lib/aws-sdk-sagemaker/types.rb', line 31661

class InferenceExperimentSummary < Struct.new(
  :name,
  :type,
  :schedule,
  :status,
  :status_reason,
  :description,
  :creation_time,
  :completion_time,
  :last_modified_time,
  :role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The ARN of the IAM role that Amazon SageMaker can assume to access model artifacts and container images, and manage Amazon SageMaker Inference endpoints for model deployment.

Returns:

  • (String)


31661
31662
31663
31664
31665
31666
31667
31668
31669
31670
31671
31672
31673
31674
# File 'lib/aws-sdk-sagemaker/types.rb', line 31661

class InferenceExperimentSummary < Struct.new(
  :name,
  :type,
  :schedule,
  :status,
  :status_reason,
  :description,
  :creation_time,
  :completion_time,
  :last_modified_time,
  :role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#scheduleTypes::InferenceExperimentSchedule

The duration for which the inference experiment ran or will run.

The maximum duration that you can set for an inference experiment is 30 days.



31661
31662
31663
31664
31665
31666
31667
31668
31669
31670
31671
31672
31673
31674
# File 'lib/aws-sdk-sagemaker/types.rb', line 31661

class InferenceExperimentSummary < Struct.new(
  :name,
  :type,
  :schedule,
  :status,
  :status_reason,
  :description,
  :creation_time,
  :completion_time,
  :last_modified_time,
  :role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the inference experiment.

Returns:

  • (String)


31661
31662
31663
31664
31665
31666
31667
31668
31669
31670
31671
31672
31673
31674
# File 'lib/aws-sdk-sagemaker/types.rb', line 31661

class InferenceExperimentSummary < Struct.new(
  :name,
  :type,
  :schedule,
  :status,
  :status_reason,
  :description,
  :creation_time,
  :completion_time,
  :last_modified_time,
  :role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#status_reasonString

The error message for the inference experiment status result.

Returns:

  • (String)


31661
31662
31663
31664
31665
31666
31667
31668
31669
31670
31671
31672
31673
31674
# File 'lib/aws-sdk-sagemaker/types.rb', line 31661

class InferenceExperimentSummary < Struct.new(
  :name,
  :type,
  :schedule,
  :status,
  :status_reason,
  :description,
  :creation_time,
  :completion_time,
  :last_modified_time,
  :role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of the inference experiment.

Returns:

  • (String)


31661
31662
31663
31664
31665
31666
31667
31668
31669
31670
31671
31672
31673
31674
# File 'lib/aws-sdk-sagemaker/types.rb', line 31661

class InferenceExperimentSummary < Struct.new(
  :name,
  :type,
  :schedule,
  :status,
  :status_reason,
  :description,
  :creation_time,
  :completion_time,
  :last_modified_time,
  :role_arn)
  SENSITIVE = []
  include Aws::Structure
end