Class: Aws::SageMaker::Types::InferenceExperimentSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::InferenceExperimentSummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Lists a summary of properties of an inference experiment.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#completion_time ⇒ Time
The timestamp at which the inference experiment was completed.
-
#creation_time ⇒ Time
The timestamp at which the inference experiment was created.
-
#description ⇒ String
The description of the inference experiment.
-
#last_modified_time ⇒ Time
The timestamp when you last modified the inference experiment.
-
#name ⇒ String
The name of the inference experiment.
-
#role_arn ⇒ String
The ARN of the IAM role that Amazon SageMaker can assume to access model artifacts and container images, and manage Amazon SageMaker Inference endpoints for model deployment.
-
#schedule ⇒ Types::InferenceExperimentSchedule
The duration for which the inference experiment ran or will run.
-
#status ⇒ String
The status of the inference experiment.
-
#status_reason ⇒ String
The error message for the inference experiment status result.
-
#type ⇒ String
The type of the inference experiment.
Instance Attribute Details
#completion_time ⇒ Time
The timestamp at which the inference experiment was completed.
30984 30985 30986 30987 30988 30989 30990 30991 30992 30993 30994 30995 30996 30997 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30984 class InferenceExperimentSummary < Struct.new( :name, :type, :schedule, :status, :status_reason, :description, :creation_time, :completion_time, :last_modified_time, :role_arn) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The timestamp at which the inference experiment was created.
30984 30985 30986 30987 30988 30989 30990 30991 30992 30993 30994 30995 30996 30997 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30984 class InferenceExperimentSummary < Struct.new( :name, :type, :schedule, :status, :status_reason, :description, :creation_time, :completion_time, :last_modified_time, :role_arn) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the inference experiment.
30984 30985 30986 30987 30988 30989 30990 30991 30992 30993 30994 30995 30996 30997 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30984 class InferenceExperimentSummary < Struct.new( :name, :type, :schedule, :status, :status_reason, :description, :creation_time, :completion_time, :last_modified_time, :role_arn) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp when you last modified the inference experiment.
30984 30985 30986 30987 30988 30989 30990 30991 30992 30993 30994 30995 30996 30997 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30984 class InferenceExperimentSummary < Struct.new( :name, :type, :schedule, :status, :status_reason, :description, :creation_time, :completion_time, :last_modified_time, :role_arn) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the inference experiment.
30984 30985 30986 30987 30988 30989 30990 30991 30992 30993 30994 30995 30996 30997 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30984 class InferenceExperimentSummary < Struct.new( :name, :type, :schedule, :status, :status_reason, :description, :creation_time, :completion_time, :last_modified_time, :role_arn) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The ARN of the IAM role that Amazon SageMaker can assume to access model artifacts and container images, and manage Amazon SageMaker Inference endpoints for model deployment.
30984 30985 30986 30987 30988 30989 30990 30991 30992 30993 30994 30995 30996 30997 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30984 class InferenceExperimentSummary < Struct.new( :name, :type, :schedule, :status, :status_reason, :description, :creation_time, :completion_time, :last_modified_time, :role_arn) SENSITIVE = [] include Aws::Structure end |
#schedule ⇒ Types::InferenceExperimentSchedule
The duration for which the inference experiment ran or will run.
The maximum duration that you can set for an inference experiment is 30 days.
30984 30985 30986 30987 30988 30989 30990 30991 30992 30993 30994 30995 30996 30997 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30984 class InferenceExperimentSummary < Struct.new( :name, :type, :schedule, :status, :status_reason, :description, :creation_time, :completion_time, :last_modified_time, :role_arn) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the inference experiment.
30984 30985 30986 30987 30988 30989 30990 30991 30992 30993 30994 30995 30996 30997 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30984 class InferenceExperimentSummary < Struct.new( :name, :type, :schedule, :status, :status_reason, :description, :creation_time, :completion_time, :last_modified_time, :role_arn) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
The error message for the inference experiment status result.
30984 30985 30986 30987 30988 30989 30990 30991 30992 30993 30994 30995 30996 30997 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30984 class InferenceExperimentSummary < Struct.new( :name, :type, :schedule, :status, :status_reason, :description, :creation_time, :completion_time, :last_modified_time, :role_arn) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the inference experiment.
30984 30985 30986 30987 30988 30989 30990 30991 30992 30993 30994 30995 30996 30997 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30984 class InferenceExperimentSummary < Struct.new( :name, :type, :schedule, :status, :status_reason, :description, :creation_time, :completion_time, :last_modified_time, :role_arn) SENSITIVE = [] include Aws::Structure end |