Class: Aws::SageMaker::Types::InferenceSpecification
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::InferenceSpecification
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Defines how to perform inference generation after a training job is run.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#containers ⇒ Array<Types::ModelPackageContainerDefinition>
The Amazon ECR registry path of the Docker image that contains the inference code.
-
#supported_content_types ⇒ Array<String>
The supported MIME types for the input data.
-
#supported_realtime_inference_instance_types ⇒ Array<String>
A list of the instance types that are used to generate inferences in real-time.
-
#supported_response_mime_types ⇒ Array<String>
The supported MIME types for the output data.
-
#supported_transform_instance_types ⇒ Array<String>
A list of the instance types on which a transformation job can be run or on which an endpoint can be deployed.
Instance Attribute Details
#containers ⇒ Array<Types::ModelPackageContainerDefinition>
The Amazon ECR registry path of the Docker image that contains the inference code.
31187 31188 31189 31190 31191 31192 31193 31194 31195 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31187 class InferenceSpecification < Struct.new( :containers, :supported_transform_instance_types, :supported_realtime_inference_instance_types, :supported_content_types, :supported_response_mime_types) SENSITIVE = [] include Aws::Structure end |
#supported_content_types ⇒ Array<String>
The supported MIME types for the input data.
31187 31188 31189 31190 31191 31192 31193 31194 31195 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31187 class InferenceSpecification < Struct.new( :containers, :supported_transform_instance_types, :supported_realtime_inference_instance_types, :supported_content_types, :supported_response_mime_types) SENSITIVE = [] include Aws::Structure end |
#supported_realtime_inference_instance_types ⇒ Array<String>
A list of the instance types that are used to generate inferences in real-time.
This parameter is required for unversioned models, and optional for versioned models.
31187 31188 31189 31190 31191 31192 31193 31194 31195 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31187 class InferenceSpecification < Struct.new( :containers, :supported_transform_instance_types, :supported_realtime_inference_instance_types, :supported_content_types, :supported_response_mime_types) SENSITIVE = [] include Aws::Structure end |
#supported_response_mime_types ⇒ Array<String>
The supported MIME types for the output data.
31187 31188 31189 31190 31191 31192 31193 31194 31195 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31187 class InferenceSpecification < Struct.new( :containers, :supported_transform_instance_types, :supported_realtime_inference_instance_types, :supported_content_types, :supported_response_mime_types) SENSITIVE = [] include Aws::Structure end |
#supported_transform_instance_types ⇒ Array<String>
A list of the instance types on which a transformation job can be run or on which an endpoint can be deployed.
This parameter is required for unversioned models, and optional for versioned models.
31187 31188 31189 31190 31191 31192 31193 31194 31195 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31187 class InferenceSpecification < Struct.new( :containers, :supported_transform_instance_types, :supported_realtime_inference_instance_types, :supported_content_types, :supported_response_mime_types) SENSITIVE = [] include Aws::Structure end |