Class: Aws::SageMaker::Types::InstancePlacementConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::InstancePlacementConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Configuration for how instances are placed and allocated within UltraServers. This is only applicable for UltraServer capacity.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enable_multiple_jobs ⇒ Boolean
If set to true, allows multiple jobs to share the same UltraServer instances.
-
#placement_specifications ⇒ Array<Types::PlacementSpecification>
A list of specifications for how instances should be placed on specific UltraServers.
Instance Attribute Details
#enable_multiple_jobs ⇒ Boolean
If set to true, allows multiple jobs to share the same UltraServer instances. If set to false, ensures this job’s instances are placed on an UltraServer exclusively, with no other jobs sharing the same UltraServer. Default is false.
30371 30372 30373 30374 30375 30376 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30371 class InstancePlacementConfig < Struct.new( :enable_multiple_jobs, :placement_specifications) SENSITIVE = [] include Aws::Structure end |
#placement_specifications ⇒ Array<Types::PlacementSpecification>
A list of specifications for how instances should be placed on specific UltraServers. Maximum of 10 items is supported.
30371 30372 30373 30374 30375 30376 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30371 class InstancePlacementConfig < Struct.new( :enable_multiple_jobs, :placement_specifications) SENSITIVE = [] include Aws::Structure end |