Class: Aws::SageMaker::Types::InstancePool
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::InstancePool
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Specifies an instance type and its priority for a heterogeneous endpoint. Use instance pools to configure a production variant with multiple instance types, enabling the endpoint to provision instances across different types based on priority.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_type ⇒ String
The ML compute instance type for the instance pool.
-
#model_name_override ⇒ String
The name of a SageMaker model to use for this instance pool instead of the model specified for the production variant.
-
#priority ⇒ Integer
The priority for the instance pool.
Instance Attribute Details
#instance_type ⇒ String
The ML compute instance type for the instance pool.
31663 31664 31665 31666 31667 31668 31669 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31663 class InstancePool < Struct.new( :instance_type, :model_name_override, :priority) SENSITIVE = [] include Aws::Structure end |
#model_name_override ⇒ String
The name of a SageMaker model to use for this instance pool instead of the model specified for the production variant. Use this to deploy a different model optimized for the instance type in this pool.
31663 31664 31665 31666 31667 31668 31669 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31663 class InstancePool < Struct.new( :instance_type, :model_name_override, :priority) SENSITIVE = [] include Aws::Structure end |
#priority ⇒ Integer
The priority for the instance pool. SageMaker attempts to provision instances in order of priority, starting with the lowest value. If instances for a higher-priority pool are unavailable, SageMaker attempts to provision from the next pool.
Valid values: 1 to 5, where 1 is the highest priority.
31663 31664 31665 31666 31667 31668 31669 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31663 class InstancePool < Struct.new( :instance_type, :model_name_override, :priority) SENSITIVE = [] include Aws::Structure end |