Class: Aws::SageMaker::Types::InstancePoolSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::InstancePoolSummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
A summary of an instance pool for a production variant, including the instance type and the current number of instances.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#current_instance_count ⇒ Integer
The current number of instances of this type in the instance pool.
-
#instance_type ⇒ String
The ML compute instance type for the instance pool.
Instance Attribute Details
#current_instance_count ⇒ Integer
The current number of instances of this type in the instance pool.
31684 31685 31686 31687 31688 31689 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31684 class InstancePoolSummary < Struct.new( :instance_type, :current_instance_count) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The ML compute instance type for the instance pool.
31684 31685 31686 31687 31688 31689 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31684 class InstancePoolSummary < Struct.new( :instance_type, :current_instance_count) SENSITIVE = [] include Aws::Structure end |