Class: Aws::SageMaker::Types::JobSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::JobSummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Provides summary information about a job, returned by the ‘ListJobs` operation. Use `DescribeJob` to get full details for a specific job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Time
The date and time that the job was created.
-
#end_time ⇒ Time
The date and time that the job ended.
-
#job_arn ⇒ String
The Amazon Resource Name (ARN) of the job.
-
#job_category ⇒ String
The category of the job.
-
#job_name ⇒ String
The name of the job.
-
#job_secondary_status ⇒ String
The secondary status of the job, providing more granular information about the job’s progress.
-
#job_status ⇒ String
The current status of the job.
-
#last_modified_time ⇒ Time
The date and time that the job was last modified.
Instance Attribute Details
#creation_time ⇒ Time
The date and time that the job was created.
32709 32710 32711 32712 32713 32714 32715 32716 32717 32718 32719 32720 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32709 class JobSummary < Struct.new( :job_arn, :job_name, :job_category, :job_status, :job_secondary_status, :creation_time, :last_modified_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
The date and time that the job ended.
32709 32710 32711 32712 32713 32714 32715 32716 32717 32718 32719 32720 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32709 class JobSummary < Struct.new( :job_arn, :job_name, :job_category, :job_status, :job_secondary_status, :creation_time, :last_modified_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#job_arn ⇒ String
The Amazon Resource Name (ARN) of the job.
32709 32710 32711 32712 32713 32714 32715 32716 32717 32718 32719 32720 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32709 class JobSummary < Struct.new( :job_arn, :job_name, :job_category, :job_status, :job_secondary_status, :creation_time, :last_modified_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#job_category ⇒ String
The category of the job.
32709 32710 32711 32712 32713 32714 32715 32716 32717 32718 32719 32720 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32709 class JobSummary < Struct.new( :job_arn, :job_name, :job_category, :job_status, :job_secondary_status, :creation_time, :last_modified_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#job_name ⇒ String
The name of the job.
32709 32710 32711 32712 32713 32714 32715 32716 32717 32718 32719 32720 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32709 class JobSummary < Struct.new( :job_arn, :job_name, :job_category, :job_status, :job_secondary_status, :creation_time, :last_modified_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#job_secondary_status ⇒ String
The secondary status of the job, providing more granular information about the job’s progress. Secondary statuses may change between releases.
32709 32710 32711 32712 32713 32714 32715 32716 32717 32718 32719 32720 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32709 class JobSummary < Struct.new( :job_arn, :job_name, :job_category, :job_status, :job_secondary_status, :creation_time, :last_modified_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#job_status ⇒ String
The current status of the job.
32709 32710 32711 32712 32713 32714 32715 32716 32717 32718 32719 32720 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32709 class JobSummary < Struct.new( :job_arn, :job_name, :job_category, :job_status, :job_secondary_status, :creation_time, :last_modified_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The date and time that the job was last modified.
32709 32710 32711 32712 32713 32714 32715 32716 32717 32718 32719 32720 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32709 class JobSummary < Struct.new( :job_arn, :job_name, :job_category, :job_status, :job_secondary_status, :creation_time, :last_modified_time, :end_time) SENSITIVE = [] include Aws::Structure end |