Class: Aws::SageMaker::Types::JobSummary

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Provides summary information about a job, returned by the ‘ListJobs` operation. Use `DescribeJob` to get full details for a specific job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timeTime

The date and time that the job was created.

Returns:

  • (Time)


32282
32283
32284
32285
32286
32287
32288
32289
32290
32291
32292
32293
# File 'lib/aws-sdk-sagemaker/types.rb', line 32282

class JobSummary < Struct.new(
  :job_arn,
  :job_name,
  :job_category,
  :job_status,
  :job_secondary_status,
  :creation_time,
  :last_modified_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

The date and time that the job ended.

Returns:

  • (Time)


32282
32283
32284
32285
32286
32287
32288
32289
32290
32291
32292
32293
# File 'lib/aws-sdk-sagemaker/types.rb', line 32282

class JobSummary < Struct.new(
  :job_arn,
  :job_name,
  :job_category,
  :job_status,
  :job_secondary_status,
  :creation_time,
  :last_modified_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#job_arnString

The Amazon Resource Name (ARN) of the job.

Returns:

  • (String)


32282
32283
32284
32285
32286
32287
32288
32289
32290
32291
32292
32293
# File 'lib/aws-sdk-sagemaker/types.rb', line 32282

class JobSummary < Struct.new(
  :job_arn,
  :job_name,
  :job_category,
  :job_status,
  :job_secondary_status,
  :creation_time,
  :last_modified_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#job_categoryString

The category of the job.

Returns:

  • (String)


32282
32283
32284
32285
32286
32287
32288
32289
32290
32291
32292
32293
# File 'lib/aws-sdk-sagemaker/types.rb', line 32282

class JobSummary < Struct.new(
  :job_arn,
  :job_name,
  :job_category,
  :job_status,
  :job_secondary_status,
  :creation_time,
  :last_modified_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#job_nameString

The name of the job.

Returns:

  • (String)


32282
32283
32284
32285
32286
32287
32288
32289
32290
32291
32292
32293
# File 'lib/aws-sdk-sagemaker/types.rb', line 32282

class JobSummary < Struct.new(
  :job_arn,
  :job_name,
  :job_category,
  :job_status,
  :job_secondary_status,
  :creation_time,
  :last_modified_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#job_secondary_statusString

The secondary status of the job, providing more granular information about the job’s progress. Secondary statuses may change between releases.

Returns:

  • (String)


32282
32283
32284
32285
32286
32287
32288
32289
32290
32291
32292
32293
# File 'lib/aws-sdk-sagemaker/types.rb', line 32282

class JobSummary < Struct.new(
  :job_arn,
  :job_name,
  :job_category,
  :job_status,
  :job_secondary_status,
  :creation_time,
  :last_modified_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#job_statusString

The current status of the job.

Returns:

  • (String)


32282
32283
32284
32285
32286
32287
32288
32289
32290
32291
32292
32293
# File 'lib/aws-sdk-sagemaker/types.rb', line 32282

class JobSummary < Struct.new(
  :job_arn,
  :job_name,
  :job_category,
  :job_status,
  :job_secondary_status,
  :creation_time,
  :last_modified_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The date and time that the job was last modified.

Returns:

  • (Time)


32282
32283
32284
32285
32286
32287
32288
32289
32290
32291
32292
32293
# File 'lib/aws-sdk-sagemaker/types.rb', line 32282

class JobSummary < Struct.new(
  :job_arn,
  :job_name,
  :job_category,
  :job_status,
  :job_secondary_status,
  :creation_time,
  :last_modified_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end