Class: Aws::SageMaker::Types::JupyterLabAppSettings

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The settings for the JupyterLab application.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#app_lifecycle_managementTypes::AppLifecycleManagement

Indicates whether idle shutdown is activated for JupyterLab applications.



32371
32372
32373
32374
32375
32376
32377
32378
32379
32380
32381
# File 'lib/aws-sdk-sagemaker/types.rb', line 32371

class JupyterLabAppSettings < Struct.new(
  :default_resource_spec,
  :custom_images,
  :lifecycle_config_arns,
  :code_repositories,
  :app_lifecycle_management,
  :emr_settings,
  :built_in_lifecycle_config_arn)
  SENSITIVE = []
  include Aws::Structure
end

#built_in_lifecycle_config_arnString

The lifecycle configuration that runs before the default lifecycle configuration. It can override changes made in the default lifecycle configuration.

Returns:

  • (String)


32371
32372
32373
32374
32375
32376
32377
32378
32379
32380
32381
# File 'lib/aws-sdk-sagemaker/types.rb', line 32371

class JupyterLabAppSettings < Struct.new(
  :default_resource_spec,
  :custom_images,
  :lifecycle_config_arns,
  :code_repositories,
  :app_lifecycle_management,
  :emr_settings,
  :built_in_lifecycle_config_arn)
  SENSITIVE = []
  include Aws::Structure
end

#code_repositoriesArray<Types::CodeRepository>

A list of Git repositories that SageMaker automatically displays to users for cloning in the JupyterLab application.

Returns:



32371
32372
32373
32374
32375
32376
32377
32378
32379
32380
32381
# File 'lib/aws-sdk-sagemaker/types.rb', line 32371

class JupyterLabAppSettings < Struct.new(
  :default_resource_spec,
  :custom_images,
  :lifecycle_config_arns,
  :code_repositories,
  :app_lifecycle_management,
  :emr_settings,
  :built_in_lifecycle_config_arn)
  SENSITIVE = []
  include Aws::Structure
end

#custom_imagesArray<Types::CustomImage>

A list of custom SageMaker images that are configured to run as a JupyterLab app.

Returns:



32371
32372
32373
32374
32375
32376
32377
32378
32379
32380
32381
# File 'lib/aws-sdk-sagemaker/types.rb', line 32371

class JupyterLabAppSettings < Struct.new(
  :default_resource_spec,
  :custom_images,
  :lifecycle_config_arns,
  :code_repositories,
  :app_lifecycle_management,
  :emr_settings,
  :built_in_lifecycle_config_arn)
  SENSITIVE = []
  include Aws::Structure
end

#default_resource_specTypes::ResourceSpec

Specifies the ARN’s of a SageMaker AI image and SageMaker AI image version, and the instance type that the version runs on.

<note markdown=“1”> When both ‘SageMakerImageVersionArn` and `SageMakerImageArn` are passed, `SageMakerImageVersionArn` is used. Any updates to `SageMakerImageArn` will not take effect if `SageMakerImageVersionArn` already exists in the `ResourceSpec` because `SageMakerImageVersionArn` always takes precedence. To clear the value set for `SageMakerImageVersionArn`, pass `None` as the value.

</note>

Returns:



32371
32372
32373
32374
32375
32376
32377
32378
32379
32380
32381
# File 'lib/aws-sdk-sagemaker/types.rb', line 32371

class JupyterLabAppSettings < Struct.new(
  :default_resource_spec,
  :custom_images,
  :lifecycle_config_arns,
  :code_repositories,
  :app_lifecycle_management,
  :emr_settings,
  :built_in_lifecycle_config_arn)
  SENSITIVE = []
  include Aws::Structure
end

#emr_settingsTypes::EmrSettings

The configuration parameters that specify the IAM roles assumed by the execution role of SageMaker (assumable roles) and the cluster instances or job execution environments (execution roles or runtime roles) to manage and access resources required for running Amazon EMR clusters or Amazon EMR Serverless applications.

Returns:



32371
32372
32373
32374
32375
32376
32377
32378
32379
32380
32381
# File 'lib/aws-sdk-sagemaker/types.rb', line 32371

class JupyterLabAppSettings < Struct.new(
  :default_resource_spec,
  :custom_images,
  :lifecycle_config_arns,
  :code_repositories,
  :app_lifecycle_management,
  :emr_settings,
  :built_in_lifecycle_config_arn)
  SENSITIVE = []
  include Aws::Structure
end

#lifecycle_config_arnsArray<String>

The Amazon Resource Name (ARN) of the lifecycle configurations attached to the user profile or domain. To remove a lifecycle config, you must set ‘LifecycleConfigArns` to an empty list.

Returns:

  • (Array<String>)


32371
32372
32373
32374
32375
32376
32377
32378
32379
32380
32381
# File 'lib/aws-sdk-sagemaker/types.rb', line 32371

class JupyterLabAppSettings < Struct.new(
  :default_resource_spec,
  :custom_images,
  :lifecycle_config_arns,
  :code_repositories,
  :app_lifecycle_management,
  :emr_settings,
  :built_in_lifecycle_config_arn)
  SENSITIVE = []
  include Aws::Structure
end