Class: Aws::SageMaker::Types::JupyterServerAppSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::JupyterServerAppSettings
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The JupyterServer app settings.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code_repositories ⇒ Array<Types::CodeRepository>
A list of Git repositories that SageMaker AI automatically displays to users for cloning in the JupyterServer application.
-
#default_resource_spec ⇒ Types::ResourceSpec
The default instance type and the Amazon Resource Name (ARN) of the default SageMaker AI image used by the JupyterServer app.
-
#lifecycle_config_arns ⇒ Array<String>
The Amazon Resource Name (ARN) of the Lifecycle Configurations attached to the JupyterServerApp.
Instance Attribute Details
#code_repositories ⇒ Array<Types::CodeRepository>
A list of Git repositories that SageMaker AI automatically displays to users for cloning in the JupyterServer application.
30500 30501 30502 30503 30504 30505 30506 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30500 class JupyterServerAppSettings < Struct.new( :default_resource_spec, :lifecycle_config_arns, :code_repositories) SENSITIVE = [] include Aws::Structure end |
#default_resource_spec ⇒ Types::ResourceSpec
The default instance type and the Amazon Resource Name (ARN) of the
default SageMaker AI image used by the JupyterServer app. If you use
the LifecycleConfigArns parameter, then this parameter is also
required.
30500 30501 30502 30503 30504 30505 30506 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30500 class JupyterServerAppSettings < Struct.new( :default_resource_spec, :lifecycle_config_arns, :code_repositories) SENSITIVE = [] include Aws::Structure end |
#lifecycle_config_arns ⇒ Array<String>
The Amazon Resource Name (ARN) of the Lifecycle Configurations
attached to the JupyterServerApp. If you use this parameter, the
DefaultResourceSpec parameter is also required.
LifecycleConfigArns to
an empty list.
30500 30501 30502 30503 30504 30505 30506 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30500 class JupyterServerAppSettings < Struct.new( :default_resource_spec, :lifecycle_config_arns, :code_repositories) SENSITIVE = [] include Aws::Structure end |