Class: Aws::SageMaker::Types::KernelGatewayAppSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::KernelGatewayAppSettings
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The KernelGateway app settings.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#custom_images ⇒ Array<Types::CustomImage>
A list of custom SageMaker AI images that are configured to run as a KernelGateway app.
-
#default_resource_spec ⇒ Types::ResourceSpec
The default instance type and the Amazon Resource Name (ARN) of the default SageMaker AI image used by the KernelGateway app.
-
#lifecycle_config_arns ⇒ Array<String>
The Amazon Resource Name (ARN) of the Lifecycle Configurations attached to the the user profile or domain.
Instance Attribute Details
#custom_images ⇒ Array<Types::CustomImage>
A list of custom SageMaker AI images that are configured to run as a KernelGateway app.
The maximum number of custom images are as follows.
-
On a domain level: 200
-
On a space level: 5
-
On a user profile level: 5
30239 30240 30241 30242 30243 30244 30245 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30239 class KernelGatewayAppSettings < Struct.new( :default_resource_spec, :custom_images, :lifecycle_config_arns) SENSITIVE = [] include Aws::Structure end |
#default_resource_spec ⇒ Types::ResourceSpec
The default instance type and the Amazon Resource Name (ARN) of the default SageMaker AI image used by the KernelGateway app.
<note markdown=“1”> The Amazon SageMaker AI Studio UI does not use the default instance type value set here. The default instance type set here is used when Apps are created using the CLI or CloudFormation and the instance type parameter value is not passed.
</note>
30239 30240 30241 30242 30243 30244 30245 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30239 class KernelGatewayAppSettings < Struct.new( :default_resource_spec, :custom_images, :lifecycle_config_arns) SENSITIVE = [] include Aws::Structure end |
#lifecycle_config_arns ⇒ Array<String>
The Amazon Resource Name (ARN) of the Lifecycle Configurations attached to the the user profile or domain.
<note markdown=“1”> To remove a Lifecycle Config, you must set ‘LifecycleConfigArns` to an empty list.
</note>
30239 30240 30241 30242 30243 30244 30245 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 30239 class KernelGatewayAppSettings < Struct.new( :default_resource_spec, :custom_images, :lifecycle_config_arns) SENSITIVE = [] include Aws::Structure end |