Class: Aws::SageMaker::Types::LabelingJobDataAttributes

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Attributes of the data specified by the customer. Use these to describe the data to be labeled.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#content_classifiersArray<String>

Declares that your content is free of personally identifiable information or adult content. SageMaker may restrict the Amazon Mechanical Turk workers that can view your task based on this information.

Returns:

  • (Array<String>)


32919
32920
32921
32922
32923
# File 'lib/aws-sdk-sagemaker/types.rb', line 32919

class LabelingJobDataAttributes < Struct.new(
  :content_classifiers)
  SENSITIVE = []
  include Aws::Structure
end