Class: Aws::SageMaker::Types::LabelingJobDataAttributes
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::LabelingJobDataAttributes
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Attributes of the data specified by the customer. Use these to describe the data to be labeled.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#content_classifiers ⇒ Array<String>
Declares that your content is free of personally identifiable information or adult content.
Instance Attribute Details
#content_classifiers ⇒ Array<String>
Declares that your content is free of personally identifiable information or adult content. SageMaker may restrict the Amazon Mechanical Turk workers that can view your task based on this information.
32127 32128 32129 32130 32131 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32127 class LabelingJobDataAttributes < Struct.new( :content_classifiers) SENSITIVE = [] include Aws::Structure end |