Class: Aws::SageMaker::Types::LabelingJobSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::LabelingJobSummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Provides summary information about a labeling job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#annotation_consolidation_lambda_arn ⇒ String
The Amazon Resource Name (ARN) of the Lambda function used to consolidate the annotations from individual workers into a label for a data object.
-
#creation_time ⇒ Time
The date and time that the job was created (timestamp).
-
#failure_reason ⇒ String
If the ‘LabelingJobStatus` field is `Failed`, this field contains a description of the error.
-
#input_config ⇒ Types::LabelingJobInputConfig
Input configuration for the labeling job.
-
#label_counters ⇒ Types::LabelCounters
Counts showing the progress of the labeling job.
-
#labeling_job_arn ⇒ String
The Amazon Resource Name (ARN) assigned to the labeling job when it was created.
-
#labeling_job_name ⇒ String
The name of the labeling job.
-
#labeling_job_output ⇒ Types::LabelingJobOutput
The location of the output produced by the labeling job.
-
#labeling_job_status ⇒ String
The current status of the labeling job.
-
#last_modified_time ⇒ Time
The date and time that the job was last modified (timestamp).
-
#pre_human_task_lambda_arn ⇒ String
The Amazon Resource Name (ARN) of a Lambda function.
-
#workteam_arn ⇒ String
The Amazon Resource Name (ARN) of the work team assigned to the job.
Instance Attribute Details
#annotation_consolidation_lambda_arn ⇒ String
The Amazon Resource Name (ARN) of the Lambda function used to consolidate the annotations from individual workers into a label for a data object. For more information, see [Annotation Consolidation].
[1]: docs.aws.amazon.com/sagemaker/latest/dg/sms-annotation-consolidation.html
33439 33440 33441 33442 33443 33444 33445 33446 33447 33448 33449 33450 33451 33452 33453 33454 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33439 class LabelingJobSummary < Struct.new( :labeling_job_name, :labeling_job_arn, :creation_time, :last_modified_time, :labeling_job_status, :label_counters, :workteam_arn, :pre_human_task_lambda_arn, :annotation_consolidation_lambda_arn, :failure_reason, :labeling_job_output, :input_config) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The date and time that the job was created (timestamp).
33439 33440 33441 33442 33443 33444 33445 33446 33447 33448 33449 33450 33451 33452 33453 33454 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33439 class LabelingJobSummary < Struct.new( :labeling_job_name, :labeling_job_arn, :creation_time, :last_modified_time, :labeling_job_status, :label_counters, :workteam_arn, :pre_human_task_lambda_arn, :annotation_consolidation_lambda_arn, :failure_reason, :labeling_job_output, :input_config) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
If the ‘LabelingJobStatus` field is `Failed`, this field contains a description of the error.
33439 33440 33441 33442 33443 33444 33445 33446 33447 33448 33449 33450 33451 33452 33453 33454 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33439 class LabelingJobSummary < Struct.new( :labeling_job_name, :labeling_job_arn, :creation_time, :last_modified_time, :labeling_job_status, :label_counters, :workteam_arn, :pre_human_task_lambda_arn, :annotation_consolidation_lambda_arn, :failure_reason, :labeling_job_output, :input_config) SENSITIVE = [] include Aws::Structure end |
#input_config ⇒ Types::LabelingJobInputConfig
Input configuration for the labeling job.
33439 33440 33441 33442 33443 33444 33445 33446 33447 33448 33449 33450 33451 33452 33453 33454 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33439 class LabelingJobSummary < Struct.new( :labeling_job_name, :labeling_job_arn, :creation_time, :last_modified_time, :labeling_job_status, :label_counters, :workteam_arn, :pre_human_task_lambda_arn, :annotation_consolidation_lambda_arn, :failure_reason, :labeling_job_output, :input_config) SENSITIVE = [] include Aws::Structure end |
#label_counters ⇒ Types::LabelCounters
Counts showing the progress of the labeling job.
33439 33440 33441 33442 33443 33444 33445 33446 33447 33448 33449 33450 33451 33452 33453 33454 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33439 class LabelingJobSummary < Struct.new( :labeling_job_name, :labeling_job_arn, :creation_time, :last_modified_time, :labeling_job_status, :label_counters, :workteam_arn, :pre_human_task_lambda_arn, :annotation_consolidation_lambda_arn, :failure_reason, :labeling_job_output, :input_config) SENSITIVE = [] include Aws::Structure end |
#labeling_job_arn ⇒ String
The Amazon Resource Name (ARN) assigned to the labeling job when it was created.
33439 33440 33441 33442 33443 33444 33445 33446 33447 33448 33449 33450 33451 33452 33453 33454 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33439 class LabelingJobSummary < Struct.new( :labeling_job_name, :labeling_job_arn, :creation_time, :last_modified_time, :labeling_job_status, :label_counters, :workteam_arn, :pre_human_task_lambda_arn, :annotation_consolidation_lambda_arn, :failure_reason, :labeling_job_output, :input_config) SENSITIVE = [] include Aws::Structure end |
#labeling_job_name ⇒ String
The name of the labeling job.
33439 33440 33441 33442 33443 33444 33445 33446 33447 33448 33449 33450 33451 33452 33453 33454 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33439 class LabelingJobSummary < Struct.new( :labeling_job_name, :labeling_job_arn, :creation_time, :last_modified_time, :labeling_job_status, :label_counters, :workteam_arn, :pre_human_task_lambda_arn, :annotation_consolidation_lambda_arn, :failure_reason, :labeling_job_output, :input_config) SENSITIVE = [] include Aws::Structure end |
#labeling_job_output ⇒ Types::LabelingJobOutput
The location of the output produced by the labeling job.
33439 33440 33441 33442 33443 33444 33445 33446 33447 33448 33449 33450 33451 33452 33453 33454 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33439 class LabelingJobSummary < Struct.new( :labeling_job_name, :labeling_job_arn, :creation_time, :last_modified_time, :labeling_job_status, :label_counters, :workteam_arn, :pre_human_task_lambda_arn, :annotation_consolidation_lambda_arn, :failure_reason, :labeling_job_output, :input_config) SENSITIVE = [] include Aws::Structure end |
#labeling_job_status ⇒ String
The current status of the labeling job.
33439 33440 33441 33442 33443 33444 33445 33446 33447 33448 33449 33450 33451 33452 33453 33454 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33439 class LabelingJobSummary < Struct.new( :labeling_job_name, :labeling_job_arn, :creation_time, :last_modified_time, :labeling_job_status, :label_counters, :workteam_arn, :pre_human_task_lambda_arn, :annotation_consolidation_lambda_arn, :failure_reason, :labeling_job_output, :input_config) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The date and time that the job was last modified (timestamp).
33439 33440 33441 33442 33443 33444 33445 33446 33447 33448 33449 33450 33451 33452 33453 33454 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33439 class LabelingJobSummary < Struct.new( :labeling_job_name, :labeling_job_arn, :creation_time, :last_modified_time, :labeling_job_status, :label_counters, :workteam_arn, :pre_human_task_lambda_arn, :annotation_consolidation_lambda_arn, :failure_reason, :labeling_job_output, :input_config) SENSITIVE = [] include Aws::Structure end |
#pre_human_task_lambda_arn ⇒ String
The Amazon Resource Name (ARN) of a Lambda function. The function is run before each data object is sent to a worker.
33439 33440 33441 33442 33443 33444 33445 33446 33447 33448 33449 33450 33451 33452 33453 33454 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33439 class LabelingJobSummary < Struct.new( :labeling_job_name, :labeling_job_arn, :creation_time, :last_modified_time, :labeling_job_status, :label_counters, :workteam_arn, :pre_human_task_lambda_arn, :annotation_consolidation_lambda_arn, :failure_reason, :labeling_job_output, :input_config) SENSITIVE = [] include Aws::Structure end |
#workteam_arn ⇒ String
The Amazon Resource Name (ARN) of the work team assigned to the job.
33439 33440 33441 33442 33443 33444 33445 33446 33447 33448 33449 33450 33451 33452 33453 33454 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33439 class LabelingJobSummary < Struct.new( :labeling_job_name, :labeling_job_arn, :creation_time, :last_modified_time, :labeling_job_status, :label_counters, :workteam_arn, :pre_human_task_lambda_arn, :annotation_consolidation_lambda_arn, :failure_reason, :labeling_job_output, :input_config) SENSITIVE = [] include Aws::Structure end |