Class: Aws::SageMaker::Types::ListArtifactsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListArtifactsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#artifact_type ⇒ String
A filter that returns only artifacts of the specified type.
-
#created_after ⇒ Time
A filter that returns only artifacts created on or after the specified time.
-
#created_before ⇒ Time
A filter that returns only artifacts created on or before the specified time.
-
#max_results ⇒ Integer
The maximum number of artifacts to return in the response.
-
#next_token ⇒ String
If the previous call to
ListArtifactsdidn’t return the full set of artifacts, the call returns a token for getting the next set of artifacts. -
#sort_by ⇒ String
The property used to sort results.
-
#sort_order ⇒ String
The sort order.
-
#source_uri ⇒ String
A filter that returns only artifacts with the specified source URI.
Instance Attribute Details
#artifact_type ⇒ String
A filter that returns only artifacts of the specified type.
31282 31283 31284 31285 31286 31287 31288 31289 31290 31291 31292 31293 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31282 class ListArtifactsRequest < Struct.new( :source_uri, :artifact_type, :created_after, :created_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#created_after ⇒ Time
A filter that returns only artifacts created on or after the specified time.
31282 31283 31284 31285 31286 31287 31288 31289 31290 31291 31292 31293 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31282 class ListArtifactsRequest < Struct.new( :source_uri, :artifact_type, :created_after, :created_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#created_before ⇒ Time
A filter that returns only artifacts created on or before the specified time.
31282 31283 31284 31285 31286 31287 31288 31289 31290 31291 31292 31293 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31282 class ListArtifactsRequest < Struct.new( :source_uri, :artifact_type, :created_after, :created_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of artifacts to return in the response. The default value is 10.
31282 31283 31284 31285 31286 31287 31288 31289 31290 31291 31292 31293 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31282 class ListArtifactsRequest < Struct.new( :source_uri, :artifact_type, :created_after, :created_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the previous call to ListArtifacts didn’t return the full set of artifacts, the call returns a token for getting the next set of artifacts.
31282 31283 31284 31285 31286 31287 31288 31289 31290 31291 31292 31293 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31282 class ListArtifactsRequest < Struct.new( :source_uri, :artifact_type, :created_after, :created_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
The property used to sort results. The default value is CreationTime.
31282 31283 31284 31285 31286 31287 31288 31289 31290 31291 31292 31293 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31282 class ListArtifactsRequest < Struct.new( :source_uri, :artifact_type, :created_after, :created_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
The sort order. The default value is Descending.
31282 31283 31284 31285 31286 31287 31288 31289 31290 31291 31292 31293 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31282 class ListArtifactsRequest < Struct.new( :source_uri, :artifact_type, :created_after, :created_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#source_uri ⇒ String
A filter that returns only artifacts with the specified source URI.
31282 31283 31284 31285 31286 31287 31288 31289 31290 31291 31292 31293 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31282 class ListArtifactsRequest < Struct.new( :source_uri, :artifact_type, :created_after, :created_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |