Class: Aws::SageMaker::Types::ListClusterEventsResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#eventsArray<Types::ClusterEventSummary>

A list of event summaries matching the specified criteria.

Returns:



31618
31619
31620
31621
31622
31623
# File 'lib/aws-sdk-sagemaker/types.rb', line 31618

class ListClusterEventsResponse < Struct.new(
  :next_token,
  :events)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token to retrieve the next set of results. Include this token in subsequent ListClusterEvents calls to fetch more events.

Returns:

  • (String)


31618
31619
31620
31621
31622
31623
# File 'lib/aws-sdk-sagemaker/types.rb', line 31618

class ListClusterEventsResponse < Struct.new(
  :next_token,
  :events)
  SENSITIVE = []
  include Aws::Structure
end