Class: Aws::SageMaker::Types::ListClusterSchedulerConfigsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListClusterSchedulerConfigsResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster_scheduler_config_summaries ⇒ Array<Types::ClusterSchedulerConfigSummary>
Summaries of the cluster policies.
-
#next_token ⇒ String
If the previous response was truncated, you will receive this token.
Instance Attribute Details
#cluster_scheduler_config_summaries ⇒ Array<Types::ClusterSchedulerConfigSummary>
Summaries of the cluster policies.
31906 31907 31908 31909 31910 31911 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31906 class ListClusterSchedulerConfigsResponse < Struct.new( :cluster_scheduler_config_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the previous response was truncated, you will receive this token. Use it in your next request to receive the next set of results.
31906 31907 31908 31909 31910 31911 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 31906 class ListClusterSchedulerConfigsResponse < Struct.new( :cluster_scheduler_config_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |