Class: Aws::SageMaker::Types::ListClustersRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_time_afterTime

Set a start time for the time range during which you want to list SageMaker HyperPod clusters. Timestamps are formatted according to the ISO 8601 standard.

Acceptable formats include:

  • YYYY-MM-DDThh:mm:ss.sssTZD (UTC), for example, 2014-10-01T20:30:00.000Z

  • YYYY-MM-DDThh:mm:ss.sssTZD (with offset), for example, 2014-10-01T12:30:00.000-08:00

  • YYYY-MM-DD, for example, 2014-10-01

  • Unix time in seconds, for example, 1412195400. This is also referred to as Unix Epoch time and represents the number of seconds since midnight, January 1, 1970 UTC.

For more information about the timestamp format, see [Timestamp] in the *Amazon Web Services Command Line Interface User Guide*.

[1]: docs.aws.amazon.com/cli/latest/userguide/cli-usage-parameters-types.html#parameter-type-timestamp

Returns:

  • (Time)


31923
31924
31925
31926
31927
31928
31929
31930
31931
31932
31933
31934
# File 'lib/aws-sdk-sagemaker/types.rb', line 31923

class ListClustersRequest < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :max_results,
  :name_contains,
  :next_token,
  :sort_by,
  :sort_order,
  :training_plan_arn)
  SENSITIVE = []
  include Aws::Structure
end

#creation_time_beforeTime

Set an end time for the time range during which you want to list SageMaker HyperPod clusters. A filter that returns nodes in a SageMaker HyperPod cluster created before the specified time. The acceptable formats are the same as the timestamp formats for CreationTimeAfter. For more information about the timestamp format, see [Timestamp] in the *Amazon Web Services Command Line Interface User Guide*.

[1]: docs.aws.amazon.com/cli/latest/userguide/cli-usage-parameters-types.html#parameter-type-timestamp

Returns:

  • (Time)


31923
31924
31925
31926
31927
31928
31929
31930
31931
31932
31933
31934
# File 'lib/aws-sdk-sagemaker/types.rb', line 31923

class ListClustersRequest < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :max_results,
  :name_contains,
  :next_token,
  :sort_by,
  :sort_order,
  :training_plan_arn)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

Specifies the maximum number of clusters to evaluate for the operation (not necessarily the number of matching items). After SageMaker processes the number of clusters up to MaxResults, it stops the operation and returns the matching clusters up to that point. If all the matching clusters are desired, SageMaker will go through all the clusters until NextToken is empty.

Returns:

  • (Integer)


31923
31924
31925
31926
31927
31928
31929
31930
31931
31932
31933
31934
# File 'lib/aws-sdk-sagemaker/types.rb', line 31923

class ListClustersRequest < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :max_results,
  :name_contains,
  :next_token,
  :sort_by,
  :sort_order,
  :training_plan_arn)
  SENSITIVE = []
  include Aws::Structure
end

#name_containsString

Set the maximum number of instances to print in the list.

Returns:

  • (String)


31923
31924
31925
31926
31927
31928
31929
31930
31931
31932
31933
31934
# File 'lib/aws-sdk-sagemaker/types.rb', line 31923

class ListClustersRequest < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :max_results,
  :name_contains,
  :next_token,
  :sort_by,
  :sort_order,
  :training_plan_arn)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

Set the next token to retrieve the list of SageMaker HyperPod clusters.

Returns:

  • (String)


31923
31924
31925
31926
31927
31928
31929
31930
31931
31932
31933
31934
# File 'lib/aws-sdk-sagemaker/types.rb', line 31923

class ListClustersRequest < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :max_results,
  :name_contains,
  :next_token,
  :sort_by,
  :sort_order,
  :training_plan_arn)
  SENSITIVE = []
  include Aws::Structure
end

#sort_byString

The field by which to sort results. The default value is CREATION_TIME.

Returns:

  • (String)


31923
31924
31925
31926
31927
31928
31929
31930
31931
31932
31933
31934
# File 'lib/aws-sdk-sagemaker/types.rb', line 31923

class ListClustersRequest < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :max_results,
  :name_contains,
  :next_token,
  :sort_by,
  :sort_order,
  :training_plan_arn)
  SENSITIVE = []
  include Aws::Structure
end

#sort_orderString

The sort order for results. The default value is Ascending.

Returns:

  • (String)


31923
31924
31925
31926
31927
31928
31929
31930
31931
31932
31933
31934
# File 'lib/aws-sdk-sagemaker/types.rb', line 31923

class ListClustersRequest < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :max_results,
  :name_contains,
  :next_token,
  :sort_by,
  :sort_order,
  :training_plan_arn)
  SENSITIVE = []
  include Aws::Structure
end

#training_plan_arnString

The Amazon Resource Name (ARN); of the training plan to filter clusters by. For more information about reserving GPU capacity for your SageMaker HyperPod clusters using Amazon SageMaker Training Plan, see ‘ CreateTrainingPlan `.

Returns:

  • (String)


31923
31924
31925
31926
31927
31928
31929
31930
31931
31932
31933
31934
# File 'lib/aws-sdk-sagemaker/types.rb', line 31923

class ListClustersRequest < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :max_results,
  :name_contains,
  :next_token,
  :sort_by,
  :sort_order,
  :training_plan_arn)
  SENSITIVE = []
  include Aws::Structure
end