Class: Aws::SageMaker::Types::ListComputeQuotasRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_arnString

Filter for ARN of the cluster.



35528
35529
35530
35531
35532
35533
35534
35535
35536
35537
35538
35539
35540
# File 'lib/aws-sdk-sagemaker/types.rb', line 35528

class ListComputeQuotasRequest < Struct.new(
  :created_after,
  :created_before,
  :name_contains,
  :status,
  :cluster_arn,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#created_afterTime

Filter for after this creation time. The input for this parameter is a Unix timestamp. To convert a date and time into a Unix timestamp, see EpochConverter.



35528
35529
35530
35531
35532
35533
35534
35535
35536
35537
35538
35539
35540
# File 'lib/aws-sdk-sagemaker/types.rb', line 35528

class ListComputeQuotasRequest < Struct.new(
  :created_after,
  :created_before,
  :name_contains,
  :status,
  :cluster_arn,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#created_beforeTime

Filter for before this creation time. The input for this parameter is a Unix timestamp. To convert a date and time into a Unix timestamp, see EpochConverter.



35528
35529
35530
35531
35532
35533
35534
35535
35536
35537
35538
35539
35540
# File 'lib/aws-sdk-sagemaker/types.rb', line 35528

class ListComputeQuotasRequest < Struct.new(
  :created_after,
  :created_before,
  :name_contains,
  :status,
  :cluster_arn,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of compute allocation definitions to list.



35528
35529
35530
35531
35532
35533
35534
35535
35536
35537
35538
35539
35540
# File 'lib/aws-sdk-sagemaker/types.rb', line 35528

class ListComputeQuotasRequest < Struct.new(
  :created_after,
  :created_before,
  :name_contains,
  :status,
  :cluster_arn,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#name_containsString

Filter for name containing this string.



35528
35529
35530
35531
35532
35533
35534
35535
35536
35537
35538
35539
35540
# File 'lib/aws-sdk-sagemaker/types.rb', line 35528

class ListComputeQuotasRequest < Struct.new(
  :created_after,
  :created_before,
  :name_contains,
  :status,
  :cluster_arn,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the previous response was truncated, you will receive this token. Use it in your next request to receive the next set of results.



35528
35529
35530
35531
35532
35533
35534
35535
35536
35537
35538
35539
35540
# File 'lib/aws-sdk-sagemaker/types.rb', line 35528

class ListComputeQuotasRequest < Struct.new(
  :created_after,
  :created_before,
  :name_contains,
  :status,
  :cluster_arn,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#sort_byString

Filter for sorting the list by a given value. For example, sort by name, creation time, or status.



35528
35529
35530
35531
35532
35533
35534
35535
35536
35537
35538
35539
35540
# File 'lib/aws-sdk-sagemaker/types.rb', line 35528

class ListComputeQuotasRequest < Struct.new(
  :created_after,
  :created_before,
  :name_contains,
  :status,
  :cluster_arn,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#sort_orderString

The order of the list. By default, listed in Descending order according to by SortBy. To change the list order, you can specify SortOrder to be Ascending.



35528
35529
35530
35531
35532
35533
35534
35535
35536
35537
35538
35539
35540
# File 'lib/aws-sdk-sagemaker/types.rb', line 35528

class ListComputeQuotasRequest < Struct.new(
  :created_after,
  :created_before,
  :name_contains,
  :status,
  :cluster_arn,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

Filter for status.



35528
35529
35530
35531
35532
35533
35534
35535
35536
35537
35538
35539
35540
# File 'lib/aws-sdk-sagemaker/types.rb', line 35528

class ListComputeQuotasRequest < Struct.new(
  :created_after,
  :created_before,
  :name_contains,
  :status,
  :cluster_arn,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end