Class: Aws::SageMaker::Types::ListComputeQuotasRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListComputeQuotasRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster_arn ⇒ String
Filter for ARN of the cluster.
-
#created_after ⇒ Time
Filter for after this creation time.
-
#created_before ⇒ Time
Filter for before this creation time.
-
#max_results ⇒ Integer
The maximum number of compute allocation definitions to list.
-
#name_contains ⇒ String
Filter for name containing this string.
-
#next_token ⇒ String
If the previous response was truncated, you will receive this token.
-
#sort_by ⇒ String
Filter for sorting the list by a given value.
-
#sort_order ⇒ String
The order of the list.
-
#status ⇒ String
Filter for status.
Instance Attribute Details
#cluster_arn ⇒ String
Filter for ARN of the cluster.
35528 35529 35530 35531 35532 35533 35534 35535 35536 35537 35538 35539 35540 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35528 class ListComputeQuotasRequest < Struct.new( :created_after, :created_before, :name_contains, :status, :cluster_arn, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#created_after ⇒ Time
Filter for after this creation time. The input for this parameter is a Unix timestamp. To convert a date and time into a Unix timestamp, see EpochConverter.
35528 35529 35530 35531 35532 35533 35534 35535 35536 35537 35538 35539 35540 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35528 class ListComputeQuotasRequest < Struct.new( :created_after, :created_before, :name_contains, :status, :cluster_arn, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#created_before ⇒ Time
Filter for before this creation time. The input for this parameter is a Unix timestamp. To convert a date and time into a Unix timestamp, see EpochConverter.
35528 35529 35530 35531 35532 35533 35534 35535 35536 35537 35538 35539 35540 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35528 class ListComputeQuotasRequest < Struct.new( :created_after, :created_before, :name_contains, :status, :cluster_arn, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of compute allocation definitions to list.
35528 35529 35530 35531 35532 35533 35534 35535 35536 35537 35538 35539 35540 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35528 class ListComputeQuotasRequest < Struct.new( :created_after, :created_before, :name_contains, :status, :cluster_arn, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#name_contains ⇒ String
Filter for name containing this string.
35528 35529 35530 35531 35532 35533 35534 35535 35536 35537 35538 35539 35540 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35528 class ListComputeQuotasRequest < Struct.new( :created_after, :created_before, :name_contains, :status, :cluster_arn, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the previous response was truncated, you will receive this token. Use it in your next request to receive the next set of results.
35528 35529 35530 35531 35532 35533 35534 35535 35536 35537 35538 35539 35540 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35528 class ListComputeQuotasRequest < Struct.new( :created_after, :created_before, :name_contains, :status, :cluster_arn, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
Filter for sorting the list by a given value. For example, sort by name, creation time, or status.
35528 35529 35530 35531 35532 35533 35534 35535 35536 35537 35538 35539 35540 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35528 class ListComputeQuotasRequest < Struct.new( :created_after, :created_before, :name_contains, :status, :cluster_arn, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
The order of the list. By default, listed in Descending order
according to by SortBy. To change the list order, you can specify
SortOrder to be Ascending.
35528 35529 35530 35531 35532 35533 35534 35535 35536 35537 35538 35539 35540 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35528 class ListComputeQuotasRequest < Struct.new( :created_after, :created_before, :name_contains, :status, :cluster_arn, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Filter for status.
35528 35529 35530 35531 35532 35533 35534 35535 35536 35537 35538 35539 35540 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35528 class ListComputeQuotasRequest < Struct.new( :created_after, :created_before, :name_contains, :status, :cluster_arn, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |