Class: Aws::SageMaker::Types::ListComputeQuotasResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListComputeQuotasResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compute_quota_summaries ⇒ Array<Types::ComputeQuotaSummary>
Summaries of the compute allocation definitions.
-
#next_token ⇒ String
If the previous response was truncated, you will receive this token.
Instance Attribute Details
#compute_quota_summaries ⇒ Array<Types::ComputeQuotaSummary>
Summaries of the compute allocation definitions.
32216 32217 32218 32219 32220 32221 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32216 class ListComputeQuotasResponse < Struct.new( :compute_quota_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the previous response was truncated, you will receive this token. Use it in your next request to receive the next set of results.
32216 32217 32218 32219 32220 32221 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32216 class ListComputeQuotasResponse < Struct.new( :compute_quota_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |