Class: Aws::SageMaker::Types::ListComputeQuotasResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#compute_quota_summariesArray<Types::ComputeQuotaSummary>

Summaries of the compute allocation definitions.

Returns:



32190
32191
32192
32193
32194
32195
# File 'lib/aws-sdk-sagemaker/types.rb', line 32190

class ListComputeQuotasResponse < Struct.new(
  :compute_quota_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the previous response was truncated, you will receive this token. Use it in your next request to receive the next set of results.

Returns:

  • (String)


32190
32191
32192
32193
32194
32195
# File 'lib/aws-sdk-sagemaker/types.rb', line 32190

class ListComputeQuotasResponse < Struct.new(
  :compute_quota_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end