Class: Aws::SageMaker::Types::ListDataQualityJobDefinitionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListDataQualityJobDefinitionsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time_after ⇒ Time
A filter that returns only data quality monitoring job definitions created after the specified time.
-
#creation_time_before ⇒ Time
A filter that returns only data quality monitoring job definitions created before the specified time.
-
#endpoint_name ⇒ String
A filter that lists the data quality job definitions associated with the specified endpoint.
-
#max_results ⇒ Integer
The maximum number of data quality monitoring job definitions to return in the response.
-
#name_contains ⇒ String
A string in the data quality monitoring job definition name.
-
#next_token ⇒ String
If the result of the previous
ListDataQualityJobDefinitionsrequest was truncated, the response includes aNextToken. -
#sort_by ⇒ String
The field to sort results by.
-
#sort_order ⇒ String
Whether to sort the results in
AscendingorDescendingorder.
Instance Attribute Details
#creation_time_after ⇒ Time
A filter that returns only data quality monitoring job definitions created after the specified time.
32404 32405 32406 32407 32408 32409 32410 32411 32412 32413 32414 32415 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32404 class ListDataQualityJobDefinitionsRequest < Struct.new( :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after) SENSITIVE = [] include Aws::Structure end |
#creation_time_before ⇒ Time
A filter that returns only data quality monitoring job definitions created before the specified time.
32404 32405 32406 32407 32408 32409 32410 32411 32412 32413 32414 32415 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32404 class ListDataQualityJobDefinitionsRequest < Struct.new( :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after) SENSITIVE = [] include Aws::Structure end |
#endpoint_name ⇒ String
A filter that lists the data quality job definitions associated with the specified endpoint.
32404 32405 32406 32407 32408 32409 32410 32411 32412 32413 32414 32415 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32404 class ListDataQualityJobDefinitionsRequest < Struct.new( :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of data quality monitoring job definitions to return in the response.
32404 32405 32406 32407 32408 32409 32410 32411 32412 32413 32414 32415 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32404 class ListDataQualityJobDefinitionsRequest < Struct.new( :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after) SENSITIVE = [] include Aws::Structure end |
#name_contains ⇒ String
A string in the data quality monitoring job definition name. This filter returns only data quality monitoring job definitions whose name contains the specified string.
32404 32405 32406 32407 32408 32409 32410 32411 32412 32413 32414 32415 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32404 class ListDataQualityJobDefinitionsRequest < Struct.new( :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the result of the previous ListDataQualityJobDefinitions request was truncated, the response includes a NextToken. To retrieve the next set of transform jobs, use the token in the next request.>
32404 32405 32406 32407 32408 32409 32410 32411 32412 32413 32414 32415 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32404 class ListDataQualityJobDefinitionsRequest < Struct.new( :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
The field to sort results by. The default is CreationTime.
32404 32405 32406 32407 32408 32409 32410 32411 32412 32413 32414 32415 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32404 class ListDataQualityJobDefinitionsRequest < Struct.new( :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
Whether to sort the results in Ascending or Descending order. The default is Descending.
32404 32405 32406 32407 32408 32409 32410 32411 32412 32413 32414 32415 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32404 class ListDataQualityJobDefinitionsRequest < Struct.new( :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after) SENSITIVE = [] include Aws::Structure end |