Class: Aws::SageMaker::Types::ListDomainsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListDomainsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
This parameter defines the maximum number of results that can be return in a single response.
-
#next_token ⇒ String
If the previous response was truncated, you will receive this token.
Instance Attribute Details
#max_results ⇒ Integer
This parameter defines the maximum number of results that can be return in a single response. The MaxResults parameter is an upper bound, not a target. If there are more results available than the value specified, a NextToken is provided in the response. The NextToken indicates that the user should get the next set of results by providing this token as a part of a subsequent call. The default value for MaxResults is 10.
32511 32512 32513 32514 32515 32516 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32511 class ListDomainsRequest < Struct.new( :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the previous response was truncated, you will receive this token. Use it in your next request to receive the next set of results.
32511 32512 32513 32514 32515 32516 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32511 class ListDomainsRequest < Struct.new( :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |