Class: Aws::SageMaker::Types::ListHubContentVersionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListHubContentVersionsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time_after ⇒ Time
Only list hub content versions that were created after the time specified.
-
#creation_time_before ⇒ Time
Only list hub content versions that were created before the time specified.
-
#hub_content_name ⇒ String
The name of the hub content.
-
#hub_content_type ⇒ String
The type of hub content to list versions of.
-
#hub_name ⇒ String
The name of the hub to list the content versions of.
-
#max_results ⇒ Integer
The maximum number of hub content versions to list.
-
#max_schema_version ⇒ String
The upper bound of the hub content schema version.
-
#min_version ⇒ String
The lower bound of the hub content versions to list.
-
#next_token ⇒ String
If the response to a previous
ListHubContentVersionsrequest was truncated, the response includes aNextToken. -
#sort_by ⇒ String
Sort hub content versions by either name or creation time.
-
#sort_order ⇒ String
Sort hub content versions by ascending or descending order.
Instance Attribute Details
#creation_time_after ⇒ Time
Only list hub content versions that were created after the time specified.
33150 33151 33152 33153 33154 33155 33156 33157 33158 33159 33160 33161 33162 33163 33164 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33150 class ListHubContentVersionsRequest < Struct.new( :hub_name, :hub_content_type, :hub_content_name, :min_version, :max_schema_version, :creation_time_before, :creation_time_after, :sort_by, :sort_order, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#creation_time_before ⇒ Time
Only list hub content versions that were created before the time specified.
33150 33151 33152 33153 33154 33155 33156 33157 33158 33159 33160 33161 33162 33163 33164 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33150 class ListHubContentVersionsRequest < Struct.new( :hub_name, :hub_content_type, :hub_content_name, :min_version, :max_schema_version, :creation_time_before, :creation_time_after, :sort_by, :sort_order, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#hub_content_name ⇒ String
The name of the hub content.
33150 33151 33152 33153 33154 33155 33156 33157 33158 33159 33160 33161 33162 33163 33164 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33150 class ListHubContentVersionsRequest < Struct.new( :hub_name, :hub_content_type, :hub_content_name, :min_version, :max_schema_version, :creation_time_before, :creation_time_after, :sort_by, :sort_order, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#hub_content_type ⇒ String
The type of hub content to list versions of.
33150 33151 33152 33153 33154 33155 33156 33157 33158 33159 33160 33161 33162 33163 33164 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33150 class ListHubContentVersionsRequest < Struct.new( :hub_name, :hub_content_type, :hub_content_name, :min_version, :max_schema_version, :creation_time_before, :creation_time_after, :sort_by, :sort_order, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#hub_name ⇒ String
The name of the hub to list the content versions of.
33150 33151 33152 33153 33154 33155 33156 33157 33158 33159 33160 33161 33162 33163 33164 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33150 class ListHubContentVersionsRequest < Struct.new( :hub_name, :hub_content_type, :hub_content_name, :min_version, :max_schema_version, :creation_time_before, :creation_time_after, :sort_by, :sort_order, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of hub content versions to list.
33150 33151 33152 33153 33154 33155 33156 33157 33158 33159 33160 33161 33162 33163 33164 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33150 class ListHubContentVersionsRequest < Struct.new( :hub_name, :hub_content_type, :hub_content_name, :min_version, :max_schema_version, :creation_time_before, :creation_time_after, :sort_by, :sort_order, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_schema_version ⇒ String
The upper bound of the hub content schema version.
33150 33151 33152 33153 33154 33155 33156 33157 33158 33159 33160 33161 33162 33163 33164 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33150 class ListHubContentVersionsRequest < Struct.new( :hub_name, :hub_content_type, :hub_content_name, :min_version, :max_schema_version, :creation_time_before, :creation_time_after, :sort_by, :sort_order, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#min_version ⇒ String
The lower bound of the hub content versions to list.
33150 33151 33152 33153 33154 33155 33156 33157 33158 33159 33160 33161 33162 33163 33164 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33150 class ListHubContentVersionsRequest < Struct.new( :hub_name, :hub_content_type, :hub_content_name, :min_version, :max_schema_version, :creation_time_before, :creation_time_after, :sort_by, :sort_order, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the response to a previous ListHubContentVersions request was truncated, the response includes a NextToken. To retrieve the next set of hub content versions, use the token in the next request.
33150 33151 33152 33153 33154 33155 33156 33157 33158 33159 33160 33161 33162 33163 33164 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33150 class ListHubContentVersionsRequest < Struct.new( :hub_name, :hub_content_type, :hub_content_name, :min_version, :max_schema_version, :creation_time_before, :creation_time_after, :sort_by, :sort_order, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
Sort hub content versions by either name or creation time.
33150 33151 33152 33153 33154 33155 33156 33157 33158 33159 33160 33161 33162 33163 33164 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33150 class ListHubContentVersionsRequest < Struct.new( :hub_name, :hub_content_type, :hub_content_name, :min_version, :max_schema_version, :creation_time_before, :creation_time_after, :sort_by, :sort_order, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
Sort hub content versions by ascending or descending order.
33150 33151 33152 33153 33154 33155 33156 33157 33158 33159 33160 33161 33162 33163 33164 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33150 class ListHubContentVersionsRequest < Struct.new( :hub_name, :hub_content_type, :hub_content_name, :min_version, :max_schema_version, :creation_time_before, :creation_time_after, :sort_by, :sort_order, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |