Class: Aws::SageMaker::Types::ListHubContentsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_time_afterTime

Only list hub content that was created after the time specified.

Returns:

  • (Time)


33162
33163
33164
33165
33166
33167
33168
33169
33170
33171
33172
33173
33174
33175
# File 'lib/aws-sdk-sagemaker/types.rb', line 33162

class ListHubContentsRequest < Struct.new(
  :hub_name,
  :hub_content_type,
  :name_contains,
  :max_schema_version,
  :creation_time_before,
  :creation_time_after,
  :sort_by,
  :sort_order,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#creation_time_beforeTime

Only list hub content that was created before the time specified.

Returns:

  • (Time)


33162
33163
33164
33165
33166
33167
33168
33169
33170
33171
33172
33173
33174
33175
# File 'lib/aws-sdk-sagemaker/types.rb', line 33162

class ListHubContentsRequest < Struct.new(
  :hub_name,
  :hub_content_type,
  :name_contains,
  :max_schema_version,
  :creation_time_before,
  :creation_time_after,
  :sort_by,
  :sort_order,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#hub_content_typeString

The type of hub content to list.

Returns:

  • (String)


33162
33163
33164
33165
33166
33167
33168
33169
33170
33171
33172
33173
33174
33175
# File 'lib/aws-sdk-sagemaker/types.rb', line 33162

class ListHubContentsRequest < Struct.new(
  :hub_name,
  :hub_content_type,
  :name_contains,
  :max_schema_version,
  :creation_time_before,
  :creation_time_after,
  :sort_by,
  :sort_order,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#hub_nameString

The name of the hub to list the contents of.

Returns:

  • (String)


33162
33163
33164
33165
33166
33167
33168
33169
33170
33171
33172
33173
33174
33175
# File 'lib/aws-sdk-sagemaker/types.rb', line 33162

class ListHubContentsRequest < Struct.new(
  :hub_name,
  :hub_content_type,
  :name_contains,
  :max_schema_version,
  :creation_time_before,
  :creation_time_after,
  :sort_by,
  :sort_order,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum amount of hub content to list.

Returns:

  • (Integer)


33162
33163
33164
33165
33166
33167
33168
33169
33170
33171
33172
33173
33174
33175
# File 'lib/aws-sdk-sagemaker/types.rb', line 33162

class ListHubContentsRequest < Struct.new(
  :hub_name,
  :hub_content_type,
  :name_contains,
  :max_schema_version,
  :creation_time_before,
  :creation_time_after,
  :sort_by,
  :sort_order,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_schema_versionString

The upper bound of the hub content schema verion.

Returns:

  • (String)


33162
33163
33164
33165
33166
33167
33168
33169
33170
33171
33172
33173
33174
33175
# File 'lib/aws-sdk-sagemaker/types.rb', line 33162

class ListHubContentsRequest < Struct.new(
  :hub_name,
  :hub_content_type,
  :name_contains,
  :max_schema_version,
  :creation_time_before,
  :creation_time_after,
  :sort_by,
  :sort_order,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#name_containsString

Only list hub content if the name contains the specified string.

Returns:

  • (String)


33162
33163
33164
33165
33166
33167
33168
33169
33170
33171
33172
33173
33174
33175
# File 'lib/aws-sdk-sagemaker/types.rb', line 33162

class ListHubContentsRequest < Struct.new(
  :hub_name,
  :hub_content_type,
  :name_contains,
  :max_schema_version,
  :creation_time_before,
  :creation_time_after,
  :sort_by,
  :sort_order,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the response to a previous ListHubContents request was truncated, the response includes a NextToken. To retrieve the next set of hub content, use the token in the next request.

Returns:

  • (String)


33162
33163
33164
33165
33166
33167
33168
33169
33170
33171
33172
33173
33174
33175
# File 'lib/aws-sdk-sagemaker/types.rb', line 33162

class ListHubContentsRequest < Struct.new(
  :hub_name,
  :hub_content_type,
  :name_contains,
  :max_schema_version,
  :creation_time_before,
  :creation_time_after,
  :sort_by,
  :sort_order,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#sort_byString

Sort hub content versions by either name or creation time.

Returns:

  • (String)


33162
33163
33164
33165
33166
33167
33168
33169
33170
33171
33172
33173
33174
33175
# File 'lib/aws-sdk-sagemaker/types.rb', line 33162

class ListHubContentsRequest < Struct.new(
  :hub_name,
  :hub_content_type,
  :name_contains,
  :max_schema_version,
  :creation_time_before,
  :creation_time_after,
  :sort_by,
  :sort_order,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#sort_orderString

Sort hubs by ascending or descending order.

Returns:

  • (String)


33162
33163
33164
33165
33166
33167
33168
33169
33170
33171
33172
33173
33174
33175
# File 'lib/aws-sdk-sagemaker/types.rb', line 33162

class ListHubContentsRequest < Struct.new(
  :hub_name,
  :hub_content_type,
  :name_contains,
  :max_schema_version,
  :creation_time_before,
  :creation_time_after,
  :sort_by,
  :sort_order,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end