Class: Aws::SageMaker::Types::ListHyperParameterTuningJobsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListHyperParameterTuningJobsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time_after ⇒ Time
A filter that returns only tuning jobs that were created after the specified time.
-
#creation_time_before ⇒ Time
A filter that returns only tuning jobs that were created before the specified time.
-
#last_modified_time_after ⇒ Time
A filter that returns only tuning jobs that were modified after the specified time.
-
#last_modified_time_before ⇒ Time
A filter that returns only tuning jobs that were modified before the specified time.
-
#max_results ⇒ Integer
The maximum number of tuning jobs to return.
-
#name_contains ⇒ String
A string in the tuning job name.
-
#next_token ⇒ String
If the result of the previous
ListHyperParameterTuningJobsrequest was truncated, the response includes aNextToken. -
#sort_by ⇒ String
The field to sort results by.
-
#sort_order ⇒ String
The sort order for results.
-
#status_equals ⇒ String
A filter that returns only tuning jobs with the specified status.
Instance Attribute Details
#creation_time_after ⇒ Time
A filter that returns only tuning jobs that were created after the specified time.
33440 33441 33442 33443 33444 33445 33446 33447 33448 33449 33450 33451 33452 33453 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33440 class ListHyperParameterTuningJobsRequest < Struct.new( :next_token, :max_results, :sort_by, :sort_order, :name_contains, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :status_equals) SENSITIVE = [] include Aws::Structure end |
#creation_time_before ⇒ Time
A filter that returns only tuning jobs that were created before the specified time.
33440 33441 33442 33443 33444 33445 33446 33447 33448 33449 33450 33451 33452 33453 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33440 class ListHyperParameterTuningJobsRequest < Struct.new( :next_token, :max_results, :sort_by, :sort_order, :name_contains, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :status_equals) SENSITIVE = [] include Aws::Structure end |
#last_modified_time_after ⇒ Time
A filter that returns only tuning jobs that were modified after the specified time.
33440 33441 33442 33443 33444 33445 33446 33447 33448 33449 33450 33451 33452 33453 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33440 class ListHyperParameterTuningJobsRequest < Struct.new( :next_token, :max_results, :sort_by, :sort_order, :name_contains, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :status_equals) SENSITIVE = [] include Aws::Structure end |
#last_modified_time_before ⇒ Time
A filter that returns only tuning jobs that were modified before the specified time.
33440 33441 33442 33443 33444 33445 33446 33447 33448 33449 33450 33451 33452 33453 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33440 class ListHyperParameterTuningJobsRequest < Struct.new( :next_token, :max_results, :sort_by, :sort_order, :name_contains, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :status_equals) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of tuning jobs to return. The default value is 10.
33440 33441 33442 33443 33444 33445 33446 33447 33448 33449 33450 33451 33452 33453 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33440 class ListHyperParameterTuningJobsRequest < Struct.new( :next_token, :max_results, :sort_by, :sort_order, :name_contains, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :status_equals) SENSITIVE = [] include Aws::Structure end |
#name_contains ⇒ String
A string in the tuning job name. This filter returns only tuning jobs whose name contains the specified string.
33440 33441 33442 33443 33444 33445 33446 33447 33448 33449 33450 33451 33452 33453 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33440 class ListHyperParameterTuningJobsRequest < Struct.new( :next_token, :max_results, :sort_by, :sort_order, :name_contains, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :status_equals) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the result of the previous ListHyperParameterTuningJobs request was truncated, the response includes a NextToken. To retrieve the next set of tuning jobs, use the token in the next request.
33440 33441 33442 33443 33444 33445 33446 33447 33448 33449 33450 33451 33452 33453 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33440 class ListHyperParameterTuningJobsRequest < Struct.new( :next_token, :max_results, :sort_by, :sort_order, :name_contains, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :status_equals) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
The field to sort results by. The default is Name.
33440 33441 33442 33443 33444 33445 33446 33447 33448 33449 33450 33451 33452 33453 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33440 class ListHyperParameterTuningJobsRequest < Struct.new( :next_token, :max_results, :sort_by, :sort_order, :name_contains, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :status_equals) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
The sort order for results. The default is Ascending.
33440 33441 33442 33443 33444 33445 33446 33447 33448 33449 33450 33451 33452 33453 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33440 class ListHyperParameterTuningJobsRequest < Struct.new( :next_token, :max_results, :sort_by, :sort_order, :name_contains, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :status_equals) SENSITIVE = [] include Aws::Structure end |
#status_equals ⇒ String
A filter that returns only tuning jobs with the specified status.
33440 33441 33442 33443 33444 33445 33446 33447 33448 33449 33450 33451 33452 33453 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33440 class ListHyperParameterTuningJobsRequest < Struct.new( :next_token, :max_results, :sort_by, :sort_order, :name_contains, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :status_equals) SENSITIVE = [] include Aws::Structure end |