Class: Aws::SageMaker::Types::ListInferenceComponentsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListInferenceComponentsInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time_after ⇒ Time
Filters the results to only those inference components that were created after the specified time.
-
#creation_time_before ⇒ Time
Filters the results to only those inference components that were created before the specified time.
-
#endpoint_name_equals ⇒ String
An endpoint name to filter the listed inference components.
-
#last_modified_time_after ⇒ Time
Filters the results to only those inference components that were updated after the specified time.
-
#last_modified_time_before ⇒ Time
Filters the results to only those inference components that were updated before the specified time.
-
#max_results ⇒ Integer
The maximum number of inference components to return in the response.
-
#name_contains ⇒ String
Filters the results to only those inference components with a name that contains the specified string.
-
#next_token ⇒ String
A token that you use to get the next set of results following a truncated response.
-
#sort_by ⇒ String
The field by which to sort the inference components in the response.
-
#sort_order ⇒ String
The sort order for results.
-
#status_equals ⇒ String
Filters the results to only those inference components with the specified status.
-
#variant_name_equals ⇒ String
A production variant name to filter the listed inference components.
Instance Attribute Details
#creation_time_after ⇒ Time
Filters the results to only those inference components that were created after the specified time.
36968 36969 36970 36971 36972 36973 36974 36975 36976 36977 36978 36979 36980 36981 36982 36983 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36968 class ListInferenceComponentsInput < Struct.new( :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after, :status_equals, :endpoint_name_equals, :variant_name_equals) SENSITIVE = [] include Aws::Structure end |
#creation_time_before ⇒ Time
Filters the results to only those inference components that were created before the specified time.
36968 36969 36970 36971 36972 36973 36974 36975 36976 36977 36978 36979 36980 36981 36982 36983 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36968 class ListInferenceComponentsInput < Struct.new( :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after, :status_equals, :endpoint_name_equals, :variant_name_equals) SENSITIVE = [] include Aws::Structure end |
#endpoint_name_equals ⇒ String
An endpoint name to filter the listed inference components. The response includes only those inference components that are hosted at the specified endpoint.
36968 36969 36970 36971 36972 36973 36974 36975 36976 36977 36978 36979 36980 36981 36982 36983 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36968 class ListInferenceComponentsInput < Struct.new( :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after, :status_equals, :endpoint_name_equals, :variant_name_equals) SENSITIVE = [] include Aws::Structure end |
#last_modified_time_after ⇒ Time
Filters the results to only those inference components that were updated after the specified time.
36968 36969 36970 36971 36972 36973 36974 36975 36976 36977 36978 36979 36980 36981 36982 36983 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36968 class ListInferenceComponentsInput < Struct.new( :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after, :status_equals, :endpoint_name_equals, :variant_name_equals) SENSITIVE = [] include Aws::Structure end |
#last_modified_time_before ⇒ Time
Filters the results to only those inference components that were updated before the specified time.
36968 36969 36970 36971 36972 36973 36974 36975 36976 36977 36978 36979 36980 36981 36982 36983 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36968 class ListInferenceComponentsInput < Struct.new( :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after, :status_equals, :endpoint_name_equals, :variant_name_equals) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of inference components to return in the response. This value defaults to 10.
36968 36969 36970 36971 36972 36973 36974 36975 36976 36977 36978 36979 36980 36981 36982 36983 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36968 class ListInferenceComponentsInput < Struct.new( :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after, :status_equals, :endpoint_name_equals, :variant_name_equals) SENSITIVE = [] include Aws::Structure end |
#name_contains ⇒ String
Filters the results to only those inference components with a name that contains the specified string.
36968 36969 36970 36971 36972 36973 36974 36975 36976 36977 36978 36979 36980 36981 36982 36983 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36968 class ListInferenceComponentsInput < Struct.new( :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after, :status_equals, :endpoint_name_equals, :variant_name_equals) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that you use to get the next set of results following a truncated response. If the response to the previous request was truncated, that response provides the value for this token.
36968 36969 36970 36971 36972 36973 36974 36975 36976 36977 36978 36979 36980 36981 36982 36983 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36968 class ListInferenceComponentsInput < Struct.new( :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after, :status_equals, :endpoint_name_equals, :variant_name_equals) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
The field by which to sort the inference components in the response.
The default is CreationTime.
36968 36969 36970 36971 36972 36973 36974 36975 36976 36977 36978 36979 36980 36981 36982 36983 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36968 class ListInferenceComponentsInput < Struct.new( :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after, :status_equals, :endpoint_name_equals, :variant_name_equals) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
The sort order for results. The default is Descending.
36968 36969 36970 36971 36972 36973 36974 36975 36976 36977 36978 36979 36980 36981 36982 36983 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36968 class ListInferenceComponentsInput < Struct.new( :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after, :status_equals, :endpoint_name_equals, :variant_name_equals) SENSITIVE = [] include Aws::Structure end |
#status_equals ⇒ String
Filters the results to only those inference components with the specified status.
36968 36969 36970 36971 36972 36973 36974 36975 36976 36977 36978 36979 36980 36981 36982 36983 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36968 class ListInferenceComponentsInput < Struct.new( :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after, :status_equals, :endpoint_name_equals, :variant_name_equals) SENSITIVE = [] include Aws::Structure end |
#variant_name_equals ⇒ String
A production variant name to filter the listed inference components. The response includes only those inference components that are hosted at the specified variant.
36968 36969 36970 36971 36972 36973 36974 36975 36976 36977 36978 36979 36980 36981 36982 36983 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36968 class ListInferenceComponentsInput < Struct.new( :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after, :status_equals, :endpoint_name_equals, :variant_name_equals) SENSITIVE = [] include Aws::Structure end |