Class: Aws::SageMaker::Types::ListInferenceExperimentsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListInferenceExperimentsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time_after ⇒ Time
Selects inference experiments which were created after this timestamp.
-
#creation_time_before ⇒ Time
Selects inference experiments which were created before this timestamp.
-
#last_modified_time_after ⇒ Time
Selects inference experiments which were last modified after this timestamp.
-
#last_modified_time_before ⇒ Time
Selects inference experiments which were last modified before this timestamp.
-
#max_results ⇒ Integer
The maximum number of results to select.
-
#name_contains ⇒ String
Selects inference experiments whose names contain this name.
-
#next_token ⇒ String
The response from the last list when returning a list large enough to need tokening.
-
#sort_by ⇒ String
The column by which to sort the listed inference experiments.
-
#sort_order ⇒ String
The direction of sorting (ascending or descending).
-
#status_equals ⇒ String
Selects inference experiments which are in this status.
-
#type ⇒ String
Selects inference experiments of this type.
Instance Attribute Details
#creation_time_after ⇒ Time
Selects inference experiments which were created after this timestamp.
36946 36947 36948 36949 36950 36951 36952 36953 36954 36955 36956 36957 36958 36959 36960 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36946 class ListInferenceExperimentsRequest < Struct.new( :name_contains, :type, :status_equals, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#creation_time_before ⇒ Time
Selects inference experiments which were created before this timestamp.
36946 36947 36948 36949 36950 36951 36952 36953 36954 36955 36956 36957 36958 36959 36960 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36946 class ListInferenceExperimentsRequest < Struct.new( :name_contains, :type, :status_equals, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#last_modified_time_after ⇒ Time
Selects inference experiments which were last modified after this timestamp.
36946 36947 36948 36949 36950 36951 36952 36953 36954 36955 36956 36957 36958 36959 36960 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36946 class ListInferenceExperimentsRequest < Struct.new( :name_contains, :type, :status_equals, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#last_modified_time_before ⇒ Time
Selects inference experiments which were last modified before this timestamp.
36946 36947 36948 36949 36950 36951 36952 36953 36954 36955 36956 36957 36958 36959 36960 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36946 class ListInferenceExperimentsRequest < Struct.new( :name_contains, :type, :status_equals, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to select.
36946 36947 36948 36949 36950 36951 36952 36953 36954 36955 36956 36957 36958 36959 36960 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36946 class ListInferenceExperimentsRequest < Struct.new( :name_contains, :type, :status_equals, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#name_contains ⇒ String
Selects inference experiments whose names contain this name.
36946 36947 36948 36949 36950 36951 36952 36953 36954 36955 36956 36957 36958 36959 36960 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36946 class ListInferenceExperimentsRequest < Struct.new( :name_contains, :type, :status_equals, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The response from the last list when returning a list large enough to need tokening.
36946 36947 36948 36949 36950 36951 36952 36953 36954 36955 36956 36957 36958 36959 36960 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36946 class ListInferenceExperimentsRequest < Struct.new( :name_contains, :type, :status_equals, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
The column by which to sort the listed inference experiments.
36946 36947 36948 36949 36950 36951 36952 36953 36954 36955 36956 36957 36958 36959 36960 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36946 class ListInferenceExperimentsRequest < Struct.new( :name_contains, :type, :status_equals, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
The direction of sorting (ascending or descending).
36946 36947 36948 36949 36950 36951 36952 36953 36954 36955 36956 36957 36958 36959 36960 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36946 class ListInferenceExperimentsRequest < Struct.new( :name_contains, :type, :status_equals, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#status_equals ⇒ String
Selects inference experiments which are in this status. For the possible statuses, see DescribeInferenceExperiment.
36946 36947 36948 36949 36950 36951 36952 36953 36954 36955 36956 36957 36958 36959 36960 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36946 class ListInferenceExperimentsRequest < Struct.new( :name_contains, :type, :status_equals, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
Selects inference experiments of this type. For the possible types of inference experiments, see CreateInferenceExperiment.
36946 36947 36948 36949 36950 36951 36952 36953 36954 36955 36956 36957 36958 36959 36960 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36946 class ListInferenceExperimentsRequest < Struct.new( :name_contains, :type, :status_equals, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |