Class: Aws::SageMaker::Types::ListInferenceRecommendationsJobsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListInferenceRecommendationsJobsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time_after ⇒ Time
A filter that returns only jobs created after the specified time (timestamp).
-
#creation_time_before ⇒ Time
A filter that returns only jobs created before the specified time (timestamp).
-
#last_modified_time_after ⇒ Time
A filter that returns only jobs that were last modified after the specified time (timestamp).
-
#last_modified_time_before ⇒ Time
A filter that returns only jobs that were last modified before the specified time (timestamp).
-
#max_results ⇒ Integer
The maximum number of recommendations to return in the response.
-
#model_name_equals ⇒ String
A filter that returns only jobs that were created for this model.
-
#model_package_version_arn_equals ⇒ String
A filter that returns only jobs that were created for this versioned model package.
-
#name_contains ⇒ String
A string in the job name.
-
#next_token ⇒ String
If the response to a previous
ListInferenceRecommendationsJobsRequestrequest was truncated, the response includes aNextToken. -
#sort_by ⇒ String
The parameter by which to sort the results.
-
#sort_order ⇒ String
The sort order for the results.
-
#status_equals ⇒ String
A filter that retrieves only inference recommendations jobs with a specific status.
Instance Attribute Details
#creation_time_after ⇒ Time
A filter that returns only jobs created after the specified time (timestamp).
37095 37096 37097 37098 37099 37100 37101 37102 37103 37104 37105 37106 37107 37108 37109 37110 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37095 class ListInferenceRecommendationsJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :next_token, :max_results, :model_name_equals, :model_package_version_arn_equals) SENSITIVE = [] include Aws::Structure end |
#creation_time_before ⇒ Time
A filter that returns only jobs created before the specified time (timestamp).
37095 37096 37097 37098 37099 37100 37101 37102 37103 37104 37105 37106 37107 37108 37109 37110 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37095 class ListInferenceRecommendationsJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :next_token, :max_results, :model_name_equals, :model_package_version_arn_equals) SENSITIVE = [] include Aws::Structure end |
#last_modified_time_after ⇒ Time
A filter that returns only jobs that were last modified after the specified time (timestamp).
37095 37096 37097 37098 37099 37100 37101 37102 37103 37104 37105 37106 37107 37108 37109 37110 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37095 class ListInferenceRecommendationsJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :next_token, :max_results, :model_name_equals, :model_package_version_arn_equals) SENSITIVE = [] include Aws::Structure end |
#last_modified_time_before ⇒ Time
A filter that returns only jobs that were last modified before the specified time (timestamp).
37095 37096 37097 37098 37099 37100 37101 37102 37103 37104 37105 37106 37107 37108 37109 37110 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37095 class ListInferenceRecommendationsJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :next_token, :max_results, :model_name_equals, :model_package_version_arn_equals) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of recommendations to return in the response.
37095 37096 37097 37098 37099 37100 37101 37102 37103 37104 37105 37106 37107 37108 37109 37110 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37095 class ListInferenceRecommendationsJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :next_token, :max_results, :model_name_equals, :model_package_version_arn_equals) SENSITIVE = [] include Aws::Structure end |
#model_name_equals ⇒ String
A filter that returns only jobs that were created for this model.
37095 37096 37097 37098 37099 37100 37101 37102 37103 37104 37105 37106 37107 37108 37109 37110 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37095 class ListInferenceRecommendationsJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :next_token, :max_results, :model_name_equals, :model_package_version_arn_equals) SENSITIVE = [] include Aws::Structure end |
#model_package_version_arn_equals ⇒ String
A filter that returns only jobs that were created for this versioned model package.
37095 37096 37097 37098 37099 37100 37101 37102 37103 37104 37105 37106 37107 37108 37109 37110 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37095 class ListInferenceRecommendationsJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :next_token, :max_results, :model_name_equals, :model_package_version_arn_equals) SENSITIVE = [] include Aws::Structure end |
#name_contains ⇒ String
A string in the job name. This filter returns only recommendations whose name contains the specified string.
37095 37096 37097 37098 37099 37100 37101 37102 37103 37104 37105 37106 37107 37108 37109 37110 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37095 class ListInferenceRecommendationsJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :next_token, :max_results, :model_name_equals, :model_package_version_arn_equals) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the response to a previous
ListInferenceRecommendationsJobsRequest request was truncated, the
response includes a NextToken. To retrieve the next set of
recommendations, use the token in the next request.
37095 37096 37097 37098 37099 37100 37101 37102 37103 37104 37105 37106 37107 37108 37109 37110 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37095 class ListInferenceRecommendationsJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :next_token, :max_results, :model_name_equals, :model_package_version_arn_equals) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
The parameter by which to sort the results.
37095 37096 37097 37098 37099 37100 37101 37102 37103 37104 37105 37106 37107 37108 37109 37110 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37095 class ListInferenceRecommendationsJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :next_token, :max_results, :model_name_equals, :model_package_version_arn_equals) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
The sort order for the results.
37095 37096 37097 37098 37099 37100 37101 37102 37103 37104 37105 37106 37107 37108 37109 37110 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37095 class ListInferenceRecommendationsJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :next_token, :max_results, :model_name_equals, :model_package_version_arn_equals) SENSITIVE = [] include Aws::Structure end |
#status_equals ⇒ String
A filter that retrieves only inference recommendations jobs with a specific status.
37095 37096 37097 37098 37099 37100 37101 37102 37103 37104 37105 37106 37107 37108 37109 37110 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37095 class ListInferenceRecommendationsJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :status_equals, :sort_by, :sort_order, :next_token, :max_results, :model_name_equals, :model_package_version_arn_equals) SENSITIVE = [] include Aws::Structure end |