Class: Aws::SageMaker::Types::ListJobSchemaVersionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListJobSchemaVersionsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_category ⇒ String
The category of job schemas to list.
-
#max_results ⇒ Integer
The maximum number of schema versions to return in the response.
-
#next_token ⇒ String
If the previous response was truncated, this token retrieves the next set of results.
Instance Attribute Details
#job_category ⇒ String
The category of job schemas to list.
37266 37267 37268 37269 37270 37271 37272 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37266 class ListJobSchemaVersionsRequest < Struct.new( :job_category, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of schema versions to return in the response. The default value is 5.
37266 37267 37268 37269 37270 37271 37272 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37266 class ListJobSchemaVersionsRequest < Struct.new( :job_category, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the previous response was truncated, this token retrieves the next set of results.
37266 37267 37268 37269 37270 37271 37272 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37266 class ListJobSchemaVersionsRequest < Struct.new( :job_category, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |