Class: Aws::SageMaker::Types::ListJobsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListJobsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time_after ⇒ Time
A filter that returns only jobs created after the specified time.
-
#creation_time_before ⇒ Time
A filter that returns only jobs created before the specified time.
-
#job_category ⇒ String
The category of jobs to list.
-
#last_modified_time_after ⇒ Time
A filter that returns only jobs modified after the specified time.
-
#last_modified_time_before ⇒ Time
A filter that returns only jobs modified before the specified time.
-
#max_results ⇒ Integer
The maximum number of jobs to return in the response.
-
#name_contains ⇒ String
A string in the job name to filter results.
-
#next_token ⇒ String
If the previous response was truncated, this token retrieves the next set of results.
-
#sort_by ⇒ String
The field to sort results by.
-
#sort_order ⇒ String
The sort order for results.
-
#status_equals ⇒ String
A filter that returns only jobs with the specified status.
Instance Attribute Details
#creation_time_after ⇒ Time
A filter that returns only jobs created after the specified time.
37343 37344 37345 37346 37347 37348 37349 37350 37351 37352 37353 37354 37355 37356 37357 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37343 class ListJobsRequest < Struct.new( :job_category, :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :sort_by, :sort_order, :status_equals) SENSITIVE = [] include Aws::Structure end |
#creation_time_before ⇒ Time
A filter that returns only jobs created before the specified time.
37343 37344 37345 37346 37347 37348 37349 37350 37351 37352 37353 37354 37355 37356 37357 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37343 class ListJobsRequest < Struct.new( :job_category, :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :sort_by, :sort_order, :status_equals) SENSITIVE = [] include Aws::Structure end |
#job_category ⇒ String
The category of jobs to list.
37343 37344 37345 37346 37347 37348 37349 37350 37351 37352 37353 37354 37355 37356 37357 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37343 class ListJobsRequest < Struct.new( :job_category, :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :sort_by, :sort_order, :status_equals) SENSITIVE = [] include Aws::Structure end |
#last_modified_time_after ⇒ Time
A filter that returns only jobs modified after the specified time.
37343 37344 37345 37346 37347 37348 37349 37350 37351 37352 37353 37354 37355 37356 37357 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37343 class ListJobsRequest < Struct.new( :job_category, :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :sort_by, :sort_order, :status_equals) SENSITIVE = [] include Aws::Structure end |
#last_modified_time_before ⇒ Time
A filter that returns only jobs modified before the specified time.
37343 37344 37345 37346 37347 37348 37349 37350 37351 37352 37353 37354 37355 37356 37357 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37343 class ListJobsRequest < Struct.new( :job_category, :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :sort_by, :sort_order, :status_equals) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of jobs to return in the response. The default value is 50.
37343 37344 37345 37346 37347 37348 37349 37350 37351 37352 37353 37354 37355 37356 37357 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37343 class ListJobsRequest < Struct.new( :job_category, :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :sort_by, :sort_order, :status_equals) SENSITIVE = [] include Aws::Structure end |
#name_contains ⇒ String
A string in the job name to filter results. Only jobs whose name contains the specified string are returned.
37343 37344 37345 37346 37347 37348 37349 37350 37351 37352 37353 37354 37355 37356 37357 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37343 class ListJobsRequest < Struct.new( :job_category, :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :sort_by, :sort_order, :status_equals) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the previous response was truncated, this token retrieves the next set of results.
37343 37344 37345 37346 37347 37348 37349 37350 37351 37352 37353 37354 37355 37356 37357 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37343 class ListJobsRequest < Struct.new( :job_category, :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :sort_by, :sort_order, :status_equals) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
The field to sort results by.
37343 37344 37345 37346 37347 37348 37349 37350 37351 37352 37353 37354 37355 37356 37357 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37343 class ListJobsRequest < Struct.new( :job_category, :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :sort_by, :sort_order, :status_equals) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
The sort order for results. Valid values are Ascending and
Descending.
37343 37344 37345 37346 37347 37348 37349 37350 37351 37352 37353 37354 37355 37356 37357 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37343 class ListJobsRequest < Struct.new( :job_category, :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :sort_by, :sort_order, :status_equals) SENSITIVE = [] include Aws::Structure end |
#status_equals ⇒ String
A filter that returns only jobs with the specified status.
37343 37344 37345 37346 37347 37348 37349 37350 37351 37352 37353 37354 37355 37356 37357 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37343 class ListJobsRequest < Struct.new( :job_category, :next_token, :max_results, :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :name_contains, :sort_by, :sort_order, :status_equals) SENSITIVE = [] include Aws::Structure end |