Class: Aws::SageMaker::Types::ListJobsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListJobsResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_summaries ⇒ Array<Types::JobSummary>
An array of
JobSummaryobjects that provide summary information about the jobs. -
#next_token ⇒ String
If the response is truncated, this token retrieves the next set of results.
Instance Attribute Details
#job_summaries ⇒ Array<Types::JobSummary>
An array of JobSummary objects that provide summary information
about the jobs.
37371 37372 37373 37374 37375 37376 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37371 class ListJobsResponse < Struct.new( :next_token, :job_summaries) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the response is truncated, this token retrieves the next set of results.
37371 37372 37373 37374 37375 37376 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37371 class ListJobsResponse < Struct.new( :next_token, :job_summaries) SENSITIVE = [] include Aws::Structure end |