Class: Aws::SageMaker::Types::ListLabelingJobsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_time_afterTime

A filter that returns only labeling jobs created after the specified time (timestamp).



37502
37503
37504
37505
37506
37507
37508
37509
37510
37511
37512
37513
37514
37515
# File 'lib/aws-sdk-sagemaker/types.rb', line 37502

class ListLabelingJobsRequest < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :max_results,
  :next_token,
  :name_contains,
  :sort_by,
  :sort_order,
  :status_equals)
  SENSITIVE = []
  include Aws::Structure
end

#creation_time_beforeTime

A filter that returns only labeling jobs created before the specified time (timestamp).



37502
37503
37504
37505
37506
37507
37508
37509
37510
37511
37512
37513
37514
37515
# File 'lib/aws-sdk-sagemaker/types.rb', line 37502

class ListLabelingJobsRequest < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :max_results,
  :next_token,
  :name_contains,
  :sort_by,
  :sort_order,
  :status_equals)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_time_afterTime

A filter that returns only labeling jobs modified after the specified time (timestamp).



37502
37503
37504
37505
37506
37507
37508
37509
37510
37511
37512
37513
37514
37515
# File 'lib/aws-sdk-sagemaker/types.rb', line 37502

class ListLabelingJobsRequest < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :max_results,
  :next_token,
  :name_contains,
  :sort_by,
  :sort_order,
  :status_equals)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_time_beforeTime

A filter that returns only labeling jobs modified before the specified time (timestamp).



37502
37503
37504
37505
37506
37507
37508
37509
37510
37511
37512
37513
37514
37515
# File 'lib/aws-sdk-sagemaker/types.rb', line 37502

class ListLabelingJobsRequest < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :max_results,
  :next_token,
  :name_contains,
  :sort_by,
  :sort_order,
  :status_equals)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of labeling jobs to return in each page of the response.



37502
37503
37504
37505
37506
37507
37508
37509
37510
37511
37512
37513
37514
37515
# File 'lib/aws-sdk-sagemaker/types.rb', line 37502

class ListLabelingJobsRequest < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :max_results,
  :next_token,
  :name_contains,
  :sort_by,
  :sort_order,
  :status_equals)
  SENSITIVE = []
  include Aws::Structure
end

#name_containsString

A string in the labeling job name. This filter returns only labeling jobs whose name contains the specified string.



37502
37503
37504
37505
37506
37507
37508
37509
37510
37511
37512
37513
37514
37515
# File 'lib/aws-sdk-sagemaker/types.rb', line 37502

class ListLabelingJobsRequest < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :max_results,
  :next_token,
  :name_contains,
  :sort_by,
  :sort_order,
  :status_equals)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the result of the previous ListLabelingJobs request was truncated, the response includes a NextToken. To retrieve the next set of labeling jobs, use the token in the next request.



37502
37503
37504
37505
37506
37507
37508
37509
37510
37511
37512
37513
37514
37515
# File 'lib/aws-sdk-sagemaker/types.rb', line 37502

class ListLabelingJobsRequest < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :max_results,
  :next_token,
  :name_contains,
  :sort_by,
  :sort_order,
  :status_equals)
  SENSITIVE = []
  include Aws::Structure
end

#sort_byString

The field to sort results by. The default is CreationTime.



37502
37503
37504
37505
37506
37507
37508
37509
37510
37511
37512
37513
37514
37515
# File 'lib/aws-sdk-sagemaker/types.rb', line 37502

class ListLabelingJobsRequest < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :max_results,
  :next_token,
  :name_contains,
  :sort_by,
  :sort_order,
  :status_equals)
  SENSITIVE = []
  include Aws::Structure
end

#sort_orderString

The sort order for results. The default is Ascending.



37502
37503
37504
37505
37506
37507
37508
37509
37510
37511
37512
37513
37514
37515
# File 'lib/aws-sdk-sagemaker/types.rb', line 37502

class ListLabelingJobsRequest < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :max_results,
  :next_token,
  :name_contains,
  :sort_by,
  :sort_order,
  :status_equals)
  SENSITIVE = []
  include Aws::Structure
end

#status_equalsString

A filter that retrieves only labeling jobs with a specific status.



37502
37503
37504
37505
37506
37507
37508
37509
37510
37511
37512
37513
37514
37515
# File 'lib/aws-sdk-sagemaker/types.rb', line 37502

class ListLabelingJobsRequest < Struct.new(
  :creation_time_after,
  :creation_time_before,
  :last_modified_time_after,
  :last_modified_time_before,
  :max_results,
  :next_token,
  :name_contains,
  :sort_by,
  :sort_order,
  :status_equals)
  SENSITIVE = []
  include Aws::Structure
end