Class: Aws::SageMaker::Types::ListLabelingJobsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListLabelingJobsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time_after ⇒ Time
A filter that returns only labeling jobs created after the specified time (timestamp).
-
#creation_time_before ⇒ Time
A filter that returns only labeling jobs created before the specified time (timestamp).
-
#last_modified_time_after ⇒ Time
A filter that returns only labeling jobs modified after the specified time (timestamp).
-
#last_modified_time_before ⇒ Time
A filter that returns only labeling jobs modified before the specified time (timestamp).
-
#max_results ⇒ Integer
The maximum number of labeling jobs to return in each page of the response.
-
#name_contains ⇒ String
A string in the labeling job name.
-
#next_token ⇒ String
If the result of the previous
ListLabelingJobsrequest was truncated, the response includes aNextToken. -
#sort_by ⇒ String
The field to sort results by.
-
#sort_order ⇒ String
The sort order for results.
-
#status_equals ⇒ String
A filter that retrieves only labeling jobs with a specific status.
Instance Attribute Details
#creation_time_after ⇒ Time
A filter that returns only labeling jobs created after the specified time (timestamp).
37502 37503 37504 37505 37506 37507 37508 37509 37510 37511 37512 37513 37514 37515 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37502 class ListLabelingJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :max_results, :next_token, :name_contains, :sort_by, :sort_order, :status_equals) SENSITIVE = [] include Aws::Structure end |
#creation_time_before ⇒ Time
A filter that returns only labeling jobs created before the specified time (timestamp).
37502 37503 37504 37505 37506 37507 37508 37509 37510 37511 37512 37513 37514 37515 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37502 class ListLabelingJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :max_results, :next_token, :name_contains, :sort_by, :sort_order, :status_equals) SENSITIVE = [] include Aws::Structure end |
#last_modified_time_after ⇒ Time
A filter that returns only labeling jobs modified after the specified time (timestamp).
37502 37503 37504 37505 37506 37507 37508 37509 37510 37511 37512 37513 37514 37515 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37502 class ListLabelingJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :max_results, :next_token, :name_contains, :sort_by, :sort_order, :status_equals) SENSITIVE = [] include Aws::Structure end |
#last_modified_time_before ⇒ Time
A filter that returns only labeling jobs modified before the specified time (timestamp).
37502 37503 37504 37505 37506 37507 37508 37509 37510 37511 37512 37513 37514 37515 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37502 class ListLabelingJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :max_results, :next_token, :name_contains, :sort_by, :sort_order, :status_equals) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of labeling jobs to return in each page of the response.
37502 37503 37504 37505 37506 37507 37508 37509 37510 37511 37512 37513 37514 37515 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37502 class ListLabelingJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :max_results, :next_token, :name_contains, :sort_by, :sort_order, :status_equals) SENSITIVE = [] include Aws::Structure end |
#name_contains ⇒ String
A string in the labeling job name. This filter returns only labeling jobs whose name contains the specified string.
37502 37503 37504 37505 37506 37507 37508 37509 37510 37511 37512 37513 37514 37515 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37502 class ListLabelingJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :max_results, :next_token, :name_contains, :sort_by, :sort_order, :status_equals) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the result of the previous ListLabelingJobs request was
truncated, the response includes a NextToken. To retrieve the next
set of labeling jobs, use the token in the next request.
37502 37503 37504 37505 37506 37507 37508 37509 37510 37511 37512 37513 37514 37515 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37502 class ListLabelingJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :max_results, :next_token, :name_contains, :sort_by, :sort_order, :status_equals) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
The field to sort results by. The default is CreationTime.
37502 37503 37504 37505 37506 37507 37508 37509 37510 37511 37512 37513 37514 37515 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37502 class ListLabelingJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :max_results, :next_token, :name_contains, :sort_by, :sort_order, :status_equals) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
The sort order for results. The default is Ascending.
37502 37503 37504 37505 37506 37507 37508 37509 37510 37511 37512 37513 37514 37515 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37502 class ListLabelingJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :max_results, :next_token, :name_contains, :sort_by, :sort_order, :status_equals) SENSITIVE = [] include Aws::Structure end |
#status_equals ⇒ String
A filter that retrieves only labeling jobs with a specific status.
37502 37503 37504 37505 37506 37507 37508 37509 37510 37511 37512 37513 37514 37515 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37502 class ListLabelingJobsRequest < Struct.new( :creation_time_after, :creation_time_before, :last_modified_time_after, :last_modified_time_before, :max_results, :next_token, :name_contains, :sort_by, :sort_order, :status_equals) SENSITIVE = [] include Aws::Structure end |