Class: Aws::SageMaker::Types::ListLineageGroupsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListLineageGroupsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_after ⇒ Time
A timestamp to filter against lineage groups created after a certain point in time.
-
#created_before ⇒ Time
A timestamp to filter against lineage groups created before a certain point in time.
-
#max_results ⇒ Integer
The maximum number of endpoints to return in the response.
-
#next_token ⇒ String
If the response is truncated, SageMaker returns this token.
-
#sort_by ⇒ String
The parameter by which to sort the results.
-
#sort_order ⇒ String
The sort order for the results.
Instance Attribute Details
#created_after ⇒ Time
A timestamp to filter against lineage groups created after a certain point in time.
37569 37570 37571 37572 37573 37574 37575 37576 37577 37578 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37569 class ListLineageGroupsRequest < Struct.new( :created_after, :created_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#created_before ⇒ Time
A timestamp to filter against lineage groups created before a certain point in time.
37569 37570 37571 37572 37573 37574 37575 37576 37577 37578 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37569 class ListLineageGroupsRequest < Struct.new( :created_after, :created_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of endpoints to return in the response. This value defaults to 10.
37569 37570 37571 37572 37573 37574 37575 37576 37577 37578 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37569 class ListLineageGroupsRequest < Struct.new( :created_after, :created_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the response is truncated, SageMaker returns this token. To retrieve the next set of algorithms, use it in the subsequent request.
37569 37570 37571 37572 37573 37574 37575 37576 37577 37578 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37569 class ListLineageGroupsRequest < Struct.new( :created_after, :created_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
The parameter by which to sort the results. The default is
CreationTime.
37569 37570 37571 37572 37573 37574 37575 37576 37577 37578 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37569 class ListLineageGroupsRequest < Struct.new( :created_after, :created_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
The sort order for the results. The default is Ascending.
37569 37570 37571 37572 37573 37574 37575 37576 37577 37578 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37569 class ListLineageGroupsRequest < Struct.new( :created_after, :created_before, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |