Class: Aws::SageMaker::Types::ListMlflowAppsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_default_statusString

Filter for MLflow Apps with the specified AccountDefaultStatus.

Returns:



34254
34255
34256
34257
34258
34259
34260
34261
34262
34263
34264
34265
34266
34267
# File 'lib/aws-sdk-sagemaker/types.rb', line 34254

class ListMlflowAppsRequest < Struct.new(
  :created_after,
  :created_before,
  :status,
  :mlflow_version,
  :default_for_domain_id,
  :account_default_status,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#created_afterTime

Use the CreatedAfter filter to only list MLflow Apps created after a specific date and time. Listed MLflow Apps are shown with a date and time such as ‘“2024-03-16T01:46:56+00:00”`. The CreatedAfter parameter takes in a Unix timestamp.

Returns:



34254
34255
34256
34257
34258
34259
34260
34261
34262
34263
34264
34265
34266
34267
# File 'lib/aws-sdk-sagemaker/types.rb', line 34254

class ListMlflowAppsRequest < Struct.new(
  :created_after,
  :created_before,
  :status,
  :mlflow_version,
  :default_for_domain_id,
  :account_default_status,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#created_beforeTime

Use the CreatedBefore filter to only list MLflow Apps created before a specific date and time. Listed MLflow Apps are shown with a date and time such as ‘“2024-03-16T01:46:56+00:00”`. The CreatedAfter parameter takes in a Unix timestamp.

Returns:



34254
34255
34256
34257
34258
34259
34260
34261
34262
34263
34264
34265
34266
34267
# File 'lib/aws-sdk-sagemaker/types.rb', line 34254

class ListMlflowAppsRequest < Struct.new(
  :created_after,
  :created_before,
  :status,
  :mlflow_version,
  :default_for_domain_id,
  :account_default_status,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#default_for_domain_idString

Filter for MLflow Apps with the specified default SageMaker Domain ID.

Returns:



34254
34255
34256
34257
34258
34259
34260
34261
34262
34263
34264
34265
34266
34267
# File 'lib/aws-sdk-sagemaker/types.rb', line 34254

class ListMlflowAppsRequest < Struct.new(
  :created_after,
  :created_before,
  :status,
  :mlflow_version,
  :default_for_domain_id,
  :account_default_status,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of MLflow Apps to list.

Returns:



34254
34255
34256
34257
34258
34259
34260
34261
34262
34263
34264
34265
34266
34267
# File 'lib/aws-sdk-sagemaker/types.rb', line 34254

class ListMlflowAppsRequest < Struct.new(
  :created_after,
  :created_before,
  :status,
  :mlflow_version,
  :default_for_domain_id,
  :account_default_status,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#mlflow_versionString

Filter for Mlflow Apps with the specified version.

Returns:



34254
34255
34256
34257
34258
34259
34260
34261
34262
34263
34264
34265
34266
34267
# File 'lib/aws-sdk-sagemaker/types.rb', line 34254

class ListMlflowAppsRequest < Struct.new(
  :created_after,
  :created_before,
  :status,
  :mlflow_version,
  :default_for_domain_id,
  :account_default_status,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the previous response was truncated, use this token in your next request to receive the next set of results.

Returns:



34254
34255
34256
34257
34258
34259
34260
34261
34262
34263
34264
34265
34266
34267
# File 'lib/aws-sdk-sagemaker/types.rb', line 34254

class ListMlflowAppsRequest < Struct.new(
  :created_after,
  :created_before,
  :status,
  :mlflow_version,
  :default_for_domain_id,
  :account_default_status,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#sort_byString

Filter for MLflow Apps sorting by name, creation time, or creation status.

Returns:



34254
34255
34256
34257
34258
34259
34260
34261
34262
34263
34264
34265
34266
34267
# File 'lib/aws-sdk-sagemaker/types.rb', line 34254

class ListMlflowAppsRequest < Struct.new(
  :created_after,
  :created_before,
  :status,
  :mlflow_version,
  :default_for_domain_id,
  :account_default_status,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#sort_orderString

Change the order of the listed MLflow Apps. By default, MLflow Apps are listed in Descending order by creation time. To change the list order, specify SortOrder to be Ascending.

Returns:



34254
34255
34256
34257
34258
34259
34260
34261
34262
34263
34264
34265
34266
34267
# File 'lib/aws-sdk-sagemaker/types.rb', line 34254

class ListMlflowAppsRequest < Struct.new(
  :created_after,
  :created_before,
  :status,
  :mlflow_version,
  :default_for_domain_id,
  :account_default_status,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

Filter for Mlflow apps with a specific creation status.

Returns:



34254
34255
34256
34257
34258
34259
34260
34261
34262
34263
34264
34265
34266
34267
# File 'lib/aws-sdk-sagemaker/types.rb', line 34254

class ListMlflowAppsRequest < Struct.new(
  :created_after,
  :created_before,
  :status,
  :mlflow_version,
  :default_for_domain_id,
  :account_default_status,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end