Class: Aws::SageMaker::Types::ListMlflowAppsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListMlflowAppsResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If the previous response was truncated, you will receive this token.
-
#summaries ⇒ Array<Types::MlflowAppSummary>
A list of MLflow Apps according to chosen filters.
Instance Attribute Details
#next_token ⇒ String
If the previous response was truncated, you will receive this token. Use it in your next request to receive the next set of results.
34280 34281 34282 34283 34284 34285 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34280 class ListMlflowAppsResponse < Struct.new( :summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#summaries ⇒ Array<Types::MlflowAppSummary>
A list of MLflow Apps according to chosen filters.
34280 34281 34282 34283 34284 34285 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34280 class ListMlflowAppsResponse < Struct.new( :summaries, :next_token) SENSITIVE = [] include Aws::Structure end |