Class: Aws::SageMaker::Types::ListMlflowTrackingServersRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListMlflowTrackingServersRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_after ⇒ Time
Use the
CreatedAfterfilter to only list tracking servers created after a specific date and time. -
#created_before ⇒ Time
Use the
CreatedBeforefilter to only list tracking servers created before a specific date and time. -
#max_results ⇒ Integer
The maximum number of tracking servers to list.
-
#mlflow_version ⇒ String
Filter for tracking servers using the specified MLflow version.
-
#next_token ⇒ String
If the previous response was truncated, you will receive this token.
-
#sort_by ⇒ String
Filter for trackings servers sorting by name, creation time, or creation status.
-
#sort_order ⇒ String
Change the order of the listed tracking servers.
-
#tracking_server_status ⇒ String
Filter for tracking servers with a specified creation status.
Instance Attribute Details
#created_after ⇒ Time
Use the CreatedAfter filter to only list tracking servers created after a specific date and time. Listed tracking servers are shown with a date and time such as ‘“2024-03-16T01:46:56+00:00”`. The CreatedAfter parameter takes in a Unix timestamp. To convert a date and time into a Unix timestamp, see [EpochConverter].
[1]: www.epochconverter.com/
34342 34343 34344 34345 34346 34347 34348 34349 34350 34351 34352 34353 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34342 class ListMlflowTrackingServersRequest < Struct.new( :created_after, :created_before, :tracking_server_status, :mlflow_version, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#created_before ⇒ Time
Use the CreatedBefore filter to only list tracking servers created before a specific date and time. Listed tracking servers are shown with a date and time such as ‘“2024-03-16T01:46:56+00:00”`. The CreatedBefore parameter takes in a Unix timestamp. To convert a date and time into a Unix timestamp, see [EpochConverter].
[1]: www.epochconverter.com/
34342 34343 34344 34345 34346 34347 34348 34349 34350 34351 34352 34353 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34342 class ListMlflowTrackingServersRequest < Struct.new( :created_after, :created_before, :tracking_server_status, :mlflow_version, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of tracking servers to list.
34342 34343 34344 34345 34346 34347 34348 34349 34350 34351 34352 34353 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34342 class ListMlflowTrackingServersRequest < Struct.new( :created_after, :created_before, :tracking_server_status, :mlflow_version, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#mlflow_version ⇒ String
Filter for tracking servers using the specified MLflow version.
34342 34343 34344 34345 34346 34347 34348 34349 34350 34351 34352 34353 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34342 class ListMlflowTrackingServersRequest < Struct.new( :created_after, :created_before, :tracking_server_status, :mlflow_version, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the previous response was truncated, you will receive this token. Use it in your next request to receive the next set of results.
34342 34343 34344 34345 34346 34347 34348 34349 34350 34351 34352 34353 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34342 class ListMlflowTrackingServersRequest < Struct.new( :created_after, :created_before, :tracking_server_status, :mlflow_version, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
Filter for trackings servers sorting by name, creation time, or creation status.
34342 34343 34344 34345 34346 34347 34348 34349 34350 34351 34352 34353 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34342 class ListMlflowTrackingServersRequest < Struct.new( :created_after, :created_before, :tracking_server_status, :mlflow_version, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
Change the order of the listed tracking servers. By default, tracking servers are listed in Descending order by creation time. To change the list order, you can specify SortOrder to be Ascending.
34342 34343 34344 34345 34346 34347 34348 34349 34350 34351 34352 34353 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34342 class ListMlflowTrackingServersRequest < Struct.new( :created_after, :created_before, :tracking_server_status, :mlflow_version, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#tracking_server_status ⇒ String
Filter for tracking servers with a specified creation status.
34342 34343 34344 34345 34346 34347 34348 34349 34350 34351 34352 34353 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34342 class ListMlflowTrackingServersRequest < Struct.new( :created_after, :created_before, :tracking_server_status, :mlflow_version, :sort_by, :sort_order, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |