Class: Aws::SageMaker::Types::ListModelBiasJobDefinitionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListModelBiasJobDefinitionsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time_after ⇒ Time
A filter that returns only model bias jobs created after a specified time.
-
#creation_time_before ⇒ Time
A filter that returns only model bias jobs created before a specified time.
-
#endpoint_name ⇒ String
Name of the endpoint to monitor for model bias.
-
#max_results ⇒ Integer
The maximum number of model bias jobs to return in the response.
-
#name_contains ⇒ String
Filter for model bias jobs whose name contains a specified string.
-
#next_token ⇒ String
The token returned if the response is truncated.
-
#sort_by ⇒ String
Whether to sort results by the
NameorCreationTimefield. -
#sort_order ⇒ String
Whether to sort the results in
AscendingorDescendingorder.
Instance Attribute Details
#creation_time_after ⇒ Time
A filter that returns only model bias jobs created after a specified time.
34346 34347 34348 34349 34350 34351 34352 34353 34354 34355 34356 34357 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34346 class ListModelBiasJobDefinitionsRequest < Struct.new( :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after) SENSITIVE = [] include Aws::Structure end |
#creation_time_before ⇒ Time
A filter that returns only model bias jobs created before a specified time.
34346 34347 34348 34349 34350 34351 34352 34353 34354 34355 34356 34357 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34346 class ListModelBiasJobDefinitionsRequest < Struct.new( :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after) SENSITIVE = [] include Aws::Structure end |
#endpoint_name ⇒ String
Name of the endpoint to monitor for model bias.
34346 34347 34348 34349 34350 34351 34352 34353 34354 34355 34356 34357 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34346 class ListModelBiasJobDefinitionsRequest < Struct.new( :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of model bias jobs to return in the response. The default value is 10.
34346 34347 34348 34349 34350 34351 34352 34353 34354 34355 34356 34357 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34346 class ListModelBiasJobDefinitionsRequest < Struct.new( :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after) SENSITIVE = [] include Aws::Structure end |
#name_contains ⇒ String
Filter for model bias jobs whose name contains a specified string.
34346 34347 34348 34349 34350 34351 34352 34353 34354 34355 34356 34357 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34346 class ListModelBiasJobDefinitionsRequest < Struct.new( :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token returned if the response is truncated. To retrieve the next set of job executions, use it in the next request.
34346 34347 34348 34349 34350 34351 34352 34353 34354 34355 34356 34357 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34346 class ListModelBiasJobDefinitionsRequest < Struct.new( :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
Whether to sort results by the Name or CreationTime field. The default is CreationTime.
34346 34347 34348 34349 34350 34351 34352 34353 34354 34355 34356 34357 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34346 class ListModelBiasJobDefinitionsRequest < Struct.new( :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
Whether to sort the results in Ascending or Descending order. The default is Descending.
34346 34347 34348 34349 34350 34351 34352 34353 34354 34355 34356 34357 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34346 class ListModelBiasJobDefinitionsRequest < Struct.new( :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after) SENSITIVE = [] include Aws::Structure end |