Class: Aws::SageMaker::Types::ListModelCardVersionsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListModelCardVersionsResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#model_card_version_summary_list ⇒ Array<Types::ModelCardVersionSummary>
The summaries of the listed versions of the model card.
-
#next_token ⇒ String
If the response is truncated, SageMaker returns this token.
Instance Attribute Details
#model_card_version_summary_list ⇒ Array<Types::ModelCardVersionSummary>
The summaries of the listed versions of the model card.
34525 34526 34527 34528 34529 34530 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34525 class ListModelCardVersionsResponse < Struct.new( :model_card_version_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the response is truncated, SageMaker returns this token. To retrieve the next set of model card versions, use it in the subsequent request.
34525 34526 34527 34528 34529 34530 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34525 class ListModelCardVersionsResponse < Struct.new( :model_card_version_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |