Class: Aws::SageMaker::Types::ListModelPackageGroupsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListModelPackageGroupsInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time_after ⇒ Time
A filter that returns only model groups created after the specified time.
-
#creation_time_before ⇒ Time
A filter that returns only model groups created before the specified time.
-
#cross_account_filter_option ⇒ String
A filter that returns either model groups shared with you or model groups in your own account.
-
#max_results ⇒ Integer
The maximum number of results to return in the response.
-
#name_contains ⇒ String
A string in the model group name.
-
#next_token ⇒ String
If the result of the previous
ListModelPackageGroupsrequest was truncated, the response includes aNextToken. -
#sort_by ⇒ String
The field to sort results by.
-
#sort_order ⇒ String
The sort order for results.
Instance Attribute Details
#creation_time_after ⇒ Time
A filter that returns only model groups created after the specified time.
38228 38229 38230 38231 38232 38233 38234 38235 38236 38237 38238 38239 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 38228 class ListModelPackageGroupsInput < Struct.new( :creation_time_after, :creation_time_before, :max_results, :name_contains, :next_token, :sort_by, :sort_order, :cross_account_filter_option) SENSITIVE = [] include Aws::Structure end |
#creation_time_before ⇒ Time
A filter that returns only model groups created before the specified time.
38228 38229 38230 38231 38232 38233 38234 38235 38236 38237 38238 38239 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 38228 class ListModelPackageGroupsInput < Struct.new( :creation_time_after, :creation_time_before, :max_results, :name_contains, :next_token, :sort_by, :sort_order, :cross_account_filter_option) SENSITIVE = [] include Aws::Structure end |
#cross_account_filter_option ⇒ String
A filter that returns either model groups shared with you or model
groups in your own account. When the value is CrossAccount, the
results show the resources made discoverable to you from other
accounts. When the value is SameAccount or null, the results
show resources from your account. The default is SameAccount.
38228 38229 38230 38231 38232 38233 38234 38235 38236 38237 38238 38239 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 38228 class ListModelPackageGroupsInput < Struct.new( :creation_time_after, :creation_time_before, :max_results, :name_contains, :next_token, :sort_by, :sort_order, :cross_account_filter_option) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in the response.
38228 38229 38230 38231 38232 38233 38234 38235 38236 38237 38238 38239 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 38228 class ListModelPackageGroupsInput < Struct.new( :creation_time_after, :creation_time_before, :max_results, :name_contains, :next_token, :sort_by, :sort_order, :cross_account_filter_option) SENSITIVE = [] include Aws::Structure end |
#name_contains ⇒ String
A string in the model group name. This filter returns only model groups whose name contains the specified string.
38228 38229 38230 38231 38232 38233 38234 38235 38236 38237 38238 38239 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 38228 class ListModelPackageGroupsInput < Struct.new( :creation_time_after, :creation_time_before, :max_results, :name_contains, :next_token, :sort_by, :sort_order, :cross_account_filter_option) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the result of the previous ListModelPackageGroups request was
truncated, the response includes a NextToken. To retrieve the next
set of model groups, use the token in the next request.
38228 38229 38230 38231 38232 38233 38234 38235 38236 38237 38238 38239 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 38228 class ListModelPackageGroupsInput < Struct.new( :creation_time_after, :creation_time_before, :max_results, :name_contains, :next_token, :sort_by, :sort_order, :cross_account_filter_option) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
The field to sort results by. The default is CreationTime.
38228 38229 38230 38231 38232 38233 38234 38235 38236 38237 38238 38239 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 38228 class ListModelPackageGroupsInput < Struct.new( :creation_time_after, :creation_time_before, :max_results, :name_contains, :next_token, :sort_by, :sort_order, :cross_account_filter_option) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
The sort order for results. The default is Ascending.
38228 38229 38230 38231 38232 38233 38234 38235 38236 38237 38238 38239 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 38228 class ListModelPackageGroupsInput < Struct.new( :creation_time_after, :creation_time_before, :max_results, :name_contains, :next_token, :sort_by, :sort_order, :cross_account_filter_option) SENSITIVE = [] include Aws::Structure end |