Class: Aws::SageMaker::Types::ListModelPackagesInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListModelPackagesInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time_after ⇒ Time
A filter that returns only model packages created after the specified time (timestamp).
-
#creation_time_before ⇒ Time
A filter that returns only model packages created before the specified time (timestamp).
-
#max_results ⇒ Integer
The maximum number of model packages to return in the response.
-
#model_approval_status ⇒ String
A filter that returns only the model packages with the specified approval status.
-
#model_package_group_name ⇒ String
A filter that returns only model versions that belong to the specified model group.
-
#model_package_type ⇒ String
A filter that returns only the model packages of the specified type.
-
#name_contains ⇒ String
A string in the model package name.
-
#next_token ⇒ String
If the response to a previous
ListModelPackagesrequest was truncated, the response includes aNextToken. -
#sort_by ⇒ String
The parameter by which to sort the results.
-
#sort_order ⇒ String
The sort order for the results.
Instance Attribute Details
#creation_time_after ⇒ Time
A filter that returns only model packages created after the specified time (timestamp).
34828 34829 34830 34831 34832 34833 34834 34835 34836 34837 34838 34839 34840 34841 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34828 class ListModelPackagesInput < Struct.new( :creation_time_after, :creation_time_before, :max_results, :name_contains, :model_approval_status, :model_package_group_name, :model_package_type, :next_token, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#creation_time_before ⇒ Time
A filter that returns only model packages created before the specified time (timestamp).
34828 34829 34830 34831 34832 34833 34834 34835 34836 34837 34838 34839 34840 34841 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34828 class ListModelPackagesInput < Struct.new( :creation_time_after, :creation_time_before, :max_results, :name_contains, :model_approval_status, :model_package_group_name, :model_package_type, :next_token, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of model packages to return in the response.
34828 34829 34830 34831 34832 34833 34834 34835 34836 34837 34838 34839 34840 34841 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34828 class ListModelPackagesInput < Struct.new( :creation_time_after, :creation_time_before, :max_results, :name_contains, :model_approval_status, :model_package_group_name, :model_package_type, :next_token, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#model_approval_status ⇒ String
A filter that returns only the model packages with the specified approval status.
34828 34829 34830 34831 34832 34833 34834 34835 34836 34837 34838 34839 34840 34841 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34828 class ListModelPackagesInput < Struct.new( :creation_time_after, :creation_time_before, :max_results, :name_contains, :model_approval_status, :model_package_group_name, :model_package_type, :next_token, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#model_package_group_name ⇒ String
A filter that returns only model versions that belong to the specified model group.
34828 34829 34830 34831 34832 34833 34834 34835 34836 34837 34838 34839 34840 34841 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34828 class ListModelPackagesInput < Struct.new( :creation_time_after, :creation_time_before, :max_results, :name_contains, :model_approval_status, :model_package_group_name, :model_package_type, :next_token, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#model_package_type ⇒ String
A filter that returns only the model packages of the specified type. This can be one of the following values.
-
UNVERSIONED- List only unversioined models. This is the default value if noModelPackageTypeis specified. -
VERSIONED- List only versioned models. -
BOTH- List both versioned and unversioned models.
34828 34829 34830 34831 34832 34833 34834 34835 34836 34837 34838 34839 34840 34841 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34828 class ListModelPackagesInput < Struct.new( :creation_time_after, :creation_time_before, :max_results, :name_contains, :model_approval_status, :model_package_group_name, :model_package_type, :next_token, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#name_contains ⇒ String
A string in the model package name. This filter returns only model packages whose name contains the specified string.
34828 34829 34830 34831 34832 34833 34834 34835 34836 34837 34838 34839 34840 34841 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34828 class ListModelPackagesInput < Struct.new( :creation_time_after, :creation_time_before, :max_results, :name_contains, :model_approval_status, :model_package_group_name, :model_package_type, :next_token, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the response to a previous ListModelPackages request was truncated, the response includes a NextToken. To retrieve the next set of model packages, use the token in the next request.
34828 34829 34830 34831 34832 34833 34834 34835 34836 34837 34838 34839 34840 34841 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34828 class ListModelPackagesInput < Struct.new( :creation_time_after, :creation_time_before, :max_results, :name_contains, :model_approval_status, :model_package_group_name, :model_package_type, :next_token, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
The parameter by which to sort the results. The default is CreationTime.
34828 34829 34830 34831 34832 34833 34834 34835 34836 34837 34838 34839 34840 34841 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34828 class ListModelPackagesInput < Struct.new( :creation_time_after, :creation_time_before, :max_results, :name_contains, :model_approval_status, :model_package_group_name, :model_package_type, :next_token, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
The sort order for the results. The default is Ascending.
34828 34829 34830 34831 34832 34833 34834 34835 34836 34837 34838 34839 34840 34841 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34828 class ListModelPackagesInput < Struct.new( :creation_time_after, :creation_time_before, :max_results, :name_contains, :model_approval_status, :model_package_group_name, :model_package_type, :next_token, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |