Class: Aws::SageMaker::Types::ListModelQualityJobDefinitionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListModelQualityJobDefinitionsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time_after ⇒ Time
A filter that returns only model quality monitoring job definitions created after the specified time.
-
#creation_time_before ⇒ Time
A filter that returns only model quality monitoring job definitions created before the specified time.
-
#endpoint_name ⇒ String
A filter that returns only model quality monitoring job definitions that are associated with the specified endpoint.
-
#max_results ⇒ Integer
The maximum number of results to return in a call to
ListModelQualityJobDefinitions. -
#name_contains ⇒ String
A string in the transform job name.
-
#next_token ⇒ String
If the result of the previous
ListModelQualityJobDefinitionsrequest was truncated, the response includes aNextToken. -
#sort_by ⇒ String
The field to sort results by.
-
#sort_order ⇒ String
Whether to sort the results in
AscendingorDescendingorder.
Instance Attribute Details
#creation_time_after ⇒ Time
A filter that returns only model quality monitoring job definitions created after the specified time.
35000 35001 35002 35003 35004 35005 35006 35007 35008 35009 35010 35011 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35000 class ListModelQualityJobDefinitionsRequest < Struct.new( :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after) SENSITIVE = [] include Aws::Structure end |
#creation_time_before ⇒ Time
A filter that returns only model quality monitoring job definitions created before the specified time.
35000 35001 35002 35003 35004 35005 35006 35007 35008 35009 35010 35011 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35000 class ListModelQualityJobDefinitionsRequest < Struct.new( :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after) SENSITIVE = [] include Aws::Structure end |
#endpoint_name ⇒ String
A filter that returns only model quality monitoring job definitions that are associated with the specified endpoint.
35000 35001 35002 35003 35004 35005 35006 35007 35008 35009 35010 35011 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35000 class ListModelQualityJobDefinitionsRequest < Struct.new( :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in a call to ListModelQualityJobDefinitions.
35000 35001 35002 35003 35004 35005 35006 35007 35008 35009 35010 35011 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35000 class ListModelQualityJobDefinitionsRequest < Struct.new( :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after) SENSITIVE = [] include Aws::Structure end |
#name_contains ⇒ String
A string in the transform job name. This filter returns only model quality monitoring job definitions whose name contains the specified string.
35000 35001 35002 35003 35004 35005 35006 35007 35008 35009 35010 35011 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35000 class ListModelQualityJobDefinitionsRequest < Struct.new( :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the result of the previous ListModelQualityJobDefinitions request was truncated, the response includes a NextToken. To retrieve the next set of model quality monitoring job definitions, use the token in the next request.
35000 35001 35002 35003 35004 35005 35006 35007 35008 35009 35010 35011 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35000 class ListModelQualityJobDefinitionsRequest < Struct.new( :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
The field to sort results by. The default is CreationTime.
35000 35001 35002 35003 35004 35005 35006 35007 35008 35009 35010 35011 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35000 class ListModelQualityJobDefinitionsRequest < Struct.new( :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
Whether to sort the results in Ascending or Descending order. The default is Descending.
35000 35001 35002 35003 35004 35005 35006 35007 35008 35009 35010 35011 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35000 class ListModelQualityJobDefinitionsRequest < Struct.new( :endpoint_name, :sort_by, :sort_order, :next_token, :max_results, :name_contains, :creation_time_before, :creation_time_after) SENSITIVE = [] include Aws::Structure end |