Class: Aws::SageMaker::Types::ListModelQualityJobDefinitionsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListModelQualityJobDefinitionsResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_definition_summaries ⇒ Array<Types::MonitoringJobDefinitionSummary>
A list of summaries of model quality monitoring job definitions.
-
#next_token ⇒ String
If the response is truncated, Amazon SageMaker AI returns this token.
Instance Attribute Details
#job_definition_summaries ⇒ Array<Types::MonitoringJobDefinitionSummary>
A list of summaries of model quality monitoring job definitions.
34932 34933 34934 34935 34936 34937 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34932 class ListModelQualityJobDefinitionsResponse < Struct.new( :job_definition_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the response is truncated, Amazon SageMaker AI returns this token. To retrieve the next set of model quality monitoring job definitions, use it in the next request.
34932 34933 34934 34935 34936 34937 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 34932 class ListModelQualityJobDefinitionsResponse < Struct.new( :job_definition_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |