Class: Aws::SageMaker::Types::ListNotebookInstanceLifecycleConfigsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListNotebookInstanceLifecycleConfigsInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time_after ⇒ Time
A filter that returns only lifecycle configurations that were created after the specified time (timestamp).
-
#creation_time_before ⇒ Time
A filter that returns only lifecycle configurations that were created before the specified time (timestamp).
-
#last_modified_time_after ⇒ Time
A filter that returns only lifecycle configurations that were modified after the specified time (timestamp).
-
#last_modified_time_before ⇒ Time
A filter that returns only lifecycle configurations that were modified before the specified time (timestamp).
-
#max_results ⇒ Integer
The maximum number of lifecycle configurations to return in the response.
-
#name_contains ⇒ String
A string in the lifecycle configuration name.
-
#next_token ⇒ String
If the result of a
ListNotebookInstanceLifecycleConfigsrequest was truncated, the response includes aNextToken. -
#sort_by ⇒ String
Sorts the list of results.
-
#sort_order ⇒ String
The sort order for results.
Instance Attribute Details
#creation_time_after ⇒ Time
A filter that returns only lifecycle configurations that were created after the specified time (timestamp).
35379 35380 35381 35382 35383 35384 35385 35386 35387 35388 35389 35390 35391 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35379 class ListNotebookInstanceLifecycleConfigsInput < Struct.new( :next_token, :max_results, :sort_by, :sort_order, :name_contains, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after) SENSITIVE = [] include Aws::Structure end |
#creation_time_before ⇒ Time
A filter that returns only lifecycle configurations that were created before the specified time (timestamp).
35379 35380 35381 35382 35383 35384 35385 35386 35387 35388 35389 35390 35391 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35379 class ListNotebookInstanceLifecycleConfigsInput < Struct.new( :next_token, :max_results, :sort_by, :sort_order, :name_contains, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after) SENSITIVE = [] include Aws::Structure end |
#last_modified_time_after ⇒ Time
A filter that returns only lifecycle configurations that were modified after the specified time (timestamp).
35379 35380 35381 35382 35383 35384 35385 35386 35387 35388 35389 35390 35391 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35379 class ListNotebookInstanceLifecycleConfigsInput < Struct.new( :next_token, :max_results, :sort_by, :sort_order, :name_contains, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after) SENSITIVE = [] include Aws::Structure end |
#last_modified_time_before ⇒ Time
A filter that returns only lifecycle configurations that were modified before the specified time (timestamp).
35379 35380 35381 35382 35383 35384 35385 35386 35387 35388 35389 35390 35391 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35379 class ListNotebookInstanceLifecycleConfigsInput < Struct.new( :next_token, :max_results, :sort_by, :sort_order, :name_contains, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of lifecycle configurations to return in the response.
35379 35380 35381 35382 35383 35384 35385 35386 35387 35388 35389 35390 35391 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35379 class ListNotebookInstanceLifecycleConfigsInput < Struct.new( :next_token, :max_results, :sort_by, :sort_order, :name_contains, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after) SENSITIVE = [] include Aws::Structure end |
#name_contains ⇒ String
A string in the lifecycle configuration name. This filter returns only lifecycle configurations whose name contains the specified string.
35379 35380 35381 35382 35383 35384 35385 35386 35387 35388 35389 35390 35391 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35379 class ListNotebookInstanceLifecycleConfigsInput < Struct.new( :next_token, :max_results, :sort_by, :sort_order, :name_contains, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the result of a ListNotebookInstanceLifecycleConfigs request was truncated, the response includes a NextToken. To get the next set of lifecycle configurations, use the token in the next request.
35379 35380 35381 35382 35383 35384 35385 35386 35387 35388 35389 35390 35391 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35379 class ListNotebookInstanceLifecycleConfigsInput < Struct.new( :next_token, :max_results, :sort_by, :sort_order, :name_contains, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
Sorts the list of results. The default is CreationTime.
35379 35380 35381 35382 35383 35384 35385 35386 35387 35388 35389 35390 35391 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35379 class ListNotebookInstanceLifecycleConfigsInput < Struct.new( :next_token, :max_results, :sort_by, :sort_order, :name_contains, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
The sort order for results.
35379 35380 35381 35382 35383 35384 35385 35386 35387 35388 35389 35390 35391 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35379 class ListNotebookInstanceLifecycleConfigsInput < Struct.new( :next_token, :max_results, :sort_by, :sort_order, :name_contains, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after) SENSITIVE = [] include Aws::Structure end |