Class: Aws::SageMaker::Types::ListNotebookInstancesInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListNotebookInstancesInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_code_repository_equals ⇒ String
A filter that returns only notebook instances with associated with the specified git repository.
-
#creation_time_after ⇒ Time
A filter that returns only notebook instances that were created after the specified time (timestamp).
-
#creation_time_before ⇒ Time
A filter that returns only notebook instances that were created before the specified time (timestamp).
-
#default_code_repository_contains ⇒ String
A string in the name or URL of a Git repository associated with this notebook instance.
-
#last_modified_time_after ⇒ Time
A filter that returns only notebook instances that were modified after the specified time (timestamp).
-
#last_modified_time_before ⇒ Time
A filter that returns only notebook instances that were modified before the specified time (timestamp).
-
#max_results ⇒ Integer
The maximum number of notebook instances to return.
-
#name_contains ⇒ String
A string in the notebook instances’ name.
-
#next_token ⇒ String
If the previous call to the
ListNotebookInstancesis truncated, the response includes aNextToken. -
#notebook_instance_lifecycle_config_name_contains ⇒ String
A string in the name of a notebook instances lifecycle configuration associated with this notebook instance.
-
#sort_by ⇒ String
The field to sort results by.
-
#sort_order ⇒ String
The sort order for results.
-
#status_equals ⇒ String
A filter that returns only notebook instances with the specified status.
Instance Attribute Details
#additional_code_repository_equals ⇒ String
A filter that returns only notebook instances with associated with the specified git repository.
35582 35583 35584 35585 35586 35587 35588 35589 35590 35591 35592 35593 35594 35595 35596 35597 35598 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35582 class ListNotebookInstancesInput < Struct.new( :next_token, :max_results, :sort_by, :sort_order, :name_contains, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after, :status_equals, :notebook_instance_lifecycle_config_name_contains, :default_code_repository_contains, :additional_code_repository_equals) SENSITIVE = [] include Aws::Structure end |
#creation_time_after ⇒ Time
A filter that returns only notebook instances that were created after the specified time (timestamp).
35582 35583 35584 35585 35586 35587 35588 35589 35590 35591 35592 35593 35594 35595 35596 35597 35598 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35582 class ListNotebookInstancesInput < Struct.new( :next_token, :max_results, :sort_by, :sort_order, :name_contains, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after, :status_equals, :notebook_instance_lifecycle_config_name_contains, :default_code_repository_contains, :additional_code_repository_equals) SENSITIVE = [] include Aws::Structure end |
#creation_time_before ⇒ Time
A filter that returns only notebook instances that were created before the specified time (timestamp).
35582 35583 35584 35585 35586 35587 35588 35589 35590 35591 35592 35593 35594 35595 35596 35597 35598 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35582 class ListNotebookInstancesInput < Struct.new( :next_token, :max_results, :sort_by, :sort_order, :name_contains, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after, :status_equals, :notebook_instance_lifecycle_config_name_contains, :default_code_repository_contains, :additional_code_repository_equals) SENSITIVE = [] include Aws::Structure end |
#default_code_repository_contains ⇒ String
A string in the name or URL of a Git repository associated with this notebook instance. This filter returns only notebook instances associated with a git repository with a name that contains the specified string.
35582 35583 35584 35585 35586 35587 35588 35589 35590 35591 35592 35593 35594 35595 35596 35597 35598 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35582 class ListNotebookInstancesInput < Struct.new( :next_token, :max_results, :sort_by, :sort_order, :name_contains, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after, :status_equals, :notebook_instance_lifecycle_config_name_contains, :default_code_repository_contains, :additional_code_repository_equals) SENSITIVE = [] include Aws::Structure end |
#last_modified_time_after ⇒ Time
A filter that returns only notebook instances that were modified after the specified time (timestamp).
35582 35583 35584 35585 35586 35587 35588 35589 35590 35591 35592 35593 35594 35595 35596 35597 35598 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35582 class ListNotebookInstancesInput < Struct.new( :next_token, :max_results, :sort_by, :sort_order, :name_contains, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after, :status_equals, :notebook_instance_lifecycle_config_name_contains, :default_code_repository_contains, :additional_code_repository_equals) SENSITIVE = [] include Aws::Structure end |
#last_modified_time_before ⇒ Time
A filter that returns only notebook instances that were modified before the specified time (timestamp).
35582 35583 35584 35585 35586 35587 35588 35589 35590 35591 35592 35593 35594 35595 35596 35597 35598 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35582 class ListNotebookInstancesInput < Struct.new( :next_token, :max_results, :sort_by, :sort_order, :name_contains, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after, :status_equals, :notebook_instance_lifecycle_config_name_contains, :default_code_repository_contains, :additional_code_repository_equals) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of notebook instances to return.
35582 35583 35584 35585 35586 35587 35588 35589 35590 35591 35592 35593 35594 35595 35596 35597 35598 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35582 class ListNotebookInstancesInput < Struct.new( :next_token, :max_results, :sort_by, :sort_order, :name_contains, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after, :status_equals, :notebook_instance_lifecycle_config_name_contains, :default_code_repository_contains, :additional_code_repository_equals) SENSITIVE = [] include Aws::Structure end |
#name_contains ⇒ String
A string in the notebook instances’ name. This filter returns only notebook instances whose name contains the specified string.
35582 35583 35584 35585 35586 35587 35588 35589 35590 35591 35592 35593 35594 35595 35596 35597 35598 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35582 class ListNotebookInstancesInput < Struct.new( :next_token, :max_results, :sort_by, :sort_order, :name_contains, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after, :status_equals, :notebook_instance_lifecycle_config_name_contains, :default_code_repository_contains, :additional_code_repository_equals) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the previous call to the ListNotebookInstances is truncated, the response includes a NextToken. You can use this token in your subsequent ListNotebookInstances request to fetch the next set of notebook instances.
<note markdown=“1”> You might specify a filter or a sort order in your request. When response is truncated, you must use the same values for the filer and sort order in the next request.
</note>
35582 35583 35584 35585 35586 35587 35588 35589 35590 35591 35592 35593 35594 35595 35596 35597 35598 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35582 class ListNotebookInstancesInput < Struct.new( :next_token, :max_results, :sort_by, :sort_order, :name_contains, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after, :status_equals, :notebook_instance_lifecycle_config_name_contains, :default_code_repository_contains, :additional_code_repository_equals) SENSITIVE = [] include Aws::Structure end |
#notebook_instance_lifecycle_config_name_contains ⇒ String
A string in the name of a notebook instances lifecycle configuration associated with this notebook instance. This filter returns only notebook instances associated with a lifecycle configuration with a name that contains the specified string.
35582 35583 35584 35585 35586 35587 35588 35589 35590 35591 35592 35593 35594 35595 35596 35597 35598 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35582 class ListNotebookInstancesInput < Struct.new( :next_token, :max_results, :sort_by, :sort_order, :name_contains, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after, :status_equals, :notebook_instance_lifecycle_config_name_contains, :default_code_repository_contains, :additional_code_repository_equals) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
The field to sort results by. The default is Name.
35582 35583 35584 35585 35586 35587 35588 35589 35590 35591 35592 35593 35594 35595 35596 35597 35598 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35582 class ListNotebookInstancesInput < Struct.new( :next_token, :max_results, :sort_by, :sort_order, :name_contains, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after, :status_equals, :notebook_instance_lifecycle_config_name_contains, :default_code_repository_contains, :additional_code_repository_equals) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
The sort order for results.
35582 35583 35584 35585 35586 35587 35588 35589 35590 35591 35592 35593 35594 35595 35596 35597 35598 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35582 class ListNotebookInstancesInput < Struct.new( :next_token, :max_results, :sort_by, :sort_order, :name_contains, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after, :status_equals, :notebook_instance_lifecycle_config_name_contains, :default_code_repository_contains, :additional_code_repository_equals) SENSITIVE = [] include Aws::Structure end |
#status_equals ⇒ String
A filter that returns only notebook instances with the specified status.
35582 35583 35584 35585 35586 35587 35588 35589 35590 35591 35592 35593 35594 35595 35596 35597 35598 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35582 class ListNotebookInstancesInput < Struct.new( :next_token, :max_results, :sort_by, :sort_order, :name_contains, :creation_time_before, :creation_time_after, :last_modified_time_before, :last_modified_time_after, :status_equals, :notebook_instance_lifecycle_config_name_contains, :default_code_repository_contains, :additional_code_repository_equals) SENSITIVE = [] include Aws::Structure end |