Class: Aws::SageMaker::Types::ListPartnerAppsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListPartnerAppsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
This parameter defines the maximum number of results that can be returned in a single response.
-
#next_token ⇒ String
If the previous response was truncated, you will receive this token.
Instance Attribute Details
#max_results ⇒ Integer
This parameter defines the maximum number of results that can be
returned in a single response. The MaxResults parameter is an
upper bound, not a target. If there are more results available than
the value specified, a NextToken is provided in the response. The
NextToken indicates that the user should get the next set of
results by providing this token as a part of a subsequent call. The
default value for MaxResults is 10.
39128 39129 39130 39131 39132 39133 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39128 class ListPartnerAppsRequest < Struct.new( :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the previous response was truncated, you will receive this token. Use it in your next request to receive the next set of results.
39128 39129 39130 39131 39132 39133 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39128 class ListPartnerAppsRequest < Struct.new( :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |