Class: Aws::SageMaker::Types::ListPipelineExecutionStepsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListPipelineExecutionStepsResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If the result of the previous
ListPipelineExecutionStepsrequest was truncated, the response includes aNextToken. -
#pipeline_execution_steps ⇒ Array<Types::PipelineExecutionStep>
A list of
PipeLineExecutionStepobjects.
Instance Attribute Details
#next_token ⇒ String
If the result of the previous ListPipelineExecutionSteps request was truncated, the response includes a NextToken. To retrieve the next set of pipeline execution steps, use the token in the next request.
35737 35738 35739 35740 35741 35742 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35737 class ListPipelineExecutionStepsResponse < Struct.new( :pipeline_execution_steps, :next_token) SENSITIVE = [] include Aws::Structure end |
#pipeline_execution_steps ⇒ Array<Types::PipelineExecutionStep>
A list of PipeLineExecutionStep objects. Each PipeLineExecutionStep consists of StepName, StartTime, EndTime, StepStatus, and Metadata. Metadata is an object with properties for each job that contains relevant information about the job created by the step.
35737 35738 35739 35740 35741 35742 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 35737 class ListPipelineExecutionStepsResponse < Struct.new( :pipeline_execution_steps, :next_token) SENSITIVE = [] include Aws::Structure end |