Class: Aws::SageMaker::Types::ListPipelinesRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_afterTime

A filter that returns the pipelines that were created after a specified time.



35954
35955
35956
35957
35958
35959
35960
35961
35962
35963
35964
# File 'lib/aws-sdk-sagemaker/types.rb', line 35954

class ListPipelinesRequest < Struct.new(
  :pipeline_name_prefix,
  :created_after,
  :created_before,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#created_beforeTime

A filter that returns the pipelines that were created before a specified time.



35954
35955
35956
35957
35958
35959
35960
35961
35962
35963
35964
# File 'lib/aws-sdk-sagemaker/types.rb', line 35954

class ListPipelinesRequest < Struct.new(
  :pipeline_name_prefix,
  :created_after,
  :created_before,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of pipelines to return in the response.



35954
35955
35956
35957
35958
35959
35960
35961
35962
35963
35964
# File 'lib/aws-sdk-sagemaker/types.rb', line 35954

class ListPipelinesRequest < Struct.new(
  :pipeline_name_prefix,
  :created_after,
  :created_before,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the result of the previous ListPipelines request was truncated, the response includes a NextToken. To retrieve the next set of pipelines, use the token in the next request.



35954
35955
35956
35957
35958
35959
35960
35961
35962
35963
35964
# File 'lib/aws-sdk-sagemaker/types.rb', line 35954

class ListPipelinesRequest < Struct.new(
  :pipeline_name_prefix,
  :created_after,
  :created_before,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#pipeline_name_prefixString

The prefix of the pipeline name.



35954
35955
35956
35957
35958
35959
35960
35961
35962
35963
35964
# File 'lib/aws-sdk-sagemaker/types.rb', line 35954

class ListPipelinesRequest < Struct.new(
  :pipeline_name_prefix,
  :created_after,
  :created_before,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#sort_byString

The field by which to sort results. The default is CreatedTime.



35954
35955
35956
35957
35958
35959
35960
35961
35962
35963
35964
# File 'lib/aws-sdk-sagemaker/types.rb', line 35954

class ListPipelinesRequest < Struct.new(
  :pipeline_name_prefix,
  :created_after,
  :created_before,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#sort_orderString

The sort order for results.



35954
35955
35956
35957
35958
35959
35960
35961
35962
35963
35964
# File 'lib/aws-sdk-sagemaker/types.rb', line 35954

class ListPipelinesRequest < Struct.new(
  :pipeline_name_prefix,
  :created_after,
  :created_before,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end