Class: Aws::SageMaker::Types::ListSpacesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListSpacesResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If the previous response was truncated, you will receive this token.
-
#spaces ⇒ Array<Types::SpaceDetails>
The list of spaces.
Instance Attribute Details
#next_token ⇒ String
If the previous response was truncated, you will receive this token. Use it in your next request to receive the next set of results.
36554 36555 36556 36557 36558 36559 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36554 class ListSpacesResponse < Struct.new( :spaces, :next_token) SENSITIVE = [] include Aws::Structure end |
#spaces ⇒ Array<Types::SpaceDetails>
The list of spaces.
36554 36555 36556 36557 36558 36559 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36554 class ListSpacesResponse < Struct.new( :spaces, :next_token) SENSITIVE = [] include Aws::Structure end |