Class: Aws::SageMaker::Types::ListStudioLifecycleConfigsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListStudioLifecycleConfigsResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If the previous response was truncated, you will receive this token.
-
#studio_lifecycle_configs ⇒ Array<Types::StudioLifecycleConfigDetails>
A list of Lifecycle Configurations and their properties.
Instance Attribute Details
#next_token ⇒ String
If the previous response was truncated, you will receive this token. Use it in your next request to receive the next set of results.
36462 36463 36464 36465 36466 36467 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36462 class ListStudioLifecycleConfigsResponse < Struct.new( :next_token, :studio_lifecycle_configs) SENSITIVE = [] include Aws::Structure end |
#studio_lifecycle_configs ⇒ Array<Types::StudioLifecycleConfigDetails>
A list of Lifecycle Configurations and their properties.
36462 36463 36464 36465 36466 36467 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36462 class ListStudioLifecycleConfigsResponse < Struct.new( :next_token, :studio_lifecycle_configs) SENSITIVE = [] include Aws::Structure end |