Class: Aws::SageMaker::Types::ListStudioLifecycleConfigsResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

If the previous response was truncated, you will receive this token. Use it in your next request to receive the next set of results.



36369
36370
36371
36372
36373
36374
# File 'lib/aws-sdk-sagemaker/types.rb', line 36369

class ListStudioLifecycleConfigsResponse < Struct.new(
  :next_token,
  :studio_lifecycle_configs)
  SENSITIVE = []
  include Aws::Structure
end

#studio_lifecycle_configsArray<Types::StudioLifecycleConfigDetails>

A list of Lifecycle Configurations and their properties.



36369
36370
36371
36372
36373
36374
# File 'lib/aws-sdk-sagemaker/types.rb', line 36369

class ListStudioLifecycleConfigsResponse < Struct.new(
  :next_token,
  :studio_lifecycle_configs)
  SENSITIVE = []
  include Aws::Structure
end