Class: Aws::SageMaker::Types::ListTrainingJobsForHyperParameterTuningJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListTrainingJobsForHyperParameterTuningJobRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#hyper_parameter_tuning_job_name ⇒ String
The name of the tuning job whose training jobs you want to list.
-
#max_results ⇒ Integer
The maximum number of training jobs to return.
-
#next_token ⇒ String
If the result of the previous
ListTrainingJobsForHyperParameterTuningJobrequest was truncated, the response includes aNextToken. -
#sort_by ⇒ String
The field to sort results by.
-
#sort_order ⇒ String
The sort order for results.
-
#status_equals ⇒ String
A filter that returns only training jobs with the specified status.
Instance Attribute Details
#hyper_parameter_tuning_job_name ⇒ String
The name of the tuning job whose training jobs you want to list.
36592 36593 36594 36595 36596 36597 36598 36599 36600 36601 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36592 class ListTrainingJobsForHyperParameterTuningJobRequest < Struct.new( :hyper_parameter_tuning_job_name, :next_token, :max_results, :status_equals, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of training jobs to return. The default value is 10.
36592 36593 36594 36595 36596 36597 36598 36599 36600 36601 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36592 class ListTrainingJobsForHyperParameterTuningJobRequest < Struct.new( :hyper_parameter_tuning_job_name, :next_token, :max_results, :status_equals, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the result of the previous ListTrainingJobsForHyperParameterTuningJob request was truncated, the response includes a NextToken. To retrieve the next set of training jobs, use the token in the next request.
36592 36593 36594 36595 36596 36597 36598 36599 36600 36601 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36592 class ListTrainingJobsForHyperParameterTuningJobRequest < Struct.new( :hyper_parameter_tuning_job_name, :next_token, :max_results, :status_equals, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
The field to sort results by. The default is Name.
If the value of this field is FinalObjectiveMetricValue, any training jobs that did not return an objective metric are not listed.
36592 36593 36594 36595 36596 36597 36598 36599 36600 36601 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36592 class ListTrainingJobsForHyperParameterTuningJobRequest < Struct.new( :hyper_parameter_tuning_job_name, :next_token, :max_results, :status_equals, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
The sort order for results. The default is Ascending.
36592 36593 36594 36595 36596 36597 36598 36599 36600 36601 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36592 class ListTrainingJobsForHyperParameterTuningJobRequest < Struct.new( :hyper_parameter_tuning_job_name, :next_token, :max_results, :status_equals, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#status_equals ⇒ String
A filter that returns only training jobs with the specified status.
36592 36593 36594 36595 36596 36597 36598 36599 36600 36601 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36592 class ListTrainingJobsForHyperParameterTuningJobRequest < Struct.new( :hyper_parameter_tuning_job_name, :next_token, :max_results, :status_equals, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |