Class: Aws::SageMaker::Types::ListUserProfilesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListUserProfilesRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_id_equals ⇒ String
A parameter by which to filter the results.
-
#max_results ⇒ Integer
This parameter defines the maximum number of results that can be return in a single response.
-
#next_token ⇒ String
If the previous response was truncated, you will receive this token.
-
#sort_by ⇒ String
The parameter by which to sort the results.
-
#sort_order ⇒ String
The sort order for the results.
-
#user_profile_name_contains ⇒ String
A parameter by which to filter the results.
Instance Attribute Details
#domain_id_equals ⇒ String
A parameter by which to filter the results.
37007 37008 37009 37010 37011 37012 37013 37014 37015 37016 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37007 class ListUserProfilesRequest < Struct.new( :next_token, :max_results, :sort_order, :sort_by, :domain_id_equals, :user_profile_name_contains) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
This parameter defines the maximum number of results that can be return in a single response. The MaxResults parameter is an upper bound, not a target. If there are more results available than the value specified, a NextToken is provided in the response. The NextToken indicates that the user should get the next set of results by providing this token as a part of a subsequent call. The default value for MaxResults is 10.
37007 37008 37009 37010 37011 37012 37013 37014 37015 37016 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37007 class ListUserProfilesRequest < Struct.new( :next_token, :max_results, :sort_order, :sort_by, :domain_id_equals, :user_profile_name_contains) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the previous response was truncated, you will receive this token. Use it in your next request to receive the next set of results.
37007 37008 37009 37010 37011 37012 37013 37014 37015 37016 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37007 class ListUserProfilesRequest < Struct.new( :next_token, :max_results, :sort_order, :sort_by, :domain_id_equals, :user_profile_name_contains) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
The parameter by which to sort the results. The default is CreationTime.
37007 37008 37009 37010 37011 37012 37013 37014 37015 37016 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37007 class ListUserProfilesRequest < Struct.new( :next_token, :max_results, :sort_order, :sort_by, :domain_id_equals, :user_profile_name_contains) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
The sort order for the results. The default is Ascending.
37007 37008 37009 37010 37011 37012 37013 37014 37015 37016 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37007 class ListUserProfilesRequest < Struct.new( :next_token, :max_results, :sort_order, :sort_by, :domain_id_equals, :user_profile_name_contains) SENSITIVE = [] include Aws::Structure end |
#user_profile_name_contains ⇒ String
A parameter by which to filter the results.
37007 37008 37009 37010 37011 37012 37013 37014 37015 37016 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37007 class ListUserProfilesRequest < Struct.new( :next_token, :max_results, :sort_order, :sort_by, :domain_id_equals, :user_profile_name_contains) SENSITIVE = [] include Aws::Structure end |