Class: Aws::SageMaker::Types::ListUserProfilesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ListUserProfilesResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If the previous response was truncated, you will receive this token.
-
#user_profiles ⇒ Array<Types::UserProfileDetails>
The list of user profiles.
Instance Attribute Details
#next_token ⇒ String
If the previous response was truncated, you will receive this token. Use it in your next request to receive the next set of results.
37122 37123 37124 37125 37126 37127 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37122 class ListUserProfilesResponse < Struct.new( :user_profiles, :next_token) SENSITIVE = [] include Aws::Structure end |
#user_profiles ⇒ Array<Types::UserProfileDetails>
The list of user profiles.
37122 37123 37124 37125 37126 37127 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37122 class ListUserProfilesResponse < Struct.new( :user_profiles, :next_token) SENSITIVE = [] include Aws::Structure end |