Class: Aws::SageMaker::Types::MetricDatum

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Information about the metric for a candidate produced by an AutoML job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#metric_nameString

The name of the metric.

Returns:

  • (String)


40306
40307
40308
40309
40310
40311
40312
40313
# File 'lib/aws-sdk-sagemaker/types.rb', line 40306

class MetricDatum < Struct.new(
  :metric_name,
  :standard_metric_name,
  :value,
  :set)
  SENSITIVE = []
  include Aws::Structure
end

#setString

The dataset split from which the AutoML job produced the metric.

Returns:

  • (String)


40306
40307
40308
40309
40310
40311
40312
40313
# File 'lib/aws-sdk-sagemaker/types.rb', line 40306

class MetricDatum < Struct.new(
  :metric_name,
  :standard_metric_name,
  :value,
  :set)
  SENSITIVE = []
  include Aws::Structure
end

#standard_metric_nameString

The name of the standard metric.

For definitions of the standard metrics, see Autopilot candidate metrics .

Returns:

  • (String)


40306
40307
40308
40309
40310
40311
40312
40313
# File 'lib/aws-sdk-sagemaker/types.rb', line 40306

class MetricDatum < Struct.new(
  :metric_name,
  :standard_metric_name,
  :value,
  :set)
  SENSITIVE = []
  include Aws::Structure
end

#valueFloat

The value of the metric.

Returns:

  • (Float)


40306
40307
40308
40309
40310
40311
40312
40313
# File 'lib/aws-sdk-sagemaker/types.rb', line 40306

class MetricDatum < Struct.new(
  :metric_name,
  :standard_metric_name,
  :value,
  :set)
  SENSITIVE = []
  include Aws::Structure
end