Class: Aws::SageMaker::Types::MetricDefinition
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::MetricDefinition
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Specifies a metric that the training algorithm writes to ‘stderr` or `stdout`. You can view these logs to understand how your training job performs and check for any errors encountered during training. SageMaker hyperparameter tuning captures all defined metrics. Specify one of the defined metrics to use as an objective metric using the
- TuningObjective][1
-
parameter in the
‘HyperParameterTrainingJobDefinition` API to evaluate job performance during hyperparameter tuning.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the metric.
-
#regex ⇒ String
A regular expression that searches the output of a training job and gets the value of the metric.
Instance Attribute Details
#name ⇒ String
The name of the metric.
40171 40172 40173 40174 40175 40176 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40171 class MetricDefinition < Struct.new( :name, :regex) SENSITIVE = [] include Aws::Structure end |
#regex ⇒ String
A regular expression that searches the output of a training job and gets the value of the metric. For more information about using regular expressions to define metrics, see [Defining metrics and environment variables].
[1]: docs.aws.amazon.com/sagemaker/latest/dg/automatic-model-tuning-define-metrics-variables.html
40171 40172 40173 40174 40175 40176 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40171 class MetricDefinition < Struct.new( :name, :regex) SENSITIVE = [] include Aws::Structure end |