Class: Aws::SageMaker::Types::MetricSpecification

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure, Aws::Structure::Union
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Note:

MetricSpecification is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of MetricSpecification corresponding to the set member.

An object containing information about a metric.

Direct Known Subclasses

Customized, Predefined, Unknown

Defined Under Namespace

Classes: Customized, Predefined, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#customizedTypes::CustomizedMetricSpecification

Information about a customized metric.

Returns:



37422
37423
37424
37425
37426
37427
37428
37429
37430
37431
37432
37433
# File 'lib/aws-sdk-sagemaker/types.rb', line 37422

class MetricSpecification < Struct.new(
  :predefined,
  :customized,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Predefined < MetricSpecification; end
  class Customized < MetricSpecification; end
  class Unknown < MetricSpecification; end
end

#predefinedTypes::PredefinedMetricSpecification

Information about a predefined metric.

Returns:



37422
37423
37424
37425
37426
37427
37428
37429
37430
37431
37432
37433
# File 'lib/aws-sdk-sagemaker/types.rb', line 37422

class MetricSpecification < Struct.new(
  :predefined,
  :customized,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Predefined < MetricSpecification; end
  class Customized < MetricSpecification; end
  class Unknown < MetricSpecification; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • the current value of unknown



37422
37423
37424
# File 'lib/aws-sdk-sagemaker/types.rb', line 37422

def unknown
  @unknown
end