Class: Aws::SageMaker::Types::MetricSpecification
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::MetricSpecification
- Includes:
- Aws::Structure, Aws::Structure::Union
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Note:
MetricSpecification is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of MetricSpecification corresponding to the set member.
An object containing information about a metric.
Direct Known Subclasses
Defined Under Namespace
Classes: Customized, Predefined, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#customized ⇒ Types::CustomizedMetricSpecification
Information about a customized metric.
-
#predefined ⇒ Types::PredefinedMetricSpecification
Information about a predefined metric.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#customized ⇒ Types::CustomizedMetricSpecification
Information about a customized metric.
37355 37356 37357 37358 37359 37360 37361 37362 37363 37364 37365 37366 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37355 class MetricSpecification < Struct.new( :predefined, :customized, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Predefined < MetricSpecification; end class Customized < MetricSpecification; end class Unknown < MetricSpecification; end end |
#predefined ⇒ Types::PredefinedMetricSpecification
Information about a predefined metric.
37355 37356 37357 37358 37359 37360 37361 37362 37363 37364 37365 37366 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37355 class MetricSpecification < Struct.new( :predefined, :customized, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Predefined < MetricSpecification; end class Customized < MetricSpecification; end class Unknown < MetricSpecification; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
37355 37356 37357 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37355 def unknown @unknown end |