Class: Aws::SageMaker::Types::MetricsEndpoint
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::MetricsEndpoint
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Specifies a metrics endpoint for a container, including the path where the container exposes Prometheus-formatted metrics and the frequency at which to publish them to Amazon CloudWatch.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#metric_publish_frequency_in_seconds ⇒ Integer
The interval, in seconds, at which container metrics scraped from the endpoint are published to Amazon CloudWatch.
-
#metrics_endpoint_path ⇒ String
The path to the metrics endpoint exposed by the container.
Instance Attribute Details
#metric_publish_frequency_in_seconds ⇒ Integer
The interval, in seconds, at which container metrics scraped from the endpoint are published to Amazon CloudWatch. Valid values: ‘10`, `30`, `60`, `120`, `180`, `240`, `300`. Defaults to `60`.
40293 40294 40295 40296 40297 40298 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40293 class MetricsEndpoint < Struct.new( :metrics_endpoint_path, :metric_publish_frequency_in_seconds) SENSITIVE = [] include Aws::Structure end |
#metrics_endpoint_path ⇒ String
The path to the metrics endpoint exposed by the container. For example, ‘/metrics` or `/server/metrics`. The path must start with `/` and can contain alphanumeric characters, forward slashes, underscores, hyphens, and periods. Maximum length is 256 characters. If not specified, defaults to `/metrics`.
40293 40294 40295 40296 40297 40298 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40293 class MetricsEndpoint < Struct.new( :metrics_endpoint_path, :metric_publish_frequency_in_seconds) SENSITIVE = [] include Aws::Structure end |