Class: Aws::SageMaker::Types::Model

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The properties of a model as returned by the [Search] API.

[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_Search.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#containersArray<Types::ContainerDefinition>

The containers in the inference pipeline.

Returns:



40623
40624
40625
40626
40627
40628
40629
40630
40631
40632
40633
40634
40635
40636
40637
# File 'lib/aws-sdk-sagemaker/types.rb', line 40623

class Model < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :tags,
  :deployment_recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

A timestamp that indicates when the model was created.

Returns:

  • (Time)


40623
40624
40625
40626
40627
40628
40629
40630
40631
40632
40633
40634
40635
40636
40637
# File 'lib/aws-sdk-sagemaker/types.rb', line 40623

class Model < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :tags,
  :deployment_recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_recommendationTypes::DeploymentRecommendation

A set of recommended deployment configurations for the model.



40623
40624
40625
40626
40627
40628
40629
40630
40631
40632
40633
40634
40635
40636
40637
# File 'lib/aws-sdk-sagemaker/types.rb', line 40623

class Model < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :tags,
  :deployment_recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#enable_network_isolationBoolean

Isolates the model container. No inbound or outbound network calls can be made to or from the model container.

Returns:

  • (Boolean)


40623
40624
40625
40626
40627
40628
40629
40630
40631
40632
40633
40634
40635
40636
40637
# File 'lib/aws-sdk-sagemaker/types.rb', line 40623

class Model < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :tags,
  :deployment_recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#execution_role_arnString

The Amazon Resource Name (ARN) of the IAM role that you specified for the model.

Returns:

  • (String)


40623
40624
40625
40626
40627
40628
40629
40630
40631
40632
40633
40634
40635
40636
40637
# File 'lib/aws-sdk-sagemaker/types.rb', line 40623

class Model < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :tags,
  :deployment_recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#inference_execution_configTypes::InferenceExecutionConfig

Specifies details about how containers in a multi-container endpoint are run.



40623
40624
40625
40626
40627
40628
40629
40630
40631
40632
40633
40634
40635
40636
40637
# File 'lib/aws-sdk-sagemaker/types.rb', line 40623

class Model < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :tags,
  :deployment_recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#model_arnString

The Amazon Resource Name (ARN) of the model.

Returns:

  • (String)


40623
40624
40625
40626
40627
40628
40629
40630
40631
40632
40633
40634
40635
40636
40637
# File 'lib/aws-sdk-sagemaker/types.rb', line 40623

class Model < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :tags,
  :deployment_recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#model_nameString

The name of the model.

Returns:

  • (String)


40623
40624
40625
40626
40627
40628
40629
40630
40631
40632
40633
40634
40635
40636
40637
# File 'lib/aws-sdk-sagemaker/types.rb', line 40623

class Model < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :tags,
  :deployment_recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#primary_containerTypes::ContainerDefinition

Describes the container, as part of model definition.



40623
40624
40625
40626
40627
40628
40629
40630
40631
40632
40633
40634
40635
40636
40637
# File 'lib/aws-sdk-sagemaker/types.rb', line 40623

class Model < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :tags,
  :deployment_recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

A list of key-value pairs associated with the model. For more information, see [Tagging Amazon Web Services resources] in the *Amazon Web Services General Reference Guide*.

[1]: docs.aws.amazon.com/general/latest/gr/aws_tagging.html

Returns:



40623
40624
40625
40626
40627
40628
40629
40630
40631
40632
40633
40634
40635
40636
40637
# File 'lib/aws-sdk-sagemaker/types.rb', line 40623

class Model < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :tags,
  :deployment_recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_configTypes::VpcConfig

Specifies an Amazon Virtual Private Cloud (VPC) that your SageMaker jobs, hosted models, and compute resources have access to. You can control access to and from your resources by configuring a VPC. For more information, see [Give SageMaker Access to Resources in your Amazon VPC].

[1]: docs.aws.amazon.com/sagemaker/latest/dg/infrastructure-give-access.html

Returns:



40623
40624
40625
40626
40627
40628
40629
40630
40631
40632
40633
40634
40635
40636
40637
# File 'lib/aws-sdk-sagemaker/types.rb', line 40623

class Model < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :tags,
  :deployment_recommendation)
  SENSITIVE = []
  include Aws::Structure
end