Class: Aws::SageMaker::Types::Model
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::Model
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The properties of a model as returned by the [Search] API.
[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_Search.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#containers ⇒ Array<Types::ContainerDefinition>
The containers in the inference pipeline.
-
#creation_time ⇒ Time
A timestamp that indicates when the model was created.
-
#deployment_recommendation ⇒ Types::DeploymentRecommendation
A set of recommended deployment configurations for the model.
-
#enable_network_isolation ⇒ Boolean
Isolates the model container.
-
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that you specified for the model.
-
#inference_execution_config ⇒ Types::InferenceExecutionConfig
Specifies details about how containers in a multi-container endpoint are run.
-
#model_arn ⇒ String
The Amazon Resource Name (ARN) of the model.
-
#model_name ⇒ String
The name of the model.
-
#primary_container ⇒ Types::ContainerDefinition
Describes the container, as part of model definition.
-
#tags ⇒ Array<Types::Tag>
A list of key-value pairs associated with the model.
-
#vpc_config ⇒ Types::VpcConfig
Specifies an Amazon Virtual Private Cloud (VPC) that your SageMaker jobs, hosted models, and compute resources have access to.
Instance Attribute Details
#containers ⇒ Array<Types::ContainerDefinition>
The containers in the inference pipeline.
40129 40130 40131 40132 40133 40134 40135 40136 40137 40138 40139 40140 40141 40142 40143 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40129 class Model < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :tags, :deployment_recommendation) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
A timestamp that indicates when the model was created.
40129 40130 40131 40132 40133 40134 40135 40136 40137 40138 40139 40140 40141 40142 40143 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40129 class Model < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :tags, :deployment_recommendation) SENSITIVE = [] include Aws::Structure end |
#deployment_recommendation ⇒ Types::DeploymentRecommendation
A set of recommended deployment configurations for the model.
40129 40130 40131 40132 40133 40134 40135 40136 40137 40138 40139 40140 40141 40142 40143 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40129 class Model < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :tags, :deployment_recommendation) SENSITIVE = [] include Aws::Structure end |
#enable_network_isolation ⇒ Boolean
Isolates the model container. No inbound or outbound network calls can be made to or from the model container.
40129 40130 40131 40132 40133 40134 40135 40136 40137 40138 40139 40140 40141 40142 40143 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40129 class Model < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :tags, :deployment_recommendation) SENSITIVE = [] include Aws::Structure end |
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that you specified for the model.
40129 40130 40131 40132 40133 40134 40135 40136 40137 40138 40139 40140 40141 40142 40143 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40129 class Model < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :tags, :deployment_recommendation) SENSITIVE = [] include Aws::Structure end |
#inference_execution_config ⇒ Types::InferenceExecutionConfig
Specifies details about how containers in a multi-container endpoint are run.
40129 40130 40131 40132 40133 40134 40135 40136 40137 40138 40139 40140 40141 40142 40143 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40129 class Model < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :tags, :deployment_recommendation) SENSITIVE = [] include Aws::Structure end |
#model_arn ⇒ String
The Amazon Resource Name (ARN) of the model.
40129 40130 40131 40132 40133 40134 40135 40136 40137 40138 40139 40140 40141 40142 40143 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40129 class Model < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :tags, :deployment_recommendation) SENSITIVE = [] include Aws::Structure end |
#model_name ⇒ String
The name of the model.
40129 40130 40131 40132 40133 40134 40135 40136 40137 40138 40139 40140 40141 40142 40143 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40129 class Model < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :tags, :deployment_recommendation) SENSITIVE = [] include Aws::Structure end |
#primary_container ⇒ Types::ContainerDefinition
Describes the container, as part of model definition.
40129 40130 40131 40132 40133 40134 40135 40136 40137 40138 40139 40140 40141 40142 40143 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40129 class Model < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :tags, :deployment_recommendation) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of key-value pairs associated with the model. For more information, see [Tagging Amazon Web Services resources] in the *Amazon Web Services General Reference Guide*.
40129 40130 40131 40132 40133 40134 40135 40136 40137 40138 40139 40140 40141 40142 40143 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40129 class Model < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :tags, :deployment_recommendation) SENSITIVE = [] include Aws::Structure end |
#vpc_config ⇒ Types::VpcConfig
Specifies an Amazon Virtual Private Cloud (VPC) that your SageMaker jobs, hosted models, and compute resources have access to. You can control access to and from your resources by configuring a VPC. For more information, see [Give SageMaker Access to Resources in your Amazon VPC].
[1]: docs.aws.amazon.com/sagemaker/latest/dg/infrastructure-give-access.html
40129 40130 40131 40132 40133 40134 40135 40136 40137 40138 40139 40140 40141 40142 40143 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40129 class Model < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :tags, :deployment_recommendation) SENSITIVE = [] include Aws::Structure end |