Class: Aws::SageMaker::Types::Model

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The properties of a model as returned by the Search API.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#containersArray<Types::ContainerDefinition>

The containers in the inference pipeline.

Returns:



26694
26695
26696
26697
26698
26699
26700
26701
26702
26703
26704
26705
26706
26707
# File 'lib/aws-sdk-sagemaker/types.rb', line 26694

class Model < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

A timestamp that indicates when the model was created.

Returns:

  • (Time)


26694
26695
26696
26697
26698
26699
26700
26701
26702
26703
26704
26705
26706
26707
# File 'lib/aws-sdk-sagemaker/types.rb', line 26694

class Model < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#enable_network_isolationBoolean

Isolates the model container. No inbound or outbound network calls can be made to or from the model container.

Returns:

  • (Boolean)


26694
26695
26696
26697
26698
26699
26700
26701
26702
26703
26704
26705
26706
26707
# File 'lib/aws-sdk-sagemaker/types.rb', line 26694

class Model < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#execution_role_arnString

The Amazon Resource Name (ARN) of the IAM role that you specified for the model.

Returns:

  • (String)


26694
26695
26696
26697
26698
26699
26700
26701
26702
26703
26704
26705
26706
26707
# File 'lib/aws-sdk-sagemaker/types.rb', line 26694

class Model < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#inference_execution_configTypes::InferenceExecutionConfig

Specifies details about how containers in a multi-container endpoint are run.



26694
26695
26696
26697
26698
26699
26700
26701
26702
26703
26704
26705
26706
26707
# File 'lib/aws-sdk-sagemaker/types.rb', line 26694

class Model < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#model_arnString

The Amazon Resource Name (ARN) of the model.

Returns:

  • (String)


26694
26695
26696
26697
26698
26699
26700
26701
26702
26703
26704
26705
26706
26707
# File 'lib/aws-sdk-sagemaker/types.rb', line 26694

class Model < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#model_nameString

The name of the model.

Returns:

  • (String)


26694
26695
26696
26697
26698
26699
26700
26701
26702
26703
26704
26705
26706
26707
# File 'lib/aws-sdk-sagemaker/types.rb', line 26694

class Model < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#primary_containerTypes::ContainerDefinition

Describes the container, as part of model definition.



26694
26695
26696
26697
26698
26699
26700
26701
26702
26703
26704
26705
26706
26707
# File 'lib/aws-sdk-sagemaker/types.rb', line 26694

class Model < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

A list of key-value pairs associated with the model. For more information, see [Tagging Amazon Web Services resources] in the *Amazon Web Services General Reference Guide*.

[1]: docs.aws.amazon.com/general/latest/gr/aws_tagging.html

Returns:



26694
26695
26696
26697
26698
26699
26700
26701
26702
26703
26704
26705
26706
26707
# File 'lib/aws-sdk-sagemaker/types.rb', line 26694

class Model < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_configTypes::VpcConfig

Specifies a VPC that your training jobs and hosted models have access to. Control access to and from your training and model containers by configuring the VPC. For more information, see

Protect Endpoints by Using an Amazon Virtual Private Cloud][1

and

[Protect Training Jobs by Using an Amazon Virtual Private Cloud].

[1]: docs.aws.amazon.com/sagemaker/latest/dg/host-vpc.html [2]: docs.aws.amazon.com/sagemaker/latest/dg/train-vpc.html

Returns:



26694
26695
26696
26697
26698
26699
26700
26701
26702
26703
26704
26705
26706
26707
# File 'lib/aws-sdk-sagemaker/types.rb', line 26694

class Model < Struct.new(
  :model_name,
  :primary_container,
  :containers,
  :inference_execution_config,
  :execution_role_arn,
  :vpc_config,
  :creation_time,
  :model_arn,
  :enable_network_isolation,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end