Class: Aws::SageMaker::Types::Model
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::Model
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The properties of a model as returned by the Search API.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#containers ⇒ Array<Types::ContainerDefinition>
The containers in the inference pipeline.
-
#creation_time ⇒ Time
A timestamp that indicates when the model was created.
-
#enable_network_isolation ⇒ Boolean
Isolates the model container.
-
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that you specified for the model.
-
#inference_execution_config ⇒ Types::InferenceExecutionConfig
Specifies details about how containers in a multi-container endpoint are run.
-
#model_arn ⇒ String
The Amazon Resource Name (ARN) of the model.
-
#model_name ⇒ String
The name of the model.
-
#primary_container ⇒ Types::ContainerDefinition
Describes the container, as part of model definition.
-
#tags ⇒ Array<Types::Tag>
A list of key-value pairs associated with the model.
-
#vpc_config ⇒ Types::VpcConfig
Specifies a VPC that your training jobs and hosted models have access to.
Instance Attribute Details
#containers ⇒ Array<Types::ContainerDefinition>
The containers in the inference pipeline.
26694 26695 26696 26697 26698 26699 26700 26701 26702 26703 26704 26705 26706 26707 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26694 class Model < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :tags) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
A timestamp that indicates when the model was created.
26694 26695 26696 26697 26698 26699 26700 26701 26702 26703 26704 26705 26706 26707 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26694 class Model < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :tags) SENSITIVE = [] include Aws::Structure end |
#enable_network_isolation ⇒ Boolean
Isolates the model container. No inbound or outbound network calls can be made to or from the model container.
26694 26695 26696 26697 26698 26699 26700 26701 26702 26703 26704 26705 26706 26707 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26694 class Model < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :tags) SENSITIVE = [] include Aws::Structure end |
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that you specified for the model.
26694 26695 26696 26697 26698 26699 26700 26701 26702 26703 26704 26705 26706 26707 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26694 class Model < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :tags) SENSITIVE = [] include Aws::Structure end |
#inference_execution_config ⇒ Types::InferenceExecutionConfig
Specifies details about how containers in a multi-container endpoint are run.
26694 26695 26696 26697 26698 26699 26700 26701 26702 26703 26704 26705 26706 26707 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26694 class Model < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :tags) SENSITIVE = [] include Aws::Structure end |
#model_arn ⇒ String
The Amazon Resource Name (ARN) of the model.
26694 26695 26696 26697 26698 26699 26700 26701 26702 26703 26704 26705 26706 26707 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26694 class Model < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :tags) SENSITIVE = [] include Aws::Structure end |
#model_name ⇒ String
The name of the model.
26694 26695 26696 26697 26698 26699 26700 26701 26702 26703 26704 26705 26706 26707 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26694 class Model < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :tags) SENSITIVE = [] include Aws::Structure end |
#primary_container ⇒ Types::ContainerDefinition
Describes the container, as part of model definition.
26694 26695 26696 26697 26698 26699 26700 26701 26702 26703 26704 26705 26706 26707 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26694 class Model < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of key-value pairs associated with the model. For more information, see [Tagging Amazon Web Services resources] in the *Amazon Web Services General Reference Guide*.
26694 26695 26696 26697 26698 26699 26700 26701 26702 26703 26704 26705 26706 26707 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26694 class Model < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :tags) SENSITIVE = [] include Aws::Structure end |
#vpc_config ⇒ Types::VpcConfig
Specifies a VPC that your training jobs and hosted models have access to. Control access to and from your training and model containers by configuring the VPC. For more information, see
- Protect Endpoints by Using an Amazon Virtual Private Cloud][1
-
and
[Protect Training Jobs by Using an Amazon Virtual Private Cloud].
[1]: docs.aws.amazon.com/sagemaker/latest/dg/host-vpc.html [2]: docs.aws.amazon.com/sagemaker/latest/dg/train-vpc.html
26694 26695 26696 26697 26698 26699 26700 26701 26702 26703 26704 26705 26706 26707 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26694 class Model < Struct.new( :model_name, :primary_container, :containers, :inference_execution_config, :execution_role_arn, :vpc_config, :creation_time, :model_arn, :enable_network_isolation, :tags) SENSITIVE = [] include Aws::Structure end |