Class: Aws::SageMaker::Types::ModelCard
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ModelCard
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
An Amazon SageMaker Model Card.
Constant Summary collapse
- SENSITIVE =
[:content]
Instance Attribute Summary collapse
-
#content ⇒ String
The content of the model card.
-
#created_by ⇒ Types::UserContext
Information about the user who created or modified an experiment, trial, trial component, lineage group, project, or model card.
-
#creation_time ⇒ Time
The date and time that the model card was created.
-
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified an experiment, trial, trial component, lineage group, project, or model card.
-
#last_modified_time ⇒ Time
The date and time that the model card was last modified.
-
#model_card_arn ⇒ String
The Amazon Resource Name (ARN) of the model card.
-
#model_card_name ⇒ String
The unique name of the model card.
-
#model_card_status ⇒ String
The approval status of the model card within your organization.
-
#model_card_version ⇒ Integer
The version of the model card.
-
#model_id ⇒ String
The unique name (ID) of the model.
-
#risk_rating ⇒ String
The risk rating of the model.
-
#security_config ⇒ Types::ModelCardSecurityConfig
The security configuration used to protect model card data.
-
#tags ⇒ Array<Types::Tag>
Key-value pairs used to manage metadata for the model card.
Instance Attribute Details
#content ⇒ String
The content of the model card. Content uses the [model card JSON schema] and provided as a string.
[1]: docs.aws.amazon.com/sagemaker/latest/dg/model-cards-api-json-schema.html
26882 26883 26884 26885 26886 26887 26888 26889 26890 26891 26892 26893 26894 26895 26896 26897 26898 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26882 class ModelCard < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :content, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :tags, :model_id, :risk_rating) SENSITIVE = [:content] include Aws::Structure end |
#created_by ⇒ Types::UserContext
Information about the user who created or modified an experiment, trial, trial component, lineage group, project, or model card.
26882 26883 26884 26885 26886 26887 26888 26889 26890 26891 26892 26893 26894 26895 26896 26897 26898 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26882 class ModelCard < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :content, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :tags, :model_id, :risk_rating) SENSITIVE = [:content] include Aws::Structure end |
#creation_time ⇒ Time
The date and time that the model card was created.
26882 26883 26884 26885 26886 26887 26888 26889 26890 26891 26892 26893 26894 26895 26896 26897 26898 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26882 class ModelCard < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :content, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :tags, :model_id, :risk_rating) SENSITIVE = [:content] include Aws::Structure end |
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified an experiment, trial, trial component, lineage group, project, or model card.
26882 26883 26884 26885 26886 26887 26888 26889 26890 26891 26892 26893 26894 26895 26896 26897 26898 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26882 class ModelCard < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :content, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :tags, :model_id, :risk_rating) SENSITIVE = [:content] include Aws::Structure end |
#last_modified_time ⇒ Time
The date and time that the model card was last modified.
26882 26883 26884 26885 26886 26887 26888 26889 26890 26891 26892 26893 26894 26895 26896 26897 26898 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26882 class ModelCard < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :content, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :tags, :model_id, :risk_rating) SENSITIVE = [:content] include Aws::Structure end |
#model_card_arn ⇒ String
The Amazon Resource Name (ARN) of the model card.
26882 26883 26884 26885 26886 26887 26888 26889 26890 26891 26892 26893 26894 26895 26896 26897 26898 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26882 class ModelCard < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :content, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :tags, :model_id, :risk_rating) SENSITIVE = [:content] include Aws::Structure end |
#model_card_name ⇒ String
The unique name of the model card.
26882 26883 26884 26885 26886 26887 26888 26889 26890 26891 26892 26893 26894 26895 26896 26897 26898 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26882 class ModelCard < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :content, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :tags, :model_id, :risk_rating) SENSITIVE = [:content] include Aws::Structure end |
#model_card_status ⇒ String
The approval status of the model card within your organization. Different organizations might have different criteria for model card review and approval.
-
Draft: The model card is a work in progress. -
PendingReview: The model card is pending review. -
Approved: The model card is approved. -
Archived: The model card is archived. No more updates should be made to the model card, but it can still be exported.
26882 26883 26884 26885 26886 26887 26888 26889 26890 26891 26892 26893 26894 26895 26896 26897 26898 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26882 class ModelCard < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :content, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :tags, :model_id, :risk_rating) SENSITIVE = [:content] include Aws::Structure end |
#model_card_version ⇒ Integer
The version of the model card.
26882 26883 26884 26885 26886 26887 26888 26889 26890 26891 26892 26893 26894 26895 26896 26897 26898 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26882 class ModelCard < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :content, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :tags, :model_id, :risk_rating) SENSITIVE = [:content] include Aws::Structure end |
#model_id ⇒ String
The unique name (ID) of the model.
26882 26883 26884 26885 26886 26887 26888 26889 26890 26891 26892 26893 26894 26895 26896 26897 26898 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26882 class ModelCard < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :content, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :tags, :model_id, :risk_rating) SENSITIVE = [:content] include Aws::Structure end |
#risk_rating ⇒ String
The risk rating of the model. Different organizations might have different criteria for model card risk ratings. For more information, see [Risk ratings].
[1]: docs.aws.amazon.com/sagemaker/latest/dg/model-cards-risk-rating.html
26882 26883 26884 26885 26886 26887 26888 26889 26890 26891 26892 26893 26894 26895 26896 26897 26898 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26882 class ModelCard < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :content, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :tags, :model_id, :risk_rating) SENSITIVE = [:content] include Aws::Structure end |
#security_config ⇒ Types::ModelCardSecurityConfig
The security configuration used to protect model card data.
26882 26883 26884 26885 26886 26887 26888 26889 26890 26891 26892 26893 26894 26895 26896 26897 26898 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26882 class ModelCard < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :content, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :tags, :model_id, :risk_rating) SENSITIVE = [:content] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Key-value pairs used to manage metadata for the model card.
26882 26883 26884 26885 26886 26887 26888 26889 26890 26891 26892 26893 26894 26895 26896 26897 26898 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 26882 class ModelCard < Struct.new( :model_card_arn, :model_card_name, :model_card_version, :content, :model_card_status, :security_config, :creation_time, :created_by, :last_modified_time, :last_modified_by, :tags, :model_id, :risk_rating) SENSITIVE = [:content] include Aws::Structure end |