Class: Aws::SageMaker::Types::ModelCardVersionSummary

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

A summary of a specific version of the model card.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timeTime

The date and time that the model card version was created.



41545
41546
41547
41548
41549
41550
41551
41552
41553
41554
# File 'lib/aws-sdk-sagemaker/types.rb', line 41545

class ModelCardVersionSummary < Struct.new(
  :model_card_name,
  :model_card_arn,
  :model_card_status,
  :model_card_version,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The time date and time that the model card version was last modified.



41545
41546
41547
41548
41549
41550
41551
41552
41553
41554
# File 'lib/aws-sdk-sagemaker/types.rb', line 41545

class ModelCardVersionSummary < Struct.new(
  :model_card_name,
  :model_card_arn,
  :model_card_status,
  :model_card_version,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#model_card_arnString

The Amazon Resource Name (ARN) of the model card.



41545
41546
41547
41548
41549
41550
41551
41552
41553
41554
# File 'lib/aws-sdk-sagemaker/types.rb', line 41545

class ModelCardVersionSummary < Struct.new(
  :model_card_name,
  :model_card_arn,
  :model_card_status,
  :model_card_version,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#model_card_nameString

The name of the model card.



41545
41546
41547
41548
41549
41550
41551
41552
41553
41554
# File 'lib/aws-sdk-sagemaker/types.rb', line 41545

class ModelCardVersionSummary < Struct.new(
  :model_card_name,
  :model_card_arn,
  :model_card_status,
  :model_card_version,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#model_card_statusString

The approval status of the model card version within your organization. Different organizations might have different criteria for model card review and approval.

  • Draft: The model card is a work in progress.

  • PendingReview: The model card is pending review.

  • Approved: The model card is approved.

  • Archived: The model card is archived. No more updates should be made to the model card, but it can still be exported.



41545
41546
41547
41548
41549
41550
41551
41552
41553
41554
# File 'lib/aws-sdk-sagemaker/types.rb', line 41545

class ModelCardVersionSummary < Struct.new(
  :model_card_name,
  :model_card_arn,
  :model_card_status,
  :model_card_version,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#model_card_versionInteger

A version of the model card.



41545
41546
41547
41548
41549
41550
41551
41552
41553
41554
# File 'lib/aws-sdk-sagemaker/types.rb', line 41545

class ModelCardVersionSummary < Struct.new(
  :model_card_name,
  :model_card_arn,
  :model_card_status,
  :model_card_version,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end