Class: Aws::SageMaker::Types::ModelPackage
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ModelPackage
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
A container for your trained model that can be deployed for SageMaker inference. This can include inference code, artifacts, and metadata. The model package type can be one of the following.
-
Versioned model: A part of a model package group in Model Registry.
-
Unversioned model: Not part of a model package group and used in Amazon Web Services Marketplace.
For more information, see [ ‘CreateModelPackage` ][1].
[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateModelPackage.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_inference_specifications ⇒ Array<Types::AdditionalInferenceSpecificationDefinition>
An array of additional Inference Specification objects.
-
#approval_description ⇒ String
A description provided when the model approval is set.
-
#certify_for_marketplace ⇒ Boolean
Whether the model package is to be certified to be listed on Amazon Web Services Marketplace.
-
#created_by ⇒ Types::UserContext
Information about the user who created or modified an experiment, trial, trial component, lineage group, or project.
-
#creation_time ⇒ Time
The time that the model package was created.
-
#customer_metadata_properties ⇒ Hash<String,String>
The metadata properties for the model package.
-
#domain ⇒ String
The machine learning domain of your model package and its components.
-
#drift_check_baselines ⇒ Types::DriftCheckBaselines
Represents the drift check baselines that can be used when the model monitor is set using the model package.
-
#inference_specification ⇒ Types::InferenceSpecification
Defines how to perform inference generation after a training job is run.
-
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified an experiment, trial, trial component, lineage group, or project.
-
#last_modified_time ⇒ Time
The last time the model package was modified.
-
#metadata_properties ⇒ Types::MetadataProperties
Metadata properties of the tracking entity, trial, or trial component.
-
#model_approval_status ⇒ String
The approval status of the model.
-
#model_card ⇒ Types::ModelPackageModelCard
The model card associated with the model package.
-
#model_life_cycle ⇒ Types::ModelLifeCycle
A structure describing the current state of the model in its life cycle.
-
#model_metrics ⇒ Types::ModelMetrics
Metrics for the model.
-
#model_package_arn ⇒ String
The Amazon Resource Name (ARN) of the model package.
-
#model_package_description ⇒ String
The description of the model package.
-
#model_package_group_name ⇒ String
The model group to which the model belongs.
-
#model_package_name ⇒ String
The name of the model package.
-
#model_package_registration_type ⇒ String
The package registration type of the model package.
-
#model_package_status ⇒ String
The status of the model package.
-
#model_package_status_details ⇒ Types::ModelPackageStatusDetails
Specifies the validation and image scan statuses of the model package.
-
#model_package_version ⇒ Integer
The version number of a versioned model.
-
#sample_payload_url ⇒ String
The Amazon Simple Storage Service path where the sample payload are stored.
-
#security_config ⇒ Types::ModelPackageSecurityConfig
An optional Key Management Service key to encrypt, decrypt, and re-encrypt model package information for regulated workloads with highly sensitive data.
-
#skip_model_validation ⇒ String
Indicates if you want to skip model validation.
-
#source_algorithm_specification ⇒ Types::SourceAlgorithmSpecification
A list of algorithms that were used to create a model package.
-
#source_uri ⇒ String
The URI of the source for the model package.
-
#tags ⇒ Array<Types::Tag>
A list of the tags associated with the model package.
-
#task ⇒ String
The machine learning task your model package accomplishes.
-
#validation_specification ⇒ Types::ModelPackageValidationSpecification
Specifies batch transform jobs that SageMaker runs to validate your model package.
Instance Attribute Details
#additional_inference_specifications ⇒ Array<Types::AdditionalInferenceSpecificationDefinition>
An array of additional Inference Specification objects.
40979 40980 40981 40982 40983 40984 40985 40986 40987 40988 40989 40990 40991 40992 40993 40994 40995 40996 40997 40998 40999 41000 41001 41002 41003 41004 41005 41006 41007 41008 41009 41010 41011 41012 41013 41014 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40979 class ModelPackage < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :additional_inference_specifications, :source_uri, :security_config, :model_card, :model_life_cycle, :tags, :customer_metadata_properties, :drift_check_baselines, :skip_model_validation) SENSITIVE = [] include Aws::Structure end |
#approval_description ⇒ String
A description provided when the model approval is set.
40979 40980 40981 40982 40983 40984 40985 40986 40987 40988 40989 40990 40991 40992 40993 40994 40995 40996 40997 40998 40999 41000 41001 41002 41003 41004 41005 41006 41007 41008 41009 41010 41011 41012 41013 41014 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40979 class ModelPackage < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :additional_inference_specifications, :source_uri, :security_config, :model_card, :model_life_cycle, :tags, :customer_metadata_properties, :drift_check_baselines, :skip_model_validation) SENSITIVE = [] include Aws::Structure end |
#certify_for_marketplace ⇒ Boolean
Whether the model package is to be certified to be listed on Amazon Web Services Marketplace. For information about listing model packages on Amazon Web Services Marketplace, see [List Your Algorithm or Model Package on Amazon Web Services Marketplace].
[1]: docs.aws.amazon.com/sagemaker/latest/dg/sagemaker-mkt-list.html
40979 40980 40981 40982 40983 40984 40985 40986 40987 40988 40989 40990 40991 40992 40993 40994 40995 40996 40997 40998 40999 41000 41001 41002 41003 41004 41005 41006 41007 41008 41009 41010 41011 41012 41013 41014 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40979 class ModelPackage < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :additional_inference_specifications, :source_uri, :security_config, :model_card, :model_life_cycle, :tags, :customer_metadata_properties, :drift_check_baselines, :skip_model_validation) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ Types::UserContext
Information about the user who created or modified an experiment, trial, trial component, lineage group, or project.
40979 40980 40981 40982 40983 40984 40985 40986 40987 40988 40989 40990 40991 40992 40993 40994 40995 40996 40997 40998 40999 41000 41001 41002 41003 41004 41005 41006 41007 41008 41009 41010 41011 41012 41013 41014 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40979 class ModelPackage < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :additional_inference_specifications, :source_uri, :security_config, :model_card, :model_life_cycle, :tags, :customer_metadata_properties, :drift_check_baselines, :skip_model_validation) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The time that the model package was created.
40979 40980 40981 40982 40983 40984 40985 40986 40987 40988 40989 40990 40991 40992 40993 40994 40995 40996 40997 40998 40999 41000 41001 41002 41003 41004 41005 41006 41007 41008 41009 41010 41011 41012 41013 41014 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40979 class ModelPackage < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :additional_inference_specifications, :source_uri, :security_config, :model_card, :model_life_cycle, :tags, :customer_metadata_properties, :drift_check_baselines, :skip_model_validation) SENSITIVE = [] include Aws::Structure end |
#customer_metadata_properties ⇒ Hash<String,String>
The metadata properties for the model package.
40979 40980 40981 40982 40983 40984 40985 40986 40987 40988 40989 40990 40991 40992 40993 40994 40995 40996 40997 40998 40999 41000 41001 41002 41003 41004 41005 41006 41007 41008 41009 41010 41011 41012 41013 41014 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40979 class ModelPackage < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :additional_inference_specifications, :source_uri, :security_config, :model_card, :model_life_cycle, :tags, :customer_metadata_properties, :drift_check_baselines, :skip_model_validation) SENSITIVE = [] include Aws::Structure end |
#domain ⇒ String
The machine learning domain of your model package and its components. Common machine learning domains include computer vision and natural language processing.
40979 40980 40981 40982 40983 40984 40985 40986 40987 40988 40989 40990 40991 40992 40993 40994 40995 40996 40997 40998 40999 41000 41001 41002 41003 41004 41005 41006 41007 41008 41009 41010 41011 41012 41013 41014 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40979 class ModelPackage < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :additional_inference_specifications, :source_uri, :security_config, :model_card, :model_life_cycle, :tags, :customer_metadata_properties, :drift_check_baselines, :skip_model_validation) SENSITIVE = [] include Aws::Structure end |
#drift_check_baselines ⇒ Types::DriftCheckBaselines
Represents the drift check baselines that can be used when the model monitor is set using the model package.
40979 40980 40981 40982 40983 40984 40985 40986 40987 40988 40989 40990 40991 40992 40993 40994 40995 40996 40997 40998 40999 41000 41001 41002 41003 41004 41005 41006 41007 41008 41009 41010 41011 41012 41013 41014 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40979 class ModelPackage < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :additional_inference_specifications, :source_uri, :security_config, :model_card, :model_life_cycle, :tags, :customer_metadata_properties, :drift_check_baselines, :skip_model_validation) SENSITIVE = [] include Aws::Structure end |
#inference_specification ⇒ Types::InferenceSpecification
Defines how to perform inference generation after a training job is run.
40979 40980 40981 40982 40983 40984 40985 40986 40987 40988 40989 40990 40991 40992 40993 40994 40995 40996 40997 40998 40999 41000 41001 41002 41003 41004 41005 41006 41007 41008 41009 41010 41011 41012 41013 41014 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40979 class ModelPackage < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :additional_inference_specifications, :source_uri, :security_config, :model_card, :model_life_cycle, :tags, :customer_metadata_properties, :drift_check_baselines, :skip_model_validation) SENSITIVE = [] include Aws::Structure end |
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified an experiment, trial, trial component, lineage group, or project.
40979 40980 40981 40982 40983 40984 40985 40986 40987 40988 40989 40990 40991 40992 40993 40994 40995 40996 40997 40998 40999 41000 41001 41002 41003 41004 41005 41006 41007 41008 41009 41010 41011 41012 41013 41014 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40979 class ModelPackage < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :additional_inference_specifications, :source_uri, :security_config, :model_card, :model_life_cycle, :tags, :customer_metadata_properties, :drift_check_baselines, :skip_model_validation) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The last time the model package was modified.
40979 40980 40981 40982 40983 40984 40985 40986 40987 40988 40989 40990 40991 40992 40993 40994 40995 40996 40997 40998 40999 41000 41001 41002 41003 41004 41005 41006 41007 41008 41009 41010 41011 41012 41013 41014 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40979 class ModelPackage < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :additional_inference_specifications, :source_uri, :security_config, :model_card, :model_life_cycle, :tags, :customer_metadata_properties, :drift_check_baselines, :skip_model_validation) SENSITIVE = [] include Aws::Structure end |
#metadata_properties ⇒ Types::MetadataProperties
Metadata properties of the tracking entity, trial, or trial component.
40979 40980 40981 40982 40983 40984 40985 40986 40987 40988 40989 40990 40991 40992 40993 40994 40995 40996 40997 40998 40999 41000 41001 41002 41003 41004 41005 41006 41007 41008 41009 41010 41011 41012 41013 41014 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40979 class ModelPackage < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :additional_inference_specifications, :source_uri, :security_config, :model_card, :model_life_cycle, :tags, :customer_metadata_properties, :drift_check_baselines, :skip_model_validation) SENSITIVE = [] include Aws::Structure end |
#model_approval_status ⇒ String
The approval status of the model. This can be one of the following values.
-
‘APPROVED` - The model is approved
-
‘REJECTED` - The model is rejected.
-
‘PENDING_MANUAL_APPROVAL` - The model is waiting for manual approval.
40979 40980 40981 40982 40983 40984 40985 40986 40987 40988 40989 40990 40991 40992 40993 40994 40995 40996 40997 40998 40999 41000 41001 41002 41003 41004 41005 41006 41007 41008 41009 41010 41011 41012 41013 41014 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40979 class ModelPackage < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :additional_inference_specifications, :source_uri, :security_config, :model_card, :model_life_cycle, :tags, :customer_metadata_properties, :drift_check_baselines, :skip_model_validation) SENSITIVE = [] include Aws::Structure end |
#model_card ⇒ Types::ModelPackageModelCard
The model card associated with the model package. Since ‘ModelPackageModelCard` is tied to a model package, it is a specific usage of a model card and its schema is simplified compared to the schema of `ModelCard`. The `ModelPackageModelCard` schema does not include `model_package_details`, and `model_overview` is composed of the `model_creator` and `model_artifact` properties. For more information about the model package model card schema, see [Model package model card schema]. For more information about the model card associated with the model package, see [View the Details of a Model Version].
[1]: docs.aws.amazon.com/sagemaker/latest/dg/model-registry-details.html#model-card-schema [2]: docs.aws.amazon.com/sagemaker/latest/dg/model-registry-details.html
40979 40980 40981 40982 40983 40984 40985 40986 40987 40988 40989 40990 40991 40992 40993 40994 40995 40996 40997 40998 40999 41000 41001 41002 41003 41004 41005 41006 41007 41008 41009 41010 41011 41012 41013 41014 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40979 class ModelPackage < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :additional_inference_specifications, :source_uri, :security_config, :model_card, :model_life_cycle, :tags, :customer_metadata_properties, :drift_check_baselines, :skip_model_validation) SENSITIVE = [] include Aws::Structure end |
#model_life_cycle ⇒ Types::ModelLifeCycle
A structure describing the current state of the model in its life cycle.
40979 40980 40981 40982 40983 40984 40985 40986 40987 40988 40989 40990 40991 40992 40993 40994 40995 40996 40997 40998 40999 41000 41001 41002 41003 41004 41005 41006 41007 41008 41009 41010 41011 41012 41013 41014 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40979 class ModelPackage < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :additional_inference_specifications, :source_uri, :security_config, :model_card, :model_life_cycle, :tags, :customer_metadata_properties, :drift_check_baselines, :skip_model_validation) SENSITIVE = [] include Aws::Structure end |
#model_metrics ⇒ Types::ModelMetrics
Metrics for the model.
40979 40980 40981 40982 40983 40984 40985 40986 40987 40988 40989 40990 40991 40992 40993 40994 40995 40996 40997 40998 40999 41000 41001 41002 41003 41004 41005 41006 41007 41008 41009 41010 41011 41012 41013 41014 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40979 class ModelPackage < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :additional_inference_specifications, :source_uri, :security_config, :model_card, :model_life_cycle, :tags, :customer_metadata_properties, :drift_check_baselines, :skip_model_validation) SENSITIVE = [] include Aws::Structure end |
#model_package_arn ⇒ String
The Amazon Resource Name (ARN) of the model package.
40979 40980 40981 40982 40983 40984 40985 40986 40987 40988 40989 40990 40991 40992 40993 40994 40995 40996 40997 40998 40999 41000 41001 41002 41003 41004 41005 41006 41007 41008 41009 41010 41011 41012 41013 41014 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40979 class ModelPackage < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :additional_inference_specifications, :source_uri, :security_config, :model_card, :model_life_cycle, :tags, :customer_metadata_properties, :drift_check_baselines, :skip_model_validation) SENSITIVE = [] include Aws::Structure end |
#model_package_description ⇒ String
The description of the model package.
40979 40980 40981 40982 40983 40984 40985 40986 40987 40988 40989 40990 40991 40992 40993 40994 40995 40996 40997 40998 40999 41000 41001 41002 41003 41004 41005 41006 41007 41008 41009 41010 41011 41012 41013 41014 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40979 class ModelPackage < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :additional_inference_specifications, :source_uri, :security_config, :model_card, :model_life_cycle, :tags, :customer_metadata_properties, :drift_check_baselines, :skip_model_validation) SENSITIVE = [] include Aws::Structure end |
#model_package_group_name ⇒ String
The model group to which the model belongs.
40979 40980 40981 40982 40983 40984 40985 40986 40987 40988 40989 40990 40991 40992 40993 40994 40995 40996 40997 40998 40999 41000 41001 41002 41003 41004 41005 41006 41007 41008 41009 41010 41011 41012 41013 41014 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40979 class ModelPackage < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :additional_inference_specifications, :source_uri, :security_config, :model_card, :model_life_cycle, :tags, :customer_metadata_properties, :drift_check_baselines, :skip_model_validation) SENSITIVE = [] include Aws::Structure end |
#model_package_name ⇒ String
The name of the model package. The name can be as follows:
-
For a versioned model, the name is automatically generated by SageMaker Model Registry and follows the format ‘`ModelPackageGroupName/ModelPackageVersion`’.
-
For an unversioned model, you must provide the name.
40979 40980 40981 40982 40983 40984 40985 40986 40987 40988 40989 40990 40991 40992 40993 40994 40995 40996 40997 40998 40999 41000 41001 41002 41003 41004 41005 41006 41007 41008 41009 41010 41011 41012 41013 41014 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40979 class ModelPackage < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :additional_inference_specifications, :source_uri, :security_config, :model_card, :model_life_cycle, :tags, :customer_metadata_properties, :drift_check_baselines, :skip_model_validation) SENSITIVE = [] include Aws::Structure end |
#model_package_registration_type ⇒ String
The package registration type of the model package.
40979 40980 40981 40982 40983 40984 40985 40986 40987 40988 40989 40990 40991 40992 40993 40994 40995 40996 40997 40998 40999 41000 41001 41002 41003 41004 41005 41006 41007 41008 41009 41010 41011 41012 41013 41014 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40979 class ModelPackage < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :additional_inference_specifications, :source_uri, :security_config, :model_card, :model_life_cycle, :tags, :customer_metadata_properties, :drift_check_baselines, :skip_model_validation) SENSITIVE = [] include Aws::Structure end |
#model_package_status ⇒ String
The status of the model package. This can be one of the following values.
-
‘PENDING` - The model package is pending being created.
-
‘IN_PROGRESS` - The model package is in the process of being created.
-
‘COMPLETED` - The model package was successfully created.
-
‘FAILED` - The model package failed.
-
‘DELETING` - The model package is in the process of being deleted.
40979 40980 40981 40982 40983 40984 40985 40986 40987 40988 40989 40990 40991 40992 40993 40994 40995 40996 40997 40998 40999 41000 41001 41002 41003 41004 41005 41006 41007 41008 41009 41010 41011 41012 41013 41014 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40979 class ModelPackage < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :additional_inference_specifications, :source_uri, :security_config, :model_card, :model_life_cycle, :tags, :customer_metadata_properties, :drift_check_baselines, :skip_model_validation) SENSITIVE = [] include Aws::Structure end |
#model_package_status_details ⇒ Types::ModelPackageStatusDetails
Specifies the validation and image scan statuses of the model package.
40979 40980 40981 40982 40983 40984 40985 40986 40987 40988 40989 40990 40991 40992 40993 40994 40995 40996 40997 40998 40999 41000 41001 41002 41003 41004 41005 41006 41007 41008 41009 41010 41011 41012 41013 41014 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40979 class ModelPackage < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :additional_inference_specifications, :source_uri, :security_config, :model_card, :model_life_cycle, :tags, :customer_metadata_properties, :drift_check_baselines, :skip_model_validation) SENSITIVE = [] include Aws::Structure end |
#model_package_version ⇒ Integer
The version number of a versioned model.
40979 40980 40981 40982 40983 40984 40985 40986 40987 40988 40989 40990 40991 40992 40993 40994 40995 40996 40997 40998 40999 41000 41001 41002 41003 41004 41005 41006 41007 41008 41009 41010 41011 41012 41013 41014 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40979 class ModelPackage < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :additional_inference_specifications, :source_uri, :security_config, :model_card, :model_life_cycle, :tags, :customer_metadata_properties, :drift_check_baselines, :skip_model_validation) SENSITIVE = [] include Aws::Structure end |
#sample_payload_url ⇒ String
The Amazon Simple Storage Service path where the sample payload are stored. This path must point to a single gzip compressed tar archive (.tar.gz suffix).
40979 40980 40981 40982 40983 40984 40985 40986 40987 40988 40989 40990 40991 40992 40993 40994 40995 40996 40997 40998 40999 41000 41001 41002 41003 41004 41005 41006 41007 41008 41009 41010 41011 41012 41013 41014 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40979 class ModelPackage < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :additional_inference_specifications, :source_uri, :security_config, :model_card, :model_life_cycle, :tags, :customer_metadata_properties, :drift_check_baselines, :skip_model_validation) SENSITIVE = [] include Aws::Structure end |
#security_config ⇒ Types::ModelPackageSecurityConfig
An optional Key Management Service key to encrypt, decrypt, and re-encrypt model package information for regulated workloads with highly sensitive data.
40979 40980 40981 40982 40983 40984 40985 40986 40987 40988 40989 40990 40991 40992 40993 40994 40995 40996 40997 40998 40999 41000 41001 41002 41003 41004 41005 41006 41007 41008 41009 41010 41011 41012 41013 41014 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40979 class ModelPackage < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :additional_inference_specifications, :source_uri, :security_config, :model_card, :model_life_cycle, :tags, :customer_metadata_properties, :drift_check_baselines, :skip_model_validation) SENSITIVE = [] include Aws::Structure end |
#skip_model_validation ⇒ String
Indicates if you want to skip model validation.
40979 40980 40981 40982 40983 40984 40985 40986 40987 40988 40989 40990 40991 40992 40993 40994 40995 40996 40997 40998 40999 41000 41001 41002 41003 41004 41005 41006 41007 41008 41009 41010 41011 41012 41013 41014 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40979 class ModelPackage < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :additional_inference_specifications, :source_uri, :security_config, :model_card, :model_life_cycle, :tags, :customer_metadata_properties, :drift_check_baselines, :skip_model_validation) SENSITIVE = [] include Aws::Structure end |
#source_algorithm_specification ⇒ Types::SourceAlgorithmSpecification
A list of algorithms that were used to create a model package.
40979 40980 40981 40982 40983 40984 40985 40986 40987 40988 40989 40990 40991 40992 40993 40994 40995 40996 40997 40998 40999 41000 41001 41002 41003 41004 41005 41006 41007 41008 41009 41010 41011 41012 41013 41014 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40979 class ModelPackage < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :additional_inference_specifications, :source_uri, :security_config, :model_card, :model_life_cycle, :tags, :customer_metadata_properties, :drift_check_baselines, :skip_model_validation) SENSITIVE = [] include Aws::Structure end |
#source_uri ⇒ String
The URI of the source for the model package.
40979 40980 40981 40982 40983 40984 40985 40986 40987 40988 40989 40990 40991 40992 40993 40994 40995 40996 40997 40998 40999 41000 41001 41002 41003 41004 41005 41006 41007 41008 41009 41010 41011 41012 41013 41014 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40979 class ModelPackage < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :additional_inference_specifications, :source_uri, :security_config, :model_card, :model_life_cycle, :tags, :customer_metadata_properties, :drift_check_baselines, :skip_model_validation) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of the tags associated with the model package. For more information, see [Tagging Amazon Web Services resources] in the *Amazon Web Services General Reference Guide*.
40979 40980 40981 40982 40983 40984 40985 40986 40987 40988 40989 40990 40991 40992 40993 40994 40995 40996 40997 40998 40999 41000 41001 41002 41003 41004 41005 41006 41007 41008 41009 41010 41011 41012 41013 41014 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40979 class ModelPackage < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :additional_inference_specifications, :source_uri, :security_config, :model_card, :model_life_cycle, :tags, :customer_metadata_properties, :drift_check_baselines, :skip_model_validation) SENSITIVE = [] include Aws::Structure end |
#task ⇒ String
The machine learning task your model package accomplishes. Common machine learning tasks include object detection and image classification.
40979 40980 40981 40982 40983 40984 40985 40986 40987 40988 40989 40990 40991 40992 40993 40994 40995 40996 40997 40998 40999 41000 41001 41002 41003 41004 41005 41006 41007 41008 41009 41010 41011 41012 41013 41014 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40979 class ModelPackage < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :additional_inference_specifications, :source_uri, :security_config, :model_card, :model_life_cycle, :tags, :customer_metadata_properties, :drift_check_baselines, :skip_model_validation) SENSITIVE = [] include Aws::Structure end |
#validation_specification ⇒ Types::ModelPackageValidationSpecification
Specifies batch transform jobs that SageMaker runs to validate your model package.
40979 40980 40981 40982 40983 40984 40985 40986 40987 40988 40989 40990 40991 40992 40993 40994 40995 40996 40997 40998 40999 41000 41001 41002 41003 41004 41005 41006 41007 41008 41009 41010 41011 41012 41013 41014 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40979 class ModelPackage < Struct.new( :model_package_name, :model_package_group_name, :model_package_version, :model_package_registration_type, :model_package_arn, :model_package_description, :creation_time, :inference_specification, :source_algorithm_specification, :validation_specification, :model_package_status, :model_package_status_details, :certify_for_marketplace, :model_approval_status, :created_by, :metadata_properties, :model_metrics, :last_modified_time, :last_modified_by, :approval_description, :domain, :task, :sample_payload_url, :additional_inference_specifications, :source_uri, :security_config, :model_card, :model_life_cycle, :tags, :customer_metadata_properties, :drift_check_baselines, :skip_model_validation) SENSITIVE = [] include Aws::Structure end |