Class: Aws::SageMaker::Types::ModelPackageContainerDefinition
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ModelPackageContainerDefinition
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Describes the Docker container for the model package.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_model_data_sources ⇒ Array<Types::AdditionalModelDataSource>
Data sources that are available to your model in addition to the one that you specify for ‘ModelDataSource` when you use the `CreateModelPackage` action.
-
#additional_s3_data_source ⇒ Types::AdditionalS3DataSource
The additional data source that is used during inference in the Docker container for your model package.
-
#base_model ⇒ Types::BaseModel
Identifies the foundation model that was used as the starting point for model customization.
-
#container_hostname ⇒ String
The DNS host name for the Docker container.
-
#environment ⇒ Hash<String,String>
The environment variables to set in the Docker container.
-
#framework ⇒ String
The machine learning framework of the model package container image.
-
#framework_version ⇒ String
The framework version of the Model Package Container Image.
-
#image ⇒ String
The Amazon Elastic Container Registry (Amazon ECR) path where inference code is stored.
-
#image_digest ⇒ String
An MD5 hash of the training algorithm that identifies the Docker image used for training.
-
#is_checkpoint ⇒ Boolean
Specifies whether the model data is a training checkpoint.
-
#model_data_etag ⇒ String
The ETag associated with Model Data URL.
-
#model_data_source ⇒ Types::ModelDataSource
Specifies the location of ML model data to deploy during endpoint creation.
-
#model_data_url ⇒ String
The Amazon S3 path where the model artifacts, which result from model training, are stored.
-
#model_input ⇒ Types::ModelInput
A structure with Model Input details.
-
#nearest_model_name ⇒ String
The name of a pre-trained machine learning benchmarked by Amazon SageMaker Inference Recommender model that matches your model.
-
#product_id ⇒ String
The Amazon Web Services Marketplace product ID of the model package.
Instance Attribute Details
#additional_model_data_sources ⇒ Array<Types::AdditionalModelDataSource>
Data sources that are available to your model in addition to the one that you specify for ‘ModelDataSource` when you use the `CreateModelPackage` action.
41944 41945 41946 41947 41948 41949 41950 41951 41952 41953 41954 41955 41956 41957 41958 41959 41960 41961 41962 41963 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 41944 class ModelPackageContainerDefinition < Struct.new( :container_hostname, :image, :image_digest, :model_data_url, :model_data_source, :product_id, :environment, :model_input, :framework, :framework_version, :nearest_model_name, :additional_model_data_sources, :additional_s3_data_source, :model_data_etag, :is_checkpoint, :base_model) SENSITIVE = [] include Aws::Structure end |
#additional_s3_data_source ⇒ Types::AdditionalS3DataSource
The additional data source that is used during inference in the Docker container for your model package.
41944 41945 41946 41947 41948 41949 41950 41951 41952 41953 41954 41955 41956 41957 41958 41959 41960 41961 41962 41963 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 41944 class ModelPackageContainerDefinition < Struct.new( :container_hostname, :image, :image_digest, :model_data_url, :model_data_source, :product_id, :environment, :model_input, :framework, :framework_version, :nearest_model_name, :additional_model_data_sources, :additional_s3_data_source, :model_data_etag, :is_checkpoint, :base_model) SENSITIVE = [] include Aws::Structure end |
#base_model ⇒ Types::BaseModel
Identifies the foundation model that was used as the starting point for model customization.
41944 41945 41946 41947 41948 41949 41950 41951 41952 41953 41954 41955 41956 41957 41958 41959 41960 41961 41962 41963 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 41944 class ModelPackageContainerDefinition < Struct.new( :container_hostname, :image, :image_digest, :model_data_url, :model_data_source, :product_id, :environment, :model_input, :framework, :framework_version, :nearest_model_name, :additional_model_data_sources, :additional_s3_data_source, :model_data_etag, :is_checkpoint, :base_model) SENSITIVE = [] include Aws::Structure end |
#container_hostname ⇒ String
The DNS host name for the Docker container.
41944 41945 41946 41947 41948 41949 41950 41951 41952 41953 41954 41955 41956 41957 41958 41959 41960 41961 41962 41963 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 41944 class ModelPackageContainerDefinition < Struct.new( :container_hostname, :image, :image_digest, :model_data_url, :model_data_source, :product_id, :environment, :model_input, :framework, :framework_version, :nearest_model_name, :additional_model_data_sources, :additional_s3_data_source, :model_data_etag, :is_checkpoint, :base_model) SENSITIVE = [] include Aws::Structure end |
#environment ⇒ Hash<String,String>
The environment variables to set in the Docker container. Each key and value in the ‘Environment` string to string map can have length of up to 1024. We support up to 16 entries in the map.
41944 41945 41946 41947 41948 41949 41950 41951 41952 41953 41954 41955 41956 41957 41958 41959 41960 41961 41962 41963 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 41944 class ModelPackageContainerDefinition < Struct.new( :container_hostname, :image, :image_digest, :model_data_url, :model_data_source, :product_id, :environment, :model_input, :framework, :framework_version, :nearest_model_name, :additional_model_data_sources, :additional_s3_data_source, :model_data_etag, :is_checkpoint, :base_model) SENSITIVE = [] include Aws::Structure end |
#framework ⇒ String
The machine learning framework of the model package container image.
41944 41945 41946 41947 41948 41949 41950 41951 41952 41953 41954 41955 41956 41957 41958 41959 41960 41961 41962 41963 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 41944 class ModelPackageContainerDefinition < Struct.new( :container_hostname, :image, :image_digest, :model_data_url, :model_data_source, :product_id, :environment, :model_input, :framework, :framework_version, :nearest_model_name, :additional_model_data_sources, :additional_s3_data_source, :model_data_etag, :is_checkpoint, :base_model) SENSITIVE = [] include Aws::Structure end |
#framework_version ⇒ String
The framework version of the Model Package Container Image.
41944 41945 41946 41947 41948 41949 41950 41951 41952 41953 41954 41955 41956 41957 41958 41959 41960 41961 41962 41963 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 41944 class ModelPackageContainerDefinition < Struct.new( :container_hostname, :image, :image_digest, :model_data_url, :model_data_source, :product_id, :environment, :model_input, :framework, :framework_version, :nearest_model_name, :additional_model_data_sources, :additional_s3_data_source, :model_data_etag, :is_checkpoint, :base_model) SENSITIVE = [] include Aws::Structure end |
#image ⇒ String
The Amazon Elastic Container Registry (Amazon ECR) path where inference code is stored.
If you are using your own custom algorithm instead of an algorithm provided by SageMaker, the inference code must meet SageMaker requirements. SageMaker supports both ‘registry/repository` and `registry/repository` image path formats. For more information, see [Using Your Own Algorithms with Amazon SageMaker].
[1]: docs.aws.amazon.com/sagemaker/latest/dg/your-algorithms.html
41944 41945 41946 41947 41948 41949 41950 41951 41952 41953 41954 41955 41956 41957 41958 41959 41960 41961 41962 41963 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 41944 class ModelPackageContainerDefinition < Struct.new( :container_hostname, :image, :image_digest, :model_data_url, :model_data_source, :product_id, :environment, :model_input, :framework, :framework_version, :nearest_model_name, :additional_model_data_sources, :additional_s3_data_source, :model_data_etag, :is_checkpoint, :base_model) SENSITIVE = [] include Aws::Structure end |
#image_digest ⇒ String
An MD5 hash of the training algorithm that identifies the Docker image used for training.
41944 41945 41946 41947 41948 41949 41950 41951 41952 41953 41954 41955 41956 41957 41958 41959 41960 41961 41962 41963 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 41944 class ModelPackageContainerDefinition < Struct.new( :container_hostname, :image, :image_digest, :model_data_url, :model_data_source, :product_id, :environment, :model_input, :framework, :framework_version, :nearest_model_name, :additional_model_data_sources, :additional_s3_data_source, :model_data_etag, :is_checkpoint, :base_model) SENSITIVE = [] include Aws::Structure end |
#is_checkpoint ⇒ Boolean
Specifies whether the model data is a training checkpoint.
41944 41945 41946 41947 41948 41949 41950 41951 41952 41953 41954 41955 41956 41957 41958 41959 41960 41961 41962 41963 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 41944 class ModelPackageContainerDefinition < Struct.new( :container_hostname, :image, :image_digest, :model_data_url, :model_data_source, :product_id, :environment, :model_input, :framework, :framework_version, :nearest_model_name, :additional_model_data_sources, :additional_s3_data_source, :model_data_etag, :is_checkpoint, :base_model) SENSITIVE = [] include Aws::Structure end |
#model_data_etag ⇒ String
The ETag associated with Model Data URL.
41944 41945 41946 41947 41948 41949 41950 41951 41952 41953 41954 41955 41956 41957 41958 41959 41960 41961 41962 41963 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 41944 class ModelPackageContainerDefinition < Struct.new( :container_hostname, :image, :image_digest, :model_data_url, :model_data_source, :product_id, :environment, :model_input, :framework, :framework_version, :nearest_model_name, :additional_model_data_sources, :additional_s3_data_source, :model_data_etag, :is_checkpoint, :base_model) SENSITIVE = [] include Aws::Structure end |
#model_data_source ⇒ Types::ModelDataSource
Specifies the location of ML model data to deploy during endpoint creation.
41944 41945 41946 41947 41948 41949 41950 41951 41952 41953 41954 41955 41956 41957 41958 41959 41960 41961 41962 41963 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 41944 class ModelPackageContainerDefinition < Struct.new( :container_hostname, :image, :image_digest, :model_data_url, :model_data_source, :product_id, :environment, :model_input, :framework, :framework_version, :nearest_model_name, :additional_model_data_sources, :additional_s3_data_source, :model_data_etag, :is_checkpoint, :base_model) SENSITIVE = [] include Aws::Structure end |
#model_data_url ⇒ String
The Amazon S3 path where the model artifacts, which result from model training, are stored. This path must point to a single ‘gzip` compressed tar archive (`.tar.gz` suffix).
<note markdown=“1”> The model artifacts must be in an S3 bucket that is in the same region as the model package.
</note>
41944 41945 41946 41947 41948 41949 41950 41951 41952 41953 41954 41955 41956 41957 41958 41959 41960 41961 41962 41963 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 41944 class ModelPackageContainerDefinition < Struct.new( :container_hostname, :image, :image_digest, :model_data_url, :model_data_source, :product_id, :environment, :model_input, :framework, :framework_version, :nearest_model_name, :additional_model_data_sources, :additional_s3_data_source, :model_data_etag, :is_checkpoint, :base_model) SENSITIVE = [] include Aws::Structure end |
#model_input ⇒ Types::ModelInput
A structure with Model Input details.
41944 41945 41946 41947 41948 41949 41950 41951 41952 41953 41954 41955 41956 41957 41958 41959 41960 41961 41962 41963 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 41944 class ModelPackageContainerDefinition < Struct.new( :container_hostname, :image, :image_digest, :model_data_url, :model_data_source, :product_id, :environment, :model_input, :framework, :framework_version, :nearest_model_name, :additional_model_data_sources, :additional_s3_data_source, :model_data_etag, :is_checkpoint, :base_model) SENSITIVE = [] include Aws::Structure end |
#nearest_model_name ⇒ String
The name of a pre-trained machine learning benchmarked by Amazon SageMaker Inference Recommender model that matches your model. You can find a list of benchmarked models by calling ‘ListModelMetadata`.
41944 41945 41946 41947 41948 41949 41950 41951 41952 41953 41954 41955 41956 41957 41958 41959 41960 41961 41962 41963 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 41944 class ModelPackageContainerDefinition < Struct.new( :container_hostname, :image, :image_digest, :model_data_url, :model_data_source, :product_id, :environment, :model_input, :framework, :framework_version, :nearest_model_name, :additional_model_data_sources, :additional_s3_data_source, :model_data_etag, :is_checkpoint, :base_model) SENSITIVE = [] include Aws::Structure end |
#product_id ⇒ String
The Amazon Web Services Marketplace product ID of the model package.
41944 41945 41946 41947 41948 41949 41950 41951 41952 41953 41954 41955 41956 41957 41958 41959 41960 41961 41962 41963 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 41944 class ModelPackageContainerDefinition < Struct.new( :container_hostname, :image, :image_digest, :model_data_url, :model_data_source, :product_id, :environment, :model_input, :framework, :framework_version, :nearest_model_name, :additional_model_data_sources, :additional_s3_data_source, :model_data_etag, :is_checkpoint, :base_model) SENSITIVE = [] include Aws::Structure end |