Class: Aws::SageMaker::Types::ModelPackageContainerDefinition
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ModelPackageContainerDefinition
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Describes the Docker container for the model package.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#container_hostname ⇒ String
The DNS host name for the Docker container.
-
#environment ⇒ Hash<String,String>
The environment variables to set in the Docker container.
-
#framework ⇒ String
The machine learning framework of the model package container image.
-
#framework_version ⇒ String
The framework version of the Model Package Container Image.
-
#image ⇒ String
The Amazon EC2 Container Registry (Amazon ECR) path where inference code is stored.
-
#image_digest ⇒ String
An MD5 hash of the training algorithm that identifies the Docker image used for training.
-
#model_data_url ⇒ String
The Amazon S3 path where the model artifacts, which result from model training, are stored.
-
#model_input ⇒ Types::ModelInput
A structure with Model Input details.
-
#nearest_model_name ⇒ String
The name of a pre-trained machine learning benchmarked by Amazon SageMaker Inference Recommender model that matches your model.
-
#product_id ⇒ String
The Amazon Web Services Marketplace product ID of the model package.
Instance Attribute Details
#container_hostname ⇒ String
The DNS host name for the Docker container.
27934 27935 27936 27937 27938 27939 27940 27941 27942 27943 27944 27945 27946 27947 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27934 class ModelPackageContainerDefinition < Struct.new( :container_hostname, :image, :image_digest, :model_data_url, :product_id, :environment, :model_input, :framework, :framework_version, :nearest_model_name) SENSITIVE = [] include Aws::Structure end |
#environment ⇒ Hash<String,String>
The environment variables to set in the Docker container. Each key and value in the Environment string to string map can have length of up to 1024. We support up to 16 entries in the map.
27934 27935 27936 27937 27938 27939 27940 27941 27942 27943 27944 27945 27946 27947 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27934 class ModelPackageContainerDefinition < Struct.new( :container_hostname, :image, :image_digest, :model_data_url, :product_id, :environment, :model_input, :framework, :framework_version, :nearest_model_name) SENSITIVE = [] include Aws::Structure end |
#framework ⇒ String
The machine learning framework of the model package container image.
27934 27935 27936 27937 27938 27939 27940 27941 27942 27943 27944 27945 27946 27947 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27934 class ModelPackageContainerDefinition < Struct.new( :container_hostname, :image, :image_digest, :model_data_url, :product_id, :environment, :model_input, :framework, :framework_version, :nearest_model_name) SENSITIVE = [] include Aws::Structure end |
#framework_version ⇒ String
The framework version of the Model Package Container Image.
27934 27935 27936 27937 27938 27939 27940 27941 27942 27943 27944 27945 27946 27947 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27934 class ModelPackageContainerDefinition < Struct.new( :container_hostname, :image, :image_digest, :model_data_url, :product_id, :environment, :model_input, :framework, :framework_version, :nearest_model_name) SENSITIVE = [] include Aws::Structure end |
#image ⇒ String
The Amazon EC2 Container Registry (Amazon ECR) path where inference code is stored.
If you are using your own custom algorithm instead of an algorithm provided by SageMaker, the inference code must meet SageMaker requirements. SageMaker supports both registry/repository[:tag] and ‘registry/repository` image path formats. For more information, see [Using Your Own Algorithms with Amazon SageMaker].
[1]: docs.aws.amazon.com/sagemaker/latest/dg/your-algorithms.html
27934 27935 27936 27937 27938 27939 27940 27941 27942 27943 27944 27945 27946 27947 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27934 class ModelPackageContainerDefinition < Struct.new( :container_hostname, :image, :image_digest, :model_data_url, :product_id, :environment, :model_input, :framework, :framework_version, :nearest_model_name) SENSITIVE = [] include Aws::Structure end |
#image_digest ⇒ String
An MD5 hash of the training algorithm that identifies the Docker image used for training.
27934 27935 27936 27937 27938 27939 27940 27941 27942 27943 27944 27945 27946 27947 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27934 class ModelPackageContainerDefinition < Struct.new( :container_hostname, :image, :image_digest, :model_data_url, :product_id, :environment, :model_input, :framework, :framework_version, :nearest_model_name) SENSITIVE = [] include Aws::Structure end |
#model_data_url ⇒ String
The Amazon S3 path where the model artifacts, which result from model training, are stored. This path must point to a single gzip compressed tar archive (.tar.gz suffix).
<note markdown=“1”> The model artifacts must be in an S3 bucket that is in the same region as the model package.
</note>
27934 27935 27936 27937 27938 27939 27940 27941 27942 27943 27944 27945 27946 27947 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27934 class ModelPackageContainerDefinition < Struct.new( :container_hostname, :image, :image_digest, :model_data_url, :product_id, :environment, :model_input, :framework, :framework_version, :nearest_model_name) SENSITIVE = [] include Aws::Structure end |
#model_input ⇒ Types::ModelInput
A structure with Model Input details.
27934 27935 27936 27937 27938 27939 27940 27941 27942 27943 27944 27945 27946 27947 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27934 class ModelPackageContainerDefinition < Struct.new( :container_hostname, :image, :image_digest, :model_data_url, :product_id, :environment, :model_input, :framework, :framework_version, :nearest_model_name) SENSITIVE = [] include Aws::Structure end |
#nearest_model_name ⇒ String
The name of a pre-trained machine learning benchmarked by Amazon SageMaker Inference Recommender model that matches your model. You can find a list of benchmarked models by calling ListModelMetadata.
27934 27935 27936 27937 27938 27939 27940 27941 27942 27943 27944 27945 27946 27947 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27934 class ModelPackageContainerDefinition < Struct.new( :container_hostname, :image, :image_digest, :model_data_url, :product_id, :environment, :model_input, :framework, :framework_version, :nearest_model_name) SENSITIVE = [] include Aws::Structure end |
#product_id ⇒ String
The Amazon Web Services Marketplace product ID of the model package.
27934 27935 27936 27937 27938 27939 27940 27941 27942 27943 27944 27945 27946 27947 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 27934 class ModelPackageContainerDefinition < Struct.new( :container_hostname, :image, :image_digest, :model_data_url, :product_id, :environment, :model_input, :framework, :framework_version, :nearest_model_name) SENSITIVE = [] include Aws::Structure end |