Class: Aws::SageMaker::Types::ModelPackageGroup
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ModelPackageGroup
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
A group of versioned models in the Model Registry.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
-
#creation_time ⇒ Time
The time that the model group was created.
-
#model_package_group_arn ⇒ String
The Amazon Resource Name (ARN) of the model group.
-
#model_package_group_description ⇒ String
The description for the model group.
-
#model_package_group_name ⇒ String
The name of the model group.
-
#model_package_group_status ⇒ String
The status of the model group.
-
#tags ⇒ Array<Types::Tag>
A list of the tags associated with the model group.
Instance Attribute Details
#created_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
42436 42437 42438 42439 42440 42441 42442 42443 42444 42445 42446 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42436 class ModelPackageGroup < Struct.new( :model_package_group_name, :model_package_group_arn, :model_package_group_description, :creation_time, :created_by, :model_package_group_status, :tags) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The time that the model group was created.
42436 42437 42438 42439 42440 42441 42442 42443 42444 42445 42446 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42436 class ModelPackageGroup < Struct.new( :model_package_group_name, :model_package_group_arn, :model_package_group_description, :creation_time, :created_by, :model_package_group_status, :tags) SENSITIVE = [] include Aws::Structure end |
#model_package_group_arn ⇒ String
The Amazon Resource Name (ARN) of the model group.
42436 42437 42438 42439 42440 42441 42442 42443 42444 42445 42446 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42436 class ModelPackageGroup < Struct.new( :model_package_group_name, :model_package_group_arn, :model_package_group_description, :creation_time, :created_by, :model_package_group_status, :tags) SENSITIVE = [] include Aws::Structure end |
#model_package_group_description ⇒ String
The description for the model group.
42436 42437 42438 42439 42440 42441 42442 42443 42444 42445 42446 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42436 class ModelPackageGroup < Struct.new( :model_package_group_name, :model_package_group_arn, :model_package_group_description, :creation_time, :created_by, :model_package_group_status, :tags) SENSITIVE = [] include Aws::Structure end |
#model_package_group_name ⇒ String
The name of the model group.
42436 42437 42438 42439 42440 42441 42442 42443 42444 42445 42446 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42436 class ModelPackageGroup < Struct.new( :model_package_group_name, :model_package_group_arn, :model_package_group_description, :creation_time, :created_by, :model_package_group_status, :tags) SENSITIVE = [] include Aws::Structure end |
#model_package_group_status ⇒ String
The status of the model group. This can be one of the following values.
-
PENDING- The model group is pending being created. -
IN_PROGRESS- The model group is in the process of being created. -
COMPLETED- The model group was successfully created. -
FAILED- The model group failed. -
DELETING- The model group is in the process of being deleted. -
DELETE_FAILED- SageMaker failed to delete the model group.
42436 42437 42438 42439 42440 42441 42442 42443 42444 42445 42446 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42436 class ModelPackageGroup < Struct.new( :model_package_group_name, :model_package_group_arn, :model_package_group_description, :creation_time, :created_by, :model_package_group_status, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of the tags associated with the model group. For more information, see Tagging Amazon Web Services resources in the Amazon Web Services General Reference Guide.
42436 42437 42438 42439 42440 42441 42442 42443 42444 42445 42446 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42436 class ModelPackageGroup < Struct.new( :model_package_group_name, :model_package_group_arn, :model_package_group_description, :creation_time, :created_by, :model_package_group_status, :tags) SENSITIVE = [] include Aws::Structure end |