Class: Aws::SageMaker::Types::ModelPackageValidationProfile
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ModelPackageValidationProfile
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Contains data, such as the inputs and targeted instance types that are used in the process of validating the model package.
The data provided in the validation profile is made available to your buyers on Amazon Web Services Marketplace.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#profile_name ⇒ String
The name of the profile for the model package.
-
#transform_job_definition ⇒ Types::TransformJobDefinition
The ‘TransformJobDefinition` object that describes the transform job used for the validation of the model package.
Instance Attribute Details
#profile_name ⇒ String
The name of the profile for the model package.
42148 42149 42150 42151 42152 42153 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42148 class ModelPackageValidationProfile < Struct.new( :profile_name, :transform_job_definition) SENSITIVE = [] include Aws::Structure end |
#transform_job_definition ⇒ Types::TransformJobDefinition
The ‘TransformJobDefinition` object that describes the transform job used for the validation of the model package.
42148 42149 42150 42151 42152 42153 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42148 class ModelPackageValidationProfile < Struct.new( :profile_name, :transform_job_definition) SENSITIVE = [] include Aws::Structure end |