Class: Aws::SageMaker::Types::ModelQualityBaselineConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ModelQualityBaselineConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Configuration for monitoring constraints and monitoring statistics. These baseline resources are compared against the results of the current job from the series of jobs scheduled to collect data periodically.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#baselining_job_name ⇒ String
The name of the job that performs baselining for the monitoring job.
-
#constraints_resource ⇒ Types::MonitoringConstraintsResource
The constraints resource for a monitoring job.
Instance Attribute Details
#baselining_job_name ⇒ String
The name of the job that performs baselining for the monitoring job.
42532 42533 42534 42535 42536 42537 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42532 class ModelQualityBaselineConfig < Struct.new( :baselining_job_name, :constraints_resource) SENSITIVE = [] include Aws::Structure end |
#constraints_resource ⇒ Types::MonitoringConstraintsResource
The constraints resource for a monitoring job.
42532 42533 42534 42535 42536 42537 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42532 class ModelQualityBaselineConfig < Struct.new( :baselining_job_name, :constraints_resource) SENSITIVE = [] include Aws::Structure end |