Class: Aws::SageMaker::Types::ModelQualityBaselineConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Configuration for monitoring constraints and monitoring statistics. These baseline resources are compared against the results of the current job from the series of jobs scheduled to collect data periodically.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#baselining_job_nameString

The name of the job that performs baselining for the monitoring job.

Returns:

  • (String)


42264
42265
42266
42267
42268
42269
# File 'lib/aws-sdk-sagemaker/types.rb', line 42264

class ModelQualityBaselineConfig < Struct.new(
  :baselining_job_name,
  :constraints_resource)
  SENSITIVE = []
  include Aws::Structure
end

#constraints_resourceTypes::MonitoringConstraintsResource

The constraints resource for a monitoring job.



42264
42265
42266
42267
42268
42269
# File 'lib/aws-sdk-sagemaker/types.rb', line 42264

class ModelQualityBaselineConfig < Struct.new(
  :baselining_job_name,
  :constraints_resource)
  SENSITIVE = []
  include Aws::Structure
end