Class: Aws::SageMaker::Types::ModelQualityBaselineConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Configuration for monitoring constraints and monitoring statistics. These baseline resources are compared against the results of the current job from the series of jobs scheduled to collect data periodically.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#baselining_job_nameString

The name of the job that performs baselining for the monitoring job.

Returns:

  • (String)


41244
41245
41246
41247
41248
41249
# File 'lib/aws-sdk-sagemaker/types.rb', line 41244

class ModelQualityBaselineConfig < Struct.new(
  :baselining_job_name,
  :constraints_resource)
  SENSITIVE = []
  include Aws::Structure
end

#constraints_resourceTypes::MonitoringConstraintsResource

The constraints resource for a monitoring job.



41244
41245
41246
41247
41248
41249
# File 'lib/aws-sdk-sagemaker/types.rb', line 41244

class ModelQualityBaselineConfig < Struct.new(
  :baselining_job_name,
  :constraints_resource)
  SENSITIVE = []
  include Aws::Structure
end