Class: Aws::SageMaker::Types::ModelSpeculativeDecodingConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Settings for the model speculative decoding technique that’s applied by a model optimization job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#techniqueString

The speculative decoding technique to apply during model optimization.

Returns:

  • (String)


39946
39947
39948
39949
39950
39951
# File 'lib/aws-sdk-sagemaker/types.rb', line 39946

class ModelSpeculativeDecodingConfig < Struct.new(
  :technique,
  :training_data_source)
  SENSITIVE = []
  include Aws::Structure
end

#training_data_sourceTypes::ModelSpeculativeDecodingTrainingDataSource

The location of the training data to use for speculative decoding. The data must be formatted as ShareGPT, OpenAI Completions or OpenAI Chat Completions. The input can also be unencrypted captured data from a SageMaker endpoint as long as the endpoint uses one of the above formats.



39946
39947
39948
39949
39950
39951
# File 'lib/aws-sdk-sagemaker/types.rb', line 39946

class ModelSpeculativeDecodingConfig < Struct.new(
  :technique,
  :training_data_source)
  SENSITIVE = []
  include Aws::Structure
end