Class: Aws::SageMaker::Types::MonitoringAlertHistorySummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::MonitoringAlertHistorySummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Provides summary information of an alert’s history.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alert_status ⇒ String
The current alert status of an alert.
-
#creation_time ⇒ Time
A timestamp that indicates when the first alert transition occurred in an alert history.
-
#monitoring_alert_name ⇒ String
The name of a monitoring alert.
-
#monitoring_schedule_name ⇒ String
The name of a monitoring schedule.
Instance Attribute Details
#alert_status ⇒ String
The current alert status of an alert.
39825 39826 39827 39828 39829 39830 39831 39832 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39825 class MonitoringAlertHistorySummary < Struct.new( :monitoring_schedule_name, :monitoring_alert_name, :creation_time, :alert_status) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
A timestamp that indicates when the first alert transition occurred in an alert history. An alert transition can be from status InAlert to OK, or from OK to InAlert.
39825 39826 39827 39828 39829 39830 39831 39832 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39825 class MonitoringAlertHistorySummary < Struct.new( :monitoring_schedule_name, :monitoring_alert_name, :creation_time, :alert_status) SENSITIVE = [] include Aws::Structure end |
#monitoring_alert_name ⇒ String
The name of a monitoring alert.
39825 39826 39827 39828 39829 39830 39831 39832 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39825 class MonitoringAlertHistorySummary < Struct.new( :monitoring_schedule_name, :monitoring_alert_name, :creation_time, :alert_status) SENSITIVE = [] include Aws::Structure end |
#monitoring_schedule_name ⇒ String
The name of a monitoring schedule.
39825 39826 39827 39828 39829 39830 39831 39832 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39825 class MonitoringAlertHistorySummary < Struct.new( :monitoring_schedule_name, :monitoring_alert_name, :creation_time, :alert_status) SENSITIVE = [] include Aws::Structure end |