Class: Aws::SageMaker::Types::MonitoringBaselineConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::MonitoringBaselineConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Configuration for monitoring constraints and monitoring statistics. These baseline resources are compared against the results of the current job from the series of jobs scheduled to collect data periodically.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#baselining_job_name ⇒ String
The name of the job that performs baselining for the monitoring job.
-
#constraints_resource ⇒ Types::MonitoringConstraintsResource
The baseline constraint file in Amazon S3 that the current monitoring job should validated against.
-
#statistics_resource ⇒ Types::MonitoringStatisticsResource
The baseline statistics file in Amazon S3 that the current monitoring job should be validated against.
Instance Attribute Details
#baselining_job_name ⇒ String
The name of the job that performs baselining for the monitoring job.
43215 43216 43217 43218 43219 43220 43221 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43215 class MonitoringBaselineConfig < Struct.new( :baselining_job_name, :constraints_resource, :statistics_resource) SENSITIVE = [] include Aws::Structure end |
#constraints_resource ⇒ Types::MonitoringConstraintsResource
The baseline constraint file in Amazon S3 that the current monitoring job should validated against.
43215 43216 43217 43218 43219 43220 43221 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43215 class MonitoringBaselineConfig < Struct.new( :baselining_job_name, :constraints_resource, :statistics_resource) SENSITIVE = [] include Aws::Structure end |
#statistics_resource ⇒ Types::MonitoringStatisticsResource
The baseline statistics file in Amazon S3 that the current monitoring job should be validated against.
43215 43216 43217 43218 43219 43220 43221 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43215 class MonitoringBaselineConfig < Struct.new( :baselining_job_name, :constraints_resource, :statistics_resource) SENSITIVE = [] include Aws::Structure end |