Class: Aws::SageMaker::Types::MonitoringBaselineConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Configuration for monitoring constraints and monitoring statistics. These baseline resources are compared against the results of the current job from the series of jobs scheduled to collect data periodically.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#baselining_job_nameString

The name of the job that performs baselining for the monitoring job.

Returns:

  • (String)


42677
42678
42679
42680
42681
42682
42683
# File 'lib/aws-sdk-sagemaker/types.rb', line 42677

class MonitoringBaselineConfig < Struct.new(
  :baselining_job_name,
  :constraints_resource,
  :statistics_resource)
  SENSITIVE = []
  include Aws::Structure
end

#constraints_resourceTypes::MonitoringConstraintsResource

The baseline constraint file in Amazon S3 that the current monitoring job should validated against.



42677
42678
42679
42680
42681
42682
42683
# File 'lib/aws-sdk-sagemaker/types.rb', line 42677

class MonitoringBaselineConfig < Struct.new(
  :baselining_job_name,
  :constraints_resource,
  :statistics_resource)
  SENSITIVE = []
  include Aws::Structure
end

#statistics_resourceTypes::MonitoringStatisticsResource

The baseline statistics file in Amazon S3 that the current monitoring job should be validated against.



42677
42678
42679
42680
42681
42682
42683
# File 'lib/aws-sdk-sagemaker/types.rb', line 42677

class MonitoringBaselineConfig < Struct.new(
  :baselining_job_name,
  :constraints_resource,
  :statistics_resource)
  SENSITIVE = []
  include Aws::Structure
end