Class: Aws::SageMaker::Types::MonitoringClusterConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Configuration for the cluster used to run model monitoring jobs.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_countInteger

The number of ML compute instances to use in the model monitoring job. For distributed processing jobs, specify a value greater than

  1. The default value is 1.

Returns:

  • (Integer)


42021
42022
42023
42024
42025
42026
42027
42028
# File 'lib/aws-sdk-sagemaker/types.rb', line 42021

class MonitoringClusterConfig < Struct.new(
  :instance_count,
  :instance_type,
  :volume_size_in_gb,
  :volume_kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typeString

The ML compute instance type for the processing job.

Returns:

  • (String)


42021
42022
42023
42024
42025
42026
42027
42028
# File 'lib/aws-sdk-sagemaker/types.rb', line 42021

class MonitoringClusterConfig < Struct.new(
  :instance_count,
  :instance_type,
  :volume_size_in_gb,
  :volume_kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#volume_kms_key_idString

The Key Management Service (KMS) key that Amazon SageMaker AI uses to encrypt data on the storage volume attached to the ML compute instance(s) that run the model monitoring job.

Returns:

  • (String)


42021
42022
42023
42024
42025
42026
42027
42028
# File 'lib/aws-sdk-sagemaker/types.rb', line 42021

class MonitoringClusterConfig < Struct.new(
  :instance_count,
  :instance_type,
  :volume_size_in_gb,
  :volume_kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#volume_size_in_gbInteger

The size of the ML storage volume, in gigabytes, that you want to provision. You must specify sufficient ML storage for your scenario.

Returns:

  • (Integer)


42021
42022
42023
42024
42025
42026
42027
42028
# File 'lib/aws-sdk-sagemaker/types.rb', line 42021

class MonitoringClusterConfig < Struct.new(
  :instance_count,
  :instance_type,
  :volume_size_in_gb,
  :volume_kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end