Class: Aws::SageMaker::Types::MonitoringClusterConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::MonitoringClusterConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Configuration for the cluster used to run model monitoring jobs.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_count ⇒ Integer
The number of ML compute instances to use in the model monitoring job.
-
#instance_type ⇒ String
The ML compute instance type for the processing job.
-
#volume_kms_key_id ⇒ String
The Key Management Service (KMS) key that Amazon SageMaker AI uses to encrypt data on the storage volume attached to the ML compute instance(s) that run the model monitoring job.
-
#volume_size_in_gb ⇒ Integer
The size of the ML storage volume, in gigabytes, that you want to provision.
Instance Attribute Details
#instance_count ⇒ Integer
The number of ML compute instances to use in the model monitoring job. For distributed processing jobs, specify a value greater than
-
The default value is 1.
41921 41922 41923 41924 41925 41926 41927 41928 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 41921 class MonitoringClusterConfig < Struct.new( :instance_count, :instance_type, :volume_size_in_gb, :volume_kms_key_id) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The ML compute instance type for the processing job.
41921 41922 41923 41924 41925 41926 41927 41928 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 41921 class MonitoringClusterConfig < Struct.new( :instance_count, :instance_type, :volume_size_in_gb, :volume_kms_key_id) SENSITIVE = [] include Aws::Structure end |
#volume_kms_key_id ⇒ String
The Key Management Service (KMS) key that Amazon SageMaker AI uses to encrypt data on the storage volume attached to the ML compute instance(s) that run the model monitoring job.
41921 41922 41923 41924 41925 41926 41927 41928 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 41921 class MonitoringClusterConfig < Struct.new( :instance_count, :instance_type, :volume_size_in_gb, :volume_kms_key_id) SENSITIVE = [] include Aws::Structure end |
#volume_size_in_gb ⇒ Integer
The size of the ML storage volume, in gigabytes, that you want to provision. You must specify sufficient ML storage for your scenario.
41921 41922 41923 41924 41925 41926 41927 41928 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 41921 class MonitoringClusterConfig < Struct.new( :instance_count, :instance_type, :volume_size_in_gb, :volume_kms_key_id) SENSITIVE = [] include Aws::Structure end |