Class: Aws::SageMaker::Types::MonitoringJobDefinition
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::MonitoringJobDefinition
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Defines the monitoring job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#baseline_config ⇒ Types::MonitoringBaselineConfig
Baseline configuration used to validate that the data conforms to the specified constraints and statistics.
-
#environment ⇒ Hash<String,String>
Sets the environment variables in the Docker container.
-
#monitoring_app_specification ⇒ Types::MonitoringAppSpecification
Configures the monitoring job to run a specified Docker container image.
-
#monitoring_inputs ⇒ Array<Types::MonitoringInput>
The array of inputs for the monitoring job.
-
#monitoring_output_config ⇒ Types::MonitoringOutputConfig
The array of outputs from the monitoring job to be uploaded to Amazon S3.
-
#monitoring_resources ⇒ Types::MonitoringResources
Identifies the resources, ML compute instances, and ML storage volumes to deploy for a monitoring job.
-
#network_config ⇒ Types::NetworkConfig
Specifies networking options for an monitoring job.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker AI can assume to perform tasks on your behalf.
-
#stopping_condition ⇒ Types::MonitoringStoppingCondition
Specifies a time limit for how long the monitoring job is allowed to run.
Instance Attribute Details
#baseline_config ⇒ Types::MonitoringBaselineConfig
Baseline configuration used to validate that the data conforms to the specified constraints and statistics
42110 42111 42112 42113 42114 42115 42116 42117 42118 42119 42120 42121 42122 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42110 class MonitoringJobDefinition < Struct.new( :baseline_config, :monitoring_inputs, :monitoring_output_config, :monitoring_resources, :monitoring_app_specification, :stopping_condition, :environment, :network_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#environment ⇒ Hash<String,String>
Sets the environment variables in the Docker container.
42110 42111 42112 42113 42114 42115 42116 42117 42118 42119 42120 42121 42122 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42110 class MonitoringJobDefinition < Struct.new( :baseline_config, :monitoring_inputs, :monitoring_output_config, :monitoring_resources, :monitoring_app_specification, :stopping_condition, :environment, :network_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#monitoring_app_specification ⇒ Types::MonitoringAppSpecification
Configures the monitoring job to run a specified Docker container image.
42110 42111 42112 42113 42114 42115 42116 42117 42118 42119 42120 42121 42122 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42110 class MonitoringJobDefinition < Struct.new( :baseline_config, :monitoring_inputs, :monitoring_output_config, :monitoring_resources, :monitoring_app_specification, :stopping_condition, :environment, :network_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#monitoring_inputs ⇒ Array<Types::MonitoringInput>
The array of inputs for the monitoring job. Currently we support monitoring an Amazon SageMaker AI Endpoint.
42110 42111 42112 42113 42114 42115 42116 42117 42118 42119 42120 42121 42122 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42110 class MonitoringJobDefinition < Struct.new( :baseline_config, :monitoring_inputs, :monitoring_output_config, :monitoring_resources, :monitoring_app_specification, :stopping_condition, :environment, :network_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#monitoring_output_config ⇒ Types::MonitoringOutputConfig
The array of outputs from the monitoring job to be uploaded to Amazon S3.
42110 42111 42112 42113 42114 42115 42116 42117 42118 42119 42120 42121 42122 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42110 class MonitoringJobDefinition < Struct.new( :baseline_config, :monitoring_inputs, :monitoring_output_config, :monitoring_resources, :monitoring_app_specification, :stopping_condition, :environment, :network_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#monitoring_resources ⇒ Types::MonitoringResources
Identifies the resources, ML compute instances, and ML storage volumes to deploy for a monitoring job. In distributed processing, you specify more than one instance.
42110 42111 42112 42113 42114 42115 42116 42117 42118 42119 42120 42121 42122 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42110 class MonitoringJobDefinition < Struct.new( :baseline_config, :monitoring_inputs, :monitoring_output_config, :monitoring_resources, :monitoring_app_specification, :stopping_condition, :environment, :network_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#network_config ⇒ Types::NetworkConfig
Specifies networking options for an monitoring job.
42110 42111 42112 42113 42114 42115 42116 42117 42118 42119 42120 42121 42122 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42110 class MonitoringJobDefinition < Struct.new( :baseline_config, :monitoring_inputs, :monitoring_output_config, :monitoring_resources, :monitoring_app_specification, :stopping_condition, :environment, :network_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker AI can assume to perform tasks on your behalf.
42110 42111 42112 42113 42114 42115 42116 42117 42118 42119 42120 42121 42122 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42110 class MonitoringJobDefinition < Struct.new( :baseline_config, :monitoring_inputs, :monitoring_output_config, :monitoring_resources, :monitoring_app_specification, :stopping_condition, :environment, :network_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#stopping_condition ⇒ Types::MonitoringStoppingCondition
Specifies a time limit for how long the monitoring job is allowed to run.
42110 42111 42112 42113 42114 42115 42116 42117 42118 42119 42120 42121 42122 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42110 class MonitoringJobDefinition < Struct.new( :baseline_config, :monitoring_inputs, :monitoring_output_config, :monitoring_resources, :monitoring_app_specification, :stopping_condition, :environment, :network_config, :role_arn) SENSITIVE = [] include Aws::Structure end |