Class: Aws::SageMaker::Types::MonitoringJobDefinition
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::MonitoringJobDefinition
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Defines the monitoring job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#baseline_config ⇒ Types::MonitoringBaselineConfig
Baseline configuration used to validate that the data conforms to the specified constraints and statistics.
-
#environment ⇒ Hash<String,String>
Sets the environment variables in the Docker container.
-
#monitoring_app_specification ⇒ Types::MonitoringAppSpecification
Configures the monitoring job to run a specified Docker container image.
-
#monitoring_inputs ⇒ Array<Types::MonitoringInput>
The array of inputs for the monitoring job.
-
#monitoring_output_config ⇒ Types::MonitoringOutputConfig
The array of outputs from the monitoring job to be uploaded to Amazon S3.
-
#monitoring_resources ⇒ Types::MonitoringResources
Identifies the resources, ML compute instances, and ML storage volumes to deploy for a monitoring job.
-
#network_config ⇒ Types::NetworkConfig
Specifies networking options for an monitoring job.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker AI can assume to perform tasks on your behalf.
-
#stopping_condition ⇒ Types::MonitoringStoppingCondition
Specifies a time limit for how long the monitoring job is allowed to run.
Instance Attribute Details
#baseline_config ⇒ Types::MonitoringBaselineConfig
Baseline configuration used to validate that the data conforms to the specified constraints and statistics
40178 40179 40180 40181 40182 40183 40184 40185 40186 40187 40188 40189 40190 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40178 class MonitoringJobDefinition < Struct.new( :baseline_config, :monitoring_inputs, :monitoring_output_config, :monitoring_resources, :monitoring_app_specification, :stopping_condition, :environment, :network_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#environment ⇒ Hash<String,String>
Sets the environment variables in the Docker container.
40178 40179 40180 40181 40182 40183 40184 40185 40186 40187 40188 40189 40190 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40178 class MonitoringJobDefinition < Struct.new( :baseline_config, :monitoring_inputs, :monitoring_output_config, :monitoring_resources, :monitoring_app_specification, :stopping_condition, :environment, :network_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#monitoring_app_specification ⇒ Types::MonitoringAppSpecification
Configures the monitoring job to run a specified Docker container image.
40178 40179 40180 40181 40182 40183 40184 40185 40186 40187 40188 40189 40190 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40178 class MonitoringJobDefinition < Struct.new( :baseline_config, :monitoring_inputs, :monitoring_output_config, :monitoring_resources, :monitoring_app_specification, :stopping_condition, :environment, :network_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#monitoring_inputs ⇒ Array<Types::MonitoringInput>
The array of inputs for the monitoring job. Currently we support monitoring an Amazon SageMaker AI Endpoint.
40178 40179 40180 40181 40182 40183 40184 40185 40186 40187 40188 40189 40190 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40178 class MonitoringJobDefinition < Struct.new( :baseline_config, :monitoring_inputs, :monitoring_output_config, :monitoring_resources, :monitoring_app_specification, :stopping_condition, :environment, :network_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#monitoring_output_config ⇒ Types::MonitoringOutputConfig
The array of outputs from the monitoring job to be uploaded to Amazon S3.
40178 40179 40180 40181 40182 40183 40184 40185 40186 40187 40188 40189 40190 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40178 class MonitoringJobDefinition < Struct.new( :baseline_config, :monitoring_inputs, :monitoring_output_config, :monitoring_resources, :monitoring_app_specification, :stopping_condition, :environment, :network_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#monitoring_resources ⇒ Types::MonitoringResources
Identifies the resources, ML compute instances, and ML storage volumes to deploy for a monitoring job. In distributed processing, you specify more than one instance.
40178 40179 40180 40181 40182 40183 40184 40185 40186 40187 40188 40189 40190 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40178 class MonitoringJobDefinition < Struct.new( :baseline_config, :monitoring_inputs, :monitoring_output_config, :monitoring_resources, :monitoring_app_specification, :stopping_condition, :environment, :network_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#network_config ⇒ Types::NetworkConfig
Specifies networking options for an monitoring job.
40178 40179 40180 40181 40182 40183 40184 40185 40186 40187 40188 40189 40190 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40178 class MonitoringJobDefinition < Struct.new( :baseline_config, :monitoring_inputs, :monitoring_output_config, :monitoring_resources, :monitoring_app_specification, :stopping_condition, :environment, :network_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker AI can assume to perform tasks on your behalf.
40178 40179 40180 40181 40182 40183 40184 40185 40186 40187 40188 40189 40190 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40178 class MonitoringJobDefinition < Struct.new( :baseline_config, :monitoring_inputs, :monitoring_output_config, :monitoring_resources, :monitoring_app_specification, :stopping_condition, :environment, :network_config, :role_arn) SENSITIVE = [] include Aws::Structure end |
#stopping_condition ⇒ Types::MonitoringStoppingCondition
Specifies a time limit for how long the monitoring job is allowed to run.
40178 40179 40180 40181 40182 40183 40184 40185 40186 40187 40188 40189 40190 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40178 class MonitoringJobDefinition < Struct.new( :baseline_config, :monitoring_inputs, :monitoring_output_config, :monitoring_resources, :monitoring_app_specification, :stopping_condition, :environment, :network_config, :role_arn) SENSITIVE = [] include Aws::Structure end |