Class: Aws::SageMaker::Types::MonitoringScheduleSummary

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Summarizes the monitoring schedule.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timeTime

The creation time of the monitoring schedule.

Returns:

  • (Time)


42555
42556
42557
42558
42559
42560
42561
42562
42563
42564
42565
42566
# File 'lib/aws-sdk-sagemaker/types.rb', line 42555

class MonitoringScheduleSummary < Struct.new(
  :monitoring_schedule_name,
  :monitoring_schedule_arn,
  :creation_time,
  :last_modified_time,
  :monitoring_schedule_status,
  :endpoint_name,
  :monitoring_job_definition_name,
  :monitoring_type)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_nameString

The name of the endpoint using the monitoring schedule.

Returns:

  • (String)


42555
42556
42557
42558
42559
42560
42561
42562
42563
42564
42565
42566
# File 'lib/aws-sdk-sagemaker/types.rb', line 42555

class MonitoringScheduleSummary < Struct.new(
  :monitoring_schedule_name,
  :monitoring_schedule_arn,
  :creation_time,
  :last_modified_time,
  :monitoring_schedule_status,
  :endpoint_name,
  :monitoring_job_definition_name,
  :monitoring_type)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The last time the monitoring schedule was modified.

Returns:

  • (Time)


42555
42556
42557
42558
42559
42560
42561
42562
42563
42564
42565
42566
# File 'lib/aws-sdk-sagemaker/types.rb', line 42555

class MonitoringScheduleSummary < Struct.new(
  :monitoring_schedule_name,
  :monitoring_schedule_arn,
  :creation_time,
  :last_modified_time,
  :monitoring_schedule_status,
  :endpoint_name,
  :monitoring_job_definition_name,
  :monitoring_type)
  SENSITIVE = []
  include Aws::Structure
end

#monitoring_job_definition_nameString

The name of the monitoring job definition that the schedule is for.

Returns:

  • (String)


42555
42556
42557
42558
42559
42560
42561
42562
42563
42564
42565
42566
# File 'lib/aws-sdk-sagemaker/types.rb', line 42555

class MonitoringScheduleSummary < Struct.new(
  :monitoring_schedule_name,
  :monitoring_schedule_arn,
  :creation_time,
  :last_modified_time,
  :monitoring_schedule_status,
  :endpoint_name,
  :monitoring_job_definition_name,
  :monitoring_type)
  SENSITIVE = []
  include Aws::Structure
end

#monitoring_schedule_arnString

The Amazon Resource Name (ARN) of the monitoring schedule.

Returns:

  • (String)


42555
42556
42557
42558
42559
42560
42561
42562
42563
42564
42565
42566
# File 'lib/aws-sdk-sagemaker/types.rb', line 42555

class MonitoringScheduleSummary < Struct.new(
  :monitoring_schedule_name,
  :monitoring_schedule_arn,
  :creation_time,
  :last_modified_time,
  :monitoring_schedule_status,
  :endpoint_name,
  :monitoring_job_definition_name,
  :monitoring_type)
  SENSITIVE = []
  include Aws::Structure
end

#monitoring_schedule_nameString

The name of the monitoring schedule.

Returns:

  • (String)


42555
42556
42557
42558
42559
42560
42561
42562
42563
42564
42565
42566
# File 'lib/aws-sdk-sagemaker/types.rb', line 42555

class MonitoringScheduleSummary < Struct.new(
  :monitoring_schedule_name,
  :monitoring_schedule_arn,
  :creation_time,
  :last_modified_time,
  :monitoring_schedule_status,
  :endpoint_name,
  :monitoring_job_definition_name,
  :monitoring_type)
  SENSITIVE = []
  include Aws::Structure
end

#monitoring_schedule_statusString

The status of the monitoring schedule.

Returns:

  • (String)


42555
42556
42557
42558
42559
42560
42561
42562
42563
42564
42565
42566
# File 'lib/aws-sdk-sagemaker/types.rb', line 42555

class MonitoringScheduleSummary < Struct.new(
  :monitoring_schedule_name,
  :monitoring_schedule_arn,
  :creation_time,
  :last_modified_time,
  :monitoring_schedule_status,
  :endpoint_name,
  :monitoring_job_definition_name,
  :monitoring_type)
  SENSITIVE = []
  include Aws::Structure
end

#monitoring_typeString

The type of the monitoring job definition that the schedule is for.

Returns:

  • (String)


42555
42556
42557
42558
42559
42560
42561
42562
42563
42564
42565
42566
# File 'lib/aws-sdk-sagemaker/types.rb', line 42555

class MonitoringScheduleSummary < Struct.new(
  :monitoring_schedule_name,
  :monitoring_schedule_arn,
  :creation_time,
  :last_modified_time,
  :monitoring_schedule_status,
  :endpoint_name,
  :monitoring_job_definition_name,
  :monitoring_type)
  SENSITIVE = []
  include Aws::Structure
end