Class: Aws::SageMaker::Types::MonitoringStoppingCondition
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::MonitoringStoppingCondition
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
A time limit for how long the monitoring job is allowed to run before stopping.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_runtime_in_seconds ⇒ Integer
The maximum runtime allowed in seconds.
Instance Attribute Details
#max_runtime_in_seconds ⇒ Integer
The maximum runtime allowed in seconds.
MaxRuntimeInSeconds cannot exceed the frequency of the job.
For data quality and model explainability, this can be up to 3600
seconds for an hourly schedule. For model bias and model quality
hourly schedules, this can be up to 1800 seconds.
43557 43558 43559 43560 43561 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43557 class MonitoringStoppingCondition < Struct.new( :max_runtime_in_seconds) SENSITIVE = [] include Aws::Structure end |