Class: Aws::SageMaker::Types::MonitoringStoppingCondition
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::MonitoringStoppingCondition
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
A time limit for how long the monitoring job is allowed to run before stopping.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_runtime_in_seconds ⇒ Integer
The maximum runtime allowed in seconds.
Instance Attribute Details
#max_runtime_in_seconds ⇒ Integer
The maximum runtime allowed in seconds.
<note markdown=“1”> The ‘MaxRuntimeInSeconds` cannot exceed the frequency of the job. For data quality and model explainability, this can be up to 3600 seconds for an hourly schedule. For model bias and model quality hourly schedules, this can be up to 1800 seconds.
</note>
42267 42268 42269 42270 42271 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42267 class MonitoringStoppingCondition < Struct.new( :max_runtime_in_seconds) SENSITIVE = [] include Aws::Structure end |