Class: Aws::SageMaker::Types::MultiModelConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::MultiModelConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Specifies additional configuration for hosting multi-model endpoints.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#model_cache_setting ⇒ String
Whether to cache models for a multi-model endpoint.
Instance Attribute Details
#model_cache_setting ⇒ String
Whether to cache models for a multi-model endpoint. By default, multi-model endpoints cache models so that a model does not have to be loaded into memory each time it is invoked. Some use cases do not benefit from model caching. For example, if an endpoint hosts a large number of models that are each invoked infrequently, the endpoint might perform better if you disable model caching. To disable model caching, set the value of this parameter to ‘Disabled`.
42422 42423 42424 42425 42426 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42422 class MultiModelConfig < Struct.new( :model_cache_setting) SENSITIVE = [] include Aws::Structure end |