Class: Aws::SageMaker::Types::NetworkConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::NetworkConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Networking options for a job, such as network traffic encryption between containers, whether to allow inbound and outbound network calls to and from containers, and the VPC subnets and security groups to use for VPC-enabled jobs.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enable_inter_container_traffic_encryption ⇒ Boolean
Whether to encrypt all communications between distributed processing jobs.
-
#enable_network_isolation ⇒ Boolean
Whether to allow inbound and outbound network calls to and from the containers used for the processing job.
-
#vpc_config ⇒ Types::VpcConfig
Specifies an Amazon Virtual Private Cloud (VPC) that your SageMaker jobs, hosted models, and compute resources have access to.
Instance Attribute Details
#enable_inter_container_traffic_encryption ⇒ Boolean
Whether to encrypt all communications between distributed processing jobs. Choose ‘True` to encrypt communications. Encryption provides greater security for distributed processing jobs, but the processing might take longer.
42615 42616 42617 42618 42619 42620 42621 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42615 class NetworkConfig < Struct.new( :enable_inter_container_traffic_encryption, :enable_network_isolation, :vpc_config) SENSITIVE = [] include Aws::Structure end |
#enable_network_isolation ⇒ Boolean
Whether to allow inbound and outbound network calls to and from the containers used for the processing job.
42615 42616 42617 42618 42619 42620 42621 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42615 class NetworkConfig < Struct.new( :enable_inter_container_traffic_encryption, :enable_network_isolation, :vpc_config) SENSITIVE = [] include Aws::Structure end |
#vpc_config ⇒ Types::VpcConfig
Specifies an Amazon Virtual Private Cloud (VPC) that your SageMaker jobs, hosted models, and compute resources have access to. You can control access to and from your resources by configuring a VPC. For more information, see [Give SageMaker Access to Resources in your Amazon VPC].
[1]: docs.aws.amazon.com/sagemaker/latest/dg/infrastructure-give-access.html
42615 42616 42617 42618 42619 42620 42621 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42615 class NetworkConfig < Struct.new( :enable_inter_container_traffic_encryption, :enable_network_isolation, :vpc_config) SENSITIVE = [] include Aws::Structure end |