Class: Aws::SageMaker::Types::NetworkConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::NetworkConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Networking options for a job, such as network traffic encryption between containers, whether to allow inbound and outbound network calls to and from containers, and the VPC subnets and security groups to use for VPC-enabled jobs.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enable_inter_container_traffic_encryption ⇒ Boolean
Whether to encrypt all communications between distributed processing jobs.
-
#enable_network_isolation ⇒ Boolean
Whether to allow inbound and outbound network calls to and from the containers used for the processing job.
-
#vpc_config ⇒ Types::VpcConfig
Specifies a VPC that your training jobs and hosted models have access to.
Instance Attribute Details
#enable_inter_container_traffic_encryption ⇒ Boolean
Whether to encrypt all communications between distributed processing jobs. Choose True to encrypt communications. Encryption provides greater security for distributed processing jobs, but the processing might take longer.
29319 29320 29321 29322 29323 29324 29325 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 29319 class NetworkConfig < Struct.new( :enable_inter_container_traffic_encryption, :enable_network_isolation, :vpc_config) SENSITIVE = [] include Aws::Structure end |
#enable_network_isolation ⇒ Boolean
Whether to allow inbound and outbound network calls to and from the containers used for the processing job.
29319 29320 29321 29322 29323 29324 29325 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 29319 class NetworkConfig < Struct.new( :enable_inter_container_traffic_encryption, :enable_network_isolation, :vpc_config) SENSITIVE = [] include Aws::Structure end |
#vpc_config ⇒ Types::VpcConfig
Specifies a VPC that your training jobs and hosted models have access to. Control access to and from your training and model containers by configuring the VPC. For more information, see
- Protect Endpoints by Using an Amazon Virtual Private Cloud][1
-
and
[Protect Training Jobs by Using an Amazon Virtual Private Cloud].
[1]: docs.aws.amazon.com/sagemaker/latest/dg/host-vpc.html [2]: docs.aws.amazon.com/sagemaker/latest/dg/train-vpc.html
29319 29320 29321 29322 29323 29324 29325 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 29319 class NetworkConfig < Struct.new( :enable_inter_container_traffic_encryption, :enable_network_isolation, :vpc_config) SENSITIVE = [] include Aws::Structure end |