Class: Aws::SageMaker::Types::NodeAdditionResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::NodeAdditionResult
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Information about a node that was successfully added to the cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zones ⇒ Array<String>
The availability zones associated with the successfully added node.
-
#instance_group_name ⇒ String
The name of the instance group to which the node was added.
-
#instance_types ⇒ Array<String>
The instance types associated with the successfully added node.
-
#node_logical_id ⇒ String
A unique identifier assigned to the node that can be used to track its provisioning status through the ‘DescribeClusterNode` operation.
-
#status ⇒ String
The current status of the node.
Instance Attribute Details
#availability_zones ⇒ Array<String>
The availability zones associated with the successfully added node.
41016 41017 41018 41019 41020 41021 41022 41023 41024 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 41016 class NodeAdditionResult < Struct.new( :node_logical_id, :instance_group_name, :status, :availability_zones, :instance_types) SENSITIVE = [] include Aws::Structure end |
#instance_group_name ⇒ String
The name of the instance group to which the node was added.
41016 41017 41018 41019 41020 41021 41022 41023 41024 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 41016 class NodeAdditionResult < Struct.new( :node_logical_id, :instance_group_name, :status, :availability_zones, :instance_types) SENSITIVE = [] include Aws::Structure end |
#instance_types ⇒ Array<String>
The instance types associated with the successfully added node.
41016 41017 41018 41019 41020 41021 41022 41023 41024 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 41016 class NodeAdditionResult < Struct.new( :node_logical_id, :instance_group_name, :status, :availability_zones, :instance_types) SENSITIVE = [] include Aws::Structure end |
#node_logical_id ⇒ String
A unique identifier assigned to the node that can be used to track its provisioning status through the ‘DescribeClusterNode` operation.
41016 41017 41018 41019 41020 41021 41022 41023 41024 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 41016 class NodeAdditionResult < Struct.new( :node_logical_id, :instance_group_name, :status, :availability_zones, :instance_types) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the node. Possible values include ‘Pending`, `Running`, `Failed`, `ShuttingDown`, `SystemUpdating`, `DeepHealthCheckInProgress`, and `NotFound`.
41016 41017 41018 41019 41020 41021 41022 41023 41024 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 41016 class NodeAdditionResult < Struct.new( :node_logical_id, :instance_group_name, :status, :availability_zones, :instance_types) SENSITIVE = [] include Aws::Structure end |