Class: Aws::SageMaker::Types::NotebookInstanceSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::NotebookInstanceSummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Provides summary information for an SageMaker AI notebook instance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_code_repositories ⇒ Array<String>
An array of up to three Git repositories associated with the notebook instance.
-
#creation_time ⇒ Time
A timestamp that shows when the notebook instance was created.
-
#default_code_repository ⇒ String
The Git repository associated with the notebook instance as its default code repository.
-
#instance_type ⇒ String
The type of ML compute instance that the notebook instance is running on.
-
#last_modified_time ⇒ Time
A timestamp that shows when the notebook instance was last modified.
-
#notebook_instance_arn ⇒ String
The Amazon Resource Name (ARN) of the notebook instance.
-
#notebook_instance_lifecycle_config_name ⇒ String
The name of a notebook instance lifecycle configuration associated with this notebook instance.
-
#notebook_instance_name ⇒ String
The name of the notebook instance that you want a summary for.
-
#notebook_instance_status ⇒ String
The status of the notebook instance.
-
#url ⇒ String
The URL that you use to connect to the Jupyter notebook running in your notebook instance.
Instance Attribute Details
#additional_code_repositories ⇒ Array<String>
An array of up to three Git repositories associated with the notebook instance. These can be either the names of Git repositories stored as resources in your account, or the URL of Git repositories in [Amazon Web Services CodeCommit] or in any other Git repository. These repositories are cloned at the same level as the default repository of your notebook instance. For more information, see [Associating Git Repositories with SageMaker AI Notebook Instances].
[1]: docs.aws.amazon.com/codecommit/latest/userguide/welcome.html [2]: docs.aws.amazon.com/sagemaker/latest/dg/nbi-git-repo.html
43379 43380 43381 43382 43383 43384 43385 43386 43387 43388 43389 43390 43391 43392 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43379 class NotebookInstanceSummary < Struct.new( :notebook_instance_name, :notebook_instance_arn, :notebook_instance_status, :url, :instance_type, :creation_time, :last_modified_time, :notebook_instance_lifecycle_config_name, :default_code_repository, :additional_code_repositories) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
A timestamp that shows when the notebook instance was created.
43379 43380 43381 43382 43383 43384 43385 43386 43387 43388 43389 43390 43391 43392 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43379 class NotebookInstanceSummary < Struct.new( :notebook_instance_name, :notebook_instance_arn, :notebook_instance_status, :url, :instance_type, :creation_time, :last_modified_time, :notebook_instance_lifecycle_config_name, :default_code_repository, :additional_code_repositories) SENSITIVE = [] include Aws::Structure end |
#default_code_repository ⇒ String
The Git repository associated with the notebook instance as its default code repository. This can be either the name of a Git repository stored as a resource in your account, or the URL of a Git repository in [Amazon Web Services CodeCommit] or in any other Git repository. When you open a notebook instance, it opens in the directory that contains this repository. For more information, see [Associating Git Repositories with SageMaker AI Notebook Instances].
[1]: docs.aws.amazon.com/codecommit/latest/userguide/welcome.html [2]: docs.aws.amazon.com/sagemaker/latest/dg/nbi-git-repo.html
43379 43380 43381 43382 43383 43384 43385 43386 43387 43388 43389 43390 43391 43392 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43379 class NotebookInstanceSummary < Struct.new( :notebook_instance_name, :notebook_instance_arn, :notebook_instance_status, :url, :instance_type, :creation_time, :last_modified_time, :notebook_instance_lifecycle_config_name, :default_code_repository, :additional_code_repositories) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The type of ML compute instance that the notebook instance is running on.
43379 43380 43381 43382 43383 43384 43385 43386 43387 43388 43389 43390 43391 43392 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43379 class NotebookInstanceSummary < Struct.new( :notebook_instance_name, :notebook_instance_arn, :notebook_instance_status, :url, :instance_type, :creation_time, :last_modified_time, :notebook_instance_lifecycle_config_name, :default_code_repository, :additional_code_repositories) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
A timestamp that shows when the notebook instance was last modified.
43379 43380 43381 43382 43383 43384 43385 43386 43387 43388 43389 43390 43391 43392 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43379 class NotebookInstanceSummary < Struct.new( :notebook_instance_name, :notebook_instance_arn, :notebook_instance_status, :url, :instance_type, :creation_time, :last_modified_time, :notebook_instance_lifecycle_config_name, :default_code_repository, :additional_code_repositories) SENSITIVE = [] include Aws::Structure end |
#notebook_instance_arn ⇒ String
The Amazon Resource Name (ARN) of the notebook instance.
43379 43380 43381 43382 43383 43384 43385 43386 43387 43388 43389 43390 43391 43392 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43379 class NotebookInstanceSummary < Struct.new( :notebook_instance_name, :notebook_instance_arn, :notebook_instance_status, :url, :instance_type, :creation_time, :last_modified_time, :notebook_instance_lifecycle_config_name, :default_code_repository, :additional_code_repositories) SENSITIVE = [] include Aws::Structure end |
#notebook_instance_lifecycle_config_name ⇒ String
The name of a notebook instance lifecycle configuration associated with this notebook instance.
For information about notebook instance lifestyle configurations, see [Step 2.1: (Optional) Customize a Notebook Instance].
[1]: docs.aws.amazon.com/sagemaker/latest/dg/notebook-lifecycle-config.html
43379 43380 43381 43382 43383 43384 43385 43386 43387 43388 43389 43390 43391 43392 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43379 class NotebookInstanceSummary < Struct.new( :notebook_instance_name, :notebook_instance_arn, :notebook_instance_status, :url, :instance_type, :creation_time, :last_modified_time, :notebook_instance_lifecycle_config_name, :default_code_repository, :additional_code_repositories) SENSITIVE = [] include Aws::Structure end |
#notebook_instance_name ⇒ String
The name of the notebook instance that you want a summary for.
43379 43380 43381 43382 43383 43384 43385 43386 43387 43388 43389 43390 43391 43392 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43379 class NotebookInstanceSummary < Struct.new( :notebook_instance_name, :notebook_instance_arn, :notebook_instance_status, :url, :instance_type, :creation_time, :last_modified_time, :notebook_instance_lifecycle_config_name, :default_code_repository, :additional_code_repositories) SENSITIVE = [] include Aws::Structure end |
#notebook_instance_status ⇒ String
The status of the notebook instance.
43379 43380 43381 43382 43383 43384 43385 43386 43387 43388 43389 43390 43391 43392 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43379 class NotebookInstanceSummary < Struct.new( :notebook_instance_name, :notebook_instance_arn, :notebook_instance_status, :url, :instance_type, :creation_time, :last_modified_time, :notebook_instance_lifecycle_config_name, :default_code_repository, :additional_code_repositories) SENSITIVE = [] include Aws::Structure end |
#url ⇒ String
The URL that you use to connect to the Jupyter notebook running in your notebook instance.
43379 43380 43381 43382 43383 43384 43385 43386 43387 43388 43389 43390 43391 43392 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43379 class NotebookInstanceSummary < Struct.new( :notebook_instance_name, :notebook_instance_arn, :notebook_instance_status, :url, :instance_type, :creation_time, :last_modified_time, :notebook_instance_lifecycle_config_name, :default_code_repository, :additional_code_repositories) SENSITIVE = [] include Aws::Structure end |