Class: Aws::SageMaker::Types::OfflineStoreConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::OfflineStoreConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The configuration of an OfflineStore.
Provide an OfflineStoreConfig in a request to CreateFeatureGroup
to create an OfflineStore.
To encrypt an OfflineStore using at rest data encryption, specify
Amazon Web Services Key Management Service (KMS) key ID, or
KMSKeyId, in S3StorageConfig.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_catalog_config ⇒ Types::DataCatalogConfig
The meta data of the Glue table for the
OfflineStore. -
#disable_glue_table_creation ⇒ Boolean
Set to
Trueto disable the automatic creation of an Amazon Web Services Glue table when configuring anOfflineStore. -
#s3_storage_config ⇒ Types::S3StorageConfig
The Amazon Simple Storage (Amazon S3) location of
OfflineStore. -
#table_format ⇒ String
Format for the offline store table.
Instance Attribute Details
#data_catalog_config ⇒ Types::DataCatalogConfig
The meta data of the Glue table for the OfflineStore. If not
provided, Feature Store auto-generates the table name, database, and
catalog when the OfflineStore is created. You can optionally
provide this configuration to specify custom values. This applies to
both Glue and Apache Iceberg table formats.
43994 43995 43996 43997 43998 43999 44000 44001 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43994 class OfflineStoreConfig < Struct.new( :s3_storage_config, :disable_glue_table_creation, :data_catalog_config, :table_format) SENSITIVE = [] include Aws::Structure end |
#disable_glue_table_creation ⇒ Boolean
Set to True to disable the automatic creation of an Amazon Web
Services Glue table when configuring an OfflineStore. If set to
True and DataCatalogConfig is provided, Feature Store associates
the provided catalog configuration with the feature group without
creating a table. In this case, you are responsible for creating and
managing the Glue table. If set to True without
DataCatalogConfig, no Glue table is created or associated with the
feature group. The Iceberg table format is only supported when
this is set to False.
If set to False and DataCatalogConfig is provided, Feature Store
creates the table using the specified names. If set to False
without DataCatalogConfig, Feature Store auto-generates the table
name following Athena's naming recommendations. This applies
to both Glue and Apache Iceberg table formats.
The default value is False.
43994 43995 43996 43997 43998 43999 44000 44001 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43994 class OfflineStoreConfig < Struct.new( :s3_storage_config, :disable_glue_table_creation, :data_catalog_config, :table_format) SENSITIVE = [] include Aws::Structure end |
#s3_storage_config ⇒ Types::S3StorageConfig
The Amazon Simple Storage (Amazon S3) location of OfflineStore.
43994 43995 43996 43997 43998 43999 44000 44001 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43994 class OfflineStoreConfig < Struct.new( :s3_storage_config, :disable_glue_table_creation, :data_catalog_config, :table_format) SENSITIVE = [] include Aws::Structure end |
#table_format ⇒ String
Format for the offline store table. Supported formats are Glue (Default) and Apache Iceberg.
43994 43995 43996 43997 43998 43999 44000 44001 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43994 class OfflineStoreConfig < Struct.new( :s3_storage_config, :disable_glue_table_creation, :data_catalog_config, :table_format) SENSITIVE = [] include Aws::Structure end |