Class: Aws::SageMaker::Types::OfflineStoreConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::OfflineStoreConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The configuration of an OfflineStore.
Provide an OfflineStoreConfig in a request to CreateFeatureGroup to create an OfflineStore.
To encrypt an OfflineStore using at rest data encryption, specify Amazon Web Services Key Management Service (KMS) key ID, or KMSKeyId, in S3StorageConfig.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_catalog_config ⇒ Types::DataCatalogConfig
The meta data of the Glue table that is autogenerated when an
OfflineStoreis created. -
#disable_glue_table_creation ⇒ Boolean
Set to
Trueto disable the automatic creation of an Amazon Web Services Glue table when configuring anOfflineStore. -
#s3_storage_config ⇒ Types::S3StorageConfig
The Amazon Simple Storage (Amazon S3) location of
OfflineStore. -
#table_format ⇒ String
Format for the offline store table.
Instance Attribute Details
#data_catalog_config ⇒ Types::DataCatalogConfig
The meta data of the Glue table that is autogenerated when an OfflineStore is created.
36566 36567 36568 36569 36570 36571 36572 36573 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36566 class OfflineStoreConfig < Struct.new( :s3_storage_config, :disable_glue_table_creation, :data_catalog_config, :table_format) SENSITIVE = [] include Aws::Structure end |
#disable_glue_table_creation ⇒ Boolean
Set to True to disable the automatic creation of an Amazon Web Services Glue table when configuring an OfflineStore. If set to False, Feature Store will name the OfflineStore Glue table following [Athena’s naming recommendations].
The default value is False.
[1]: docs.aws.amazon.com/athena/latest/ug/tables-databases-columns-names.html
36566 36567 36568 36569 36570 36571 36572 36573 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36566 class OfflineStoreConfig < Struct.new( :s3_storage_config, :disable_glue_table_creation, :data_catalog_config, :table_format) SENSITIVE = [] include Aws::Structure end |
#s3_storage_config ⇒ Types::S3StorageConfig
The Amazon Simple Storage (Amazon S3) location of OfflineStore.
36566 36567 36568 36569 36570 36571 36572 36573 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36566 class OfflineStoreConfig < Struct.new( :s3_storage_config, :disable_glue_table_creation, :data_catalog_config, :table_format) SENSITIVE = [] include Aws::Structure end |
#table_format ⇒ String
Format for the offline store table. Supported formats are Glue (Default) and [Apache Iceberg].
[1]: iceberg.apache.org/
36566 36567 36568 36569 36570 36571 36572 36573 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36566 class OfflineStoreConfig < Struct.new( :s3_storage_config, :disable_glue_table_creation, :data_catalog_config, :table_format) SENSITIVE = [] include Aws::Structure end |