Class: Aws::SageMaker::Types::OfflineStoreConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The configuration of an OfflineStore.

Provide an OfflineStoreConfig in a request to CreateFeatureGroup to create an OfflineStore.

To encrypt an OfflineStore using at rest data encryption, specify Amazon Web Services Key Management Service (KMS) key ID, or KMSKeyId, in S3StorageConfig.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#data_catalog_configTypes::DataCatalogConfig

The meta data of the Glue table that is autogenerated when an OfflineStore is created.



36550
36551
36552
36553
36554
36555
36556
36557
# File 'lib/aws-sdk-sagemaker/types.rb', line 36550

class OfflineStoreConfig < Struct.new(
  :s3_storage_config,
  :disable_glue_table_creation,
  :data_catalog_config,
  :table_format)
  SENSITIVE = []
  include Aws::Structure
end

#disable_glue_table_creationBoolean

Set to True to disable the automatic creation of an Amazon Web Services Glue table when configuring an OfflineStore. If set to False, Feature Store will name the OfflineStore Glue table following [Athena’s naming recommendations].

The default value is False.

[1]: docs.aws.amazon.com/athena/latest/ug/tables-databases-columns-names.html

Returns:

  • (Boolean)


36550
36551
36552
36553
36554
36555
36556
36557
# File 'lib/aws-sdk-sagemaker/types.rb', line 36550

class OfflineStoreConfig < Struct.new(
  :s3_storage_config,
  :disable_glue_table_creation,
  :data_catalog_config,
  :table_format)
  SENSITIVE = []
  include Aws::Structure
end

#s3_storage_configTypes::S3StorageConfig

The Amazon Simple Storage (Amazon S3) location of OfflineStore.



36550
36551
36552
36553
36554
36555
36556
36557
# File 'lib/aws-sdk-sagemaker/types.rb', line 36550

class OfflineStoreConfig < Struct.new(
  :s3_storage_config,
  :disable_glue_table_creation,
  :data_catalog_config,
  :table_format)
  SENSITIVE = []
  include Aws::Structure
end

#table_formatString

Format for the offline store table. Supported formats are Glue (Default) and [Apache Iceberg].

[1]: iceberg.apache.org/

Returns:

  • (String)


36550
36551
36552
36553
36554
36555
36556
36557
# File 'lib/aws-sdk-sagemaker/types.rb', line 36550

class OfflineStoreConfig < Struct.new(
  :s3_storage_config,
  :disable_glue_table_creation,
  :data_catalog_config,
  :table_format)
  SENSITIVE = []
  include Aws::Structure
end