Class: Aws::SageMaker::Types::OidcConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::OidcConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Use this parameter to configure your OIDC Identity Provider (IdP).
Constant Summary collapse
- SENSITIVE =
[:client_secret]
Instance Attribute Summary collapse
-
#authentication_request_extra_params ⇒ Hash<String,String>
A string to string map of identifiers specific to the custom identity provider (IdP) being used.
-
#authorization_endpoint ⇒ String
The OIDC IdP authorization endpoint used to configure your private workforce.
-
#client_id ⇒ String
The OIDC IdP client ID used to configure your private workforce.
-
#client_secret ⇒ String
The OIDC IdP client secret used to configure your private workforce.
-
#issuer ⇒ String
The OIDC IdP issuer used to configure your private workforce.
-
#jwks_uri ⇒ String
The OIDC IdP JSON Web Key Set (Jwks) URI used to configure your private workforce.
-
#logout_endpoint ⇒ String
The OIDC IdP logout endpoint used to configure your private workforce.
-
#scope ⇒ String
An array of string identifiers used to refer to the specific pieces of user data or claims that the client application wants to access.
-
#token_endpoint ⇒ String
The OIDC IdP token endpoint used to configure your private workforce.
-
#user_info_endpoint ⇒ String
The OIDC IdP user information endpoint used to configure your private workforce.
Instance Attribute Details
#authentication_request_extra_params ⇒ Hash<String,String>
A string to string map of identifiers specific to the custom identity provider (IdP) being used.
43758 43759 43760 43761 43762 43763 43764 43765 43766 43767 43768 43769 43770 43771 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43758 class OidcConfig < Struct.new( :client_id, :client_secret, :issuer, :authorization_endpoint, :token_endpoint, :user_info_endpoint, :logout_endpoint, :jwks_uri, :scope, :authentication_request_extra_params) SENSITIVE = [:client_secret] include Aws::Structure end |
#authorization_endpoint ⇒ String
The OIDC IdP authorization endpoint used to configure your private workforce.
43758 43759 43760 43761 43762 43763 43764 43765 43766 43767 43768 43769 43770 43771 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43758 class OidcConfig < Struct.new( :client_id, :client_secret, :issuer, :authorization_endpoint, :token_endpoint, :user_info_endpoint, :logout_endpoint, :jwks_uri, :scope, :authentication_request_extra_params) SENSITIVE = [:client_secret] include Aws::Structure end |
#client_id ⇒ String
The OIDC IdP client ID used to configure your private workforce.
43758 43759 43760 43761 43762 43763 43764 43765 43766 43767 43768 43769 43770 43771 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43758 class OidcConfig < Struct.new( :client_id, :client_secret, :issuer, :authorization_endpoint, :token_endpoint, :user_info_endpoint, :logout_endpoint, :jwks_uri, :scope, :authentication_request_extra_params) SENSITIVE = [:client_secret] include Aws::Structure end |
#client_secret ⇒ String
The OIDC IdP client secret used to configure your private workforce.
43758 43759 43760 43761 43762 43763 43764 43765 43766 43767 43768 43769 43770 43771 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43758 class OidcConfig < Struct.new( :client_id, :client_secret, :issuer, :authorization_endpoint, :token_endpoint, :user_info_endpoint, :logout_endpoint, :jwks_uri, :scope, :authentication_request_extra_params) SENSITIVE = [:client_secret] include Aws::Structure end |
#issuer ⇒ String
The OIDC IdP issuer used to configure your private workforce.
43758 43759 43760 43761 43762 43763 43764 43765 43766 43767 43768 43769 43770 43771 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43758 class OidcConfig < Struct.new( :client_id, :client_secret, :issuer, :authorization_endpoint, :token_endpoint, :user_info_endpoint, :logout_endpoint, :jwks_uri, :scope, :authentication_request_extra_params) SENSITIVE = [:client_secret] include Aws::Structure end |
#jwks_uri ⇒ String
The OIDC IdP JSON Web Key Set (Jwks) URI used to configure your private workforce.
43758 43759 43760 43761 43762 43763 43764 43765 43766 43767 43768 43769 43770 43771 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43758 class OidcConfig < Struct.new( :client_id, :client_secret, :issuer, :authorization_endpoint, :token_endpoint, :user_info_endpoint, :logout_endpoint, :jwks_uri, :scope, :authentication_request_extra_params) SENSITIVE = [:client_secret] include Aws::Structure end |
#logout_endpoint ⇒ String
The OIDC IdP logout endpoint used to configure your private workforce.
43758 43759 43760 43761 43762 43763 43764 43765 43766 43767 43768 43769 43770 43771 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43758 class OidcConfig < Struct.new( :client_id, :client_secret, :issuer, :authorization_endpoint, :token_endpoint, :user_info_endpoint, :logout_endpoint, :jwks_uri, :scope, :authentication_request_extra_params) SENSITIVE = [:client_secret] include Aws::Structure end |
#scope ⇒ String
An array of string identifiers used to refer to the specific pieces of user data or claims that the client application wants to access.
43758 43759 43760 43761 43762 43763 43764 43765 43766 43767 43768 43769 43770 43771 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43758 class OidcConfig < Struct.new( :client_id, :client_secret, :issuer, :authorization_endpoint, :token_endpoint, :user_info_endpoint, :logout_endpoint, :jwks_uri, :scope, :authentication_request_extra_params) SENSITIVE = [:client_secret] include Aws::Structure end |
#token_endpoint ⇒ String
The OIDC IdP token endpoint used to configure your private workforce.
43758 43759 43760 43761 43762 43763 43764 43765 43766 43767 43768 43769 43770 43771 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43758 class OidcConfig < Struct.new( :client_id, :client_secret, :issuer, :authorization_endpoint, :token_endpoint, :user_info_endpoint, :logout_endpoint, :jwks_uri, :scope, :authentication_request_extra_params) SENSITIVE = [:client_secret] include Aws::Structure end |
#user_info_endpoint ⇒ String
The OIDC IdP user information endpoint used to configure your private workforce.
43758 43759 43760 43761 43762 43763 43764 43765 43766 43767 43768 43769 43770 43771 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43758 class OidcConfig < Struct.new( :client_id, :client_secret, :issuer, :authorization_endpoint, :token_endpoint, :user_info_endpoint, :logout_endpoint, :jwks_uri, :scope, :authentication_request_extra_params) SENSITIVE = [:client_secret] include Aws::Structure end |