Class: Aws::SageMaker::Types::OidcConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Use this parameter to configure your OIDC Identity Provider (IdP).

Constant Summary collapse

SENSITIVE =
[:client_secret]

Instance Attribute Summary collapse

Instance Attribute Details

#authentication_request_extra_paramsHash<String,String>

A string to string map of identifiers specific to the custom identity provider (IdP) being used.



40981
40982
40983
40984
40985
40986
40987
40988
40989
40990
40991
40992
40993
40994
# File 'lib/aws-sdk-sagemaker/types.rb', line 40981

class OidcConfig < Struct.new(
  :client_id,
  :client_secret,
  :issuer,
  :authorization_endpoint,
  :token_endpoint,
  :user_info_endpoint,
  :logout_endpoint,
  :jwks_uri,
  :scope,
  :authentication_request_extra_params)
  SENSITIVE = [:client_secret]
  include Aws::Structure
end

#authorization_endpointString

The OIDC IdP authorization endpoint used to configure your private workforce.



40981
40982
40983
40984
40985
40986
40987
40988
40989
40990
40991
40992
40993
40994
# File 'lib/aws-sdk-sagemaker/types.rb', line 40981

class OidcConfig < Struct.new(
  :client_id,
  :client_secret,
  :issuer,
  :authorization_endpoint,
  :token_endpoint,
  :user_info_endpoint,
  :logout_endpoint,
  :jwks_uri,
  :scope,
  :authentication_request_extra_params)
  SENSITIVE = [:client_secret]
  include Aws::Structure
end

#client_idString

The OIDC IdP client ID used to configure your private workforce.



40981
40982
40983
40984
40985
40986
40987
40988
40989
40990
40991
40992
40993
40994
# File 'lib/aws-sdk-sagemaker/types.rb', line 40981

class OidcConfig < Struct.new(
  :client_id,
  :client_secret,
  :issuer,
  :authorization_endpoint,
  :token_endpoint,
  :user_info_endpoint,
  :logout_endpoint,
  :jwks_uri,
  :scope,
  :authentication_request_extra_params)
  SENSITIVE = [:client_secret]
  include Aws::Structure
end

#client_secretString

The OIDC IdP client secret used to configure your private workforce.



40981
40982
40983
40984
40985
40986
40987
40988
40989
40990
40991
40992
40993
40994
# File 'lib/aws-sdk-sagemaker/types.rb', line 40981

class OidcConfig < Struct.new(
  :client_id,
  :client_secret,
  :issuer,
  :authorization_endpoint,
  :token_endpoint,
  :user_info_endpoint,
  :logout_endpoint,
  :jwks_uri,
  :scope,
  :authentication_request_extra_params)
  SENSITIVE = [:client_secret]
  include Aws::Structure
end

#issuerString

The OIDC IdP issuer used to configure your private workforce.



40981
40982
40983
40984
40985
40986
40987
40988
40989
40990
40991
40992
40993
40994
# File 'lib/aws-sdk-sagemaker/types.rb', line 40981

class OidcConfig < Struct.new(
  :client_id,
  :client_secret,
  :issuer,
  :authorization_endpoint,
  :token_endpoint,
  :user_info_endpoint,
  :logout_endpoint,
  :jwks_uri,
  :scope,
  :authentication_request_extra_params)
  SENSITIVE = [:client_secret]
  include Aws::Structure
end

#jwks_uriString

The OIDC IdP JSON Web Key Set (Jwks) URI used to configure your private workforce.



40981
40982
40983
40984
40985
40986
40987
40988
40989
40990
40991
40992
40993
40994
# File 'lib/aws-sdk-sagemaker/types.rb', line 40981

class OidcConfig < Struct.new(
  :client_id,
  :client_secret,
  :issuer,
  :authorization_endpoint,
  :token_endpoint,
  :user_info_endpoint,
  :logout_endpoint,
  :jwks_uri,
  :scope,
  :authentication_request_extra_params)
  SENSITIVE = [:client_secret]
  include Aws::Structure
end

#logout_endpointString

The OIDC IdP logout endpoint used to configure your private workforce.



40981
40982
40983
40984
40985
40986
40987
40988
40989
40990
40991
40992
40993
40994
# File 'lib/aws-sdk-sagemaker/types.rb', line 40981

class OidcConfig < Struct.new(
  :client_id,
  :client_secret,
  :issuer,
  :authorization_endpoint,
  :token_endpoint,
  :user_info_endpoint,
  :logout_endpoint,
  :jwks_uri,
  :scope,
  :authentication_request_extra_params)
  SENSITIVE = [:client_secret]
  include Aws::Structure
end

#scopeString

An array of string identifiers used to refer to the specific pieces of user data or claims that the client application wants to access.



40981
40982
40983
40984
40985
40986
40987
40988
40989
40990
40991
40992
40993
40994
# File 'lib/aws-sdk-sagemaker/types.rb', line 40981

class OidcConfig < Struct.new(
  :client_id,
  :client_secret,
  :issuer,
  :authorization_endpoint,
  :token_endpoint,
  :user_info_endpoint,
  :logout_endpoint,
  :jwks_uri,
  :scope,
  :authentication_request_extra_params)
  SENSITIVE = [:client_secret]
  include Aws::Structure
end

#token_endpointString

The OIDC IdP token endpoint used to configure your private workforce.



40981
40982
40983
40984
40985
40986
40987
40988
40989
40990
40991
40992
40993
40994
# File 'lib/aws-sdk-sagemaker/types.rb', line 40981

class OidcConfig < Struct.new(
  :client_id,
  :client_secret,
  :issuer,
  :authorization_endpoint,
  :token_endpoint,
  :user_info_endpoint,
  :logout_endpoint,
  :jwks_uri,
  :scope,
  :authentication_request_extra_params)
  SENSITIVE = [:client_secret]
  include Aws::Structure
end

#user_info_endpointString

The OIDC IdP user information endpoint used to configure your private workforce.



40981
40982
40983
40984
40985
40986
40987
40988
40989
40990
40991
40992
40993
40994
# File 'lib/aws-sdk-sagemaker/types.rb', line 40981

class OidcConfig < Struct.new(
  :client_id,
  :client_secret,
  :issuer,
  :authorization_endpoint,
  :token_endpoint,
  :user_info_endpoint,
  :logout_endpoint,
  :jwks_uri,
  :scope,
  :authentication_request_extra_params)
  SENSITIVE = [:client_secret]
  include Aws::Structure
end