Class: Aws::SageMaker::Types::OptimizationModelAccessConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::OptimizationModelAccessConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The access configuration settings for the source ML model for an optimization job, where you can accept the model end-user license agreement (EULA).
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#accept_eula ⇒ Boolean
Specifies agreement to the model end-user license agreement (EULA).
Instance Attribute Details
#accept_eula ⇒ Boolean
Specifies agreement to the model end-user license agreement (EULA). The ‘AcceptEula` value must be explicitly defined as `True` in order to accept the EULA that this model requires. You are responsible for reviewing and complying with any applicable license terms and making sure they are acceptable for your use case before downloading or using a model.
43335 43336 43337 43338 43339 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43335 class OptimizationModelAccessConfig < Struct.new( :accept_eula) SENSITIVE = [] include Aws::Structure end |