Class: Aws::SageMaker::Types::PendingProductionVariantSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::PendingProductionVariantSummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The production variant summary for a deployment when an endpoint is
creating or updating with the CreateEndpoint or
UpdateEndpoint operations. Describes the VariantStatus , weight
and capacity for a production variant associated with an endpoint.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#accelerator_type ⇒ String
This parameter is no longer supported.
-
#current_instance_count ⇒ Integer
The number of instances associated with the variant.
-
#current_serverless_config ⇒ Types::ProductionVariantServerlessConfig
The serverless configuration for the endpoint.
-
#current_weight ⇒ Float
The weight associated with the variant.
-
#deployed_images ⇒ Array<Types::DeployedImage>
An array of
DeployedImageobjects that specify the Amazon EC2 Container Registry paths of the inference images deployed on instances of thisProductionVariant. -
#desired_instance_count ⇒ Integer
The number of instances requested in this deployment, as specified in the endpoint configuration for the endpoint.
-
#desired_serverless_config ⇒ Types::ProductionVariantServerlessConfig
The serverless configuration requested for this deployment, as specified in the endpoint configuration for the endpoint.
-
#desired_weight ⇒ Float
The requested weight for the variant in this deployment, as specified in the endpoint configuration for the endpoint.
-
#instance_pools ⇒ Array<Types::InstancePoolSummary>
A list of instance pools for the production variant.
-
#instance_type ⇒ String
The type of instances associated with the variant.
-
#managed_instance_scaling ⇒ Types::ProductionVariantManagedInstanceScaling
Settings that control the range in the number of instances that the endpoint provisions as it scales up or down to accommodate traffic.
-
#routing_config ⇒ Types::ProductionVariantRoutingConfig
Settings that control how the endpoint routes incoming traffic to the instances that the endpoint hosts.
-
#variant_name ⇒ String
The name of the variant.
-
#variant_status ⇒ Array<Types::ProductionVariantStatus>
The endpoint variant status which describes the current deployment stage status or operational status.
Instance Attribute Details
#accelerator_type ⇒ String
This parameter is no longer supported. Elastic Inference (EI) is no longer available.
This parameter was used to specify the size of the EI instance to use for the production variant.
45771 45772 45773 45774 45775 45776 45777 45778 45779 45780 45781 45782 45783 45784 45785 45786 45787 45788 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 45771 class PendingProductionVariantSummary < Struct.new( :variant_name, :deployed_images, :current_weight, :desired_weight, :current_instance_count, :desired_instance_count, :instance_type, :instance_pools, :accelerator_type, :variant_status, :current_serverless_config, :desired_serverless_config, :managed_instance_scaling, :routing_config) SENSITIVE = [] include Aws::Structure end |
#current_instance_count ⇒ Integer
The number of instances associated with the variant.
45771 45772 45773 45774 45775 45776 45777 45778 45779 45780 45781 45782 45783 45784 45785 45786 45787 45788 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 45771 class PendingProductionVariantSummary < Struct.new( :variant_name, :deployed_images, :current_weight, :desired_weight, :current_instance_count, :desired_instance_count, :instance_type, :instance_pools, :accelerator_type, :variant_status, :current_serverless_config, :desired_serverless_config, :managed_instance_scaling, :routing_config) SENSITIVE = [] include Aws::Structure end |
#current_serverless_config ⇒ Types::ProductionVariantServerlessConfig
The serverless configuration for the endpoint.
45771 45772 45773 45774 45775 45776 45777 45778 45779 45780 45781 45782 45783 45784 45785 45786 45787 45788 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 45771 class PendingProductionVariantSummary < Struct.new( :variant_name, :deployed_images, :current_weight, :desired_weight, :current_instance_count, :desired_instance_count, :instance_type, :instance_pools, :accelerator_type, :variant_status, :current_serverless_config, :desired_serverless_config, :managed_instance_scaling, :routing_config) SENSITIVE = [] include Aws::Structure end |
#current_weight ⇒ Float
The weight associated with the variant.
45771 45772 45773 45774 45775 45776 45777 45778 45779 45780 45781 45782 45783 45784 45785 45786 45787 45788 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 45771 class PendingProductionVariantSummary < Struct.new( :variant_name, :deployed_images, :current_weight, :desired_weight, :current_instance_count, :desired_instance_count, :instance_type, :instance_pools, :accelerator_type, :variant_status, :current_serverless_config, :desired_serverless_config, :managed_instance_scaling, :routing_config) SENSITIVE = [] include Aws::Structure end |
#deployed_images ⇒ Array<Types::DeployedImage>
An array of DeployedImage objects that specify the Amazon EC2
Container Registry paths of the inference images deployed on
instances of this ProductionVariant.
45771 45772 45773 45774 45775 45776 45777 45778 45779 45780 45781 45782 45783 45784 45785 45786 45787 45788 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 45771 class PendingProductionVariantSummary < Struct.new( :variant_name, :deployed_images, :current_weight, :desired_weight, :current_instance_count, :desired_instance_count, :instance_type, :instance_pools, :accelerator_type, :variant_status, :current_serverless_config, :desired_serverless_config, :managed_instance_scaling, :routing_config) SENSITIVE = [] include Aws::Structure end |
#desired_instance_count ⇒ Integer
The number of instances requested in this deployment, as specified in the endpoint configuration for the endpoint. The value is taken from the request to the CreateEndpointConfig operation.
45771 45772 45773 45774 45775 45776 45777 45778 45779 45780 45781 45782 45783 45784 45785 45786 45787 45788 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 45771 class PendingProductionVariantSummary < Struct.new( :variant_name, :deployed_images, :current_weight, :desired_weight, :current_instance_count, :desired_instance_count, :instance_type, :instance_pools, :accelerator_type, :variant_status, :current_serverless_config, :desired_serverless_config, :managed_instance_scaling, :routing_config) SENSITIVE = [] include Aws::Structure end |
#desired_serverless_config ⇒ Types::ProductionVariantServerlessConfig
The serverless configuration requested for this deployment, as specified in the endpoint configuration for the endpoint.
45771 45772 45773 45774 45775 45776 45777 45778 45779 45780 45781 45782 45783 45784 45785 45786 45787 45788 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 45771 class PendingProductionVariantSummary < Struct.new( :variant_name, :deployed_images, :current_weight, :desired_weight, :current_instance_count, :desired_instance_count, :instance_type, :instance_pools, :accelerator_type, :variant_status, :current_serverless_config, :desired_serverless_config, :managed_instance_scaling, :routing_config) SENSITIVE = [] include Aws::Structure end |
#desired_weight ⇒ Float
The requested weight for the variant in this deployment, as specified in the endpoint configuration for the endpoint. The value is taken from the request to the CreateEndpointConfig operation.
45771 45772 45773 45774 45775 45776 45777 45778 45779 45780 45781 45782 45783 45784 45785 45786 45787 45788 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 45771 class PendingProductionVariantSummary < Struct.new( :variant_name, :deployed_images, :current_weight, :desired_weight, :current_instance_count, :desired_instance_count, :instance_type, :instance_pools, :accelerator_type, :variant_status, :current_serverless_config, :desired_serverless_config, :managed_instance_scaling, :routing_config) SENSITIVE = [] include Aws::Structure end |
#instance_pools ⇒ Array<Types::InstancePoolSummary>
A list of instance pools for the production variant. Each pool indicates the instance type and the current number of instances of that type.
45771 45772 45773 45774 45775 45776 45777 45778 45779 45780 45781 45782 45783 45784 45785 45786 45787 45788 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 45771 class PendingProductionVariantSummary < Struct.new( :variant_name, :deployed_images, :current_weight, :desired_weight, :current_instance_count, :desired_instance_count, :instance_type, :instance_pools, :accelerator_type, :variant_status, :current_serverless_config, :desired_serverless_config, :managed_instance_scaling, :routing_config) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The type of instances associated with the variant.
45771 45772 45773 45774 45775 45776 45777 45778 45779 45780 45781 45782 45783 45784 45785 45786 45787 45788 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 45771 class PendingProductionVariantSummary < Struct.new( :variant_name, :deployed_images, :current_weight, :desired_weight, :current_instance_count, :desired_instance_count, :instance_type, :instance_pools, :accelerator_type, :variant_status, :current_serverless_config, :desired_serverless_config, :managed_instance_scaling, :routing_config) SENSITIVE = [] include Aws::Structure end |
#managed_instance_scaling ⇒ Types::ProductionVariantManagedInstanceScaling
Settings that control the range in the number of instances that the endpoint provisions as it scales up or down to accommodate traffic.
45771 45772 45773 45774 45775 45776 45777 45778 45779 45780 45781 45782 45783 45784 45785 45786 45787 45788 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 45771 class PendingProductionVariantSummary < Struct.new( :variant_name, :deployed_images, :current_weight, :desired_weight, :current_instance_count, :desired_instance_count, :instance_type, :instance_pools, :accelerator_type, :variant_status, :current_serverless_config, :desired_serverless_config, :managed_instance_scaling, :routing_config) SENSITIVE = [] include Aws::Structure end |
#routing_config ⇒ Types::ProductionVariantRoutingConfig
Settings that control how the endpoint routes incoming traffic to the instances that the endpoint hosts.
45771 45772 45773 45774 45775 45776 45777 45778 45779 45780 45781 45782 45783 45784 45785 45786 45787 45788 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 45771 class PendingProductionVariantSummary < Struct.new( :variant_name, :deployed_images, :current_weight, :desired_weight, :current_instance_count, :desired_instance_count, :instance_type, :instance_pools, :accelerator_type, :variant_status, :current_serverless_config, :desired_serverless_config, :managed_instance_scaling, :routing_config) SENSITIVE = [] include Aws::Structure end |
#variant_name ⇒ String
The name of the variant.
45771 45772 45773 45774 45775 45776 45777 45778 45779 45780 45781 45782 45783 45784 45785 45786 45787 45788 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 45771 class PendingProductionVariantSummary < Struct.new( :variant_name, :deployed_images, :current_weight, :desired_weight, :current_instance_count, :desired_instance_count, :instance_type, :instance_pools, :accelerator_type, :variant_status, :current_serverless_config, :desired_serverless_config, :managed_instance_scaling, :routing_config) SENSITIVE = [] include Aws::Structure end |
#variant_status ⇒ Array<Types::ProductionVariantStatus>
The endpoint variant status which describes the current deployment stage status or operational status.
45771 45772 45773 45774 45775 45776 45777 45778 45779 45780 45781 45782 45783 45784 45785 45786 45787 45788 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 45771 class PendingProductionVariantSummary < Struct.new( :variant_name, :deployed_images, :current_weight, :desired_weight, :current_instance_count, :desired_instance_count, :instance_type, :instance_pools, :accelerator_type, :variant_status, :current_serverless_config, :desired_serverless_config, :managed_instance_scaling, :routing_config) SENSITIVE = [] include Aws::Structure end |