Class: Aws::SageMaker::Types::PipelineExecution
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::PipelineExecution
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
An execution of a pipeline.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
-
#creation_time ⇒ Time
The creation time of the pipeline execution.
-
#failure_reason ⇒ String
If the execution failed, a message describing why.
-
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
-
#last_modified_time ⇒ Time
The time that the pipeline execution was last modified.
-
#parallelism_configuration ⇒ Types::ParallelismConfiguration
The parallelism configuration applied to the pipeline execution.
-
#pipeline_arn ⇒ String
The Amazon Resource Name (ARN) of the pipeline that was executed.
-
#pipeline_execution_arn ⇒ String
The Amazon Resource Name (ARN) of the pipeline execution.
-
#pipeline_execution_description ⇒ String
The description of the pipeline execution.
-
#pipeline_execution_display_name ⇒ String
The display name of the pipeline execution.
-
#pipeline_execution_status ⇒ String
The status of the pipeline status.
-
#pipeline_experiment_config ⇒ Types::PipelineExperimentConfig
Specifies the names of the experiment and trial created by a pipeline.
-
#pipeline_parameters ⇒ Array<Types::Parameter>
Contains a list of pipeline parameters.
-
#pipeline_version_display_name ⇒ String
The display name of the pipeline version that started this execution.
-
#pipeline_version_id ⇒ Integer
The ID of the pipeline version that started this execution.
-
#selective_execution_config ⇒ Types::SelectiveExecutionConfig
The selective execution configuration applied to the pipeline run.
Instance Attribute Details
#created_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
44981 44982 44983 44984 44985 44986 44987 44988 44989 44990 44991 44992 44993 44994 44995 44996 44997 44998 44999 45000 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44981 class PipelineExecution < Struct.new( :pipeline_arn, :pipeline_execution_arn, :pipeline_execution_display_name, :pipeline_execution_status, :pipeline_execution_description, :pipeline_experiment_config, :failure_reason, :creation_time, :last_modified_time, :created_by, :last_modified_by, :parallelism_configuration, :selective_execution_config, :pipeline_parameters, :pipeline_version_id, :pipeline_version_display_name) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The creation time of the pipeline execution.
44981 44982 44983 44984 44985 44986 44987 44988 44989 44990 44991 44992 44993 44994 44995 44996 44997 44998 44999 45000 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44981 class PipelineExecution < Struct.new( :pipeline_arn, :pipeline_execution_arn, :pipeline_execution_display_name, :pipeline_execution_status, :pipeline_execution_description, :pipeline_experiment_config, :failure_reason, :creation_time, :last_modified_time, :created_by, :last_modified_by, :parallelism_configuration, :selective_execution_config, :pipeline_parameters, :pipeline_version_id, :pipeline_version_display_name) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
If the execution failed, a message describing why.
44981 44982 44983 44984 44985 44986 44987 44988 44989 44990 44991 44992 44993 44994 44995 44996 44997 44998 44999 45000 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44981 class PipelineExecution < Struct.new( :pipeline_arn, :pipeline_execution_arn, :pipeline_execution_display_name, :pipeline_execution_status, :pipeline_execution_description, :pipeline_experiment_config, :failure_reason, :creation_time, :last_modified_time, :created_by, :last_modified_by, :parallelism_configuration, :selective_execution_config, :pipeline_parameters, :pipeline_version_id, :pipeline_version_display_name) SENSITIVE = [] include Aws::Structure end |
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
44981 44982 44983 44984 44985 44986 44987 44988 44989 44990 44991 44992 44993 44994 44995 44996 44997 44998 44999 45000 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44981 class PipelineExecution < Struct.new( :pipeline_arn, :pipeline_execution_arn, :pipeline_execution_display_name, :pipeline_execution_status, :pipeline_execution_description, :pipeline_experiment_config, :failure_reason, :creation_time, :last_modified_time, :created_by, :last_modified_by, :parallelism_configuration, :selective_execution_config, :pipeline_parameters, :pipeline_version_id, :pipeline_version_display_name) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The time that the pipeline execution was last modified.
44981 44982 44983 44984 44985 44986 44987 44988 44989 44990 44991 44992 44993 44994 44995 44996 44997 44998 44999 45000 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44981 class PipelineExecution < Struct.new( :pipeline_arn, :pipeline_execution_arn, :pipeline_execution_display_name, :pipeline_execution_status, :pipeline_execution_description, :pipeline_experiment_config, :failure_reason, :creation_time, :last_modified_time, :created_by, :last_modified_by, :parallelism_configuration, :selective_execution_config, :pipeline_parameters, :pipeline_version_id, :pipeline_version_display_name) SENSITIVE = [] include Aws::Structure end |
#parallelism_configuration ⇒ Types::ParallelismConfiguration
The parallelism configuration applied to the pipeline execution.
44981 44982 44983 44984 44985 44986 44987 44988 44989 44990 44991 44992 44993 44994 44995 44996 44997 44998 44999 45000 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44981 class PipelineExecution < Struct.new( :pipeline_arn, :pipeline_execution_arn, :pipeline_execution_display_name, :pipeline_execution_status, :pipeline_execution_description, :pipeline_experiment_config, :failure_reason, :creation_time, :last_modified_time, :created_by, :last_modified_by, :parallelism_configuration, :selective_execution_config, :pipeline_parameters, :pipeline_version_id, :pipeline_version_display_name) SENSITIVE = [] include Aws::Structure end |
#pipeline_arn ⇒ String
The Amazon Resource Name (ARN) of the pipeline that was executed.
44981 44982 44983 44984 44985 44986 44987 44988 44989 44990 44991 44992 44993 44994 44995 44996 44997 44998 44999 45000 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44981 class PipelineExecution < Struct.new( :pipeline_arn, :pipeline_execution_arn, :pipeline_execution_display_name, :pipeline_execution_status, :pipeline_execution_description, :pipeline_experiment_config, :failure_reason, :creation_time, :last_modified_time, :created_by, :last_modified_by, :parallelism_configuration, :selective_execution_config, :pipeline_parameters, :pipeline_version_id, :pipeline_version_display_name) SENSITIVE = [] include Aws::Structure end |
#pipeline_execution_arn ⇒ String
The Amazon Resource Name (ARN) of the pipeline execution.
44981 44982 44983 44984 44985 44986 44987 44988 44989 44990 44991 44992 44993 44994 44995 44996 44997 44998 44999 45000 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44981 class PipelineExecution < Struct.new( :pipeline_arn, :pipeline_execution_arn, :pipeline_execution_display_name, :pipeline_execution_status, :pipeline_execution_description, :pipeline_experiment_config, :failure_reason, :creation_time, :last_modified_time, :created_by, :last_modified_by, :parallelism_configuration, :selective_execution_config, :pipeline_parameters, :pipeline_version_id, :pipeline_version_display_name) SENSITIVE = [] include Aws::Structure end |
#pipeline_execution_description ⇒ String
The description of the pipeline execution.
44981 44982 44983 44984 44985 44986 44987 44988 44989 44990 44991 44992 44993 44994 44995 44996 44997 44998 44999 45000 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44981 class PipelineExecution < Struct.new( :pipeline_arn, :pipeline_execution_arn, :pipeline_execution_display_name, :pipeline_execution_status, :pipeline_execution_description, :pipeline_experiment_config, :failure_reason, :creation_time, :last_modified_time, :created_by, :last_modified_by, :parallelism_configuration, :selective_execution_config, :pipeline_parameters, :pipeline_version_id, :pipeline_version_display_name) SENSITIVE = [] include Aws::Structure end |
#pipeline_execution_display_name ⇒ String
The display name of the pipeline execution.
44981 44982 44983 44984 44985 44986 44987 44988 44989 44990 44991 44992 44993 44994 44995 44996 44997 44998 44999 45000 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44981 class PipelineExecution < Struct.new( :pipeline_arn, :pipeline_execution_arn, :pipeline_execution_display_name, :pipeline_execution_status, :pipeline_execution_description, :pipeline_experiment_config, :failure_reason, :creation_time, :last_modified_time, :created_by, :last_modified_by, :parallelism_configuration, :selective_execution_config, :pipeline_parameters, :pipeline_version_id, :pipeline_version_display_name) SENSITIVE = [] include Aws::Structure end |
#pipeline_execution_status ⇒ String
The status of the pipeline status.
44981 44982 44983 44984 44985 44986 44987 44988 44989 44990 44991 44992 44993 44994 44995 44996 44997 44998 44999 45000 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44981 class PipelineExecution < Struct.new( :pipeline_arn, :pipeline_execution_arn, :pipeline_execution_display_name, :pipeline_execution_status, :pipeline_execution_description, :pipeline_experiment_config, :failure_reason, :creation_time, :last_modified_time, :created_by, :last_modified_by, :parallelism_configuration, :selective_execution_config, :pipeline_parameters, :pipeline_version_id, :pipeline_version_display_name) SENSITIVE = [] include Aws::Structure end |
#pipeline_experiment_config ⇒ Types::PipelineExperimentConfig
Specifies the names of the experiment and trial created by a pipeline.
44981 44982 44983 44984 44985 44986 44987 44988 44989 44990 44991 44992 44993 44994 44995 44996 44997 44998 44999 45000 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44981 class PipelineExecution < Struct.new( :pipeline_arn, :pipeline_execution_arn, :pipeline_execution_display_name, :pipeline_execution_status, :pipeline_execution_description, :pipeline_experiment_config, :failure_reason, :creation_time, :last_modified_time, :created_by, :last_modified_by, :parallelism_configuration, :selective_execution_config, :pipeline_parameters, :pipeline_version_id, :pipeline_version_display_name) SENSITIVE = [] include Aws::Structure end |
#pipeline_parameters ⇒ Array<Types::Parameter>
Contains a list of pipeline parameters. This list can be empty.
44981 44982 44983 44984 44985 44986 44987 44988 44989 44990 44991 44992 44993 44994 44995 44996 44997 44998 44999 45000 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44981 class PipelineExecution < Struct.new( :pipeline_arn, :pipeline_execution_arn, :pipeline_execution_display_name, :pipeline_execution_status, :pipeline_execution_description, :pipeline_experiment_config, :failure_reason, :creation_time, :last_modified_time, :created_by, :last_modified_by, :parallelism_configuration, :selective_execution_config, :pipeline_parameters, :pipeline_version_id, :pipeline_version_display_name) SENSITIVE = [] include Aws::Structure end |
#pipeline_version_display_name ⇒ String
The display name of the pipeline version that started this execution.
44981 44982 44983 44984 44985 44986 44987 44988 44989 44990 44991 44992 44993 44994 44995 44996 44997 44998 44999 45000 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44981 class PipelineExecution < Struct.new( :pipeline_arn, :pipeline_execution_arn, :pipeline_execution_display_name, :pipeline_execution_status, :pipeline_execution_description, :pipeline_experiment_config, :failure_reason, :creation_time, :last_modified_time, :created_by, :last_modified_by, :parallelism_configuration, :selective_execution_config, :pipeline_parameters, :pipeline_version_id, :pipeline_version_display_name) SENSITIVE = [] include Aws::Structure end |
#pipeline_version_id ⇒ Integer
The ID of the pipeline version that started this execution.
44981 44982 44983 44984 44985 44986 44987 44988 44989 44990 44991 44992 44993 44994 44995 44996 44997 44998 44999 45000 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44981 class PipelineExecution < Struct.new( :pipeline_arn, :pipeline_execution_arn, :pipeline_execution_display_name, :pipeline_execution_status, :pipeline_execution_description, :pipeline_experiment_config, :failure_reason, :creation_time, :last_modified_time, :created_by, :last_modified_by, :parallelism_configuration, :selective_execution_config, :pipeline_parameters, :pipeline_version_id, :pipeline_version_display_name) SENSITIVE = [] include Aws::Structure end |
#selective_execution_config ⇒ Types::SelectiveExecutionConfig
The selective execution configuration applied to the pipeline run.
44981 44982 44983 44984 44985 44986 44987 44988 44989 44990 44991 44992 44993 44994 44995 44996 44997 44998 44999 45000 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44981 class PipelineExecution < Struct.new( :pipeline_arn, :pipeline_execution_arn, :pipeline_execution_display_name, :pipeline_execution_status, :pipeline_execution_description, :pipeline_experiment_config, :failure_reason, :creation_time, :last_modified_time, :created_by, :last_modified_by, :parallelism_configuration, :selective_execution_config, :pipeline_parameters, :pipeline_version_id, :pipeline_version_display_name) SENSITIVE = [] include Aws::Structure end |