Class: Aws::SageMaker::Types::PipelineExecutionStep

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

An execution of a step in a pipeline.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attempt_countInteger

The current attempt of the execution step. For more information, see Retry Policy for SageMaker Pipelines steps.

Returns:

  • (Integer)


45822
45823
45824
45825
45826
45827
45828
45829
45830
45831
45832
45833
45834
45835
45836
# File 'lib/aws-sdk-sagemaker/types.rb', line 45822

class PipelineExecutionStep < Struct.new(
  :step_name,
  :step_display_name,
  :step_description,
  :start_time,
  :end_time,
  :step_status,
  :cache_hit_result,
  :failure_reason,
  :metadata,
  :attempt_count,
  :selective_execution_result)
  SENSITIVE = []
  include Aws::Structure
end

#cache_hit_resultTypes::CacheHitResult

If this pipeline execution step was cached, details on the cache hit.



45822
45823
45824
45825
45826
45827
45828
45829
45830
45831
45832
45833
45834
45835
45836
# File 'lib/aws-sdk-sagemaker/types.rb', line 45822

class PipelineExecutionStep < Struct.new(
  :step_name,
  :step_display_name,
  :step_description,
  :start_time,
  :end_time,
  :step_status,
  :cache_hit_result,
  :failure_reason,
  :metadata,
  :attempt_count,
  :selective_execution_result)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

The time that the step stopped executing.

Returns:

  • (Time)


45822
45823
45824
45825
45826
45827
45828
45829
45830
45831
45832
45833
45834
45835
45836
# File 'lib/aws-sdk-sagemaker/types.rb', line 45822

class PipelineExecutionStep < Struct.new(
  :step_name,
  :step_display_name,
  :step_description,
  :start_time,
  :end_time,
  :step_status,
  :cache_hit_result,
  :failure_reason,
  :metadata,
  :attempt_count,
  :selective_execution_result)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

The reason why the step failed execution. This is only returned if the step failed its execution.

Returns:

  • (String)


45822
45823
45824
45825
45826
45827
45828
45829
45830
45831
45832
45833
45834
45835
45836
# File 'lib/aws-sdk-sagemaker/types.rb', line 45822

class PipelineExecutionStep < Struct.new(
  :step_name,
  :step_display_name,
  :step_description,
  :start_time,
  :end_time,
  :step_status,
  :cache_hit_result,
  :failure_reason,
  :metadata,
  :attempt_count,
  :selective_execution_result)
  SENSITIVE = []
  include Aws::Structure
end

#metadataTypes::PipelineExecutionStepMetadata

Metadata to run the pipeline step.



45822
45823
45824
45825
45826
45827
45828
45829
45830
45831
45832
45833
45834
45835
45836
# File 'lib/aws-sdk-sagemaker/types.rb', line 45822

class PipelineExecutionStep < Struct.new(
  :step_name,
  :step_display_name,
  :step_description,
  :start_time,
  :end_time,
  :step_status,
  :cache_hit_result,
  :failure_reason,
  :metadata,
  :attempt_count,
  :selective_execution_result)
  SENSITIVE = []
  include Aws::Structure
end

#selective_execution_resultTypes::SelectiveExecutionResult

The ARN from an execution of the current pipeline from which results are reused for this step.



45822
45823
45824
45825
45826
45827
45828
45829
45830
45831
45832
45833
45834
45835
45836
# File 'lib/aws-sdk-sagemaker/types.rb', line 45822

class PipelineExecutionStep < Struct.new(
  :step_name,
  :step_display_name,
  :step_description,
  :start_time,
  :end_time,
  :step_status,
  :cache_hit_result,
  :failure_reason,
  :metadata,
  :attempt_count,
  :selective_execution_result)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The time that the step started executing.

Returns:

  • (Time)


45822
45823
45824
45825
45826
45827
45828
45829
45830
45831
45832
45833
45834
45835
45836
# File 'lib/aws-sdk-sagemaker/types.rb', line 45822

class PipelineExecutionStep < Struct.new(
  :step_name,
  :step_display_name,
  :step_description,
  :start_time,
  :end_time,
  :step_status,
  :cache_hit_result,
  :failure_reason,
  :metadata,
  :attempt_count,
  :selective_execution_result)
  SENSITIVE = []
  include Aws::Structure
end

#step_descriptionString

The description of the step.

Returns:

  • (String)


45822
45823
45824
45825
45826
45827
45828
45829
45830
45831
45832
45833
45834
45835
45836
# File 'lib/aws-sdk-sagemaker/types.rb', line 45822

class PipelineExecutionStep < Struct.new(
  :step_name,
  :step_display_name,
  :step_description,
  :start_time,
  :end_time,
  :step_status,
  :cache_hit_result,
  :failure_reason,
  :metadata,
  :attempt_count,
  :selective_execution_result)
  SENSITIVE = []
  include Aws::Structure
end

#step_display_nameString

The display name of the step.

Returns:

  • (String)


45822
45823
45824
45825
45826
45827
45828
45829
45830
45831
45832
45833
45834
45835
45836
# File 'lib/aws-sdk-sagemaker/types.rb', line 45822

class PipelineExecutionStep < Struct.new(
  :step_name,
  :step_display_name,
  :step_description,
  :start_time,
  :end_time,
  :step_status,
  :cache_hit_result,
  :failure_reason,
  :metadata,
  :attempt_count,
  :selective_execution_result)
  SENSITIVE = []
  include Aws::Structure
end

#step_nameString

The name of the step that is executed.

Returns:

  • (String)


45822
45823
45824
45825
45826
45827
45828
45829
45830
45831
45832
45833
45834
45835
45836
# File 'lib/aws-sdk-sagemaker/types.rb', line 45822

class PipelineExecutionStep < Struct.new(
  :step_name,
  :step_display_name,
  :step_description,
  :start_time,
  :end_time,
  :step_status,
  :cache_hit_result,
  :failure_reason,
  :metadata,
  :attempt_count,
  :selective_execution_result)
  SENSITIVE = []
  include Aws::Structure
end

#step_statusString

The status of the step execution.

Returns:

  • (String)


45822
45823
45824
45825
45826
45827
45828
45829
45830
45831
45832
45833
45834
45835
45836
# File 'lib/aws-sdk-sagemaker/types.rb', line 45822

class PipelineExecutionStep < Struct.new(
  :step_name,
  :step_display_name,
  :step_description,
  :start_time,
  :end_time,
  :step_status,
  :cache_hit_result,
  :failure_reason,
  :metadata,
  :attempt_count,
  :selective_execution_result)
  SENSITIVE = []
  include Aws::Structure
end