Class: Aws::SageMaker::Types::PipelineExecutionStep
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::PipelineExecutionStep
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
An execution of a step in a pipeline.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attempt_count ⇒ Integer
The current attempt of the execution step.
-
#cache_hit_result ⇒ Types::CacheHitResult
If this pipeline execution step was cached, details on the cache hit.
-
#end_time ⇒ Time
The time that the step stopped executing.
-
#failure_reason ⇒ String
The reason why the step failed execution.
-
#metadata ⇒ Types::PipelineExecutionStepMetadata
Metadata to run the pipeline step.
-
#selective_execution_result ⇒ Types::SelectiveExecutionResult
The ARN from an execution of the current pipeline from which results are reused for this step.
-
#start_time ⇒ Time
The time that the step started executing.
-
#step_description ⇒ String
The description of the step.
-
#step_display_name ⇒ String
The display name of the step.
-
#step_name ⇒ String
The name of the step that is executed.
-
#step_status ⇒ String
The status of the step execution.
Instance Attribute Details
#attempt_count ⇒ Integer
The current attempt of the execution step. For more information, see [Retry Policy for SageMaker Pipelines steps].
[1]: docs.aws.amazon.com/sagemaker/latest/dg/pipelines-retry-policy.html
44482 44483 44484 44485 44486 44487 44488 44489 44490 44491 44492 44493 44494 44495 44496 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44482 class PipelineExecutionStep < Struct.new( :step_name, :step_display_name, :step_description, :start_time, :end_time, :step_status, :cache_hit_result, :failure_reason, :metadata, :attempt_count, :selective_execution_result) SENSITIVE = [] include Aws::Structure end |
#cache_hit_result ⇒ Types::CacheHitResult
If this pipeline execution step was cached, details on the cache hit.
44482 44483 44484 44485 44486 44487 44488 44489 44490 44491 44492 44493 44494 44495 44496 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44482 class PipelineExecutionStep < Struct.new( :step_name, :step_display_name, :step_description, :start_time, :end_time, :step_status, :cache_hit_result, :failure_reason, :metadata, :attempt_count, :selective_execution_result) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
The time that the step stopped executing.
44482 44483 44484 44485 44486 44487 44488 44489 44490 44491 44492 44493 44494 44495 44496 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44482 class PipelineExecutionStep < Struct.new( :step_name, :step_display_name, :step_description, :start_time, :end_time, :step_status, :cache_hit_result, :failure_reason, :metadata, :attempt_count, :selective_execution_result) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
The reason why the step failed execution. This is only returned if the step failed its execution.
44482 44483 44484 44485 44486 44487 44488 44489 44490 44491 44492 44493 44494 44495 44496 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44482 class PipelineExecutionStep < Struct.new( :step_name, :step_display_name, :step_description, :start_time, :end_time, :step_status, :cache_hit_result, :failure_reason, :metadata, :attempt_count, :selective_execution_result) SENSITIVE = [] include Aws::Structure end |
#metadata ⇒ Types::PipelineExecutionStepMetadata
Metadata to run the pipeline step.
44482 44483 44484 44485 44486 44487 44488 44489 44490 44491 44492 44493 44494 44495 44496 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44482 class PipelineExecutionStep < Struct.new( :step_name, :step_display_name, :step_description, :start_time, :end_time, :step_status, :cache_hit_result, :failure_reason, :metadata, :attempt_count, :selective_execution_result) SENSITIVE = [] include Aws::Structure end |
#selective_execution_result ⇒ Types::SelectiveExecutionResult
The ARN from an execution of the current pipeline from which results are reused for this step.
44482 44483 44484 44485 44486 44487 44488 44489 44490 44491 44492 44493 44494 44495 44496 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44482 class PipelineExecutionStep < Struct.new( :step_name, :step_display_name, :step_description, :start_time, :end_time, :step_status, :cache_hit_result, :failure_reason, :metadata, :attempt_count, :selective_execution_result) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The time that the step started executing.
44482 44483 44484 44485 44486 44487 44488 44489 44490 44491 44492 44493 44494 44495 44496 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44482 class PipelineExecutionStep < Struct.new( :step_name, :step_display_name, :step_description, :start_time, :end_time, :step_status, :cache_hit_result, :failure_reason, :metadata, :attempt_count, :selective_execution_result) SENSITIVE = [] include Aws::Structure end |
#step_description ⇒ String
The description of the step.
44482 44483 44484 44485 44486 44487 44488 44489 44490 44491 44492 44493 44494 44495 44496 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44482 class PipelineExecutionStep < Struct.new( :step_name, :step_display_name, :step_description, :start_time, :end_time, :step_status, :cache_hit_result, :failure_reason, :metadata, :attempt_count, :selective_execution_result) SENSITIVE = [] include Aws::Structure end |
#step_display_name ⇒ String
The display name of the step.
44482 44483 44484 44485 44486 44487 44488 44489 44490 44491 44492 44493 44494 44495 44496 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44482 class PipelineExecutionStep < Struct.new( :step_name, :step_display_name, :step_description, :start_time, :end_time, :step_status, :cache_hit_result, :failure_reason, :metadata, :attempt_count, :selective_execution_result) SENSITIVE = [] include Aws::Structure end |
#step_name ⇒ String
The name of the step that is executed.
44482 44483 44484 44485 44486 44487 44488 44489 44490 44491 44492 44493 44494 44495 44496 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44482 class PipelineExecutionStep < Struct.new( :step_name, :step_display_name, :step_description, :start_time, :end_time, :step_status, :cache_hit_result, :failure_reason, :metadata, :attempt_count, :selective_execution_result) SENSITIVE = [] include Aws::Structure end |
#step_status ⇒ String
The status of the step execution.
44482 44483 44484 44485 44486 44487 44488 44489 44490 44491 44492 44493 44494 44495 44496 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44482 class PipelineExecutionStep < Struct.new( :step_name, :step_display_name, :step_description, :start_time, :end_time, :step_status, :cache_hit_result, :failure_reason, :metadata, :attempt_count, :selective_execution_result) SENSITIVE = [] include Aws::Structure end |