Class: Aws::SageMaker::Types::PipelineExecutionStep

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

An execution of a step in a pipeline.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attempt_countInteger

The current attempt of the execution step. For more information, see [Retry Policy for SageMaker Pipelines steps].

[1]: docs.aws.amazon.com/sagemaker/latest/dg/pipelines-retry-policy.html

Returns:

  • (Integer)


44398
44399
44400
44401
44402
44403
44404
44405
44406
44407
44408
44409
44410
44411
44412
# File 'lib/aws-sdk-sagemaker/types.rb', line 44398

class PipelineExecutionStep < Struct.new(
  :step_name,
  :step_display_name,
  :step_description,
  :start_time,
  :end_time,
  :step_status,
  :cache_hit_result,
  :failure_reason,
  :metadata,
  :attempt_count,
  :selective_execution_result)
  SENSITIVE = []
  include Aws::Structure
end

#cache_hit_resultTypes::CacheHitResult

If this pipeline execution step was cached, details on the cache hit.



44398
44399
44400
44401
44402
44403
44404
44405
44406
44407
44408
44409
44410
44411
44412
# File 'lib/aws-sdk-sagemaker/types.rb', line 44398

class PipelineExecutionStep < Struct.new(
  :step_name,
  :step_display_name,
  :step_description,
  :start_time,
  :end_time,
  :step_status,
  :cache_hit_result,
  :failure_reason,
  :metadata,
  :attempt_count,
  :selective_execution_result)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

The time that the step stopped executing.

Returns:

  • (Time)


44398
44399
44400
44401
44402
44403
44404
44405
44406
44407
44408
44409
44410
44411
44412
# File 'lib/aws-sdk-sagemaker/types.rb', line 44398

class PipelineExecutionStep < Struct.new(
  :step_name,
  :step_display_name,
  :step_description,
  :start_time,
  :end_time,
  :step_status,
  :cache_hit_result,
  :failure_reason,
  :metadata,
  :attempt_count,
  :selective_execution_result)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

The reason why the step failed execution. This is only returned if the step failed its execution.

Returns:

  • (String)


44398
44399
44400
44401
44402
44403
44404
44405
44406
44407
44408
44409
44410
44411
44412
# File 'lib/aws-sdk-sagemaker/types.rb', line 44398

class PipelineExecutionStep < Struct.new(
  :step_name,
  :step_display_name,
  :step_description,
  :start_time,
  :end_time,
  :step_status,
  :cache_hit_result,
  :failure_reason,
  :metadata,
  :attempt_count,
  :selective_execution_result)
  SENSITIVE = []
  include Aws::Structure
end

#metadataTypes::PipelineExecutionStepMetadata

Metadata to run the pipeline step.



44398
44399
44400
44401
44402
44403
44404
44405
44406
44407
44408
44409
44410
44411
44412
# File 'lib/aws-sdk-sagemaker/types.rb', line 44398

class PipelineExecutionStep < Struct.new(
  :step_name,
  :step_display_name,
  :step_description,
  :start_time,
  :end_time,
  :step_status,
  :cache_hit_result,
  :failure_reason,
  :metadata,
  :attempt_count,
  :selective_execution_result)
  SENSITIVE = []
  include Aws::Structure
end

#selective_execution_resultTypes::SelectiveExecutionResult

The ARN from an execution of the current pipeline from which results are reused for this step.



44398
44399
44400
44401
44402
44403
44404
44405
44406
44407
44408
44409
44410
44411
44412
# File 'lib/aws-sdk-sagemaker/types.rb', line 44398

class PipelineExecutionStep < Struct.new(
  :step_name,
  :step_display_name,
  :step_description,
  :start_time,
  :end_time,
  :step_status,
  :cache_hit_result,
  :failure_reason,
  :metadata,
  :attempt_count,
  :selective_execution_result)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The time that the step started executing.

Returns:

  • (Time)


44398
44399
44400
44401
44402
44403
44404
44405
44406
44407
44408
44409
44410
44411
44412
# File 'lib/aws-sdk-sagemaker/types.rb', line 44398

class PipelineExecutionStep < Struct.new(
  :step_name,
  :step_display_name,
  :step_description,
  :start_time,
  :end_time,
  :step_status,
  :cache_hit_result,
  :failure_reason,
  :metadata,
  :attempt_count,
  :selective_execution_result)
  SENSITIVE = []
  include Aws::Structure
end

#step_descriptionString

The description of the step.

Returns:

  • (String)


44398
44399
44400
44401
44402
44403
44404
44405
44406
44407
44408
44409
44410
44411
44412
# File 'lib/aws-sdk-sagemaker/types.rb', line 44398

class PipelineExecutionStep < Struct.new(
  :step_name,
  :step_display_name,
  :step_description,
  :start_time,
  :end_time,
  :step_status,
  :cache_hit_result,
  :failure_reason,
  :metadata,
  :attempt_count,
  :selective_execution_result)
  SENSITIVE = []
  include Aws::Structure
end

#step_display_nameString

The display name of the step.

Returns:

  • (String)


44398
44399
44400
44401
44402
44403
44404
44405
44406
44407
44408
44409
44410
44411
44412
# File 'lib/aws-sdk-sagemaker/types.rb', line 44398

class PipelineExecutionStep < Struct.new(
  :step_name,
  :step_display_name,
  :step_description,
  :start_time,
  :end_time,
  :step_status,
  :cache_hit_result,
  :failure_reason,
  :metadata,
  :attempt_count,
  :selective_execution_result)
  SENSITIVE = []
  include Aws::Structure
end

#step_nameString

The name of the step that is executed.

Returns:

  • (String)


44398
44399
44400
44401
44402
44403
44404
44405
44406
44407
44408
44409
44410
44411
44412
# File 'lib/aws-sdk-sagemaker/types.rb', line 44398

class PipelineExecutionStep < Struct.new(
  :step_name,
  :step_display_name,
  :step_description,
  :start_time,
  :end_time,
  :step_status,
  :cache_hit_result,
  :failure_reason,
  :metadata,
  :attempt_count,
  :selective_execution_result)
  SENSITIVE = []
  include Aws::Structure
end

#step_statusString

The status of the step execution.

Returns:

  • (String)


44398
44399
44400
44401
44402
44403
44404
44405
44406
44407
44408
44409
44410
44411
44412
# File 'lib/aws-sdk-sagemaker/types.rb', line 44398

class PipelineExecutionStep < Struct.new(
  :step_name,
  :step_display_name,
  :step_description,
  :start_time,
  :end_time,
  :step_status,
  :cache_hit_result,
  :failure_reason,
  :metadata,
  :attempt_count,
  :selective_execution_result)
  SENSITIVE = []
  include Aws::Structure
end