Class: Aws::SageMaker::Types::PipelineExecutionStepMetadata

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Metadata for a step execution.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_ml_jobTypes::AutoMLJobStepMetadata

The Amazon Resource Name (ARN) of the AutoML job that was run by this step.



45723
45724
45725
45726
45727
45728
45729
45730
45731
45732
45733
45734
45735
45736
45737
45738
45739
45740
45741
45742
45743
45744
45745
45746
45747
45748
45749
# File 'lib/aws-sdk-sagemaker/types.rb', line 45723

class PipelineExecutionStepMetadata < Struct.new(
  :training_job,
  :processing_job,
  :transform_job,
  :tuning_job,
  :model,
  :register_model,
  :condition,
  :callback,
  :lambda,
  :emr,
  :quality_check,
  :clarify_check,
  :fail,
  :auto_ml_job,
  :endpoint,
  :endpoint_config,
  :bedrock_custom_model,
  :bedrock_custom_model_deployment,
  :bedrock_provisioned_model_throughput,
  :bedrock_model_import,
  :inference_component,
  :lineage,
  :job)
  SENSITIVE = []
  include Aws::Structure
end

#bedrock_custom_modelTypes::BedrockCustomModelMetadata

The metadata of the Amazon Bedrock custom model used in the pipeline execution step.



45723
45724
45725
45726
45727
45728
45729
45730
45731
45732
45733
45734
45735
45736
45737
45738
45739
45740
45741
45742
45743
45744
45745
45746
45747
45748
45749
# File 'lib/aws-sdk-sagemaker/types.rb', line 45723

class PipelineExecutionStepMetadata < Struct.new(
  :training_job,
  :processing_job,
  :transform_job,
  :tuning_job,
  :model,
  :register_model,
  :condition,
  :callback,
  :lambda,
  :emr,
  :quality_check,
  :clarify_check,
  :fail,
  :auto_ml_job,
  :endpoint,
  :endpoint_config,
  :bedrock_custom_model,
  :bedrock_custom_model_deployment,
  :bedrock_provisioned_model_throughput,
  :bedrock_model_import,
  :inference_component,
  :lineage,
  :job)
  SENSITIVE = []
  include Aws::Structure
end

#bedrock_custom_model_deploymentTypes::BedrockCustomModelDeploymentMetadata

The metadata of the Amazon Bedrock custom model deployment used in pipeline execution step.



45723
45724
45725
45726
45727
45728
45729
45730
45731
45732
45733
45734
45735
45736
45737
45738
45739
45740
45741
45742
45743
45744
45745
45746
45747
45748
45749
# File 'lib/aws-sdk-sagemaker/types.rb', line 45723

class PipelineExecutionStepMetadata < Struct.new(
  :training_job,
  :processing_job,
  :transform_job,
  :tuning_job,
  :model,
  :register_model,
  :condition,
  :callback,
  :lambda,
  :emr,
  :quality_check,
  :clarify_check,
  :fail,
  :auto_ml_job,
  :endpoint,
  :endpoint_config,
  :bedrock_custom_model,
  :bedrock_custom_model_deployment,
  :bedrock_provisioned_model_throughput,
  :bedrock_model_import,
  :inference_component,
  :lineage,
  :job)
  SENSITIVE = []
  include Aws::Structure
end

#bedrock_model_importTypes::BedrockModelImportMetadata

The metadata of Amazon Bedrock model import used in pipeline execution step.



45723
45724
45725
45726
45727
45728
45729
45730
45731
45732
45733
45734
45735
45736
45737
45738
45739
45740
45741
45742
45743
45744
45745
45746
45747
45748
45749
# File 'lib/aws-sdk-sagemaker/types.rb', line 45723

class PipelineExecutionStepMetadata < Struct.new(
  :training_job,
  :processing_job,
  :transform_job,
  :tuning_job,
  :model,
  :register_model,
  :condition,
  :callback,
  :lambda,
  :emr,
  :quality_check,
  :clarify_check,
  :fail,
  :auto_ml_job,
  :endpoint,
  :endpoint_config,
  :bedrock_custom_model,
  :bedrock_custom_model_deployment,
  :bedrock_provisioned_model_throughput,
  :bedrock_model_import,
  :inference_component,
  :lineage,
  :job)
  SENSITIVE = []
  include Aws::Structure
end

#bedrock_provisioned_model_throughputTypes::BedrockProvisionedModelThroughputMetadata

The metadata of the Amazon Bedrock provisioned model throughput used in the pipeline execution step.



45723
45724
45725
45726
45727
45728
45729
45730
45731
45732
45733
45734
45735
45736
45737
45738
45739
45740
45741
45742
45743
45744
45745
45746
45747
45748
45749
# File 'lib/aws-sdk-sagemaker/types.rb', line 45723

class PipelineExecutionStepMetadata < Struct.new(
  :training_job,
  :processing_job,
  :transform_job,
  :tuning_job,
  :model,
  :register_model,
  :condition,
  :callback,
  :lambda,
  :emr,
  :quality_check,
  :clarify_check,
  :fail,
  :auto_ml_job,
  :endpoint,
  :endpoint_config,
  :bedrock_custom_model,
  :bedrock_custom_model_deployment,
  :bedrock_provisioned_model_throughput,
  :bedrock_model_import,
  :inference_component,
  :lineage,
  :job)
  SENSITIVE = []
  include Aws::Structure
end

#callbackTypes::CallbackStepMetadata

The URL of the Amazon SQS queue used by this step execution, the pipeline generated token, and a list of output parameters.



45723
45724
45725
45726
45727
45728
45729
45730
45731
45732
45733
45734
45735
45736
45737
45738
45739
45740
45741
45742
45743
45744
45745
45746
45747
45748
45749
# File 'lib/aws-sdk-sagemaker/types.rb', line 45723

class PipelineExecutionStepMetadata < Struct.new(
  :training_job,
  :processing_job,
  :transform_job,
  :tuning_job,
  :model,
  :register_model,
  :condition,
  :callback,
  :lambda,
  :emr,
  :quality_check,
  :clarify_check,
  :fail,
  :auto_ml_job,
  :endpoint,
  :endpoint_config,
  :bedrock_custom_model,
  :bedrock_custom_model_deployment,
  :bedrock_provisioned_model_throughput,
  :bedrock_model_import,
  :inference_component,
  :lineage,
  :job)
  SENSITIVE = []
  include Aws::Structure
end

#clarify_checkTypes::ClarifyCheckStepMetadata

Container for the metadata for a Clarify check step. The configurations and outcomes of the check step execution. This includes:

  • The type of the check conducted,

  • The Amazon S3 URIs of baseline constraints and statistics files to be used for the drift check.

  • The Amazon S3 URIs of newly calculated baseline constraints and statistics.

  • The model package group name provided.

  • The Amazon S3 URI of the violation report if violations detected.

  • The Amazon Resource Name (ARN) of check processing job initiated by the step execution.

  • The boolean flags indicating if the drift check is skipped.

  • If step property ‘BaselineUsedForDriftCheck` is set the same as `CalculatedBaseline`.



45723
45724
45725
45726
45727
45728
45729
45730
45731
45732
45733
45734
45735
45736
45737
45738
45739
45740
45741
45742
45743
45744
45745
45746
45747
45748
45749
# File 'lib/aws-sdk-sagemaker/types.rb', line 45723

class PipelineExecutionStepMetadata < Struct.new(
  :training_job,
  :processing_job,
  :transform_job,
  :tuning_job,
  :model,
  :register_model,
  :condition,
  :callback,
  :lambda,
  :emr,
  :quality_check,
  :clarify_check,
  :fail,
  :auto_ml_job,
  :endpoint,
  :endpoint_config,
  :bedrock_custom_model,
  :bedrock_custom_model_deployment,
  :bedrock_provisioned_model_throughput,
  :bedrock_model_import,
  :inference_component,
  :lineage,
  :job)
  SENSITIVE = []
  include Aws::Structure
end

#conditionTypes::ConditionStepMetadata

The outcome of the condition evaluation that was run by this step execution.



45723
45724
45725
45726
45727
45728
45729
45730
45731
45732
45733
45734
45735
45736
45737
45738
45739
45740
45741
45742
45743
45744
45745
45746
45747
45748
45749
# File 'lib/aws-sdk-sagemaker/types.rb', line 45723

class PipelineExecutionStepMetadata < Struct.new(
  :training_job,
  :processing_job,
  :transform_job,
  :tuning_job,
  :model,
  :register_model,
  :condition,
  :callback,
  :lambda,
  :emr,
  :quality_check,
  :clarify_check,
  :fail,
  :auto_ml_job,
  :endpoint,
  :endpoint_config,
  :bedrock_custom_model,
  :bedrock_custom_model_deployment,
  :bedrock_provisioned_model_throughput,
  :bedrock_model_import,
  :inference_component,
  :lineage,
  :job)
  SENSITIVE = []
  include Aws::Structure
end

#emrTypes::EMRStepMetadata

The configurations and outcomes of an Amazon EMR step execution.



45723
45724
45725
45726
45727
45728
45729
45730
45731
45732
45733
45734
45735
45736
45737
45738
45739
45740
45741
45742
45743
45744
45745
45746
45747
45748
45749
# File 'lib/aws-sdk-sagemaker/types.rb', line 45723

class PipelineExecutionStepMetadata < Struct.new(
  :training_job,
  :processing_job,
  :transform_job,
  :tuning_job,
  :model,
  :register_model,
  :condition,
  :callback,
  :lambda,
  :emr,
  :quality_check,
  :clarify_check,
  :fail,
  :auto_ml_job,
  :endpoint,
  :endpoint_config,
  :bedrock_custom_model,
  :bedrock_custom_model_deployment,
  :bedrock_provisioned_model_throughput,
  :bedrock_model_import,
  :inference_component,
  :lineage,
  :job)
  SENSITIVE = []
  include Aws::Structure
end

#endpointTypes::EndpointStepMetadata

The endpoint that was invoked during this step execution.



45723
45724
45725
45726
45727
45728
45729
45730
45731
45732
45733
45734
45735
45736
45737
45738
45739
45740
45741
45742
45743
45744
45745
45746
45747
45748
45749
# File 'lib/aws-sdk-sagemaker/types.rb', line 45723

class PipelineExecutionStepMetadata < Struct.new(
  :training_job,
  :processing_job,
  :transform_job,
  :tuning_job,
  :model,
  :register_model,
  :condition,
  :callback,
  :lambda,
  :emr,
  :quality_check,
  :clarify_check,
  :fail,
  :auto_ml_job,
  :endpoint,
  :endpoint_config,
  :bedrock_custom_model,
  :bedrock_custom_model_deployment,
  :bedrock_provisioned_model_throughput,
  :bedrock_model_import,
  :inference_component,
  :lineage,
  :job)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_configTypes::EndpointConfigStepMetadata

The endpoint configuration used to create an endpoint during this step execution.



45723
45724
45725
45726
45727
45728
45729
45730
45731
45732
45733
45734
45735
45736
45737
45738
45739
45740
45741
45742
45743
45744
45745
45746
45747
45748
45749
# File 'lib/aws-sdk-sagemaker/types.rb', line 45723

class PipelineExecutionStepMetadata < Struct.new(
  :training_job,
  :processing_job,
  :transform_job,
  :tuning_job,
  :model,
  :register_model,
  :condition,
  :callback,
  :lambda,
  :emr,
  :quality_check,
  :clarify_check,
  :fail,
  :auto_ml_job,
  :endpoint,
  :endpoint_config,
  :bedrock_custom_model,
  :bedrock_custom_model_deployment,
  :bedrock_provisioned_model_throughput,
  :bedrock_model_import,
  :inference_component,
  :lineage,
  :job)
  SENSITIVE = []
  include Aws::Structure
end

#failTypes::FailStepMetadata

The configurations and outcomes of a Fail step execution.



45723
45724
45725
45726
45727
45728
45729
45730
45731
45732
45733
45734
45735
45736
45737
45738
45739
45740
45741
45742
45743
45744
45745
45746
45747
45748
45749
# File 'lib/aws-sdk-sagemaker/types.rb', line 45723

class PipelineExecutionStepMetadata < Struct.new(
  :training_job,
  :processing_job,
  :transform_job,
  :tuning_job,
  :model,
  :register_model,
  :condition,
  :callback,
  :lambda,
  :emr,
  :quality_check,
  :clarify_check,
  :fail,
  :auto_ml_job,
  :endpoint,
  :endpoint_config,
  :bedrock_custom_model,
  :bedrock_custom_model_deployment,
  :bedrock_provisioned_model_throughput,
  :bedrock_model_import,
  :inference_component,
  :lineage,
  :job)
  SENSITIVE = []
  include Aws::Structure
end

#inference_componentTypes::InferenceComponentMetadata

The metadata of the inference component used in pipeline execution step.



45723
45724
45725
45726
45727
45728
45729
45730
45731
45732
45733
45734
45735
45736
45737
45738
45739
45740
45741
45742
45743
45744
45745
45746
45747
45748
45749
# File 'lib/aws-sdk-sagemaker/types.rb', line 45723

class PipelineExecutionStepMetadata < Struct.new(
  :training_job,
  :processing_job,
  :transform_job,
  :tuning_job,
  :model,
  :register_model,
  :condition,
  :callback,
  :lambda,
  :emr,
  :quality_check,
  :clarify_check,
  :fail,
  :auto_ml_job,
  :endpoint,
  :endpoint_config,
  :bedrock_custom_model,
  :bedrock_custom_model_deployment,
  :bedrock_provisioned_model_throughput,
  :bedrock_model_import,
  :inference_component,
  :lineage,
  :job)
  SENSITIVE = []
  include Aws::Structure
end

#jobTypes::JobStepMetadata

The metadata for a SageMaker job used in a pipeline execution step.



45723
45724
45725
45726
45727
45728
45729
45730
45731
45732
45733
45734
45735
45736
45737
45738
45739
45740
45741
45742
45743
45744
45745
45746
45747
45748
45749
# File 'lib/aws-sdk-sagemaker/types.rb', line 45723

class PipelineExecutionStepMetadata < Struct.new(
  :training_job,
  :processing_job,
  :transform_job,
  :tuning_job,
  :model,
  :register_model,
  :condition,
  :callback,
  :lambda,
  :emr,
  :quality_check,
  :clarify_check,
  :fail,
  :auto_ml_job,
  :endpoint,
  :endpoint_config,
  :bedrock_custom_model,
  :bedrock_custom_model_deployment,
  :bedrock_provisioned_model_throughput,
  :bedrock_model_import,
  :inference_component,
  :lineage,
  :job)
  SENSITIVE = []
  include Aws::Structure
end

#lambdaTypes::LambdaStepMetadata

The Amazon Resource Name (ARN) of the Lambda function that was run by this step execution and a list of output parameters.



45723
45724
45725
45726
45727
45728
45729
45730
45731
45732
45733
45734
45735
45736
45737
45738
45739
45740
45741
45742
45743
45744
45745
45746
45747
45748
45749
# File 'lib/aws-sdk-sagemaker/types.rb', line 45723

class PipelineExecutionStepMetadata < Struct.new(
  :training_job,
  :processing_job,
  :transform_job,
  :tuning_job,
  :model,
  :register_model,
  :condition,
  :callback,
  :lambda,
  :emr,
  :quality_check,
  :clarify_check,
  :fail,
  :auto_ml_job,
  :endpoint,
  :endpoint_config,
  :bedrock_custom_model,
  :bedrock_custom_model_deployment,
  :bedrock_provisioned_model_throughput,
  :bedrock_model_import,
  :inference_component,
  :lineage,
  :job)
  SENSITIVE = []
  include Aws::Structure
end

#lineageTypes::LineageMetadata

The metadata of the lineage used in pipeline execution step.



45723
45724
45725
45726
45727
45728
45729
45730
45731
45732
45733
45734
45735
45736
45737
45738
45739
45740
45741
45742
45743
45744
45745
45746
45747
45748
45749
# File 'lib/aws-sdk-sagemaker/types.rb', line 45723

class PipelineExecutionStepMetadata < Struct.new(
  :training_job,
  :processing_job,
  :transform_job,
  :tuning_job,
  :model,
  :register_model,
  :condition,
  :callback,
  :lambda,
  :emr,
  :quality_check,
  :clarify_check,
  :fail,
  :auto_ml_job,
  :endpoint,
  :endpoint_config,
  :bedrock_custom_model,
  :bedrock_custom_model_deployment,
  :bedrock_provisioned_model_throughput,
  :bedrock_model_import,
  :inference_component,
  :lineage,
  :job)
  SENSITIVE = []
  include Aws::Structure
end

#modelTypes::ModelStepMetadata

The Amazon Resource Name (ARN) of the model that was created by this step execution.



45723
45724
45725
45726
45727
45728
45729
45730
45731
45732
45733
45734
45735
45736
45737
45738
45739
45740
45741
45742
45743
45744
45745
45746
45747
45748
45749
# File 'lib/aws-sdk-sagemaker/types.rb', line 45723

class PipelineExecutionStepMetadata < Struct.new(
  :training_job,
  :processing_job,
  :transform_job,
  :tuning_job,
  :model,
  :register_model,
  :condition,
  :callback,
  :lambda,
  :emr,
  :quality_check,
  :clarify_check,
  :fail,
  :auto_ml_job,
  :endpoint,
  :endpoint_config,
  :bedrock_custom_model,
  :bedrock_custom_model_deployment,
  :bedrock_provisioned_model_throughput,
  :bedrock_model_import,
  :inference_component,
  :lineage,
  :job)
  SENSITIVE = []
  include Aws::Structure
end

#processing_jobTypes::ProcessingJobStepMetadata

The Amazon Resource Name (ARN) of the processing job that was run by this step execution.



45723
45724
45725
45726
45727
45728
45729
45730
45731
45732
45733
45734
45735
45736
45737
45738
45739
45740
45741
45742
45743
45744
45745
45746
45747
45748
45749
# File 'lib/aws-sdk-sagemaker/types.rb', line 45723

class PipelineExecutionStepMetadata < Struct.new(
  :training_job,
  :processing_job,
  :transform_job,
  :tuning_job,
  :model,
  :register_model,
  :condition,
  :callback,
  :lambda,
  :emr,
  :quality_check,
  :clarify_check,
  :fail,
  :auto_ml_job,
  :endpoint,
  :endpoint_config,
  :bedrock_custom_model,
  :bedrock_custom_model_deployment,
  :bedrock_provisioned_model_throughput,
  :bedrock_model_import,
  :inference_component,
  :lineage,
  :job)
  SENSITIVE = []
  include Aws::Structure
end

#quality_checkTypes::QualityCheckStepMetadata

The configurations and outcomes of the check step execution. This includes:

  • The type of the check conducted.

  • The Amazon S3 URIs of baseline constraints and statistics files to be used for the drift check.

  • The Amazon S3 URIs of newly calculated baseline constraints and statistics.

  • The model package group name provided.

  • The Amazon S3 URI of the violation report if violations detected.

  • The Amazon Resource Name (ARN) of check processing job initiated by the step execution.

  • The Boolean flags indicating if the drift check is skipped.

  • If step property ‘BaselineUsedForDriftCheck` is set the same as `CalculatedBaseline`.



45723
45724
45725
45726
45727
45728
45729
45730
45731
45732
45733
45734
45735
45736
45737
45738
45739
45740
45741
45742
45743
45744
45745
45746
45747
45748
45749
# File 'lib/aws-sdk-sagemaker/types.rb', line 45723

class PipelineExecutionStepMetadata < Struct.new(
  :training_job,
  :processing_job,
  :transform_job,
  :tuning_job,
  :model,
  :register_model,
  :condition,
  :callback,
  :lambda,
  :emr,
  :quality_check,
  :clarify_check,
  :fail,
  :auto_ml_job,
  :endpoint,
  :endpoint_config,
  :bedrock_custom_model,
  :bedrock_custom_model_deployment,
  :bedrock_provisioned_model_throughput,
  :bedrock_model_import,
  :inference_component,
  :lineage,
  :job)
  SENSITIVE = []
  include Aws::Structure
end

#register_modelTypes::RegisterModelStepMetadata

The Amazon Resource Name (ARN) of the model package that the model was registered to by this step execution.



45723
45724
45725
45726
45727
45728
45729
45730
45731
45732
45733
45734
45735
45736
45737
45738
45739
45740
45741
45742
45743
45744
45745
45746
45747
45748
45749
# File 'lib/aws-sdk-sagemaker/types.rb', line 45723

class PipelineExecutionStepMetadata < Struct.new(
  :training_job,
  :processing_job,
  :transform_job,
  :tuning_job,
  :model,
  :register_model,
  :condition,
  :callback,
  :lambda,
  :emr,
  :quality_check,
  :clarify_check,
  :fail,
  :auto_ml_job,
  :endpoint,
  :endpoint_config,
  :bedrock_custom_model,
  :bedrock_custom_model_deployment,
  :bedrock_provisioned_model_throughput,
  :bedrock_model_import,
  :inference_component,
  :lineage,
  :job)
  SENSITIVE = []
  include Aws::Structure
end

#training_jobTypes::TrainingJobStepMetadata

The Amazon Resource Name (ARN) of the training job that was run by this step execution.



45723
45724
45725
45726
45727
45728
45729
45730
45731
45732
45733
45734
45735
45736
45737
45738
45739
45740
45741
45742
45743
45744
45745
45746
45747
45748
45749
# File 'lib/aws-sdk-sagemaker/types.rb', line 45723

class PipelineExecutionStepMetadata < Struct.new(
  :training_job,
  :processing_job,
  :transform_job,
  :tuning_job,
  :model,
  :register_model,
  :condition,
  :callback,
  :lambda,
  :emr,
  :quality_check,
  :clarify_check,
  :fail,
  :auto_ml_job,
  :endpoint,
  :endpoint_config,
  :bedrock_custom_model,
  :bedrock_custom_model_deployment,
  :bedrock_provisioned_model_throughput,
  :bedrock_model_import,
  :inference_component,
  :lineage,
  :job)
  SENSITIVE = []
  include Aws::Structure
end

#transform_jobTypes::TransformJobStepMetadata

The Amazon Resource Name (ARN) of the transform job that was run by this step execution.



45723
45724
45725
45726
45727
45728
45729
45730
45731
45732
45733
45734
45735
45736
45737
45738
45739
45740
45741
45742
45743
45744
45745
45746
45747
45748
45749
# File 'lib/aws-sdk-sagemaker/types.rb', line 45723

class PipelineExecutionStepMetadata < Struct.new(
  :training_job,
  :processing_job,
  :transform_job,
  :tuning_job,
  :model,
  :register_model,
  :condition,
  :callback,
  :lambda,
  :emr,
  :quality_check,
  :clarify_check,
  :fail,
  :auto_ml_job,
  :endpoint,
  :endpoint_config,
  :bedrock_custom_model,
  :bedrock_custom_model_deployment,
  :bedrock_provisioned_model_throughput,
  :bedrock_model_import,
  :inference_component,
  :lineage,
  :job)
  SENSITIVE = []
  include Aws::Structure
end

#tuning_jobTypes::TuningJobStepMetaData

The Amazon Resource Name (ARN) of the tuning job that was run by this step execution.



45723
45724
45725
45726
45727
45728
45729
45730
45731
45732
45733
45734
45735
45736
45737
45738
45739
45740
45741
45742
45743
45744
45745
45746
45747
45748
45749
# File 'lib/aws-sdk-sagemaker/types.rb', line 45723

class PipelineExecutionStepMetadata < Struct.new(
  :training_job,
  :processing_job,
  :transform_job,
  :tuning_job,
  :model,
  :register_model,
  :condition,
  :callback,
  :lambda,
  :emr,
  :quality_check,
  :clarify_check,
  :fail,
  :auto_ml_job,
  :endpoint,
  :endpoint_config,
  :bedrock_custom_model,
  :bedrock_custom_model_deployment,
  :bedrock_provisioned_model_throughput,
  :bedrock_model_import,
  :inference_component,
  :lineage,
  :job)
  SENSITIVE = []
  include Aws::Structure
end