Class: Aws::SageMaker::Types::PipelineExecutionStepMetadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::PipelineExecutionStepMetadata
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Metadata for a step execution.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_ml_job ⇒ Types::AutoMLJobStepMetadata
The Amazon Resource Name (ARN) of the AutoML job that was run by this step.
-
#bedrock_custom_model ⇒ Types::BedrockCustomModelMetadata
The metadata of the Amazon Bedrock custom model used in the pipeline execution step.
-
#bedrock_custom_model_deployment ⇒ Types::BedrockCustomModelDeploymentMetadata
The metadata of the Amazon Bedrock custom model deployment used in pipeline execution step.
-
#bedrock_model_import ⇒ Types::BedrockModelImportMetadata
The metadata of Amazon Bedrock model import used in pipeline execution step.
-
#bedrock_provisioned_model_throughput ⇒ Types::BedrockProvisionedModelThroughputMetadata
The metadata of the Amazon Bedrock provisioned model throughput used in the pipeline execution step.
-
#callback ⇒ Types::CallbackStepMetadata
The URL of the Amazon SQS queue used by this step execution, the pipeline generated token, and a list of output parameters.
-
#clarify_check ⇒ Types::ClarifyCheckStepMetadata
Container for the metadata for a Clarify check step.
-
#condition ⇒ Types::ConditionStepMetadata
The outcome of the condition evaluation that was run by this step execution.
-
#emr ⇒ Types::EMRStepMetadata
The configurations and outcomes of an Amazon EMR step execution.
-
#endpoint ⇒ Types::EndpointStepMetadata
The endpoint that was invoked during this step execution.
-
#endpoint_config ⇒ Types::EndpointConfigStepMetadata
The endpoint configuration used to create an endpoint during this step execution.
-
#fail ⇒ Types::FailStepMetadata
The configurations and outcomes of a Fail step execution.
-
#inference_component ⇒ Types::InferenceComponentMetadata
The metadata of the inference component used in pipeline execution step.
-
#lambda ⇒ Types::LambdaStepMetadata
The Amazon Resource Name (ARN) of the Lambda function that was run by this step execution and a list of output parameters.
-
#lineage ⇒ Types::LineageMetadata
The metadata of the lineage used in pipeline execution step.
-
#model ⇒ Types::ModelStepMetadata
The Amazon Resource Name (ARN) of the model that was created by this step execution.
-
#processing_job ⇒ Types::ProcessingJobStepMetadata
The Amazon Resource Name (ARN) of the processing job that was run by this step execution.
-
#quality_check ⇒ Types::QualityCheckStepMetadata
The configurations and outcomes of the check step execution.
-
#register_model ⇒ Types::RegisterModelStepMetadata
The Amazon Resource Name (ARN) of the model package that the model was registered to by this step execution.
-
#training_job ⇒ Types::TrainingJobStepMetadata
The Amazon Resource Name (ARN) of the training job that was run by this step execution.
-
#transform_job ⇒ Types::TransformJobStepMetadata
The Amazon Resource Name (ARN) of the transform job that was run by this step execution.
-
#tuning_job ⇒ Types::TuningJobStepMetaData
The Amazon Resource Name (ARN) of the tuning job that was run by this step execution.
Instance Attribute Details
#auto_ml_job ⇒ Types::AutoMLJobStepMetadata
The Amazon Resource Name (ARN) of the AutoML job that was run by this step.
42686 42687 42688 42689 42690 42691 42692 42693 42694 42695 42696 42697 42698 42699 42700 42701 42702 42703 42704 42705 42706 42707 42708 42709 42710 42711 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42686 class PipelineExecutionStepMetadata < Struct.new( :training_job, :processing_job, :transform_job, :tuning_job, :model, :register_model, :condition, :callback, :lambda, :emr, :quality_check, :clarify_check, :fail, :auto_ml_job, :endpoint, :endpoint_config, :bedrock_custom_model, :bedrock_custom_model_deployment, :bedrock_provisioned_model_throughput, :bedrock_model_import, :inference_component, :lineage) SENSITIVE = [] include Aws::Structure end |
#bedrock_custom_model ⇒ Types::BedrockCustomModelMetadata
The metadata of the Amazon Bedrock custom model used in the pipeline execution step.
42686 42687 42688 42689 42690 42691 42692 42693 42694 42695 42696 42697 42698 42699 42700 42701 42702 42703 42704 42705 42706 42707 42708 42709 42710 42711 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42686 class PipelineExecutionStepMetadata < Struct.new( :training_job, :processing_job, :transform_job, :tuning_job, :model, :register_model, :condition, :callback, :lambda, :emr, :quality_check, :clarify_check, :fail, :auto_ml_job, :endpoint, :endpoint_config, :bedrock_custom_model, :bedrock_custom_model_deployment, :bedrock_provisioned_model_throughput, :bedrock_model_import, :inference_component, :lineage) SENSITIVE = [] include Aws::Structure end |
#bedrock_custom_model_deployment ⇒ Types::BedrockCustomModelDeploymentMetadata
The metadata of the Amazon Bedrock custom model deployment used in pipeline execution step.
42686 42687 42688 42689 42690 42691 42692 42693 42694 42695 42696 42697 42698 42699 42700 42701 42702 42703 42704 42705 42706 42707 42708 42709 42710 42711 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42686 class PipelineExecutionStepMetadata < Struct.new( :training_job, :processing_job, :transform_job, :tuning_job, :model, :register_model, :condition, :callback, :lambda, :emr, :quality_check, :clarify_check, :fail, :auto_ml_job, :endpoint, :endpoint_config, :bedrock_custom_model, :bedrock_custom_model_deployment, :bedrock_provisioned_model_throughput, :bedrock_model_import, :inference_component, :lineage) SENSITIVE = [] include Aws::Structure end |
#bedrock_model_import ⇒ Types::BedrockModelImportMetadata
The metadata of Amazon Bedrock model import used in pipeline execution step.
42686 42687 42688 42689 42690 42691 42692 42693 42694 42695 42696 42697 42698 42699 42700 42701 42702 42703 42704 42705 42706 42707 42708 42709 42710 42711 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42686 class PipelineExecutionStepMetadata < Struct.new( :training_job, :processing_job, :transform_job, :tuning_job, :model, :register_model, :condition, :callback, :lambda, :emr, :quality_check, :clarify_check, :fail, :auto_ml_job, :endpoint, :endpoint_config, :bedrock_custom_model, :bedrock_custom_model_deployment, :bedrock_provisioned_model_throughput, :bedrock_model_import, :inference_component, :lineage) SENSITIVE = [] include Aws::Structure end |
#bedrock_provisioned_model_throughput ⇒ Types::BedrockProvisionedModelThroughputMetadata
The metadata of the Amazon Bedrock provisioned model throughput used in the pipeline execution step.
42686 42687 42688 42689 42690 42691 42692 42693 42694 42695 42696 42697 42698 42699 42700 42701 42702 42703 42704 42705 42706 42707 42708 42709 42710 42711 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42686 class PipelineExecutionStepMetadata < Struct.new( :training_job, :processing_job, :transform_job, :tuning_job, :model, :register_model, :condition, :callback, :lambda, :emr, :quality_check, :clarify_check, :fail, :auto_ml_job, :endpoint, :endpoint_config, :bedrock_custom_model, :bedrock_custom_model_deployment, :bedrock_provisioned_model_throughput, :bedrock_model_import, :inference_component, :lineage) SENSITIVE = [] include Aws::Structure end |
#callback ⇒ Types::CallbackStepMetadata
The URL of the Amazon SQS queue used by this step execution, the pipeline generated token, and a list of output parameters.
42686 42687 42688 42689 42690 42691 42692 42693 42694 42695 42696 42697 42698 42699 42700 42701 42702 42703 42704 42705 42706 42707 42708 42709 42710 42711 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42686 class PipelineExecutionStepMetadata < Struct.new( :training_job, :processing_job, :transform_job, :tuning_job, :model, :register_model, :condition, :callback, :lambda, :emr, :quality_check, :clarify_check, :fail, :auto_ml_job, :endpoint, :endpoint_config, :bedrock_custom_model, :bedrock_custom_model_deployment, :bedrock_provisioned_model_throughput, :bedrock_model_import, :inference_component, :lineage) SENSITIVE = [] include Aws::Structure end |
#clarify_check ⇒ Types::ClarifyCheckStepMetadata
Container for the metadata for a Clarify check step. The configurations and outcomes of the check step execution. This includes:
-
The type of the check conducted,
-
The Amazon S3 URIs of baseline constraints and statistics files to be used for the drift check.
-
The Amazon S3 URIs of newly calculated baseline constraints and statistics.
-
The model package group name provided.
-
The Amazon S3 URI of the violation report if violations detected.
-
The Amazon Resource Name (ARN) of check processing job initiated by the step execution.
-
The boolean flags indicating if the drift check is skipped.
-
If step property
BaselineUsedForDriftCheckis set the same asCalculatedBaseline.
42686 42687 42688 42689 42690 42691 42692 42693 42694 42695 42696 42697 42698 42699 42700 42701 42702 42703 42704 42705 42706 42707 42708 42709 42710 42711 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42686 class PipelineExecutionStepMetadata < Struct.new( :training_job, :processing_job, :transform_job, :tuning_job, :model, :register_model, :condition, :callback, :lambda, :emr, :quality_check, :clarify_check, :fail, :auto_ml_job, :endpoint, :endpoint_config, :bedrock_custom_model, :bedrock_custom_model_deployment, :bedrock_provisioned_model_throughput, :bedrock_model_import, :inference_component, :lineage) SENSITIVE = [] include Aws::Structure end |
#condition ⇒ Types::ConditionStepMetadata
The outcome of the condition evaluation that was run by this step execution.
42686 42687 42688 42689 42690 42691 42692 42693 42694 42695 42696 42697 42698 42699 42700 42701 42702 42703 42704 42705 42706 42707 42708 42709 42710 42711 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42686 class PipelineExecutionStepMetadata < Struct.new( :training_job, :processing_job, :transform_job, :tuning_job, :model, :register_model, :condition, :callback, :lambda, :emr, :quality_check, :clarify_check, :fail, :auto_ml_job, :endpoint, :endpoint_config, :bedrock_custom_model, :bedrock_custom_model_deployment, :bedrock_provisioned_model_throughput, :bedrock_model_import, :inference_component, :lineage) SENSITIVE = [] include Aws::Structure end |
#emr ⇒ Types::EMRStepMetadata
The configurations and outcomes of an Amazon EMR step execution.
42686 42687 42688 42689 42690 42691 42692 42693 42694 42695 42696 42697 42698 42699 42700 42701 42702 42703 42704 42705 42706 42707 42708 42709 42710 42711 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42686 class PipelineExecutionStepMetadata < Struct.new( :training_job, :processing_job, :transform_job, :tuning_job, :model, :register_model, :condition, :callback, :lambda, :emr, :quality_check, :clarify_check, :fail, :auto_ml_job, :endpoint, :endpoint_config, :bedrock_custom_model, :bedrock_custom_model_deployment, :bedrock_provisioned_model_throughput, :bedrock_model_import, :inference_component, :lineage) SENSITIVE = [] include Aws::Structure end |
#endpoint ⇒ Types::EndpointStepMetadata
The endpoint that was invoked during this step execution.
42686 42687 42688 42689 42690 42691 42692 42693 42694 42695 42696 42697 42698 42699 42700 42701 42702 42703 42704 42705 42706 42707 42708 42709 42710 42711 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42686 class PipelineExecutionStepMetadata < Struct.new( :training_job, :processing_job, :transform_job, :tuning_job, :model, :register_model, :condition, :callback, :lambda, :emr, :quality_check, :clarify_check, :fail, :auto_ml_job, :endpoint, :endpoint_config, :bedrock_custom_model, :bedrock_custom_model_deployment, :bedrock_provisioned_model_throughput, :bedrock_model_import, :inference_component, :lineage) SENSITIVE = [] include Aws::Structure end |
#endpoint_config ⇒ Types::EndpointConfigStepMetadata
The endpoint configuration used to create an endpoint during this step execution.
42686 42687 42688 42689 42690 42691 42692 42693 42694 42695 42696 42697 42698 42699 42700 42701 42702 42703 42704 42705 42706 42707 42708 42709 42710 42711 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42686 class PipelineExecutionStepMetadata < Struct.new( :training_job, :processing_job, :transform_job, :tuning_job, :model, :register_model, :condition, :callback, :lambda, :emr, :quality_check, :clarify_check, :fail, :auto_ml_job, :endpoint, :endpoint_config, :bedrock_custom_model, :bedrock_custom_model_deployment, :bedrock_provisioned_model_throughput, :bedrock_model_import, :inference_component, :lineage) SENSITIVE = [] include Aws::Structure end |
#fail ⇒ Types::FailStepMetadata
The configurations and outcomes of a Fail step execution.
42686 42687 42688 42689 42690 42691 42692 42693 42694 42695 42696 42697 42698 42699 42700 42701 42702 42703 42704 42705 42706 42707 42708 42709 42710 42711 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42686 class PipelineExecutionStepMetadata < Struct.new( :training_job, :processing_job, :transform_job, :tuning_job, :model, :register_model, :condition, :callback, :lambda, :emr, :quality_check, :clarify_check, :fail, :auto_ml_job, :endpoint, :endpoint_config, :bedrock_custom_model, :bedrock_custom_model_deployment, :bedrock_provisioned_model_throughput, :bedrock_model_import, :inference_component, :lineage) SENSITIVE = [] include Aws::Structure end |
#inference_component ⇒ Types::InferenceComponentMetadata
The metadata of the inference component used in pipeline execution step.
42686 42687 42688 42689 42690 42691 42692 42693 42694 42695 42696 42697 42698 42699 42700 42701 42702 42703 42704 42705 42706 42707 42708 42709 42710 42711 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42686 class PipelineExecutionStepMetadata < Struct.new( :training_job, :processing_job, :transform_job, :tuning_job, :model, :register_model, :condition, :callback, :lambda, :emr, :quality_check, :clarify_check, :fail, :auto_ml_job, :endpoint, :endpoint_config, :bedrock_custom_model, :bedrock_custom_model_deployment, :bedrock_provisioned_model_throughput, :bedrock_model_import, :inference_component, :lineage) SENSITIVE = [] include Aws::Structure end |
#lambda ⇒ Types::LambdaStepMetadata
The Amazon Resource Name (ARN) of the Lambda function that was run by this step execution and a list of output parameters.
42686 42687 42688 42689 42690 42691 42692 42693 42694 42695 42696 42697 42698 42699 42700 42701 42702 42703 42704 42705 42706 42707 42708 42709 42710 42711 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42686 class PipelineExecutionStepMetadata < Struct.new( :training_job, :processing_job, :transform_job, :tuning_job, :model, :register_model, :condition, :callback, :lambda, :emr, :quality_check, :clarify_check, :fail, :auto_ml_job, :endpoint, :endpoint_config, :bedrock_custom_model, :bedrock_custom_model_deployment, :bedrock_provisioned_model_throughput, :bedrock_model_import, :inference_component, :lineage) SENSITIVE = [] include Aws::Structure end |
#lineage ⇒ Types::LineageMetadata
The metadata of the lineage used in pipeline execution step.
42686 42687 42688 42689 42690 42691 42692 42693 42694 42695 42696 42697 42698 42699 42700 42701 42702 42703 42704 42705 42706 42707 42708 42709 42710 42711 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42686 class PipelineExecutionStepMetadata < Struct.new( :training_job, :processing_job, :transform_job, :tuning_job, :model, :register_model, :condition, :callback, :lambda, :emr, :quality_check, :clarify_check, :fail, :auto_ml_job, :endpoint, :endpoint_config, :bedrock_custom_model, :bedrock_custom_model_deployment, :bedrock_provisioned_model_throughput, :bedrock_model_import, :inference_component, :lineage) SENSITIVE = [] include Aws::Structure end |
#model ⇒ Types::ModelStepMetadata
The Amazon Resource Name (ARN) of the model that was created by this step execution.
42686 42687 42688 42689 42690 42691 42692 42693 42694 42695 42696 42697 42698 42699 42700 42701 42702 42703 42704 42705 42706 42707 42708 42709 42710 42711 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42686 class PipelineExecutionStepMetadata < Struct.new( :training_job, :processing_job, :transform_job, :tuning_job, :model, :register_model, :condition, :callback, :lambda, :emr, :quality_check, :clarify_check, :fail, :auto_ml_job, :endpoint, :endpoint_config, :bedrock_custom_model, :bedrock_custom_model_deployment, :bedrock_provisioned_model_throughput, :bedrock_model_import, :inference_component, :lineage) SENSITIVE = [] include Aws::Structure end |
#processing_job ⇒ Types::ProcessingJobStepMetadata
The Amazon Resource Name (ARN) of the processing job that was run by this step execution.
42686 42687 42688 42689 42690 42691 42692 42693 42694 42695 42696 42697 42698 42699 42700 42701 42702 42703 42704 42705 42706 42707 42708 42709 42710 42711 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42686 class PipelineExecutionStepMetadata < Struct.new( :training_job, :processing_job, :transform_job, :tuning_job, :model, :register_model, :condition, :callback, :lambda, :emr, :quality_check, :clarify_check, :fail, :auto_ml_job, :endpoint, :endpoint_config, :bedrock_custom_model, :bedrock_custom_model_deployment, :bedrock_provisioned_model_throughput, :bedrock_model_import, :inference_component, :lineage) SENSITIVE = [] include Aws::Structure end |
#quality_check ⇒ Types::QualityCheckStepMetadata
The configurations and outcomes of the check step execution. This includes:
-
The type of the check conducted.
-
The Amazon S3 URIs of baseline constraints and statistics files to be used for the drift check.
-
The Amazon S3 URIs of newly calculated baseline constraints and statistics.
-
The model package group name provided.
-
The Amazon S3 URI of the violation report if violations detected.
-
The Amazon Resource Name (ARN) of check processing job initiated by the step execution.
-
The Boolean flags indicating if the drift check is skipped.
-
If step property
BaselineUsedForDriftCheckis set the same asCalculatedBaseline.
42686 42687 42688 42689 42690 42691 42692 42693 42694 42695 42696 42697 42698 42699 42700 42701 42702 42703 42704 42705 42706 42707 42708 42709 42710 42711 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42686 class PipelineExecutionStepMetadata < Struct.new( :training_job, :processing_job, :transform_job, :tuning_job, :model, :register_model, :condition, :callback, :lambda, :emr, :quality_check, :clarify_check, :fail, :auto_ml_job, :endpoint, :endpoint_config, :bedrock_custom_model, :bedrock_custom_model_deployment, :bedrock_provisioned_model_throughput, :bedrock_model_import, :inference_component, :lineage) SENSITIVE = [] include Aws::Structure end |
#register_model ⇒ Types::RegisterModelStepMetadata
The Amazon Resource Name (ARN) of the model package that the model was registered to by this step execution.
42686 42687 42688 42689 42690 42691 42692 42693 42694 42695 42696 42697 42698 42699 42700 42701 42702 42703 42704 42705 42706 42707 42708 42709 42710 42711 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42686 class PipelineExecutionStepMetadata < Struct.new( :training_job, :processing_job, :transform_job, :tuning_job, :model, :register_model, :condition, :callback, :lambda, :emr, :quality_check, :clarify_check, :fail, :auto_ml_job, :endpoint, :endpoint_config, :bedrock_custom_model, :bedrock_custom_model_deployment, :bedrock_provisioned_model_throughput, :bedrock_model_import, :inference_component, :lineage) SENSITIVE = [] include Aws::Structure end |
#training_job ⇒ Types::TrainingJobStepMetadata
The Amazon Resource Name (ARN) of the training job that was run by this step execution.
42686 42687 42688 42689 42690 42691 42692 42693 42694 42695 42696 42697 42698 42699 42700 42701 42702 42703 42704 42705 42706 42707 42708 42709 42710 42711 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42686 class PipelineExecutionStepMetadata < Struct.new( :training_job, :processing_job, :transform_job, :tuning_job, :model, :register_model, :condition, :callback, :lambda, :emr, :quality_check, :clarify_check, :fail, :auto_ml_job, :endpoint, :endpoint_config, :bedrock_custom_model, :bedrock_custom_model_deployment, :bedrock_provisioned_model_throughput, :bedrock_model_import, :inference_component, :lineage) SENSITIVE = [] include Aws::Structure end |
#transform_job ⇒ Types::TransformJobStepMetadata
The Amazon Resource Name (ARN) of the transform job that was run by this step execution.
42686 42687 42688 42689 42690 42691 42692 42693 42694 42695 42696 42697 42698 42699 42700 42701 42702 42703 42704 42705 42706 42707 42708 42709 42710 42711 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42686 class PipelineExecutionStepMetadata < Struct.new( :training_job, :processing_job, :transform_job, :tuning_job, :model, :register_model, :condition, :callback, :lambda, :emr, :quality_check, :clarify_check, :fail, :auto_ml_job, :endpoint, :endpoint_config, :bedrock_custom_model, :bedrock_custom_model_deployment, :bedrock_provisioned_model_throughput, :bedrock_model_import, :inference_component, :lineage) SENSITIVE = [] include Aws::Structure end |
#tuning_job ⇒ Types::TuningJobStepMetaData
The Amazon Resource Name (ARN) of the tuning job that was run by this step execution.
42686 42687 42688 42689 42690 42691 42692 42693 42694 42695 42696 42697 42698 42699 42700 42701 42702 42703 42704 42705 42706 42707 42708 42709 42710 42711 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 42686 class PipelineExecutionStepMetadata < Struct.new( :training_job, :processing_job, :transform_job, :tuning_job, :model, :register_model, :condition, :callback, :lambda, :emr, :quality_check, :clarify_check, :fail, :auto_ml_job, :endpoint, :endpoint_config, :bedrock_custom_model, :bedrock_custom_model_deployment, :bedrock_provisioned_model_throughput, :bedrock_model_import, :inference_component, :lineage) SENSITIVE = [] include Aws::Structure end |