Class: Aws::SageMaker::Types::PipelineExecutionStepMetadata

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Metadata for a step execution.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_ml_jobTypes::AutoMLJobStepMetadata

The Amazon Resource Name (ARN) of the AutoML job that was run by this step.

Returns:



38185
38186
38187
38188
38189
38190
38191
38192
38193
38194
38195
38196
38197
38198
38199
38200
38201
38202
38203
38204
# File 'lib/aws-sdk-sagemaker/types.rb', line 38185

class  < Struct.new(
  :training_job,
  :processing_job,
  :transform_job,
  :tuning_job,
  :model,
  :register_model,
  :condition,
  :callback,
  :lambda,
  :emr,
  :quality_check,
  :clarify_check,
  :fail,
  :auto_ml_job,
  :endpoint,
  :endpoint_config)
  SENSITIVE = []
  include Aws::Structure
end

#callbackTypes::CallbackStepMetadata

The URL of the Amazon SQS queue used by this step execution, the pipeline generated token, and a list of output parameters.

Returns:



38185
38186
38187
38188
38189
38190
38191
38192
38193
38194
38195
38196
38197
38198
38199
38200
38201
38202
38203
38204
# File 'lib/aws-sdk-sagemaker/types.rb', line 38185

class  < Struct.new(
  :training_job,
  :processing_job,
  :transform_job,
  :tuning_job,
  :model,
  :register_model,
  :condition,
  :callback,
  :lambda,
  :emr,
  :quality_check,
  :clarify_check,
  :fail,
  :auto_ml_job,
  :endpoint,
  :endpoint_config)
  SENSITIVE = []
  include Aws::Structure
end

#clarify_checkTypes::ClarifyCheckStepMetadata

Container for the metadata for a Clarify check step. The configurations and outcomes of the check step execution. This includes:

  • The type of the check conducted,

  • The Amazon S3 URIs of baseline constraints and statistics files to be used for the drift check.

  • The Amazon S3 URIs of newly calculated baseline constraints and statistics.

  • The model package group name provided.

  • The Amazon S3 URI of the violation report if violations detected.

  • The Amazon Resource Name (ARN) of check processing job initiated by the step execution.

  • The boolean flags indicating if the drift check is skipped.

  • If step property BaselineUsedForDriftCheck is set the same as CalculatedBaseline.

Returns:



38185
38186
38187
38188
38189
38190
38191
38192
38193
38194
38195
38196
38197
38198
38199
38200
38201
38202
38203
38204
# File 'lib/aws-sdk-sagemaker/types.rb', line 38185

class  < Struct.new(
  :training_job,
  :processing_job,
  :transform_job,
  :tuning_job,
  :model,
  :register_model,
  :condition,
  :callback,
  :lambda,
  :emr,
  :quality_check,
  :clarify_check,
  :fail,
  :auto_ml_job,
  :endpoint,
  :endpoint_config)
  SENSITIVE = []
  include Aws::Structure
end

#conditionTypes::ConditionStepMetadata

The outcome of the condition evaluation that was run by this step execution.

Returns:



38185
38186
38187
38188
38189
38190
38191
38192
38193
38194
38195
38196
38197
38198
38199
38200
38201
38202
38203
38204
# File 'lib/aws-sdk-sagemaker/types.rb', line 38185

class  < Struct.new(
  :training_job,
  :processing_job,
  :transform_job,
  :tuning_job,
  :model,
  :register_model,
  :condition,
  :callback,
  :lambda,
  :emr,
  :quality_check,
  :clarify_check,
  :fail,
  :auto_ml_job,
  :endpoint,
  :endpoint_config)
  SENSITIVE = []
  include Aws::Structure
end

#emrTypes::EMRStepMetadata

The configurations and outcomes of an Amazon EMR step execution.

Returns:



38185
38186
38187
38188
38189
38190
38191
38192
38193
38194
38195
38196
38197
38198
38199
38200
38201
38202
38203
38204
# File 'lib/aws-sdk-sagemaker/types.rb', line 38185

class  < Struct.new(
  :training_job,
  :processing_job,
  :transform_job,
  :tuning_job,
  :model,
  :register_model,
  :condition,
  :callback,
  :lambda,
  :emr,
  :quality_check,
  :clarify_check,
  :fail,
  :auto_ml_job,
  :endpoint,
  :endpoint_config)
  SENSITIVE = []
  include Aws::Structure
end

#endpointTypes::EndpointStepMetadata

The endpoint that was invoked during this step execution.

Returns:



38185
38186
38187
38188
38189
38190
38191
38192
38193
38194
38195
38196
38197
38198
38199
38200
38201
38202
38203
38204
# File 'lib/aws-sdk-sagemaker/types.rb', line 38185

class  < Struct.new(
  :training_job,
  :processing_job,
  :transform_job,
  :tuning_job,
  :model,
  :register_model,
  :condition,
  :callback,
  :lambda,
  :emr,
  :quality_check,
  :clarify_check,
  :fail,
  :auto_ml_job,
  :endpoint,
  :endpoint_config)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_configTypes::EndpointConfigStepMetadata

The endpoint configuration used to create an endpoint during this step execution.

Returns:



38185
38186
38187
38188
38189
38190
38191
38192
38193
38194
38195
38196
38197
38198
38199
38200
38201
38202
38203
38204
# File 'lib/aws-sdk-sagemaker/types.rb', line 38185

class  < Struct.new(
  :training_job,
  :processing_job,
  :transform_job,
  :tuning_job,
  :model,
  :register_model,
  :condition,
  :callback,
  :lambda,
  :emr,
  :quality_check,
  :clarify_check,
  :fail,
  :auto_ml_job,
  :endpoint,
  :endpoint_config)
  SENSITIVE = []
  include Aws::Structure
end

#failTypes::FailStepMetadata

The configurations and outcomes of a Fail step execution.

Returns:



38185
38186
38187
38188
38189
38190
38191
38192
38193
38194
38195
38196
38197
38198
38199
38200
38201
38202
38203
38204
# File 'lib/aws-sdk-sagemaker/types.rb', line 38185

class  < Struct.new(
  :training_job,
  :processing_job,
  :transform_job,
  :tuning_job,
  :model,
  :register_model,
  :condition,
  :callback,
  :lambda,
  :emr,
  :quality_check,
  :clarify_check,
  :fail,
  :auto_ml_job,
  :endpoint,
  :endpoint_config)
  SENSITIVE = []
  include Aws::Structure
end

#lambdaTypes::LambdaStepMetadata

The Amazon Resource Name (ARN) of the Lambda function that was run by this step execution and a list of output parameters.

Returns:



38185
38186
38187
38188
38189
38190
38191
38192
38193
38194
38195
38196
38197
38198
38199
38200
38201
38202
38203
38204
# File 'lib/aws-sdk-sagemaker/types.rb', line 38185

class  < Struct.new(
  :training_job,
  :processing_job,
  :transform_job,
  :tuning_job,
  :model,
  :register_model,
  :condition,
  :callback,
  :lambda,
  :emr,
  :quality_check,
  :clarify_check,
  :fail,
  :auto_ml_job,
  :endpoint,
  :endpoint_config)
  SENSITIVE = []
  include Aws::Structure
end

#modelTypes::ModelStepMetadata

The Amazon Resource Name (ARN) of the model that was created by this step execution.

Returns:



38185
38186
38187
38188
38189
38190
38191
38192
38193
38194
38195
38196
38197
38198
38199
38200
38201
38202
38203
38204
# File 'lib/aws-sdk-sagemaker/types.rb', line 38185

class  < Struct.new(
  :training_job,
  :processing_job,
  :transform_job,
  :tuning_job,
  :model,
  :register_model,
  :condition,
  :callback,
  :lambda,
  :emr,
  :quality_check,
  :clarify_check,
  :fail,
  :auto_ml_job,
  :endpoint,
  :endpoint_config)
  SENSITIVE = []
  include Aws::Structure
end

#processing_jobTypes::ProcessingJobStepMetadata

The Amazon Resource Name (ARN) of the processing job that was run by this step execution.

Returns:



38185
38186
38187
38188
38189
38190
38191
38192
38193
38194
38195
38196
38197
38198
38199
38200
38201
38202
38203
38204
# File 'lib/aws-sdk-sagemaker/types.rb', line 38185

class  < Struct.new(
  :training_job,
  :processing_job,
  :transform_job,
  :tuning_job,
  :model,
  :register_model,
  :condition,
  :callback,
  :lambda,
  :emr,
  :quality_check,
  :clarify_check,
  :fail,
  :auto_ml_job,
  :endpoint,
  :endpoint_config)
  SENSITIVE = []
  include Aws::Structure
end

#quality_checkTypes::QualityCheckStepMetadata

The configurations and outcomes of the check step execution. This includes:

  • The type of the check conducted.

  • The Amazon S3 URIs of baseline constraints and statistics files to be used for the drift check.

  • The Amazon S3 URIs of newly calculated baseline constraints and statistics.

  • The model package group name provided.

  • The Amazon S3 URI of the violation report if violations detected.

  • The Amazon Resource Name (ARN) of check processing job initiated by the step execution.

  • The Boolean flags indicating if the drift check is skipped.

  • If step property BaselineUsedForDriftCheck is set the same as CalculatedBaseline.

Returns:



38185
38186
38187
38188
38189
38190
38191
38192
38193
38194
38195
38196
38197
38198
38199
38200
38201
38202
38203
38204
# File 'lib/aws-sdk-sagemaker/types.rb', line 38185

class  < Struct.new(
  :training_job,
  :processing_job,
  :transform_job,
  :tuning_job,
  :model,
  :register_model,
  :condition,
  :callback,
  :lambda,
  :emr,
  :quality_check,
  :clarify_check,
  :fail,
  :auto_ml_job,
  :endpoint,
  :endpoint_config)
  SENSITIVE = []
  include Aws::Structure
end

#register_modelTypes::RegisterModelStepMetadata

The Amazon Resource Name (ARN) of the model package that the model was registered to by this step execution.

Returns:



38185
38186
38187
38188
38189
38190
38191
38192
38193
38194
38195
38196
38197
38198
38199
38200
38201
38202
38203
38204
# File 'lib/aws-sdk-sagemaker/types.rb', line 38185

class  < Struct.new(
  :training_job,
  :processing_job,
  :transform_job,
  :tuning_job,
  :model,
  :register_model,
  :condition,
  :callback,
  :lambda,
  :emr,
  :quality_check,
  :clarify_check,
  :fail,
  :auto_ml_job,
  :endpoint,
  :endpoint_config)
  SENSITIVE = []
  include Aws::Structure
end

#training_jobTypes::TrainingJobStepMetadata

The Amazon Resource Name (ARN) of the training job that was run by this step execution.

Returns:



38185
38186
38187
38188
38189
38190
38191
38192
38193
38194
38195
38196
38197
38198
38199
38200
38201
38202
38203
38204
# File 'lib/aws-sdk-sagemaker/types.rb', line 38185

class  < Struct.new(
  :training_job,
  :processing_job,
  :transform_job,
  :tuning_job,
  :model,
  :register_model,
  :condition,
  :callback,
  :lambda,
  :emr,
  :quality_check,
  :clarify_check,
  :fail,
  :auto_ml_job,
  :endpoint,
  :endpoint_config)
  SENSITIVE = []
  include Aws::Structure
end

#transform_jobTypes::TransformJobStepMetadata

The Amazon Resource Name (ARN) of the transform job that was run by this step execution.

Returns:



38185
38186
38187
38188
38189
38190
38191
38192
38193
38194
38195
38196
38197
38198
38199
38200
38201
38202
38203
38204
# File 'lib/aws-sdk-sagemaker/types.rb', line 38185

class  < Struct.new(
  :training_job,
  :processing_job,
  :transform_job,
  :tuning_job,
  :model,
  :register_model,
  :condition,
  :callback,
  :lambda,
  :emr,
  :quality_check,
  :clarify_check,
  :fail,
  :auto_ml_job,
  :endpoint,
  :endpoint_config)
  SENSITIVE = []
  include Aws::Structure
end

#tuning_jobTypes::TuningJobStepMetaData

The Amazon Resource Name (ARN) of the tuning job that was run by this step execution.

Returns:



38185
38186
38187
38188
38189
38190
38191
38192
38193
38194
38195
38196
38197
38198
38199
38200
38201
38202
38203
38204
# File 'lib/aws-sdk-sagemaker/types.rb', line 38185

class  < Struct.new(
  :training_job,
  :processing_job,
  :transform_job,
  :tuning_job,
  :model,
  :register_model,
  :condition,
  :callback,
  :lambda,
  :emr,
  :quality_check,
  :clarify_check,
  :fail,
  :auto_ml_job,
  :endpoint,
  :endpoint_config)
  SENSITIVE = []
  include Aws::Structure
end