Class: Aws::SageMaker::Types::PipelineVersion
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::PipelineVersion
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The version of the pipeline.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
-
#creation_time ⇒ Time
The creation time of the pipeline version.
-
#last_executed_pipeline_execution_arn ⇒ String
The Amazon Resource Name (ARN) of the most recent pipeline execution created from this pipeline version.
-
#last_executed_pipeline_execution_display_name ⇒ String
The display name of the most recent pipeline execution created from this pipeline version.
-
#last_executed_pipeline_execution_status ⇒ String
The status of the most recent pipeline execution created from this pipeline version.
-
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
-
#last_modified_time ⇒ Time
The time when the pipeline version was last modified.
-
#pipeline_arn ⇒ String
The Amazon Resource Name (ARN) of the pipeline.
-
#pipeline_version_description ⇒ String
The description of the pipeline version.
-
#pipeline_version_display_name ⇒ String
The display name of the pipeline version.
-
#pipeline_version_id ⇒ Integer
The ID of the pipeline version.
Instance Attribute Details
#created_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
44753 44754 44755 44756 44757 44758 44759 44760 44761 44762 44763 44764 44765 44766 44767 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44753 class PipelineVersion < Struct.new( :pipeline_arn, :pipeline_version_id, :pipeline_version_display_name, :pipeline_version_description, :creation_time, :last_modified_time, :created_by, :last_modified_by, :last_executed_pipeline_execution_arn, :last_executed_pipeline_execution_display_name, :last_executed_pipeline_execution_status) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The creation time of the pipeline version.
44753 44754 44755 44756 44757 44758 44759 44760 44761 44762 44763 44764 44765 44766 44767 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44753 class PipelineVersion < Struct.new( :pipeline_arn, :pipeline_version_id, :pipeline_version_display_name, :pipeline_version_description, :creation_time, :last_modified_time, :created_by, :last_modified_by, :last_executed_pipeline_execution_arn, :last_executed_pipeline_execution_display_name, :last_executed_pipeline_execution_status) SENSITIVE = [] include Aws::Structure end |
#last_executed_pipeline_execution_arn ⇒ String
The Amazon Resource Name (ARN) of the most recent pipeline execution created from this pipeline version.
44753 44754 44755 44756 44757 44758 44759 44760 44761 44762 44763 44764 44765 44766 44767 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44753 class PipelineVersion < Struct.new( :pipeline_arn, :pipeline_version_id, :pipeline_version_display_name, :pipeline_version_description, :creation_time, :last_modified_time, :created_by, :last_modified_by, :last_executed_pipeline_execution_arn, :last_executed_pipeline_execution_display_name, :last_executed_pipeline_execution_status) SENSITIVE = [] include Aws::Structure end |
#last_executed_pipeline_execution_display_name ⇒ String
The display name of the most recent pipeline execution created from this pipeline version.
44753 44754 44755 44756 44757 44758 44759 44760 44761 44762 44763 44764 44765 44766 44767 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44753 class PipelineVersion < Struct.new( :pipeline_arn, :pipeline_version_id, :pipeline_version_display_name, :pipeline_version_description, :creation_time, :last_modified_time, :created_by, :last_modified_by, :last_executed_pipeline_execution_arn, :last_executed_pipeline_execution_display_name, :last_executed_pipeline_execution_status) SENSITIVE = [] include Aws::Structure end |
#last_executed_pipeline_execution_status ⇒ String
The status of the most recent pipeline execution created from this pipeline version.
44753 44754 44755 44756 44757 44758 44759 44760 44761 44762 44763 44764 44765 44766 44767 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44753 class PipelineVersion < Struct.new( :pipeline_arn, :pipeline_version_id, :pipeline_version_display_name, :pipeline_version_description, :creation_time, :last_modified_time, :created_by, :last_modified_by, :last_executed_pipeline_execution_arn, :last_executed_pipeline_execution_display_name, :last_executed_pipeline_execution_status) SENSITIVE = [] include Aws::Structure end |
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
44753 44754 44755 44756 44757 44758 44759 44760 44761 44762 44763 44764 44765 44766 44767 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44753 class PipelineVersion < Struct.new( :pipeline_arn, :pipeline_version_id, :pipeline_version_display_name, :pipeline_version_description, :creation_time, :last_modified_time, :created_by, :last_modified_by, :last_executed_pipeline_execution_arn, :last_executed_pipeline_execution_display_name, :last_executed_pipeline_execution_status) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The time when the pipeline version was last modified.
44753 44754 44755 44756 44757 44758 44759 44760 44761 44762 44763 44764 44765 44766 44767 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44753 class PipelineVersion < Struct.new( :pipeline_arn, :pipeline_version_id, :pipeline_version_display_name, :pipeline_version_description, :creation_time, :last_modified_time, :created_by, :last_modified_by, :last_executed_pipeline_execution_arn, :last_executed_pipeline_execution_display_name, :last_executed_pipeline_execution_status) SENSITIVE = [] include Aws::Structure end |
#pipeline_arn ⇒ String
The Amazon Resource Name (ARN) of the pipeline.
44753 44754 44755 44756 44757 44758 44759 44760 44761 44762 44763 44764 44765 44766 44767 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44753 class PipelineVersion < Struct.new( :pipeline_arn, :pipeline_version_id, :pipeline_version_display_name, :pipeline_version_description, :creation_time, :last_modified_time, :created_by, :last_modified_by, :last_executed_pipeline_execution_arn, :last_executed_pipeline_execution_display_name, :last_executed_pipeline_execution_status) SENSITIVE = [] include Aws::Structure end |
#pipeline_version_description ⇒ String
The description of the pipeline version.
44753 44754 44755 44756 44757 44758 44759 44760 44761 44762 44763 44764 44765 44766 44767 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44753 class PipelineVersion < Struct.new( :pipeline_arn, :pipeline_version_id, :pipeline_version_display_name, :pipeline_version_description, :creation_time, :last_modified_time, :created_by, :last_modified_by, :last_executed_pipeline_execution_arn, :last_executed_pipeline_execution_display_name, :last_executed_pipeline_execution_status) SENSITIVE = [] include Aws::Structure end |
#pipeline_version_display_name ⇒ String
The display name of the pipeline version.
44753 44754 44755 44756 44757 44758 44759 44760 44761 44762 44763 44764 44765 44766 44767 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44753 class PipelineVersion < Struct.new( :pipeline_arn, :pipeline_version_id, :pipeline_version_display_name, :pipeline_version_description, :creation_time, :last_modified_time, :created_by, :last_modified_by, :last_executed_pipeline_execution_arn, :last_executed_pipeline_execution_display_name, :last_executed_pipeline_execution_status) SENSITIVE = [] include Aws::Structure end |
#pipeline_version_id ⇒ Integer
The ID of the pipeline version.
44753 44754 44755 44756 44757 44758 44759 44760 44761 44762 44763 44764 44765 44766 44767 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44753 class PipelineVersion < Struct.new( :pipeline_arn, :pipeline_version_id, :pipeline_version_display_name, :pipeline_version_description, :creation_time, :last_modified_time, :created_by, :last_modified_by, :last_executed_pipeline_execution_arn, :last_executed_pipeline_execution_display_name, :last_executed_pipeline_execution_status) SENSITIVE = [] include Aws::Structure end |