Class: Aws::SageMaker::Types::ProcessingFeatureStoreOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ProcessingFeatureStoreOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Configuration for processing job outputs in Amazon SageMaker Feature Store.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#feature_group_name ⇒ String
The name of the Amazon SageMaker FeatureGroup to use as the destination for processing job output.
Instance Attribute Details
#feature_group_name ⇒ String
The name of the Amazon SageMaker FeatureGroup to use as the destination for processing job output. Note that your processing script is responsible for putting records into your Feature Store.
46359 46360 46361 46362 46363 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46359 class ProcessingFeatureStoreOutput < Struct.new( :feature_group_name) SENSITIVE = [] include Aws::Structure end |