Class: Aws::SageMaker::Types::ProcessingFeatureStoreOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Configuration for processing job outputs in Amazon SageMaker Feature Store.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#feature_group_nameString

The name of the Amazon SageMaker FeatureGroup to use as the destination for processing job output. Note that your processing script is responsible for putting records into your Feature Store.

Returns:

  • (String)


44833
44834
44835
44836
44837
# File 'lib/aws-sdk-sagemaker/types.rb', line 44833

class ProcessingFeatureStoreOutput < Struct.new(
  :feature_group_name)
  SENSITIVE = []
  include Aws::Structure
end