Class: Aws::SageMaker::Types::ProcessingInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ProcessingInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The inputs for a processing job. The processing input must specify exactly one of either S3Input or DatasetDefinition types.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#app_managed ⇒ Boolean
When
True, input operations such as data download are managed natively by the processing job application. -
#dataset_definition ⇒ Types::DatasetDefinition
Configuration for a Dataset Definition input.
-
#input_name ⇒ String
The name for the processing job input.
-
#s3_input ⇒ Types::ProcessingS3Input
Configuration for downloading input data from Amazon S3 into the processing container.
Instance Attribute Details
#app_managed ⇒ Boolean
When True, input operations such as data download are managed natively by the processing job application. When False (default), input operations are managed by Amazon SageMaker.
43125 43126 43127 43128 43129 43130 43131 43132 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43125 class ProcessingInput < Struct.new( :input_name, :app_managed, :s3_input, :dataset_definition) SENSITIVE = [] include Aws::Structure end |
#dataset_definition ⇒ Types::DatasetDefinition
Configuration for a Dataset Definition input.
43125 43126 43127 43128 43129 43130 43131 43132 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43125 class ProcessingInput < Struct.new( :input_name, :app_managed, :s3_input, :dataset_definition) SENSITIVE = [] include Aws::Structure end |
#input_name ⇒ String
The name for the processing job input.
43125 43126 43127 43128 43129 43130 43131 43132 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43125 class ProcessingInput < Struct.new( :input_name, :app_managed, :s3_input, :dataset_definition) SENSITIVE = [] include Aws::Structure end |
#s3_input ⇒ Types::ProcessingS3Input
Configuration for downloading input data from Amazon S3 into the processing container.
43125 43126 43127 43128 43129 43130 43131 43132 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43125 class ProcessingInput < Struct.new( :input_name, :app_managed, :s3_input, :dataset_definition) SENSITIVE = [] include Aws::Structure end |