Class: Aws::SageMaker::Types::ProcessingJob
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ProcessingJob
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
An Amazon SageMaker processing job that is used to analyze data and evaluate models. For more information, see Process Data and Evaluate Models.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#app_specification ⇒ Types::AppSpecification
Configuration to run a processing job in a specified container image.
-
#auto_ml_job_arn ⇒ String
The Amazon Resource Name (ARN) of the AutoML job associated with this processing job.
-
#creation_time ⇒ Time
The time the processing job was created.
-
#environment ⇒ Hash<String,String>
Sets the environment variables in the Docker container.
-
#exit_message ⇒ String
A string, up to one KB in size, that contains metadata from the processing container when the processing job exits.
-
#experiment_config ⇒ Types::ExperimentConfig
Associates a SageMaker job as a trial component with an experiment and trial.
-
#failure_reason ⇒ String
A string, up to one KB in size, that contains the reason a processing job failed, if it failed.
-
#last_modified_time ⇒ Time
The time the processing job was last modified.
-
#monitoring_schedule_arn ⇒ String
The ARN of a monitoring schedule for an endpoint associated with this processing job.
-
#network_config ⇒ Types::NetworkConfig
Networking options for a job, such as network traffic encryption between containers, whether to allow inbound and outbound network calls to and from containers, and the VPC subnets and security groups to use for VPC-enabled jobs.
-
#processing_end_time ⇒ Time
The time that the processing job ended.
-
#processing_inputs ⇒ Array<Types::ProcessingInput>
List of input configurations for the processing job.
-
#processing_job_arn ⇒ String
The ARN of the processing job.
-
#processing_job_name ⇒ String
The name of the processing job.
-
#processing_job_status ⇒ String
The status of the processing job.
-
#processing_output_config ⇒ Types::ProcessingOutputConfig
Configuration for uploading output from the processing container.
-
#processing_resources ⇒ Types::ProcessingResources
Identifies the resources, ML compute instances, and ML storage volumes to deploy for a processing job.
-
#processing_start_time ⇒ Time
The time that the processing job started.
-
#role_arn ⇒ String
The ARN of the role used to create the processing job.
-
#stopping_condition ⇒ Types::ProcessingStoppingCondition
Configures conditions under which the processing job should be stopped, such as how long the processing job has been running.
-
#tags ⇒ Array<Types::Tag>
An array of key-value pairs.
-
#training_job_arn ⇒ String
The ARN of the training job associated with this processing job.
Instance Attribute Details
#app_specification ⇒ Types::AppSpecification
Configuration to run a processing job in a specified container image.
46327 46328 46329 46330 46331 46332 46333 46334 46335 46336 46337 46338 46339 46340 46341 46342 46343 46344 46345 46346 46347 46348 46349 46350 46351 46352 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46327 class ProcessingJob < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#auto_ml_job_arn ⇒ String
The Amazon Resource Name (ARN) of the AutoML job associated with this processing job.
46327 46328 46329 46330 46331 46332 46333 46334 46335 46336 46337 46338 46339 46340 46341 46342 46343 46344 46345 46346 46347 46348 46349 46350 46351 46352 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46327 class ProcessingJob < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The time the processing job was created.
46327 46328 46329 46330 46331 46332 46333 46334 46335 46336 46337 46338 46339 46340 46341 46342 46343 46344 46345 46346 46347 46348 46349 46350 46351 46352 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46327 class ProcessingJob < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#environment ⇒ Hash<String,String>
Sets the environment variables in the Docker container.
46327 46328 46329 46330 46331 46332 46333 46334 46335 46336 46337 46338 46339 46340 46341 46342 46343 46344 46345 46346 46347 46348 46349 46350 46351 46352 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46327 class ProcessingJob < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#exit_message ⇒ String
A string, up to one KB in size, that contains metadata from the processing container when the processing job exits.
46327 46328 46329 46330 46331 46332 46333 46334 46335 46336 46337 46338 46339 46340 46341 46342 46343 46344 46345 46346 46347 46348 46349 46350 46351 46352 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46327 class ProcessingJob < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#experiment_config ⇒ Types::ExperimentConfig
Associates a SageMaker job as a trial component with an experiment and trial. Specified when you call the following APIs:
46327 46328 46329 46330 46331 46332 46333 46334 46335 46336 46337 46338 46339 46340 46341 46342 46343 46344 46345 46346 46347 46348 46349 46350 46351 46352 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46327 class ProcessingJob < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
A string, up to one KB in size, that contains the reason a processing job failed, if it failed.
46327 46328 46329 46330 46331 46332 46333 46334 46335 46336 46337 46338 46339 46340 46341 46342 46343 46344 46345 46346 46347 46348 46349 46350 46351 46352 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46327 class ProcessingJob < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The time the processing job was last modified.
46327 46328 46329 46330 46331 46332 46333 46334 46335 46336 46337 46338 46339 46340 46341 46342 46343 46344 46345 46346 46347 46348 46349 46350 46351 46352 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46327 class ProcessingJob < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#monitoring_schedule_arn ⇒ String
The ARN of a monitoring schedule for an endpoint associated with this processing job.
46327 46328 46329 46330 46331 46332 46333 46334 46335 46336 46337 46338 46339 46340 46341 46342 46343 46344 46345 46346 46347 46348 46349 46350 46351 46352 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46327 class ProcessingJob < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#network_config ⇒ Types::NetworkConfig
Networking options for a job, such as network traffic encryption between containers, whether to allow inbound and outbound network calls to and from containers, and the VPC subnets and security groups to use for VPC-enabled jobs.
46327 46328 46329 46330 46331 46332 46333 46334 46335 46336 46337 46338 46339 46340 46341 46342 46343 46344 46345 46346 46347 46348 46349 46350 46351 46352 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46327 class ProcessingJob < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#processing_end_time ⇒ Time
The time that the processing job ended.
46327 46328 46329 46330 46331 46332 46333 46334 46335 46336 46337 46338 46339 46340 46341 46342 46343 46344 46345 46346 46347 46348 46349 46350 46351 46352 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46327 class ProcessingJob < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#processing_inputs ⇒ Array<Types::ProcessingInput>
List of input configurations for the processing job.
46327 46328 46329 46330 46331 46332 46333 46334 46335 46336 46337 46338 46339 46340 46341 46342 46343 46344 46345 46346 46347 46348 46349 46350 46351 46352 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46327 class ProcessingJob < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#processing_job_arn ⇒ String
The ARN of the processing job.
46327 46328 46329 46330 46331 46332 46333 46334 46335 46336 46337 46338 46339 46340 46341 46342 46343 46344 46345 46346 46347 46348 46349 46350 46351 46352 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46327 class ProcessingJob < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#processing_job_name ⇒ String
The name of the processing job.
46327 46328 46329 46330 46331 46332 46333 46334 46335 46336 46337 46338 46339 46340 46341 46342 46343 46344 46345 46346 46347 46348 46349 46350 46351 46352 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46327 class ProcessingJob < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#processing_job_status ⇒ String
The status of the processing job.
46327 46328 46329 46330 46331 46332 46333 46334 46335 46336 46337 46338 46339 46340 46341 46342 46343 46344 46345 46346 46347 46348 46349 46350 46351 46352 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46327 class ProcessingJob < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#processing_output_config ⇒ Types::ProcessingOutputConfig
Configuration for uploading output from the processing container.
46327 46328 46329 46330 46331 46332 46333 46334 46335 46336 46337 46338 46339 46340 46341 46342 46343 46344 46345 46346 46347 46348 46349 46350 46351 46352 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46327 class ProcessingJob < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#processing_resources ⇒ Types::ProcessingResources
Identifies the resources, ML compute instances, and ML storage volumes to deploy for a processing job. In distributed training, you specify more than one instance.
46327 46328 46329 46330 46331 46332 46333 46334 46335 46336 46337 46338 46339 46340 46341 46342 46343 46344 46345 46346 46347 46348 46349 46350 46351 46352 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46327 class ProcessingJob < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#processing_start_time ⇒ Time
The time that the processing job started.
46327 46328 46329 46330 46331 46332 46333 46334 46335 46336 46337 46338 46339 46340 46341 46342 46343 46344 46345 46346 46347 46348 46349 46350 46351 46352 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46327 class ProcessingJob < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The ARN of the role used to create the processing job.
46327 46328 46329 46330 46331 46332 46333 46334 46335 46336 46337 46338 46339 46340 46341 46342 46343 46344 46345 46346 46347 46348 46349 46350 46351 46352 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46327 class ProcessingJob < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#stopping_condition ⇒ Types::ProcessingStoppingCondition
Configures conditions under which the processing job should be stopped, such as how long the processing job has been running. After the condition is met, the processing job is stopped.
46327 46328 46329 46330 46331 46332 46333 46334 46335 46336 46337 46338 46339 46340 46341 46342 46343 46344 46345 46346 46347 46348 46349 46350 46351 46352 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46327 class ProcessingJob < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
An array of key-value pairs. For more information, see Using Cost Allocation Tags in the Amazon Web Services Billing and Cost Management User Guide.
46327 46328 46329 46330 46331 46332 46333 46334 46335 46336 46337 46338 46339 46340 46341 46342 46343 46344 46345 46346 46347 46348 46349 46350 46351 46352 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46327 class ProcessingJob < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#training_job_arn ⇒ String
The ARN of the training job associated with this processing job.
46327 46328 46329 46330 46331 46332 46333 46334 46335 46336 46337 46338 46339 46340 46341 46342 46343 46344 46345 46346 46347 46348 46349 46350 46351 46352 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46327 class ProcessingJob < Struct.new( :processing_inputs, :processing_output_config, :processing_job_name, :processing_resources, :stopping_condition, :app_specification, :environment, :network_config, :role_arn, :experiment_config, :processing_job_arn, :processing_job_status, :exit_message, :failure_reason, :processing_end_time, :processing_start_time, :last_modified_time, :creation_time, :monitoring_schedule_arn, :auto_ml_job_arn, :training_job_arn, :tags) SENSITIVE = [] include Aws::Structure end |