Class: Aws::SageMaker::Types::ProcessingJobSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ProcessingJobSummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Summary of information about a processing job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Time
The time at which the processing job was created.
-
#exit_message ⇒ String
An optional string, up to one KB in size, that contains metadata from the processing container when the processing job exits.
-
#failure_reason ⇒ String
A string, up to one KB in size, that contains the reason a processing job failed, if it failed.
-
#last_modified_time ⇒ Time
A timestamp that indicates the last time the processing job was modified.
-
#processing_end_time ⇒ Time
The time at which the processing job completed.
-
#processing_job_arn ⇒ String
The Amazon Resource Name (ARN) of the processing job..
-
#processing_job_name ⇒ String
The name of the processing job.
-
#processing_job_status ⇒ String
The status of the processing job.
Instance Attribute Details
#creation_time ⇒ Time
The time at which the processing job was created.
46065 46066 46067 46068 46069 46070 46071 46072 46073 46074 46075 46076 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46065 class ProcessingJobSummary < Struct.new( :processing_job_name, :processing_job_arn, :creation_time, :processing_end_time, :last_modified_time, :processing_job_status, :failure_reason, :exit_message) SENSITIVE = [] include Aws::Structure end |
#exit_message ⇒ String
An optional string, up to one KB in size, that contains metadata from the processing container when the processing job exits.
46065 46066 46067 46068 46069 46070 46071 46072 46073 46074 46075 46076 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46065 class ProcessingJobSummary < Struct.new( :processing_job_name, :processing_job_arn, :creation_time, :processing_end_time, :last_modified_time, :processing_job_status, :failure_reason, :exit_message) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
A string, up to one KB in size, that contains the reason a processing job failed, if it failed.
46065 46066 46067 46068 46069 46070 46071 46072 46073 46074 46075 46076 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46065 class ProcessingJobSummary < Struct.new( :processing_job_name, :processing_job_arn, :creation_time, :processing_end_time, :last_modified_time, :processing_job_status, :failure_reason, :exit_message) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
A timestamp that indicates the last time the processing job was modified.
46065 46066 46067 46068 46069 46070 46071 46072 46073 46074 46075 46076 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46065 class ProcessingJobSummary < Struct.new( :processing_job_name, :processing_job_arn, :creation_time, :processing_end_time, :last_modified_time, :processing_job_status, :failure_reason, :exit_message) SENSITIVE = [] include Aws::Structure end |
#processing_end_time ⇒ Time
The time at which the processing job completed.
46065 46066 46067 46068 46069 46070 46071 46072 46073 46074 46075 46076 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46065 class ProcessingJobSummary < Struct.new( :processing_job_name, :processing_job_arn, :creation_time, :processing_end_time, :last_modified_time, :processing_job_status, :failure_reason, :exit_message) SENSITIVE = [] include Aws::Structure end |
#processing_job_arn ⇒ String
The Amazon Resource Name (ARN) of the processing job..
46065 46066 46067 46068 46069 46070 46071 46072 46073 46074 46075 46076 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46065 class ProcessingJobSummary < Struct.new( :processing_job_name, :processing_job_arn, :creation_time, :processing_end_time, :last_modified_time, :processing_job_status, :failure_reason, :exit_message) SENSITIVE = [] include Aws::Structure end |
#processing_job_name ⇒ String
The name of the processing job.
46065 46066 46067 46068 46069 46070 46071 46072 46073 46074 46075 46076 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46065 class ProcessingJobSummary < Struct.new( :processing_job_name, :processing_job_arn, :creation_time, :processing_end_time, :last_modified_time, :processing_job_status, :failure_reason, :exit_message) SENSITIVE = [] include Aws::Structure end |
#processing_job_status ⇒ String
The status of the processing job.
46065 46066 46067 46068 46069 46070 46071 46072 46073 46074 46075 46076 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46065 class ProcessingJobSummary < Struct.new( :processing_job_name, :processing_job_arn, :creation_time, :processing_end_time, :last_modified_time, :processing_job_status, :failure_reason, :exit_message) SENSITIVE = [] include Aws::Structure end |