Class: Aws::SageMaker::Types::ProcessingOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ProcessingOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Describes the results of a processing job. The processing output must specify exactly one of either S3Output or FeatureStoreOutput types.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#app_managed ⇒ Boolean
When
True, output operations such as data upload are managed natively by the processing job application. -
#feature_store_output ⇒ Types::ProcessingFeatureStoreOutput
Configuration for processing job outputs in Amazon SageMaker Feature Store.
-
#output_name ⇒ String
The name for the processing job output.
-
#s3_output ⇒ Types::ProcessingS3Output
Configuration for processing job outputs in Amazon S3.
Instance Attribute Details
#app_managed ⇒ Boolean
When True, output operations such as data upload are managed natively by the processing job application. When False (default), output operations are managed by Amazon SageMaker.
38705 38706 38707 38708 38709 38710 38711 38712 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 38705 class ProcessingOutput < Struct.new( :output_name, :s3_output, :feature_store_output, :app_managed) SENSITIVE = [] include Aws::Structure end |
#feature_store_output ⇒ Types::ProcessingFeatureStoreOutput
Configuration for processing job outputs in Amazon SageMaker Feature Store. This processing output type is only supported when AppManaged is specified.
38705 38706 38707 38708 38709 38710 38711 38712 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 38705 class ProcessingOutput < Struct.new( :output_name, :s3_output, :feature_store_output, :app_managed) SENSITIVE = [] include Aws::Structure end |
#output_name ⇒ String
The name for the processing job output.
38705 38706 38707 38708 38709 38710 38711 38712 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 38705 class ProcessingOutput < Struct.new( :output_name, :s3_output, :feature_store_output, :app_managed) SENSITIVE = [] include Aws::Structure end |
#s3_output ⇒ Types::ProcessingS3Output
Configuration for processing job outputs in Amazon S3.
38705 38706 38707 38708 38709 38710 38711 38712 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 38705 class ProcessingOutput < Struct.new( :output_name, :s3_output, :feature_store_output, :app_managed) SENSITIVE = [] include Aws::Structure end |