Class: Aws::SageMaker::Types::ProcessingStoppingCondition
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ProcessingStoppingCondition
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Configures conditions under which the processing job should be stopped, such as how long the processing job has been running. After the condition is met, the processing job is stopped.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_runtime_in_seconds ⇒ Integer
Specifies the maximum runtime in seconds.
Instance Attribute Details
#max_runtime_in_seconds ⇒ Integer
Specifies the maximum runtime in seconds.
46256 46257 46258 46259 46260 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46256 class ProcessingStoppingCondition < Struct.new( :max_runtime_in_seconds) SENSITIVE = [] include Aws::Structure end |