Class: Aws::SageMaker::Types::ProcessingStoppingCondition

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Configures conditions under which the processing job should be stopped, such as how long the processing job has been running. After the condition is met, the processing job is stopped.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_runtime_in_secondsInteger

Specifies the maximum runtime in seconds.

Returns:

  • (Integer)


43842
43843
43844
43845
43846
# File 'lib/aws-sdk-sagemaker/types.rb', line 43842

class ProcessingStoppingCondition < Struct.new(
  :max_runtime_in_seconds)
  SENSITIVE = []
  include Aws::Structure
end