Class: Aws::SageMaker::Types::ProfilerConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Configuration information for Amazon SageMaker Debugger system monitoring, framework profiling, and storage paths.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#disable_profilerBoolean

Configuration to turn off Amazon SageMaker Debugger’s system monitoring and profiling functionality. To turn it off, set to ‘True`.

Returns:

  • (Boolean)


45907
45908
45909
45910
45911
45912
45913
45914
# File 'lib/aws-sdk-sagemaker/types.rb', line 45907

class ProfilerConfig < Struct.new(
  :s3_output_path,
  :profiling_interval_in_milliseconds,
  :profiling_parameters,
  :disable_profiler)
  SENSITIVE = []
  include Aws::Structure
end

#profiling_interval_in_millisecondsInteger

A time interval for capturing system metrics in milliseconds. Available values are 100, 200, 500, 1000 (1 second), 5000 (5 seconds), and 60000 (1 minute) milliseconds. The default value is 500 milliseconds.

Returns:

  • (Integer)


45907
45908
45909
45910
45911
45912
45913
45914
# File 'lib/aws-sdk-sagemaker/types.rb', line 45907

class ProfilerConfig < Struct.new(
  :s3_output_path,
  :profiling_interval_in_milliseconds,
  :profiling_parameters,
  :disable_profiler)
  SENSITIVE = []
  include Aws::Structure
end

#profiling_parametersHash<String,String>

Configuration information for capturing framework metrics. Available key strings for different profiling options are ‘DetailedProfilingConfig`, `PythonProfilingConfig`, and `DataLoaderProfilingConfig`. The following codes are configuration structures for the `ProfilingParameters` parameter. To learn more about how to configure the `ProfilingParameters` parameter, see [Use the SageMaker and Debugger Configuration API Operations to Create, Update, and Debug Your Training Job].

[1]: docs.aws.amazon.com/sagemaker/latest/dg/debugger-createtrainingjob-api.html

Returns:

  • (Hash<String,String>)


45907
45908
45909
45910
45911
45912
45913
45914
# File 'lib/aws-sdk-sagemaker/types.rb', line 45907

class ProfilerConfig < Struct.new(
  :s3_output_path,
  :profiling_interval_in_milliseconds,
  :profiling_parameters,
  :disable_profiler)
  SENSITIVE = []
  include Aws::Structure
end

#s3_output_pathString

Path to Amazon S3 storage location for system and framework metrics.

Returns:

  • (String)


45907
45908
45909
45910
45911
45912
45913
45914
# File 'lib/aws-sdk-sagemaker/types.rb', line 45907

class ProfilerConfig < Struct.new(
  :s3_output_path,
  :profiling_interval_in_milliseconds,
  :profiling_parameters,
  :disable_profiler)
  SENSITIVE = []
  include Aws::Structure
end