Class: Aws::SageMaker::Types::ProfilerConfigForUpdate
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ProfilerConfigForUpdate
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Configuration information for updating the Amazon SageMaker Debugger profile parameters, system and framework metrics configurations, and storage paths.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#disable_profiler ⇒ Boolean
To turn off Amazon SageMaker Debugger monitoring and profiling while a training job is in progress, set to ‘True`.
-
#profiling_interval_in_milliseconds ⇒ Integer
A time interval for capturing system metrics in milliseconds.
-
#profiling_parameters ⇒ Hash<String,String>
Configuration information for capturing framework metrics.
-
#s3_output_path ⇒ String
Path to Amazon S3 storage location for system and framework metrics.
Instance Attribute Details
#disable_profiler ⇒ Boolean
To turn off Amazon SageMaker Debugger monitoring and profiling while a training job is in progress, set to ‘True`.
46969 46970 46971 46972 46973 46974 46975 46976 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46969 class ProfilerConfigForUpdate < Struct.new( :s3_output_path, :profiling_interval_in_milliseconds, :profiling_parameters, :disable_profiler) SENSITIVE = [] include Aws::Structure end |
#profiling_interval_in_milliseconds ⇒ Integer
A time interval for capturing system metrics in milliseconds. Available values are 100, 200, 500, 1000 (1 second), 5000 (5 seconds), and 60000 (1 minute) milliseconds. The default value is 500 milliseconds.
46969 46970 46971 46972 46973 46974 46975 46976 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46969 class ProfilerConfigForUpdate < Struct.new( :s3_output_path, :profiling_interval_in_milliseconds, :profiling_parameters, :disable_profiler) SENSITIVE = [] include Aws::Structure end |
#profiling_parameters ⇒ Hash<String,String>
Configuration information for capturing framework metrics. Available key strings for different profiling options are ‘DetailedProfilingConfig`, `PythonProfilingConfig`, and `DataLoaderProfilingConfig`. The following codes are configuration structures for the `ProfilingParameters` parameter. To learn more about how to configure the `ProfilingParameters` parameter, see [Use the SageMaker and Debugger Configuration API Operations to Create, Update, and Debug Your Training Job].
[1]: docs.aws.amazon.com/sagemaker/latest/dg/debugger-createtrainingjob-api.html
46969 46970 46971 46972 46973 46974 46975 46976 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46969 class ProfilerConfigForUpdate < Struct.new( :s3_output_path, :profiling_interval_in_milliseconds, :profiling_parameters, :disable_profiler) SENSITIVE = [] include Aws::Structure end |
#s3_output_path ⇒ String
Path to Amazon S3 storage location for system and framework metrics.
46969 46970 46971 46972 46973 46974 46975 46976 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46969 class ProfilerConfigForUpdate < Struct.new( :s3_output_path, :profiling_interval_in_milliseconds, :profiling_parameters, :disable_profiler) SENSITIVE = [] include Aws::Structure end |