Class: Aws::SageMaker::Types::Project

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The properties of a project as returned by the Search API.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_byTypes::UserContext

Who created the project.

Returns:



47691
47692
47693
47694
47695
47696
47697
47698
47699
47700
47701
47702
47703
47704
47705
47706
47707
# File 'lib/aws-sdk-sagemaker/types.rb', line 47691

class Project < Struct.new(
  :project_arn,
  :project_name,
  :project_id,
  :project_description,
  :service_catalog_provisioning_details,
  :service_catalog_provisioned_product_details,
  :project_status,
  :created_by,
  :creation_time,
  :template_provider_details,
  :tags,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

A timestamp specifying when the project was created.

Returns:

  • (Time)


47691
47692
47693
47694
47695
47696
47697
47698
47699
47700
47701
47702
47703
47704
47705
47706
47707
# File 'lib/aws-sdk-sagemaker/types.rb', line 47691

class Project < Struct.new(
  :project_arn,
  :project_name,
  :project_id,
  :project_description,
  :service_catalog_provisioning_details,
  :service_catalog_provisioned_product_details,
  :project_status,
  :created_by,
  :creation_time,
  :template_provider_details,
  :tags,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_byTypes::UserContext

Information about the user who created or modified a SageMaker resource.

Returns:



47691
47692
47693
47694
47695
47696
47697
47698
47699
47700
47701
47702
47703
47704
47705
47706
47707
# File 'lib/aws-sdk-sagemaker/types.rb', line 47691

class Project < Struct.new(
  :project_arn,
  :project_name,
  :project_id,
  :project_description,
  :service_catalog_provisioning_details,
  :service_catalog_provisioned_product_details,
  :project_status,
  :created_by,
  :creation_time,
  :template_provider_details,
  :tags,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

A timestamp container for when the project was last modified.

Returns:

  • (Time)


47691
47692
47693
47694
47695
47696
47697
47698
47699
47700
47701
47702
47703
47704
47705
47706
47707
# File 'lib/aws-sdk-sagemaker/types.rb', line 47691

class Project < Struct.new(
  :project_arn,
  :project_name,
  :project_id,
  :project_description,
  :service_catalog_provisioning_details,
  :service_catalog_provisioned_product_details,
  :project_status,
  :created_by,
  :creation_time,
  :template_provider_details,
  :tags,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#project_arnString

The Amazon Resource Name (ARN) of the project.

Returns:

  • (String)


47691
47692
47693
47694
47695
47696
47697
47698
47699
47700
47701
47702
47703
47704
47705
47706
47707
# File 'lib/aws-sdk-sagemaker/types.rb', line 47691

class Project < Struct.new(
  :project_arn,
  :project_name,
  :project_id,
  :project_description,
  :service_catalog_provisioning_details,
  :service_catalog_provisioned_product_details,
  :project_status,
  :created_by,
  :creation_time,
  :template_provider_details,
  :tags,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#project_descriptionString

The description of the project.

Returns:

  • (String)


47691
47692
47693
47694
47695
47696
47697
47698
47699
47700
47701
47702
47703
47704
47705
47706
47707
# File 'lib/aws-sdk-sagemaker/types.rb', line 47691

class Project < Struct.new(
  :project_arn,
  :project_name,
  :project_id,
  :project_description,
  :service_catalog_provisioning_details,
  :service_catalog_provisioned_product_details,
  :project_status,
  :created_by,
  :creation_time,
  :template_provider_details,
  :tags,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#project_idString

The ID of the project.

Returns:

  • (String)


47691
47692
47693
47694
47695
47696
47697
47698
47699
47700
47701
47702
47703
47704
47705
47706
47707
# File 'lib/aws-sdk-sagemaker/types.rb', line 47691

class Project < Struct.new(
  :project_arn,
  :project_name,
  :project_id,
  :project_description,
  :service_catalog_provisioning_details,
  :service_catalog_provisioned_product_details,
  :project_status,
  :created_by,
  :creation_time,
  :template_provider_details,
  :tags,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#project_nameString

The name of the project.

Returns:

  • (String)


47691
47692
47693
47694
47695
47696
47697
47698
47699
47700
47701
47702
47703
47704
47705
47706
47707
# File 'lib/aws-sdk-sagemaker/types.rb', line 47691

class Project < Struct.new(
  :project_arn,
  :project_name,
  :project_id,
  :project_description,
  :service_catalog_provisioning_details,
  :service_catalog_provisioned_product_details,
  :project_status,
  :created_by,
  :creation_time,
  :template_provider_details,
  :tags,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#project_statusString

The status of the project.

Returns:

  • (String)


47691
47692
47693
47694
47695
47696
47697
47698
47699
47700
47701
47702
47703
47704
47705
47706
47707
# File 'lib/aws-sdk-sagemaker/types.rb', line 47691

class Project < Struct.new(
  :project_arn,
  :project_name,
  :project_id,
  :project_description,
  :service_catalog_provisioning_details,
  :service_catalog_provisioned_product_details,
  :project_status,
  :created_by,
  :creation_time,
  :template_provider_details,
  :tags,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#service_catalog_provisioned_product_detailsTypes::ServiceCatalogProvisionedProductDetails

Details of a provisioned service catalog product. For information about service catalog, see What is Amazon Web Services Service Catalog.



47691
47692
47693
47694
47695
47696
47697
47698
47699
47700
47701
47702
47703
47704
47705
47706
47707
# File 'lib/aws-sdk-sagemaker/types.rb', line 47691

class Project < Struct.new(
  :project_arn,
  :project_name,
  :project_id,
  :project_description,
  :service_catalog_provisioning_details,
  :service_catalog_provisioned_product_details,
  :project_status,
  :created_by,
  :creation_time,
  :template_provider_details,
  :tags,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#service_catalog_provisioning_detailsTypes::ServiceCatalogProvisioningDetails

Details that you specify to provision a service catalog product. For information about service catalog, see What is Amazon Web Services Service Catalog.



47691
47692
47693
47694
47695
47696
47697
47698
47699
47700
47701
47702
47703
47704
47705
47706
47707
# File 'lib/aws-sdk-sagemaker/types.rb', line 47691

class Project < Struct.new(
  :project_arn,
  :project_name,
  :project_id,
  :project_description,
  :service_catalog_provisioning_details,
  :service_catalog_provisioned_product_details,
  :project_status,
  :created_by,
  :creation_time,
  :template_provider_details,
  :tags,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

An array of key-value pairs. You can use tags to categorize your Amazon Web Services resources in different ways, for example, by purpose, owner, or environment. For more information, see Tagging Amazon Web Services Resources.

Returns:



47691
47692
47693
47694
47695
47696
47697
47698
47699
47700
47701
47702
47703
47704
47705
47706
47707
# File 'lib/aws-sdk-sagemaker/types.rb', line 47691

class Project < Struct.new(
  :project_arn,
  :project_name,
  :project_id,
  :project_description,
  :service_catalog_provisioning_details,
  :service_catalog_provisioned_product_details,
  :project_status,
  :created_by,
  :creation_time,
  :template_provider_details,
  :tags,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end

#template_provider_detailsArray<Types::TemplateProviderDetail>

An array of template providers associated with the project.

Returns:



47691
47692
47693
47694
47695
47696
47697
47698
47699
47700
47701
47702
47703
47704
47705
47706
47707
# File 'lib/aws-sdk-sagemaker/types.rb', line 47691

class Project < Struct.new(
  :project_arn,
  :project_name,
  :project_id,
  :project_description,
  :service_catalog_provisioning_details,
  :service_catalog_provisioned_product_details,
  :project_status,
  :created_by,
  :creation_time,
  :template_provider_details,
  :tags,
  :last_modified_time,
  :last_modified_by)
  SENSITIVE = []
  include Aws::Structure
end