Class: Aws::SageMaker::Types::QualityCheckStepMetadata

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Container for the metadata for a Quality check step. For more information, see the topic on [QualityCheck step] in the *Amazon SageMaker Developer Guide*.

[1]: docs.aws.amazon.com/sagemaker/latest/dg/build-and-manage-steps.html#step-type-quality-check

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#baseline_used_for_drift_check_constraintsString

The Amazon S3 URI of the baseline constraints file used for the drift check.

Returns:



44762
44763
44764
44765
44766
44767
44768
44769
44770
44771
44772
44773
44774
44775
# File 'lib/aws-sdk-sagemaker/types.rb', line 44762

class  < Struct.new(
  :check_type,
  :baseline_used_for_drift_check_statistics,
  :baseline_used_for_drift_check_constraints,
  :calculated_baseline_statistics,
  :calculated_baseline_constraints,
  :model_package_group_name,
  :violation_report,
  :check_job_arn,
  :skip_check,
  :register_new_baseline)
  SENSITIVE = []
  include Aws::Structure
end

#baseline_used_for_drift_check_statisticsString

The Amazon S3 URI of the baseline statistics file used for the drift check.

Returns:



44762
44763
44764
44765
44766
44767
44768
44769
44770
44771
44772
44773
44774
44775
# File 'lib/aws-sdk-sagemaker/types.rb', line 44762

class  < Struct.new(
  :check_type,
  :baseline_used_for_drift_check_statistics,
  :baseline_used_for_drift_check_constraints,
  :calculated_baseline_statistics,
  :calculated_baseline_constraints,
  :model_package_group_name,
  :violation_report,
  :check_job_arn,
  :skip_check,
  :register_new_baseline)
  SENSITIVE = []
  include Aws::Structure
end

#calculated_baseline_constraintsString

The Amazon S3 URI of the newly calculated baseline constraints file.

Returns:



44762
44763
44764
44765
44766
44767
44768
44769
44770
44771
44772
44773
44774
44775
# File 'lib/aws-sdk-sagemaker/types.rb', line 44762

class  < Struct.new(
  :check_type,
  :baseline_used_for_drift_check_statistics,
  :baseline_used_for_drift_check_constraints,
  :calculated_baseline_statistics,
  :calculated_baseline_constraints,
  :model_package_group_name,
  :violation_report,
  :check_job_arn,
  :skip_check,
  :register_new_baseline)
  SENSITIVE = []
  include Aws::Structure
end

#calculated_baseline_statisticsString

The Amazon S3 URI of the newly calculated baseline statistics file.

Returns:



44762
44763
44764
44765
44766
44767
44768
44769
44770
44771
44772
44773
44774
44775
# File 'lib/aws-sdk-sagemaker/types.rb', line 44762

class  < Struct.new(
  :check_type,
  :baseline_used_for_drift_check_statistics,
  :baseline_used_for_drift_check_constraints,
  :calculated_baseline_statistics,
  :calculated_baseline_constraints,
  :model_package_group_name,
  :violation_report,
  :check_job_arn,
  :skip_check,
  :register_new_baseline)
  SENSITIVE = []
  include Aws::Structure
end

#check_job_arnString

The Amazon Resource Name (ARN) of the Quality check processing job that was run by this step execution.

Returns:



44762
44763
44764
44765
44766
44767
44768
44769
44770
44771
44772
44773
44774
44775
# File 'lib/aws-sdk-sagemaker/types.rb', line 44762

class  < Struct.new(
  :check_type,
  :baseline_used_for_drift_check_statistics,
  :baseline_used_for_drift_check_constraints,
  :calculated_baseline_statistics,
  :calculated_baseline_constraints,
  :model_package_group_name,
  :violation_report,
  :check_job_arn,
  :skip_check,
  :register_new_baseline)
  SENSITIVE = []
  include Aws::Structure
end

#check_typeString

The type of the Quality check step.

Returns:



44762
44763
44764
44765
44766
44767
44768
44769
44770
44771
44772
44773
44774
44775
# File 'lib/aws-sdk-sagemaker/types.rb', line 44762

class  < Struct.new(
  :check_type,
  :baseline_used_for_drift_check_statistics,
  :baseline_used_for_drift_check_constraints,
  :calculated_baseline_statistics,
  :calculated_baseline_constraints,
  :model_package_group_name,
  :violation_report,
  :check_job_arn,
  :skip_check,
  :register_new_baseline)
  SENSITIVE = []
  include Aws::Structure
end

#model_package_group_nameString

The model package group name.

Returns:



44762
44763
44764
44765
44766
44767
44768
44769
44770
44771
44772
44773
44774
44775
# File 'lib/aws-sdk-sagemaker/types.rb', line 44762

class  < Struct.new(
  :check_type,
  :baseline_used_for_drift_check_statistics,
  :baseline_used_for_drift_check_constraints,
  :calculated_baseline_statistics,
  :calculated_baseline_constraints,
  :model_package_group_name,
  :violation_report,
  :check_job_arn,
  :skip_check,
  :register_new_baseline)
  SENSITIVE = []
  include Aws::Structure
end

#register_new_baselineBoolean

This flag indicates if a newly calculated baseline can be accessed through step properties BaselineUsedForDriftCheckConstraints and BaselineUsedForDriftCheckStatistics. If it is set to False, the previous baseline of the configured check type must also be available. These can be accessed through the BaselineUsedForDriftCheckConstraints and ‘ BaselineUsedForDriftCheckStatistics` properties.

Returns:



44762
44763
44764
44765
44766
44767
44768
44769
44770
44771
44772
44773
44774
44775
# File 'lib/aws-sdk-sagemaker/types.rb', line 44762

class  < Struct.new(
  :check_type,
  :baseline_used_for_drift_check_statistics,
  :baseline_used_for_drift_check_constraints,
  :calculated_baseline_statistics,
  :calculated_baseline_constraints,
  :model_package_group_name,
  :violation_report,
  :check_job_arn,
  :skip_check,
  :register_new_baseline)
  SENSITIVE = []
  include Aws::Structure
end

#skip_checkBoolean

This flag indicates if the drift check against the previous baseline will be skipped or not. If it is set to False, the previous baseline of the configured check type must be available.

Returns:



44762
44763
44764
44765
44766
44767
44768
44769
44770
44771
44772
44773
44774
44775
# File 'lib/aws-sdk-sagemaker/types.rb', line 44762

class  < Struct.new(
  :check_type,
  :baseline_used_for_drift_check_statistics,
  :baseline_used_for_drift_check_constraints,
  :calculated_baseline_statistics,
  :calculated_baseline_constraints,
  :model_package_group_name,
  :violation_report,
  :check_job_arn,
  :skip_check,
  :register_new_baseline)
  SENSITIVE = []
  include Aws::Structure
end

#violation_reportString

The Amazon S3 URI of violation report if violations are detected.

Returns:



44762
44763
44764
44765
44766
44767
44768
44769
44770
44771
44772
44773
44774
44775
# File 'lib/aws-sdk-sagemaker/types.rb', line 44762

class  < Struct.new(
  :check_type,
  :baseline_used_for_drift_check_statistics,
  :baseline_used_for_drift_check_constraints,
  :calculated_baseline_statistics,
  :calculated_baseline_constraints,
  :model_package_group_name,
  :violation_report,
  :check_job_arn,
  :skip_check,
  :register_new_baseline)
  SENSITIVE = []
  include Aws::Structure
end