Class: Aws::SageMaker::Types::QualityCheckStepMetadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::QualityCheckStepMetadata
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Container for the metadata for a Quality check step. For more information, see the topic on [QualityCheck step] in the *Amazon SageMaker Developer Guide*.
[1]: docs.aws.amazon.com/sagemaker/latest/dg/build-and-manage-steps.html#step-type-quality-check
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#baseline_used_for_drift_check_constraints ⇒ String
The Amazon S3 URI of the baseline constraints file used for the drift check.
-
#baseline_used_for_drift_check_statistics ⇒ String
The Amazon S3 URI of the baseline statistics file used for the drift check.
-
#calculated_baseline_constraints ⇒ String
The Amazon S3 URI of the newly calculated baseline constraints file.
-
#calculated_baseline_statistics ⇒ String
The Amazon S3 URI of the newly calculated baseline statistics file.
-
#check_job_arn ⇒ String
The Amazon Resource Name (ARN) of the Quality check processing job that was run by this step execution.
-
#check_type ⇒ String
The type of the Quality check step.
-
#model_package_group_name ⇒ String
The model package group name.
-
#register_new_baseline ⇒ Boolean
This flag indicates if a newly calculated baseline can be accessed through step properties
BaselineUsedForDriftCheckConstraintsandBaselineUsedForDriftCheckStatistics. -
#skip_check ⇒ Boolean
This flag indicates if the drift check against the previous baseline will be skipped or not.
-
#violation_report ⇒ String
The Amazon S3 URI of violation report if violations are detected.
Instance Attribute Details
#baseline_used_for_drift_check_constraints ⇒ String
The Amazon S3 URI of the baseline constraints file used for the drift check.
44660 44661 44662 44663 44664 44665 44666 44667 44668 44669 44670 44671 44672 44673 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44660 class QualityCheckStepMetadata < Struct.new( :check_type, :baseline_used_for_drift_check_statistics, :baseline_used_for_drift_check_constraints, :calculated_baseline_statistics, :calculated_baseline_constraints, :model_package_group_name, :violation_report, :check_job_arn, :skip_check, :register_new_baseline) SENSITIVE = [] include Aws::Structure end |
#baseline_used_for_drift_check_statistics ⇒ String
The Amazon S3 URI of the baseline statistics file used for the drift check.
44660 44661 44662 44663 44664 44665 44666 44667 44668 44669 44670 44671 44672 44673 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44660 class QualityCheckStepMetadata < Struct.new( :check_type, :baseline_used_for_drift_check_statistics, :baseline_used_for_drift_check_constraints, :calculated_baseline_statistics, :calculated_baseline_constraints, :model_package_group_name, :violation_report, :check_job_arn, :skip_check, :register_new_baseline) SENSITIVE = [] include Aws::Structure end |
#calculated_baseline_constraints ⇒ String
The Amazon S3 URI of the newly calculated baseline constraints file.
44660 44661 44662 44663 44664 44665 44666 44667 44668 44669 44670 44671 44672 44673 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44660 class QualityCheckStepMetadata < Struct.new( :check_type, :baseline_used_for_drift_check_statistics, :baseline_used_for_drift_check_constraints, :calculated_baseline_statistics, :calculated_baseline_constraints, :model_package_group_name, :violation_report, :check_job_arn, :skip_check, :register_new_baseline) SENSITIVE = [] include Aws::Structure end |
#calculated_baseline_statistics ⇒ String
The Amazon S3 URI of the newly calculated baseline statistics file.
44660 44661 44662 44663 44664 44665 44666 44667 44668 44669 44670 44671 44672 44673 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44660 class QualityCheckStepMetadata < Struct.new( :check_type, :baseline_used_for_drift_check_statistics, :baseline_used_for_drift_check_constraints, :calculated_baseline_statistics, :calculated_baseline_constraints, :model_package_group_name, :violation_report, :check_job_arn, :skip_check, :register_new_baseline) SENSITIVE = [] include Aws::Structure end |
#check_job_arn ⇒ String
The Amazon Resource Name (ARN) of the Quality check processing job that was run by this step execution.
44660 44661 44662 44663 44664 44665 44666 44667 44668 44669 44670 44671 44672 44673 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44660 class QualityCheckStepMetadata < Struct.new( :check_type, :baseline_used_for_drift_check_statistics, :baseline_used_for_drift_check_constraints, :calculated_baseline_statistics, :calculated_baseline_constraints, :model_package_group_name, :violation_report, :check_job_arn, :skip_check, :register_new_baseline) SENSITIVE = [] include Aws::Structure end |
#check_type ⇒ String
The type of the Quality check step.
44660 44661 44662 44663 44664 44665 44666 44667 44668 44669 44670 44671 44672 44673 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44660 class QualityCheckStepMetadata < Struct.new( :check_type, :baseline_used_for_drift_check_statistics, :baseline_used_for_drift_check_constraints, :calculated_baseline_statistics, :calculated_baseline_constraints, :model_package_group_name, :violation_report, :check_job_arn, :skip_check, :register_new_baseline) SENSITIVE = [] include Aws::Structure end |
#model_package_group_name ⇒ String
The model package group name.
44660 44661 44662 44663 44664 44665 44666 44667 44668 44669 44670 44671 44672 44673 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44660 class QualityCheckStepMetadata < Struct.new( :check_type, :baseline_used_for_drift_check_statistics, :baseline_used_for_drift_check_constraints, :calculated_baseline_statistics, :calculated_baseline_constraints, :model_package_group_name, :violation_report, :check_job_arn, :skip_check, :register_new_baseline) SENSITIVE = [] include Aws::Structure end |
#register_new_baseline ⇒ Boolean
This flag indicates if a newly calculated baseline can be accessed through step properties BaselineUsedForDriftCheckConstraints and BaselineUsedForDriftCheckStatistics. If it is set to False, the previous baseline of the configured check type must also be available. These can be accessed through the BaselineUsedForDriftCheckConstraints and ‘ BaselineUsedForDriftCheckStatistics` properties.
44660 44661 44662 44663 44664 44665 44666 44667 44668 44669 44670 44671 44672 44673 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44660 class QualityCheckStepMetadata < Struct.new( :check_type, :baseline_used_for_drift_check_statistics, :baseline_used_for_drift_check_constraints, :calculated_baseline_statistics, :calculated_baseline_constraints, :model_package_group_name, :violation_report, :check_job_arn, :skip_check, :register_new_baseline) SENSITIVE = [] include Aws::Structure end |
#skip_check ⇒ Boolean
This flag indicates if the drift check against the previous baseline will be skipped or not. If it is set to False, the previous baseline of the configured check type must be available.
44660 44661 44662 44663 44664 44665 44666 44667 44668 44669 44670 44671 44672 44673 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44660 class QualityCheckStepMetadata < Struct.new( :check_type, :baseline_used_for_drift_check_statistics, :baseline_used_for_drift_check_constraints, :calculated_baseline_statistics, :calculated_baseline_constraints, :model_package_group_name, :violation_report, :check_job_arn, :skip_check, :register_new_baseline) SENSITIVE = [] include Aws::Structure end |
#violation_report ⇒ String
The Amazon S3 URI of violation report if violations are detected.
44660 44661 44662 44663 44664 44665 44666 44667 44668 44669 44670 44671 44672 44673 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 44660 class QualityCheckStepMetadata < Struct.new( :check_type, :baseline_used_for_drift_check_statistics, :baseline_used_for_drift_check_constraints, :calculated_baseline_statistics, :calculated_baseline_constraints, :model_package_group_name, :violation_report, :check_job_arn, :skip_check, :register_new_baseline) SENSITIVE = [] include Aws::Structure end |