Class: Aws::SageMaker::Types::RStudioServerProAppSettings

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

A collection of settings that configure user interaction with the RStudioServerPro app.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_statusString

Indicates whether the current user has access to the RStudioServerPro app.

Returns:

  • (String)


40159
40160
40161
40162
40163
40164
# File 'lib/aws-sdk-sagemaker/types.rb', line 40159

class RStudioServerProAppSettings < Struct.new(
  :access_status,
  :user_group)
  SENSITIVE = []
  include Aws::Structure
end

#user_groupString

The level of permissions that the user has within the RStudioServerPro app. This value defaults to User. The Admin value allows the user access to the RStudio Administrative Dashboard.

Returns:

  • (String)


40159
40160
40161
40162
40163
40164
# File 'lib/aws-sdk-sagemaker/types.rb', line 40159

class RStudioServerProAppSettings < Struct.new(
  :access_status,
  :user_group)
  SENSITIVE = []
  include Aws::Structure
end