Class: Aws::SageMaker::Types::RStudioServerProAppSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::RStudioServerProAppSettings
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
A collection of settings that configure user interaction with the RStudioServerPro app.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_status ⇒ String
Indicates whether the current user has access to the
RStudioServerProapp. -
#user_group ⇒ String
The level of permissions that the user has within the
RStudioServerProapp.
Instance Attribute Details
#access_status ⇒ String
Indicates whether the current user has access to the RStudioServerPro app.
36523 36524 36525 36526 36527 36528 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36523 class RStudioServerProAppSettings < Struct.new( :access_status, :user_group) SENSITIVE = [] include Aws::Structure end |
#user_group ⇒ String
The level of permissions that the user has within the RStudioServerPro app. This value defaults to User. The Admin value allows the user access to the RStudio Administrative Dashboard.
36523 36524 36525 36526 36527 36528 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 36523 class RStudioServerProAppSettings < Struct.new( :access_status, :user_group) SENSITIVE = [] include Aws::Structure end |