Class: Aws::SageMaker::Types::RStudioServerProAppSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::RStudioServerProAppSettings
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
A collection of settings that configure user interaction with the RStudioServerPro app. RStudioServerProAppSettings cannot be updated. The RStudioServerPro app must be deleted and a new one created to make any changes.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_status ⇒ String
Indicates whether the current user has access to the
RStudioServerProapp. -
#user_group ⇒ String
The level of permissions that the user has within the
RStudioServerProapp.
Instance Attribute Details
#access_status ⇒ String
Indicates whether the current user has access to the RStudioServerPro app.
32522 32523 32524 32525 32526 32527 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32522 class RStudioServerProAppSettings < Struct.new( :access_status, :user_group) SENSITIVE = [] include Aws::Structure end |
#user_group ⇒ String
The level of permissions that the user has within the RStudioServerPro app. This value defaults to User. The Admin value allows the user access to the RStudio Administrative Dashboard.
32522 32523 32524 32525 32526 32527 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 32522 class RStudioServerProAppSettings < Struct.new( :access_status, :user_group) SENSITIVE = [] include Aws::Structure end |