Class: Aws::SageMaker::Types::RStudioServerProDomainSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::RStudioServerProDomainSettings
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
A collection of settings that configure the RStudioServerPro Domain-level app.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#default_resource_spec ⇒ Types::ResourceSpec
Specifies the ARN’s of a SageMaker AI image and SageMaker AI image version, and the instance type that the version runs on.
-
#domain_execution_role_arn ⇒ String
The ARN of the execution role for the
RStudioServerProDomain-level app. -
#r_studio_connect_url ⇒ String
A URL pointing to an RStudio Connect server.
-
#r_studio_package_manager_url ⇒ String
A URL pointing to an RStudio Package Manager server.
Instance Attribute Details
#default_resource_spec ⇒ Types::ResourceSpec
Specifies the ARN’s of a SageMaker AI image and SageMaker AI image version, and the instance type that the version runs on.
40189 40190 40191 40192 40193 40194 40195 40196 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40189 class RStudioServerProDomainSettings < Struct.new( :domain_execution_role_arn, :r_studio_connect_url, :r_studio_package_manager_url, :default_resource_spec) SENSITIVE = [] include Aws::Structure end |
#domain_execution_role_arn ⇒ String
The ARN of the execution role for the RStudioServerPro Domain-level app.
40189 40190 40191 40192 40193 40194 40195 40196 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40189 class RStudioServerProDomainSettings < Struct.new( :domain_execution_role_arn, :r_studio_connect_url, :r_studio_package_manager_url, :default_resource_spec) SENSITIVE = [] include Aws::Structure end |
#r_studio_connect_url ⇒ String
A URL pointing to an RStudio Connect server.
40189 40190 40191 40192 40193 40194 40195 40196 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40189 class RStudioServerProDomainSettings < Struct.new( :domain_execution_role_arn, :r_studio_connect_url, :r_studio_package_manager_url, :default_resource_spec) SENSITIVE = [] include Aws::Structure end |
#r_studio_package_manager_url ⇒ String
A URL pointing to an RStudio Package Manager server.
40189 40190 40191 40192 40193 40194 40195 40196 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 40189 class RStudioServerProDomainSettings < Struct.new( :domain_execution_role_arn, :r_studio_connect_url, :r_studio_package_manager_url, :default_resource_spec) SENSITIVE = [] include Aws::Structure end |