Class: Aws::SageMaker::Types::RStudioServerProDomainSettingsForUpdate

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

A collection of settings that update the current configuration for the RStudioServerPro Domain-level app.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#default_resource_specTypes::ResourceSpec

Specifies the ARN's of a SageMaker AI image and SageMaker AI image version, and the instance type that the version runs on.

When both SageMakerImageVersionArn and SageMakerImageArn are passed, SageMakerImageVersionArn is used. Any updates to SageMakerImageArn will not take effect if SageMakerImageVersionArn already exists in the ResourceSpec because SageMakerImageVersionArn always takes precedence. To clear the value set for SageMakerImageVersionArn, pass None as the value.

Returns:



48192
48193
48194
48195
48196
48197
48198
48199
# File 'lib/aws-sdk-sagemaker/types.rb', line 48192

class RStudioServerProDomainSettingsForUpdate < Struct.new(
  :domain_execution_role_arn,
  :default_resource_spec,
  :r_studio_connect_url,
  :r_studio_package_manager_url)
  SENSITIVE = []
  include Aws::Structure
end

#domain_execution_role_arnString

The execution role for the RStudioServerPro Domain-level app.

Returns:

  • (String)


48192
48193
48194
48195
48196
48197
48198
48199
# File 'lib/aws-sdk-sagemaker/types.rb', line 48192

class RStudioServerProDomainSettingsForUpdate < Struct.new(
  :domain_execution_role_arn,
  :default_resource_spec,
  :r_studio_connect_url,
  :r_studio_package_manager_url)
  SENSITIVE = []
  include Aws::Structure
end

#r_studio_connect_urlString

A URL pointing to an RStudio Connect server.

Returns:

  • (String)


48192
48193
48194
48195
48196
48197
48198
48199
# File 'lib/aws-sdk-sagemaker/types.rb', line 48192

class RStudioServerProDomainSettingsForUpdate < Struct.new(
  :domain_execution_role_arn,
  :default_resource_spec,
  :r_studio_connect_url,
  :r_studio_package_manager_url)
  SENSITIVE = []
  include Aws::Structure
end

#r_studio_package_manager_urlString

A URL pointing to an RStudio Package Manager server.

Returns:

  • (String)


48192
48193
48194
48195
48196
48197
48198
48199
# File 'lib/aws-sdk-sagemaker/types.rb', line 48192

class RStudioServerProDomainSettingsForUpdate < Struct.new(
  :domain_execution_role_arn,
  :default_resource_spec,
  :r_studio_connect_url,
  :r_studio_package_manager_url)
  SENSITIVE = []
  include Aws::Structure
end