Class: Aws::SageMaker::Types::RStudioServerProDomainSettingsForUpdate
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::RStudioServerProDomainSettingsForUpdate
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
A collection of settings that update the current configuration for the
RStudioServerPro Domain-level app.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#default_resource_spec ⇒ Types::ResourceSpec
Specifies the ARN's of a SageMaker AI image and SageMaker AI image version, and the instance type that the version runs on.
-
#domain_execution_role_arn ⇒ String
The execution role for the
RStudioServerProDomain-level app. -
#r_studio_connect_url ⇒ String
A URL pointing to an RStudio Connect server.
-
#r_studio_package_manager_url ⇒ String
A URL pointing to an RStudio Package Manager server.
Instance Attribute Details
#default_resource_spec ⇒ Types::ResourceSpec
Specifies the ARN's of a SageMaker AI image and SageMaker AI image version, and the instance type that the version runs on.
SageMakerImageVersionArn and SageMakerImageArn are
passed, SageMakerImageVersionArn is used. Any updates to
SageMakerImageArn will not take effect if
SageMakerImageVersionArn already exists in the ResourceSpec
because SageMakerImageVersionArn always takes precedence. To clear
the value set for SageMakerImageVersionArn, pass None as the
value.
48166 48167 48168 48169 48170 48171 48172 48173 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 48166 class RStudioServerProDomainSettingsForUpdate < Struct.new( :domain_execution_role_arn, :default_resource_spec, :r_studio_connect_url, :r_studio_package_manager_url) SENSITIVE = [] include Aws::Structure end |
#domain_execution_role_arn ⇒ String
The execution role for the RStudioServerPro Domain-level app.
48166 48167 48168 48169 48170 48171 48172 48173 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 48166 class RStudioServerProDomainSettingsForUpdate < Struct.new( :domain_execution_role_arn, :default_resource_spec, :r_studio_connect_url, :r_studio_package_manager_url) SENSITIVE = [] include Aws::Structure end |
#r_studio_connect_url ⇒ String
A URL pointing to an RStudio Connect server.
48166 48167 48168 48169 48170 48171 48172 48173 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 48166 class RStudioServerProDomainSettingsForUpdate < Struct.new( :domain_execution_role_arn, :default_resource_spec, :r_studio_connect_url, :r_studio_package_manager_url) SENSITIVE = [] include Aws::Structure end |
#r_studio_package_manager_url ⇒ String
A URL pointing to an RStudio Package Manager server.
48166 48167 48168 48169 48170 48171 48172 48173 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 48166 class RStudioServerProDomainSettingsForUpdate < Struct.new( :domain_execution_role_arn, :default_resource_spec, :r_studio_connect_url, :r_studio_package_manager_url) SENSITIVE = [] include Aws::Structure end |