Class: Aws::SageMaker::Types::RecommendationJobContainerConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::RecommendationJobContainerConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Specifies mandatory fields for running an Inference Recommender job
directly in the CreateInferenceRecommendationsJob API. The fields
specified in ContainerConfig override the corresponding fields in
the model package. Use ContainerConfig if you want to specify these
fields for the recommendation job but don't want to edit them in your
model package.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_input_config ⇒ String
Specifies the name and shape of the expected data inputs for your trained model with a JSON dictionary form.
-
#domain ⇒ String
The machine learning domain of the model and its components.
-
#framework ⇒ String
The machine learning framework of the container image.
-
#framework_version ⇒ String
The framework version of the container image.
-
#nearest_model_name ⇒ String
The name of a pre-trained machine learning model benchmarked by Amazon SageMaker Inference Recommender that matches your model.
-
#payload_config ⇒ Types::RecommendationJobPayloadConfig
Specifies the
SamplePayloadUrland all other sample payload-related fields. -
#supported_endpoint_type ⇒ String
The endpoint type to receive recommendations for.
-
#supported_instance_types ⇒ Array<String>
A list of the instance types that are used to generate inferences in real-time.
-
#supported_response_mime_types ⇒ Array<String>
The supported MIME types for the output data.
-
#task ⇒ String
The machine learning task that the model accomplishes.
Instance Attribute Details
#data_input_config ⇒ String
Specifies the name and shape of the expected data inputs for your trained model with a JSON dictionary form. This field is used for optimizing your model using SageMaker Neo. For more information, see DataInputConfig.
48557 48558 48559 48560 48561 48562 48563 48564 48565 48566 48567 48568 48569 48570 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 48557 class RecommendationJobContainerConfig < Struct.new( :domain, :task, :framework, :framework_version, :payload_config, :nearest_model_name, :supported_instance_types, :supported_endpoint_type, :data_input_config, :supported_response_mime_types) SENSITIVE = [] include Aws::Structure end |
#domain ⇒ String
The machine learning domain of the model and its components.
Valid Values: COMPUTER_VISION | NATURAL_LANGUAGE_PROCESSING | MACHINE_LEARNING
48557 48558 48559 48560 48561 48562 48563 48564 48565 48566 48567 48568 48569 48570 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 48557 class RecommendationJobContainerConfig < Struct.new( :domain, :task, :framework, :framework_version, :payload_config, :nearest_model_name, :supported_instance_types, :supported_endpoint_type, :data_input_config, :supported_response_mime_types) SENSITIVE = [] include Aws::Structure end |
#framework ⇒ String
The machine learning framework of the container image.
Valid Values: TENSORFLOW | PYTORCH | XGBOOST | SAGEMAKER-SCIKIT-LEARN
48557 48558 48559 48560 48561 48562 48563 48564 48565 48566 48567 48568 48569 48570 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 48557 class RecommendationJobContainerConfig < Struct.new( :domain, :task, :framework, :framework_version, :payload_config, :nearest_model_name, :supported_instance_types, :supported_endpoint_type, :data_input_config, :supported_response_mime_types) SENSITIVE = [] include Aws::Structure end |
#framework_version ⇒ String
The framework version of the container image.
48557 48558 48559 48560 48561 48562 48563 48564 48565 48566 48567 48568 48569 48570 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 48557 class RecommendationJobContainerConfig < Struct.new( :domain, :task, :framework, :framework_version, :payload_config, :nearest_model_name, :supported_instance_types, :supported_endpoint_type, :data_input_config, :supported_response_mime_types) SENSITIVE = [] include Aws::Structure end |
#nearest_model_name ⇒ String
The name of a pre-trained machine learning model benchmarked by Amazon SageMaker Inference Recommender that matches your model.
Valid Values: efficientnetb7 | unet | xgboost | faster-rcnn-resnet101 | nasnetlarge | vgg16 | inception-v3 | mask-rcnn | sagemaker-scikit-learn | densenet201-gluon | resnet18v2-gluon | xception | densenet201 | yolov4 | resnet152 | bert-base-cased | xceptionV1-keras | resnet50 | retinanet
48557 48558 48559 48560 48561 48562 48563 48564 48565 48566 48567 48568 48569 48570 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 48557 class RecommendationJobContainerConfig < Struct.new( :domain, :task, :framework, :framework_version, :payload_config, :nearest_model_name, :supported_instance_types, :supported_endpoint_type, :data_input_config, :supported_response_mime_types) SENSITIVE = [] include Aws::Structure end |
#payload_config ⇒ Types::RecommendationJobPayloadConfig
Specifies the SamplePayloadUrl and all other sample
payload-related fields.
48557 48558 48559 48560 48561 48562 48563 48564 48565 48566 48567 48568 48569 48570 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 48557 class RecommendationJobContainerConfig < Struct.new( :domain, :task, :framework, :framework_version, :payload_config, :nearest_model_name, :supported_instance_types, :supported_endpoint_type, :data_input_config, :supported_response_mime_types) SENSITIVE = [] include Aws::Structure end |
#supported_endpoint_type ⇒ String
The endpoint type to receive recommendations for. By default this is null, and the results of the inference recommendation job return a combined list of both real-time and serverless benchmarks. By specifying a value for this field, you can receive a longer list of benchmarks for the desired endpoint type.
48557 48558 48559 48560 48561 48562 48563 48564 48565 48566 48567 48568 48569 48570 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 48557 class RecommendationJobContainerConfig < Struct.new( :domain, :task, :framework, :framework_version, :payload_config, :nearest_model_name, :supported_instance_types, :supported_endpoint_type, :data_input_config, :supported_response_mime_types) SENSITIVE = [] include Aws::Structure end |
#supported_instance_types ⇒ Array<String>
A list of the instance types that are used to generate inferences in real-time.
48557 48558 48559 48560 48561 48562 48563 48564 48565 48566 48567 48568 48569 48570 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 48557 class RecommendationJobContainerConfig < Struct.new( :domain, :task, :framework, :framework_version, :payload_config, :nearest_model_name, :supported_instance_types, :supported_endpoint_type, :data_input_config, :supported_response_mime_types) SENSITIVE = [] include Aws::Structure end |
#supported_response_mime_types ⇒ Array<String>
The supported MIME types for the output data.
48557 48558 48559 48560 48561 48562 48563 48564 48565 48566 48567 48568 48569 48570 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 48557 class RecommendationJobContainerConfig < Struct.new( :domain, :task, :framework, :framework_version, :payload_config, :nearest_model_name, :supported_instance_types, :supported_endpoint_type, :data_input_config, :supported_response_mime_types) SENSITIVE = [] include Aws::Structure end |
#task ⇒ String
The machine learning task that the model accomplishes.
Valid Values: IMAGE_CLASSIFICATION | OBJECT_DETECTION | TEXT_GENERATION | IMAGE_SEGMENTATION | FILL_MASK | CLASSIFICATION | REGRESSION | OTHER
48557 48558 48559 48560 48561 48562 48563 48564 48565 48566 48567 48568 48569 48570 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 48557 class RecommendationJobContainerConfig < Struct.new( :domain, :task, :framework, :framework_version, :payload_config, :nearest_model_name, :supported_instance_types, :supported_endpoint_type, :data_input_config, :supported_response_mime_types) SENSITIVE = [] include Aws::Structure end |