Class: Aws::SageMaker::Types::RecommendationJobInputConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::RecommendationJobInputConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The input configuration of the recommendation job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#container_config ⇒ Types::RecommendationJobContainerConfig
Specifies mandatory fields for running an Inference Recommender job.
-
#endpoint_configurations ⇒ Array<Types::EndpointInputConfiguration>
Specifies the endpoint configuration to use for a job.
-
#endpoints ⇒ Array<Types::EndpointInfo>
Existing customer endpoints on which to run an Inference Recommender job.
-
#job_duration_in_seconds ⇒ Integer
Specifies the maximum duration of the job, in seconds.
-
#model_name ⇒ String
The name of the created model.
-
#model_package_version_arn ⇒ String
The Amazon Resource Name (ARN) of a versioned model package.
-
#resource_limit ⇒ Types::RecommendationJobResourceLimit
Defines the resource limit of the job.
-
#traffic_pattern ⇒ Types::TrafficPattern
Specifies the traffic pattern of the job.
-
#volume_kms_key_id ⇒ String
The Amazon Resource Name (ARN) of a Amazon Web Services Key Management Service (Amazon Web Services KMS) key that Amazon SageMaker uses to encrypt data on the storage volume attached to the ML compute instance that hosts the endpoint.
-
#vpc_config ⇒ Types::RecommendationJobVpcConfig
Inference Recommender provisions SageMaker endpoints with access to VPC in the inference recommendation job.
Instance Attribute Details
#container_config ⇒ Types::RecommendationJobContainerConfig
Specifies mandatory fields for running an Inference Recommender job. The fields specified in ‘ContainerConfig` override the corresponding fields in the model package.
45261 45262 45263 45264 45265 45266 45267 45268 45269 45270 45271 45272 45273 45274 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 45261 class RecommendationJobInputConfig < Struct.new( :model_package_version_arn, :model_name, :job_duration_in_seconds, :traffic_pattern, :resource_limit, :endpoint_configurations, :volume_kms_key_id, :container_config, :endpoints, :vpc_config) SENSITIVE = [] include Aws::Structure end |
#endpoint_configurations ⇒ Array<Types::EndpointInputConfiguration>
Specifies the endpoint configuration to use for a job.
45261 45262 45263 45264 45265 45266 45267 45268 45269 45270 45271 45272 45273 45274 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 45261 class RecommendationJobInputConfig < Struct.new( :model_package_version_arn, :model_name, :job_duration_in_seconds, :traffic_pattern, :resource_limit, :endpoint_configurations, :volume_kms_key_id, :container_config, :endpoints, :vpc_config) SENSITIVE = [] include Aws::Structure end |
#endpoints ⇒ Array<Types::EndpointInfo>
Existing customer endpoints on which to run an Inference Recommender job.
45261 45262 45263 45264 45265 45266 45267 45268 45269 45270 45271 45272 45273 45274 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 45261 class RecommendationJobInputConfig < Struct.new( :model_package_version_arn, :model_name, :job_duration_in_seconds, :traffic_pattern, :resource_limit, :endpoint_configurations, :volume_kms_key_id, :container_config, :endpoints, :vpc_config) SENSITIVE = [] include Aws::Structure end |
#job_duration_in_seconds ⇒ Integer
Specifies the maximum duration of the job, in seconds. The maximum value is 18,000 seconds.
45261 45262 45263 45264 45265 45266 45267 45268 45269 45270 45271 45272 45273 45274 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 45261 class RecommendationJobInputConfig < Struct.new( :model_package_version_arn, :model_name, :job_duration_in_seconds, :traffic_pattern, :resource_limit, :endpoint_configurations, :volume_kms_key_id, :container_config, :endpoints, :vpc_config) SENSITIVE = [] include Aws::Structure end |
#model_name ⇒ String
The name of the created model.
45261 45262 45263 45264 45265 45266 45267 45268 45269 45270 45271 45272 45273 45274 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 45261 class RecommendationJobInputConfig < Struct.new( :model_package_version_arn, :model_name, :job_duration_in_seconds, :traffic_pattern, :resource_limit, :endpoint_configurations, :volume_kms_key_id, :container_config, :endpoints, :vpc_config) SENSITIVE = [] include Aws::Structure end |
#model_package_version_arn ⇒ String
The Amazon Resource Name (ARN) of a versioned model package.
45261 45262 45263 45264 45265 45266 45267 45268 45269 45270 45271 45272 45273 45274 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 45261 class RecommendationJobInputConfig < Struct.new( :model_package_version_arn, :model_name, :job_duration_in_seconds, :traffic_pattern, :resource_limit, :endpoint_configurations, :volume_kms_key_id, :container_config, :endpoints, :vpc_config) SENSITIVE = [] include Aws::Structure end |
#resource_limit ⇒ Types::RecommendationJobResourceLimit
Defines the resource limit of the job.
45261 45262 45263 45264 45265 45266 45267 45268 45269 45270 45271 45272 45273 45274 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 45261 class RecommendationJobInputConfig < Struct.new( :model_package_version_arn, :model_name, :job_duration_in_seconds, :traffic_pattern, :resource_limit, :endpoint_configurations, :volume_kms_key_id, :container_config, :endpoints, :vpc_config) SENSITIVE = [] include Aws::Structure end |
#traffic_pattern ⇒ Types::TrafficPattern
Specifies the traffic pattern of the job.
45261 45262 45263 45264 45265 45266 45267 45268 45269 45270 45271 45272 45273 45274 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 45261 class RecommendationJobInputConfig < Struct.new( :model_package_version_arn, :model_name, :job_duration_in_seconds, :traffic_pattern, :resource_limit, :endpoint_configurations, :volume_kms_key_id, :container_config, :endpoints, :vpc_config) SENSITIVE = [] include Aws::Structure end |
#volume_kms_key_id ⇒ String
The Amazon Resource Name (ARN) of a Amazon Web Services Key Management Service (Amazon Web Services KMS) key that Amazon SageMaker uses to encrypt data on the storage volume attached to the ML compute instance that hosts the endpoint. This key will be passed to SageMaker Hosting for endpoint creation.
The SageMaker execution role must have ‘kms:CreateGrant` permission in order to encrypt data on the storage volume of the endpoints created for inference recommendation. The inference recommendation job will fail asynchronously during endpoint configuration creation if the role passed does not have `kms:CreateGrant` permission.
The ‘KmsKeyId` can be any of the following formats:
-
// KMS Key ID
‘“1234abcd-12ab-34cd-56ef-1234567890ab”`
-
// Amazon Resource Name (ARN) of a KMS Key
‘“arn:aws:kms:<region>:<account>:key/<key-id-12ab-34cd-56ef-1234567890ab>”`
-
// KMS Key Alias
‘“alias/ExampleAlias”`
-
// Amazon Resource Name (ARN) of a KMS Key Alias
‘“arn:aws:kms:<region>:<account>:alias/<ExampleAlias>”`
For more information about key identifiers, see [Key identifiers (KeyID)] in the Amazon Web Services Key Management Service (Amazon Web Services KMS) documentation.
[1]: docs.aws.amazon.com/kms/latest/developerguide/concepts.html#key-id-key-id
45261 45262 45263 45264 45265 45266 45267 45268 45269 45270 45271 45272 45273 45274 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 45261 class RecommendationJobInputConfig < Struct.new( :model_package_version_arn, :model_name, :job_duration_in_seconds, :traffic_pattern, :resource_limit, :endpoint_configurations, :volume_kms_key_id, :container_config, :endpoints, :vpc_config) SENSITIVE = [] include Aws::Structure end |
#vpc_config ⇒ Types::RecommendationJobVpcConfig
Inference Recommender provisions SageMaker endpoints with access to VPC in the inference recommendation job.
45261 45262 45263 45264 45265 45266 45267 45268 45269 45270 45271 45272 45273 45274 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 45261 class RecommendationJobInputConfig < Struct.new( :model_package_version_arn, :model_name, :job_duration_in_seconds, :traffic_pattern, :resource_limit, :endpoint_configurations, :volume_kms_key_id, :container_config, :endpoints, :vpc_config) SENSITIVE = [] include Aws::Structure end |