Class: Aws::SageMaker::Types::ReservedCapacityOffering
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ReservedCapacityOffering
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Details about a reserved capacity offering for a training plan offering.
For more information about how to reserve GPU capacity for your
SageMaker HyperPod clusters using Amazon SageMaker Training Plan, see
CreateTrainingPlan.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zone ⇒ String
The availability zone for the reserved capacity offering.
-
#duration_hours ⇒ Integer
The number of whole hours in the total duration for this reserved capacity offering.
-
#duration_minutes ⇒ Integer
The additional minutes beyond whole hours in the total duration for this reserved capacity offering.
-
#end_time ⇒ Time
The end time of the reserved capacity offering.
-
#extension_end_time ⇒ Time
The end time of the extension for the reserved capacity offering.
-
#extension_start_time ⇒ Time
The start time of the extension for the reserved capacity offering.
-
#instance_count ⇒ Integer
The number of instances in the reserved capacity offering.
-
#instance_type ⇒ String
The instance type for the reserved capacity offering.
-
#reserved_capacity_type ⇒ String
The type of reserved capacity offering.
-
#start_time ⇒ Time
The start time of the reserved capacity offering.
-
#ultra_server_count ⇒ Integer
The number of UltraServers included in this reserved capacity offering.
-
#ultra_server_type ⇒ String
The type of UltraServer included in this reserved capacity offering, such as ml.u-p6e-gb200x72.
Instance Attribute Details
#availability_zone ⇒ String
The availability zone for the reserved capacity offering.
49195 49196 49197 49198 49199 49200 49201 49202 49203 49204 49205 49206 49207 49208 49209 49210 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49195 class ReservedCapacityOffering < Struct.new( :reserved_capacity_type, :ultra_server_type, :ultra_server_count, :instance_type, :instance_count, :availability_zone, :duration_hours, :duration_minutes, :start_time, :end_time, :extension_start_time, :extension_end_time) SENSITIVE = [] include Aws::Structure end |
#duration_hours ⇒ Integer
The number of whole hours in the total duration for this reserved capacity offering.
49195 49196 49197 49198 49199 49200 49201 49202 49203 49204 49205 49206 49207 49208 49209 49210 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49195 class ReservedCapacityOffering < Struct.new( :reserved_capacity_type, :ultra_server_type, :ultra_server_count, :instance_type, :instance_count, :availability_zone, :duration_hours, :duration_minutes, :start_time, :end_time, :extension_start_time, :extension_end_time) SENSITIVE = [] include Aws::Structure end |
#duration_minutes ⇒ Integer
The additional minutes beyond whole hours in the total duration for this reserved capacity offering.
49195 49196 49197 49198 49199 49200 49201 49202 49203 49204 49205 49206 49207 49208 49209 49210 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49195 class ReservedCapacityOffering < Struct.new( :reserved_capacity_type, :ultra_server_type, :ultra_server_count, :instance_type, :instance_count, :availability_zone, :duration_hours, :duration_minutes, :start_time, :end_time, :extension_start_time, :extension_end_time) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
The end time of the reserved capacity offering.
49195 49196 49197 49198 49199 49200 49201 49202 49203 49204 49205 49206 49207 49208 49209 49210 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49195 class ReservedCapacityOffering < Struct.new( :reserved_capacity_type, :ultra_server_type, :ultra_server_count, :instance_type, :instance_count, :availability_zone, :duration_hours, :duration_minutes, :start_time, :end_time, :extension_start_time, :extension_end_time) SENSITIVE = [] include Aws::Structure end |
#extension_end_time ⇒ Time
The end time of the extension for the reserved capacity offering.
49195 49196 49197 49198 49199 49200 49201 49202 49203 49204 49205 49206 49207 49208 49209 49210 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49195 class ReservedCapacityOffering < Struct.new( :reserved_capacity_type, :ultra_server_type, :ultra_server_count, :instance_type, :instance_count, :availability_zone, :duration_hours, :duration_minutes, :start_time, :end_time, :extension_start_time, :extension_end_time) SENSITIVE = [] include Aws::Structure end |
#extension_start_time ⇒ Time
The start time of the extension for the reserved capacity offering.
49195 49196 49197 49198 49199 49200 49201 49202 49203 49204 49205 49206 49207 49208 49209 49210 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49195 class ReservedCapacityOffering < Struct.new( :reserved_capacity_type, :ultra_server_type, :ultra_server_count, :instance_type, :instance_count, :availability_zone, :duration_hours, :duration_minutes, :start_time, :end_time, :extension_start_time, :extension_end_time) SENSITIVE = [] include Aws::Structure end |
#instance_count ⇒ Integer
The number of instances in the reserved capacity offering.
49195 49196 49197 49198 49199 49200 49201 49202 49203 49204 49205 49206 49207 49208 49209 49210 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49195 class ReservedCapacityOffering < Struct.new( :reserved_capacity_type, :ultra_server_type, :ultra_server_count, :instance_type, :instance_count, :availability_zone, :duration_hours, :duration_minutes, :start_time, :end_time, :extension_start_time, :extension_end_time) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The instance type for the reserved capacity offering.
49195 49196 49197 49198 49199 49200 49201 49202 49203 49204 49205 49206 49207 49208 49209 49210 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49195 class ReservedCapacityOffering < Struct.new( :reserved_capacity_type, :ultra_server_type, :ultra_server_count, :instance_type, :instance_count, :availability_zone, :duration_hours, :duration_minutes, :start_time, :end_time, :extension_start_time, :extension_end_time) SENSITIVE = [] include Aws::Structure end |
#reserved_capacity_type ⇒ String
The type of reserved capacity offering.
49195 49196 49197 49198 49199 49200 49201 49202 49203 49204 49205 49206 49207 49208 49209 49210 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49195 class ReservedCapacityOffering < Struct.new( :reserved_capacity_type, :ultra_server_type, :ultra_server_count, :instance_type, :instance_count, :availability_zone, :duration_hours, :duration_minutes, :start_time, :end_time, :extension_start_time, :extension_end_time) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The start time of the reserved capacity offering.
49195 49196 49197 49198 49199 49200 49201 49202 49203 49204 49205 49206 49207 49208 49209 49210 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49195 class ReservedCapacityOffering < Struct.new( :reserved_capacity_type, :ultra_server_type, :ultra_server_count, :instance_type, :instance_count, :availability_zone, :duration_hours, :duration_minutes, :start_time, :end_time, :extension_start_time, :extension_end_time) SENSITIVE = [] include Aws::Structure end |
#ultra_server_count ⇒ Integer
The number of UltraServers included in this reserved capacity offering.
49195 49196 49197 49198 49199 49200 49201 49202 49203 49204 49205 49206 49207 49208 49209 49210 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49195 class ReservedCapacityOffering < Struct.new( :reserved_capacity_type, :ultra_server_type, :ultra_server_count, :instance_type, :instance_count, :availability_zone, :duration_hours, :duration_minutes, :start_time, :end_time, :extension_start_time, :extension_end_time) SENSITIVE = [] include Aws::Structure end |
#ultra_server_type ⇒ String
The type of UltraServer included in this reserved capacity offering, such as ml.u-p6e-gb200x72.
49195 49196 49197 49198 49199 49200 49201 49202 49203 49204 49205 49206 49207 49208 49209 49210 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49195 class ReservedCapacityOffering < Struct.new( :reserved_capacity_type, :ultra_server_type, :ultra_server_count, :instance_type, :instance_count, :availability_zone, :duration_hours, :duration_minutes, :start_time, :end_time, :extension_start_time, :extension_end_time) SENSITIVE = [] include Aws::Structure end |