Class: Aws::SageMaker::Types::ReservedCapacityOffering

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Details about a reserved capacity offering for a training plan offering.

For more information about how to reserve GPU capacity for your SageMaker HyperPod clusters using Amazon SageMaker Training Plan, see ‘ CreateTrainingPlan `.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#availability_zoneString

The availability zone for the reserved capacity offering.

Returns:



45892
45893
45894
45895
45896
45897
45898
45899
45900
45901
45902
45903
45904
45905
45906
45907
# File 'lib/aws-sdk-sagemaker/types.rb', line 45892

class ReservedCapacityOffering < Struct.new(
  :reserved_capacity_type,
  :ultra_server_type,
  :ultra_server_count,
  :instance_type,
  :instance_count,
  :availability_zone,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :extension_start_time,
  :extension_end_time)
  SENSITIVE = []
  include Aws::Structure
end

#duration_hoursInteger

The number of whole hours in the total duration for this reserved capacity offering.

Returns:



45892
45893
45894
45895
45896
45897
45898
45899
45900
45901
45902
45903
45904
45905
45906
45907
# File 'lib/aws-sdk-sagemaker/types.rb', line 45892

class ReservedCapacityOffering < Struct.new(
  :reserved_capacity_type,
  :ultra_server_type,
  :ultra_server_count,
  :instance_type,
  :instance_count,
  :availability_zone,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :extension_start_time,
  :extension_end_time)
  SENSITIVE = []
  include Aws::Structure
end

#duration_minutesInteger

The additional minutes beyond whole hours in the total duration for this reserved capacity offering.

Returns:



45892
45893
45894
45895
45896
45897
45898
45899
45900
45901
45902
45903
45904
45905
45906
45907
# File 'lib/aws-sdk-sagemaker/types.rb', line 45892

class ReservedCapacityOffering < Struct.new(
  :reserved_capacity_type,
  :ultra_server_type,
  :ultra_server_count,
  :instance_type,
  :instance_count,
  :availability_zone,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :extension_start_time,
  :extension_end_time)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

The end time of the reserved capacity offering.

Returns:



45892
45893
45894
45895
45896
45897
45898
45899
45900
45901
45902
45903
45904
45905
45906
45907
# File 'lib/aws-sdk-sagemaker/types.rb', line 45892

class ReservedCapacityOffering < Struct.new(
  :reserved_capacity_type,
  :ultra_server_type,
  :ultra_server_count,
  :instance_type,
  :instance_count,
  :availability_zone,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :extension_start_time,
  :extension_end_time)
  SENSITIVE = []
  include Aws::Structure
end

#extension_end_timeTime

The end time of the extension for the reserved capacity offering.

Returns:



45892
45893
45894
45895
45896
45897
45898
45899
45900
45901
45902
45903
45904
45905
45906
45907
# File 'lib/aws-sdk-sagemaker/types.rb', line 45892

class ReservedCapacityOffering < Struct.new(
  :reserved_capacity_type,
  :ultra_server_type,
  :ultra_server_count,
  :instance_type,
  :instance_count,
  :availability_zone,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :extension_start_time,
  :extension_end_time)
  SENSITIVE = []
  include Aws::Structure
end

#extension_start_timeTime

The start time of the extension for the reserved capacity offering.

Returns:



45892
45893
45894
45895
45896
45897
45898
45899
45900
45901
45902
45903
45904
45905
45906
45907
# File 'lib/aws-sdk-sagemaker/types.rb', line 45892

class ReservedCapacityOffering < Struct.new(
  :reserved_capacity_type,
  :ultra_server_type,
  :ultra_server_count,
  :instance_type,
  :instance_count,
  :availability_zone,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :extension_start_time,
  :extension_end_time)
  SENSITIVE = []
  include Aws::Structure
end

#instance_countInteger

The number of instances in the reserved capacity offering.

Returns:



45892
45893
45894
45895
45896
45897
45898
45899
45900
45901
45902
45903
45904
45905
45906
45907
# File 'lib/aws-sdk-sagemaker/types.rb', line 45892

class ReservedCapacityOffering < Struct.new(
  :reserved_capacity_type,
  :ultra_server_type,
  :ultra_server_count,
  :instance_type,
  :instance_count,
  :availability_zone,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :extension_start_time,
  :extension_end_time)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typeString

The instance type for the reserved capacity offering.

Returns:



45892
45893
45894
45895
45896
45897
45898
45899
45900
45901
45902
45903
45904
45905
45906
45907
# File 'lib/aws-sdk-sagemaker/types.rb', line 45892

class ReservedCapacityOffering < Struct.new(
  :reserved_capacity_type,
  :ultra_server_type,
  :ultra_server_count,
  :instance_type,
  :instance_count,
  :availability_zone,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :extension_start_time,
  :extension_end_time)
  SENSITIVE = []
  include Aws::Structure
end

#reserved_capacity_typeString

The type of reserved capacity offering.

Returns:



45892
45893
45894
45895
45896
45897
45898
45899
45900
45901
45902
45903
45904
45905
45906
45907
# File 'lib/aws-sdk-sagemaker/types.rb', line 45892

class ReservedCapacityOffering < Struct.new(
  :reserved_capacity_type,
  :ultra_server_type,
  :ultra_server_count,
  :instance_type,
  :instance_count,
  :availability_zone,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :extension_start_time,
  :extension_end_time)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The start time of the reserved capacity offering.

Returns:



45892
45893
45894
45895
45896
45897
45898
45899
45900
45901
45902
45903
45904
45905
45906
45907
# File 'lib/aws-sdk-sagemaker/types.rb', line 45892

class ReservedCapacityOffering < Struct.new(
  :reserved_capacity_type,
  :ultra_server_type,
  :ultra_server_count,
  :instance_type,
  :instance_count,
  :availability_zone,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :extension_start_time,
  :extension_end_time)
  SENSITIVE = []
  include Aws::Structure
end

#ultra_server_countInteger

The number of UltraServers included in this reserved capacity offering.

Returns:



45892
45893
45894
45895
45896
45897
45898
45899
45900
45901
45902
45903
45904
45905
45906
45907
# File 'lib/aws-sdk-sagemaker/types.rb', line 45892

class ReservedCapacityOffering < Struct.new(
  :reserved_capacity_type,
  :ultra_server_type,
  :ultra_server_count,
  :instance_type,
  :instance_count,
  :availability_zone,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :extension_start_time,
  :extension_end_time)
  SENSITIVE = []
  include Aws::Structure
end

#ultra_server_typeString

The type of UltraServer included in this reserved capacity offering, such as ml.u-p6e-gb200x72.

Returns:



45892
45893
45894
45895
45896
45897
45898
45899
45900
45901
45902
45903
45904
45905
45906
45907
# File 'lib/aws-sdk-sagemaker/types.rb', line 45892

class ReservedCapacityOffering < Struct.new(
  :reserved_capacity_type,
  :ultra_server_type,
  :ultra_server_count,
  :instance_type,
  :instance_count,
  :availability_zone,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :extension_start_time,
  :extension_end_time)
  SENSITIVE = []
  include Aws::Structure
end