Class: Aws::SageMaker::Types::ReservedCapacitySummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ReservedCapacitySummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Details of a reserved capacity for the training plan.
For more information about how to reserve GPU capacity for your SageMaker HyperPod clusters using Amazon SageMaker Training Plan, see ‘ CreateTrainingPlan `.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zone ⇒ String
The availability zone for the reserved capacity.
-
#availability_zone_id ⇒ String
The Availability Zone ID of the reserved capacity.
-
#duration_hours ⇒ Integer
The number of whole hours in the total duration for this reserved capacity.
-
#duration_minutes ⇒ Integer
The additional minutes beyond whole hours in the total duration for this reserved capacity.
-
#end_time ⇒ Time
The end time of the reserved capacity.
-
#instance_type ⇒ String
The instance type for the reserved capacity.
-
#reserved_capacity_arn ⇒ String
The Amazon Resource Name (ARN); of the reserved capacity.
-
#reserved_capacity_type ⇒ String
The type of reserved capacity.
-
#start_time ⇒ Time
The start time of the reserved capacity.
-
#status ⇒ String
The current status of the reserved capacity.
-
#total_instance_count ⇒ Integer
The total number of instances in the reserved capacity.
-
#ultra_server_count ⇒ Integer
The number of UltraServers included in this reserved capacity.
-
#ultra_server_type ⇒ String
The type of UltraServer included in this reserved capacity, such as ml.u-p6e-gb200x72.
Instance Attribute Details
#availability_zone ⇒ String
The availability zone for the reserved capacity.
49085 49086 49087 49088 49089 49090 49091 49092 49093 49094 49095 49096 49097 49098 49099 49100 49101 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49085 class ReservedCapacitySummary < Struct.new( :reserved_capacity_arn, :reserved_capacity_type, :ultra_server_type, :ultra_server_count, :instance_type, :total_instance_count, :status, :availability_zone, :availability_zone_id, :duration_hours, :duration_minutes, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#availability_zone_id ⇒ String
The Availability Zone ID of the reserved capacity.
49085 49086 49087 49088 49089 49090 49091 49092 49093 49094 49095 49096 49097 49098 49099 49100 49101 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49085 class ReservedCapacitySummary < Struct.new( :reserved_capacity_arn, :reserved_capacity_type, :ultra_server_type, :ultra_server_count, :instance_type, :total_instance_count, :status, :availability_zone, :availability_zone_id, :duration_hours, :duration_minutes, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#duration_hours ⇒ Integer
The number of whole hours in the total duration for this reserved capacity.
49085 49086 49087 49088 49089 49090 49091 49092 49093 49094 49095 49096 49097 49098 49099 49100 49101 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49085 class ReservedCapacitySummary < Struct.new( :reserved_capacity_arn, :reserved_capacity_type, :ultra_server_type, :ultra_server_count, :instance_type, :total_instance_count, :status, :availability_zone, :availability_zone_id, :duration_hours, :duration_minutes, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#duration_minutes ⇒ Integer
The additional minutes beyond whole hours in the total duration for this reserved capacity.
49085 49086 49087 49088 49089 49090 49091 49092 49093 49094 49095 49096 49097 49098 49099 49100 49101 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49085 class ReservedCapacitySummary < Struct.new( :reserved_capacity_arn, :reserved_capacity_type, :ultra_server_type, :ultra_server_count, :instance_type, :total_instance_count, :status, :availability_zone, :availability_zone_id, :duration_hours, :duration_minutes, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
The end time of the reserved capacity.
49085 49086 49087 49088 49089 49090 49091 49092 49093 49094 49095 49096 49097 49098 49099 49100 49101 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49085 class ReservedCapacitySummary < Struct.new( :reserved_capacity_arn, :reserved_capacity_type, :ultra_server_type, :ultra_server_count, :instance_type, :total_instance_count, :status, :availability_zone, :availability_zone_id, :duration_hours, :duration_minutes, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The instance type for the reserved capacity.
49085 49086 49087 49088 49089 49090 49091 49092 49093 49094 49095 49096 49097 49098 49099 49100 49101 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49085 class ReservedCapacitySummary < Struct.new( :reserved_capacity_arn, :reserved_capacity_type, :ultra_server_type, :ultra_server_count, :instance_type, :total_instance_count, :status, :availability_zone, :availability_zone_id, :duration_hours, :duration_minutes, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#reserved_capacity_arn ⇒ String
The Amazon Resource Name (ARN); of the reserved capacity.
49085 49086 49087 49088 49089 49090 49091 49092 49093 49094 49095 49096 49097 49098 49099 49100 49101 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49085 class ReservedCapacitySummary < Struct.new( :reserved_capacity_arn, :reserved_capacity_type, :ultra_server_type, :ultra_server_count, :instance_type, :total_instance_count, :status, :availability_zone, :availability_zone_id, :duration_hours, :duration_minutes, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#reserved_capacity_type ⇒ String
The type of reserved capacity.
49085 49086 49087 49088 49089 49090 49091 49092 49093 49094 49095 49096 49097 49098 49099 49100 49101 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49085 class ReservedCapacitySummary < Struct.new( :reserved_capacity_arn, :reserved_capacity_type, :ultra_server_type, :ultra_server_count, :instance_type, :total_instance_count, :status, :availability_zone, :availability_zone_id, :duration_hours, :duration_minutes, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The start time of the reserved capacity.
49085 49086 49087 49088 49089 49090 49091 49092 49093 49094 49095 49096 49097 49098 49099 49100 49101 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49085 class ReservedCapacitySummary < Struct.new( :reserved_capacity_arn, :reserved_capacity_type, :ultra_server_type, :ultra_server_count, :instance_type, :total_instance_count, :status, :availability_zone, :availability_zone_id, :duration_hours, :duration_minutes, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the reserved capacity.
49085 49086 49087 49088 49089 49090 49091 49092 49093 49094 49095 49096 49097 49098 49099 49100 49101 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49085 class ReservedCapacitySummary < Struct.new( :reserved_capacity_arn, :reserved_capacity_type, :ultra_server_type, :ultra_server_count, :instance_type, :total_instance_count, :status, :availability_zone, :availability_zone_id, :duration_hours, :duration_minutes, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#total_instance_count ⇒ Integer
The total number of instances in the reserved capacity.
49085 49086 49087 49088 49089 49090 49091 49092 49093 49094 49095 49096 49097 49098 49099 49100 49101 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49085 class ReservedCapacitySummary < Struct.new( :reserved_capacity_arn, :reserved_capacity_type, :ultra_server_type, :ultra_server_count, :instance_type, :total_instance_count, :status, :availability_zone, :availability_zone_id, :duration_hours, :duration_minutes, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#ultra_server_count ⇒ Integer
The number of UltraServers included in this reserved capacity.
49085 49086 49087 49088 49089 49090 49091 49092 49093 49094 49095 49096 49097 49098 49099 49100 49101 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49085 class ReservedCapacitySummary < Struct.new( :reserved_capacity_arn, :reserved_capacity_type, :ultra_server_type, :ultra_server_count, :instance_type, :total_instance_count, :status, :availability_zone, :availability_zone_id, :duration_hours, :duration_minutes, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#ultra_server_type ⇒ String
The type of UltraServer included in this reserved capacity, such as ml.u-p6e-gb200x72.
49085 49086 49087 49088 49089 49090 49091 49092 49093 49094 49095 49096 49097 49098 49099 49100 49101 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49085 class ReservedCapacitySummary < Struct.new( :reserved_capacity_arn, :reserved_capacity_type, :ultra_server_type, :ultra_server_count, :instance_type, :total_instance_count, :status, :availability_zone, :availability_zone_id, :duration_hours, :duration_minutes, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |