Class: Aws::SageMaker::Types::ResourceConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ResourceConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Describes the resources, including machine learning (ML) compute instances and ML storage volumes, to use for model training.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_count ⇒ Integer
The number of ML compute instances to use.
-
#instance_groups ⇒ Array<Types::InstanceGroup>
The configuration of a heterogeneous cluster in JSON format.
-
#instance_placement_config ⇒ Types::InstancePlacementConfig
Configuration for how training job instances are placed and allocated within UltraServers.
-
#instance_type ⇒ String
The ML compute instance type.
-
#keep_alive_period_in_seconds ⇒ Integer
The duration of time in seconds to retain configured resources in a warm pool for subsequent training jobs.
-
#training_plan_arn ⇒ String
The Amazon Resource Name (ARN); of the training plan to use for this resource configuration.
-
#volume_kms_key_id ⇒ String
The Amazon Web Services KMS key that SageMaker uses to encrypt data on the storage volume attached to the ML compute instance(s) that run the training job.
-
#volume_size_in_gb ⇒ Integer
The size of the ML storage volume that you want to provision.
Instance Attribute Details
#instance_count ⇒ Integer
The number of ML compute instances to use. For distributed training, provide a value greater than 1.
46053 46054 46055 46056 46057 46058 46059 46060 46061 46062 46063 46064 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46053 class ResourceConfig < Struct.new( :instance_type, :instance_count, :volume_size_in_gb, :volume_kms_key_id, :keep_alive_period_in_seconds, :instance_groups, :training_plan_arn, :instance_placement_config) SENSITIVE = [] include Aws::Structure end |
#instance_groups ⇒ Array<Types::InstanceGroup>
The configuration of a heterogeneous cluster in JSON format.
46053 46054 46055 46056 46057 46058 46059 46060 46061 46062 46063 46064 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46053 class ResourceConfig < Struct.new( :instance_type, :instance_count, :volume_size_in_gb, :volume_kms_key_id, :keep_alive_period_in_seconds, :instance_groups, :training_plan_arn, :instance_placement_config) SENSITIVE = [] include Aws::Structure end |
#instance_placement_config ⇒ Types::InstancePlacementConfig
Configuration for how training job instances are placed and allocated within UltraServers. Only applicable for UltraServer capacity.
46053 46054 46055 46056 46057 46058 46059 46060 46061 46062 46063 46064 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46053 class ResourceConfig < Struct.new( :instance_type, :instance_count, :volume_size_in_gb, :volume_kms_key_id, :keep_alive_period_in_seconds, :instance_groups, :training_plan_arn, :instance_placement_config) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The ML compute instance type.
46053 46054 46055 46056 46057 46058 46059 46060 46061 46062 46063 46064 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46053 class ResourceConfig < Struct.new( :instance_type, :instance_count, :volume_size_in_gb, :volume_kms_key_id, :keep_alive_period_in_seconds, :instance_groups, :training_plan_arn, :instance_placement_config) SENSITIVE = [] include Aws::Structure end |
#keep_alive_period_in_seconds ⇒ Integer
The duration of time in seconds to retain configured resources in a warm pool for subsequent training jobs.
46053 46054 46055 46056 46057 46058 46059 46060 46061 46062 46063 46064 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46053 class ResourceConfig < Struct.new( :instance_type, :instance_count, :volume_size_in_gb, :volume_kms_key_id, :keep_alive_period_in_seconds, :instance_groups, :training_plan_arn, :instance_placement_config) SENSITIVE = [] include Aws::Structure end |
#training_plan_arn ⇒ String
The Amazon Resource Name (ARN); of the training plan to use for this resource configuration.
46053 46054 46055 46056 46057 46058 46059 46060 46061 46062 46063 46064 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46053 class ResourceConfig < Struct.new( :instance_type, :instance_count, :volume_size_in_gb, :volume_kms_key_id, :keep_alive_period_in_seconds, :instance_groups, :training_plan_arn, :instance_placement_config) SENSITIVE = [] include Aws::Structure end |
#volume_kms_key_id ⇒ String
The Amazon Web Services KMS key that SageMaker uses to encrypt data on the storage volume attached to the ML compute instance(s) that run the training job.
<note markdown=“1”> Certain Nitro-based instances include local storage, dependent on the instance type. Local storage volumes are encrypted using a hardware module on the instance. You can’t request a ‘VolumeKmsKeyId` when using an instance type with local storage.
For a list of instance types that support local instance storage,
see [Instance Store Volumes].
For more information about local instance storage encryption, see
[SSD Instance Store Volumes].
</note>
The ‘VolumeKmsKeyId` can be in any of the following formats:
-
// KMS Key ID
‘“1234abcd-12ab-34cd-56ef-1234567890ab”`
-
// Amazon Resource Name (ARN) of a KMS Key
‘“arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab”`
[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/InstanceStorage.html#instance-store-volumes [2]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/ssd-instance-store.html
46053 46054 46055 46056 46057 46058 46059 46060 46061 46062 46063 46064 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46053 class ResourceConfig < Struct.new( :instance_type, :instance_count, :volume_size_in_gb, :volume_kms_key_id, :keep_alive_period_in_seconds, :instance_groups, :training_plan_arn, :instance_placement_config) SENSITIVE = [] include Aws::Structure end |
#volume_size_in_gb ⇒ Integer
The size of the ML storage volume that you want to provision.
SageMaker automatically selects the volume size for serverless training jobs. You cannot customize this setting.
ML storage volumes store model artifacts and incremental states. Training algorithms might also use the ML storage volume for scratch space. If you want to store the training data in the ML storage volume, choose ‘File` as the `TrainingInputMode` in the algorithm specification.
When using an ML instance with [NVMe SSD volumes], SageMaker doesn’t provision Amazon EBS General Purpose SSD (gp2) storage. Available storage is fixed to the NVMe-type instance’s storage capacity. SageMaker configures storage paths for training datasets, checkpoints, model artifacts, and outputs to use the entire capacity of the instance storage. For example, ML instance families with the NVMe-type instance storage include ‘ml.p4d`, `ml.g4dn`, and `ml.g5`.
When using an ML instance with the EBS-only storage option and without instance storage, you must define the size of EBS volume through ‘VolumeSizeInGB` in the `ResourceConfig` API. For example, ML instance families that use EBS volumes include `ml.c5` and `ml.p2`.
To look up instance types and their instance storage types and volumes, see [Amazon EC2 Instance Types].
To find the default local paths defined by the SageMaker training platform, see [Amazon SageMaker Training Storage Folders for Training Datasets, Checkpoints, Model Artifacts, and Outputs].
[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/ssd-instance-store.html#nvme-ssd-volumes [2]: aws.amazon.com/ec2/instance-types/ [3]: docs.aws.amazon.com/sagemaker/latest/dg/model-train-storage.html
46053 46054 46055 46056 46057 46058 46059 46060 46061 46062 46063 46064 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 46053 class ResourceConfig < Struct.new( :instance_type, :instance_count, :volume_size_in_gb, :volume_kms_key_id, :keep_alive_period_in_seconds, :instance_groups, :training_plan_arn, :instance_placement_config) SENSITIVE = [] include Aws::Structure end |