Class: Aws::SageMaker::Types::ResourceConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ResourceConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Describes the resources, including machine learning (ML) compute instances and ML storage volumes, to use for model training.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_count ⇒ Integer
The number of ML compute instances to use.
-
#instance_groups ⇒ Array<Types::InstanceGroup>
The configuration of a heterogeneous cluster in JSON format.
-
#instance_placement_config ⇒ Types::InstancePlacementConfig
Configuration for how training job instances are placed and allocated within UltraServers.
-
#instance_preferences ⇒ Array<Types::InstancePreference>
An ordered list of ML compute instance types for the training job, in priority order.
-
#instance_type ⇒ String
The ML compute instance type.
-
#keep_alive_period_in_seconds ⇒ Integer
The duration of time in seconds to retain configured resources in a warm pool for subsequent training jobs.
-
#selected_instance_count ⇒ Integer
The number of instances of
SelectedInstanceTypethat the training job launched with. -
#selected_instance_type ⇒ String
The instance type that SageMaker selected for the job from the provided
InstancePreferences. -
#training_plan_arn ⇒ String
The Amazon Resource Name (ARN); of the training plan to use for this resource configuration.
-
#volume_kms_key_id ⇒ String
The Amazon Web Services KMS key that SageMaker uses to encrypt data on the storage volume attached to the ML compute instance(s) that run the training job.
-
#volume_size_in_gb ⇒ Integer
The size of the ML storage volume that you want to provision.
Instance Attribute Details
#instance_count ⇒ Integer
The number of ML compute instances to use. For distributed training, provide a value greater than 1.
49938 49939 49940 49941 49942 49943 49944 49945 49946 49947 49948 49949 49950 49951 49952 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49938 class ResourceConfig < Struct.new( :instance_type, :instance_count, :volume_size_in_gb, :volume_kms_key_id, :keep_alive_period_in_seconds, :instance_groups, :training_plan_arn, :instance_placement_config, :instance_preferences, :selected_instance_type, :selected_instance_count) SENSITIVE = [] include Aws::Structure end |
#instance_groups ⇒ Array<Types::InstanceGroup>
The configuration of a heterogeneous cluster in JSON format.
49938 49939 49940 49941 49942 49943 49944 49945 49946 49947 49948 49949 49950 49951 49952 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49938 class ResourceConfig < Struct.new( :instance_type, :instance_count, :volume_size_in_gb, :volume_kms_key_id, :keep_alive_period_in_seconds, :instance_groups, :training_plan_arn, :instance_placement_config, :instance_preferences, :selected_instance_type, :selected_instance_count) SENSITIVE = [] include Aws::Structure end |
#instance_placement_config ⇒ Types::InstancePlacementConfig
Configuration for how training job instances are placed and allocated within UltraServers. Only applicable for UltraServer capacity.
49938 49939 49940 49941 49942 49943 49944 49945 49946 49947 49948 49949 49950 49951 49952 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49938 class ResourceConfig < Struct.new( :instance_type, :instance_count, :volume_size_in_gb, :volume_kms_key_id, :keep_alive_period_in_seconds, :instance_groups, :training_plan_arn, :instance_placement_config, :instance_preferences, :selected_instance_type, :selected_instance_count) SENSITIVE = [] include Aws::Structure end |
#instance_preferences ⇒ Array<Types::InstancePreference>
An ordered list of ML compute instance types for the training job, in priority order. SageMaker launches the training job on the first instance type in the list that has available capacity. If capacity is insufficient, SageMaker evaluates the next instance type in the preferred list. Exactly one instance type is selected for the job.
InstancePreferences is mutually exclusive with InstanceType,
InstanceGroups, InstancePlacementConfig, and
EnableManagedSpotTraining, and supports only Flexible Training
Plans (FTP) and On-Demand capacity.
49938 49939 49940 49941 49942 49943 49944 49945 49946 49947 49948 49949 49950 49951 49952 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49938 class ResourceConfig < Struct.new( :instance_type, :instance_count, :volume_size_in_gb, :volume_kms_key_id, :keep_alive_period_in_seconds, :instance_groups, :training_plan_arn, :instance_placement_config, :instance_preferences, :selected_instance_type, :selected_instance_count) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The ML compute instance type.
49938 49939 49940 49941 49942 49943 49944 49945 49946 49947 49948 49949 49950 49951 49952 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49938 class ResourceConfig < Struct.new( :instance_type, :instance_count, :volume_size_in_gb, :volume_kms_key_id, :keep_alive_period_in_seconds, :instance_groups, :training_plan_arn, :instance_placement_config, :instance_preferences, :selected_instance_type, :selected_instance_count) SENSITIVE = [] include Aws::Structure end |
#keep_alive_period_in_seconds ⇒ Integer
The duration of time in seconds to retain configured resources in a warm pool for subsequent training jobs.
49938 49939 49940 49941 49942 49943 49944 49945 49946 49947 49948 49949 49950 49951 49952 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49938 class ResourceConfig < Struct.new( :instance_type, :instance_count, :volume_size_in_gb, :volume_kms_key_id, :keep_alive_period_in_seconds, :instance_groups, :training_plan_arn, :instance_placement_config, :instance_preferences, :selected_instance_type, :selected_instance_count) SENSITIVE = [] include Aws::Structure end |
#selected_instance_count ⇒ Integer
The number of instances of SelectedInstanceType that the training
job launched with. The job is billed for this instance type and
count. Returned by DescribeTrainingJob after an instance type is
selected. This field is read-only and isn't accepted in
CreateTrainingJob requests.
49938 49939 49940 49941 49942 49943 49944 49945 49946 49947 49948 49949 49950 49951 49952 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49938 class ResourceConfig < Struct.new( :instance_type, :instance_count, :volume_size_in_gb, :volume_kms_key_id, :keep_alive_period_in_seconds, :instance_groups, :training_plan_arn, :instance_placement_config, :instance_preferences, :selected_instance_type, :selected_instance_count) SENSITIVE = [] include Aws::Structure end |
#selected_instance_type ⇒ String
The instance type that SageMaker selected for the job from the
provided InstancePreferences. The job is billed for this instance
type and count. Returned by DescribeTrainingJob after an
instance type is selected. This field is read-only and isn't
accepted in CreateTrainingJob requests.
49938 49939 49940 49941 49942 49943 49944 49945 49946 49947 49948 49949 49950 49951 49952 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49938 class ResourceConfig < Struct.new( :instance_type, :instance_count, :volume_size_in_gb, :volume_kms_key_id, :keep_alive_period_in_seconds, :instance_groups, :training_plan_arn, :instance_placement_config, :instance_preferences, :selected_instance_type, :selected_instance_count) SENSITIVE = [] include Aws::Structure end |
#training_plan_arn ⇒ String
The Amazon Resource Name (ARN); of the training plan to use for this resource configuration.
49938 49939 49940 49941 49942 49943 49944 49945 49946 49947 49948 49949 49950 49951 49952 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49938 class ResourceConfig < Struct.new( :instance_type, :instance_count, :volume_size_in_gb, :volume_kms_key_id, :keep_alive_period_in_seconds, :instance_groups, :training_plan_arn, :instance_placement_config, :instance_preferences, :selected_instance_type, :selected_instance_count) SENSITIVE = [] include Aws::Structure end |
#volume_kms_key_id ⇒ String
The Amazon Web Services KMS key that SageMaker uses to encrypt data on the storage volume attached to the ML compute instance(s) that run the training job.
VolumeKmsKeyId when using an instance type with local storage.
For a list of instance types that support local instance storage, see Instance Store Volumes.
For more information about local instance storage encryption, see SSD Instance Store Volumes.
The VolumeKmsKeyId can be in any of the following formats:
-
// KMS Key ID
"1234abcd-12ab-34cd-56ef-1234567890ab" -
// Amazon Resource Name (ARN) of a KMS Key
"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"
49938 49939 49940 49941 49942 49943 49944 49945 49946 49947 49948 49949 49950 49951 49952 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49938 class ResourceConfig < Struct.new( :instance_type, :instance_count, :volume_size_in_gb, :volume_kms_key_id, :keep_alive_period_in_seconds, :instance_groups, :training_plan_arn, :instance_placement_config, :instance_preferences, :selected_instance_type, :selected_instance_count) SENSITIVE = [] include Aws::Structure end |
#volume_size_in_gb ⇒ Integer
The size of the ML storage volume that you want to provision.
SageMaker automatically selects the volume size for serverless training jobs. You cannot customize this setting.
ML storage volumes store model artifacts and incremental states.
Training algorithms might also use the ML storage volume for scratch
space. If you want to store the training data in the ML storage
volume, choose File as the TrainingInputMode in the algorithm
specification.
When using an ML instance with NVMe SSD volumes, SageMaker
doesn't provision Amazon EBS General Purpose SSD (gp2) storage.
Available storage is fixed to the NVMe-type instance's storage
capacity. SageMaker configures storage paths for training datasets,
checkpoints, model artifacts, and outputs to use the entire capacity
of the instance storage. For example, ML instance families with the
NVMe-type instance storage include ml.p4d, ml.g4dn, and ml.g5.
When using an ML instance with the EBS-only storage option and
without instance storage, you must define the size of EBS volume
through VolumeSizeInGB in the ResourceConfig API. For example,
ML instance families that use EBS volumes include ml.c5 and
ml.p2.
To look up instance types and their instance storage types and volumes, see Amazon EC2 Instance Types.
To find the default local paths defined by the SageMaker training platform, see Amazon SageMaker Training Storage Folders for Training Datasets, Checkpoints, Model Artifacts, and Outputs.
49938 49939 49940 49941 49942 49943 49944 49945 49946 49947 49948 49949 49950 49951 49952 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49938 class ResourceConfig < Struct.new( :instance_type, :instance_count, :volume_size_in_gb, :volume_kms_key_id, :keep_alive_period_in_seconds, :instance_groups, :training_plan_arn, :instance_placement_config, :instance_preferences, :selected_instance_type, :selected_instance_count) SENSITIVE = [] include Aws::Structure end |