Class: Aws::SageMaker::Types::ResourceSharingConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ResourceSharingConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Resource sharing configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#absolute_borrow_limits ⇒ Array<Types::ComputeQuotaResourceConfig>
The absolute limits on compute resources that can be borrowed from idle compute.
-
#borrow_limit ⇒ Integer
The limit on how much idle compute can be borrowed.The values can be 1 - 500 percent of idle compute that the team is allowed to borrow.
-
#strategy ⇒ String
The strategy of how idle compute is shared within the cluster.
Instance Attribute Details
#absolute_borrow_limits ⇒ Array<Types::ComputeQuotaResourceConfig>
The absolute limits on compute resources that can be borrowed from idle compute. When specified, these limits define the maximum amount of specific resource types (such as accelerators, vCPU, or memory) that an entity can borrow, regardless of the percentage-based ‘BorrowLimit`.
48068 48069 48070 48071 48072 48073 48074 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 48068 class ResourceSharingConfig < Struct.new( :strategy, :borrow_limit, :absolute_borrow_limits) SENSITIVE = [] include Aws::Structure end |
#borrow_limit ⇒ Integer
The limit on how much idle compute can be borrowed.The values can be 1 - 500 percent of idle compute that the team is allowed to borrow.
Default is ‘50`.
48068 48069 48070 48071 48072 48073 48074 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 48068 class ResourceSharingConfig < Struct.new( :strategy, :borrow_limit, :absolute_borrow_limits) SENSITIVE = [] include Aws::Structure end |
#strategy ⇒ String
The strategy of how idle compute is shared within the cluster. The following are the options of strategies.
-
‘DontLend`: entities do not lend idle compute.
-
‘Lend`: entities can lend idle compute to entities that can borrow.
-
‘LendandBorrow`: entities can lend idle compute and borrow idle compute from other entities.
Default is ‘LendandBorrow`.
48068 48069 48070 48071 48072 48073 48074 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 48068 class ResourceSharingConfig < Struct.new( :strategy, :borrow_limit, :absolute_borrow_limits) SENSITIVE = [] include Aws::Structure end |