Class: Aws::SageMaker::Types::ResourceSpec

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Specifies the ARN’s of a SageMaker AI image and SageMaker AI image version, and the instance type that the version runs on.

<note markdown=“1”> When both ‘SageMakerImageVersionArn` and `SageMakerImageArn` are passed, `SageMakerImageVersionArn` is used. Any updates to `SageMakerImageArn` will not take effect if `SageMakerImageVersionArn` already exists in the `ResourceSpec` because `SageMakerImageVersionArn` always takes precedence. To clear the value set for `SageMakerImageVersionArn`, pass `None` as the value.

</note>

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_typeString

The instance type that the image version runs on.

<note markdown=“1”> **JupyterServer apps** only support the ‘system` value.

For **KernelGateway apps**, the `system` value is translated to

‘ml.t3.medium`. KernelGateway apps also support all other values for available instance types.

</note>

Returns:

  • (String)


48393
48394
48395
48396
48397
48398
48399
48400
48401
48402
# File 'lib/aws-sdk-sagemaker/types.rb', line 48393

class ResourceSpec < Struct.new(
  :sage_maker_image_arn,
  :sage_maker_image_version_arn,
  :sage_maker_image_version_alias,
  :instance_type,
  :lifecycle_config_arn,
  :training_plan_arn)
  SENSITIVE = []
  include Aws::Structure
end

#lifecycle_config_arnString

The Amazon Resource Name (ARN) of the Lifecycle Configuration attached to the Resource.

Returns:

  • (String)


48393
48394
48395
48396
48397
48398
48399
48400
48401
48402
# File 'lib/aws-sdk-sagemaker/types.rb', line 48393

class ResourceSpec < Struct.new(
  :sage_maker_image_arn,
  :sage_maker_image_version_arn,
  :sage_maker_image_version_alias,
  :instance_type,
  :lifecycle_config_arn,
  :training_plan_arn)
  SENSITIVE = []
  include Aws::Structure
end

#sage_maker_image_arnString

The ARN of the SageMaker AI image that the image version belongs to.

Returns:

  • (String)


48393
48394
48395
48396
48397
48398
48399
48400
48401
48402
# File 'lib/aws-sdk-sagemaker/types.rb', line 48393

class ResourceSpec < Struct.new(
  :sage_maker_image_arn,
  :sage_maker_image_version_arn,
  :sage_maker_image_version_alias,
  :instance_type,
  :lifecycle_config_arn,
  :training_plan_arn)
  SENSITIVE = []
  include Aws::Structure
end

#sage_maker_image_version_aliasString

The SageMakerImageVersionAlias of the image to launch with. This value is in SemVer 2.0.0 versioning format.

Returns:

  • (String)


48393
48394
48395
48396
48397
48398
48399
48400
48401
48402
# File 'lib/aws-sdk-sagemaker/types.rb', line 48393

class ResourceSpec < Struct.new(
  :sage_maker_image_arn,
  :sage_maker_image_version_arn,
  :sage_maker_image_version_alias,
  :instance_type,
  :lifecycle_config_arn,
  :training_plan_arn)
  SENSITIVE = []
  include Aws::Structure
end

#sage_maker_image_version_arnString

The ARN of the image version created on the instance. To clear the value set for ‘SageMakerImageVersionArn`, pass `None` as the value.

Returns:

  • (String)


48393
48394
48395
48396
48397
48398
48399
48400
48401
48402
# File 'lib/aws-sdk-sagemaker/types.rb', line 48393

class ResourceSpec < Struct.new(
  :sage_maker_image_arn,
  :sage_maker_image_version_arn,
  :sage_maker_image_version_alias,
  :instance_type,
  :lifecycle_config_arn,
  :training_plan_arn)
  SENSITIVE = []
  include Aws::Structure
end

#training_plan_arnString

The ARN of the SageMaker AI Training Plan to use for this app. When you specify a training plan, the app launches on reserved GPU capacity. This field is supported for JupyterLab and CodeEditor app types.

For more information about how to reserve GPU capacity with SageMaker AI Training Plans, see [Using training plans in Studio applications].

[1]: docs.aws.amazon.com/sagemaker/latest/dg/training-plan-utilization-for-studio-apps.html

Returns:

  • (String)


48393
48394
48395
48396
48397
48398
48399
48400
48401
48402
# File 'lib/aws-sdk-sagemaker/types.rb', line 48393

class ResourceSpec < Struct.new(
  :sage_maker_image_arn,
  :sage_maker_image_version_arn,
  :sage_maker_image_version_alias,
  :instance_type,
  :lifecycle_config_arn,
  :training_plan_arn)
  SENSITIVE = []
  include Aws::Structure
end