Class: Aws::SageMaker::Types::ResourceSpec
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ResourceSpec
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Specifies the ARN’s of a SageMaker image and SageMaker image version, and the instance type that the version runs on.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_type ⇒ String
The instance type that the image version runs on.
-
#lifecycle_config_arn ⇒ String
The Amazon Resource Name (ARN) of the Lifecycle Configuration attached to the Resource.
-
#sage_maker_image_arn ⇒ String
The ARN of the SageMaker image that the image version belongs to.
-
#sage_maker_image_version_arn ⇒ String
The ARN of the image version created on the instance.
Instance Attribute Details
#instance_type ⇒ String
The instance type that the image version runs on.
<note markdown=“1”> **JupyterServer apps** only support the system value.
For **KernelGateway apps**, the `system` value is translated to
ml.t3.medium. KernelGateway apps also support all other values for available instance types.
</note>
33511 33512 33513 33514 33515 33516 33517 33518 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33511 class ResourceSpec < Struct.new( :sage_maker_image_arn, :sage_maker_image_version_arn, :instance_type, :lifecycle_config_arn) SENSITIVE = [] include Aws::Structure end |
#lifecycle_config_arn ⇒ String
The Amazon Resource Name (ARN) of the Lifecycle Configuration attached to the Resource.
33511 33512 33513 33514 33515 33516 33517 33518 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33511 class ResourceSpec < Struct.new( :sage_maker_image_arn, :sage_maker_image_version_arn, :instance_type, :lifecycle_config_arn) SENSITIVE = [] include Aws::Structure end |
#sage_maker_image_arn ⇒ String
The ARN of the SageMaker image that the image version belongs to.
33511 33512 33513 33514 33515 33516 33517 33518 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33511 class ResourceSpec < Struct.new( :sage_maker_image_arn, :sage_maker_image_version_arn, :instance_type, :lifecycle_config_arn) SENSITIVE = [] include Aws::Structure end |
#sage_maker_image_version_arn ⇒ String
The ARN of the image version created on the instance.
33511 33512 33513 33514 33515 33516 33517 33518 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 33511 class ResourceSpec < Struct.new( :sage_maker_image_arn, :sage_maker_image_version_arn, :instance_type, :lifecycle_config_arn) SENSITIVE = [] include Aws::Structure end |