Class: Aws::SageMaker::Types::RetryStrategy
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::RetryStrategy
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The retry strategy to use when a training job fails due to an InternalServerError. RetryStrategy is specified as part of the CreateTrainingJob and CreateHyperParameterTuningJob requests. You can add the StoppingCondition parameter to the request to limit the training time for the complete job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#maximum_retry_attempts ⇒ Integer
The number of times to retry the job.
Instance Attribute Details
#maximum_retry_attempts ⇒ Integer
The number of times to retry the job. When the job is retried, it’s SecondaryStatus is changed to STARTING.
41558 41559 41560 41561 41562 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 41558 class RetryStrategy < Struct.new( :maximum_retry_attempts) SENSITIVE = [] include Aws::Structure end |