Class: Aws::SageMaker::Types::SchedulerConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::SchedulerConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Cluster policy configuration. This policy is used for task prioritization and fair-share allocation. This helps prioritize critical workloads and distributes idle compute across entities.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#fair_share ⇒ String
When enabled, entities borrow idle compute based on their assigned ‘FairShareWeight`.
-
#idle_resource_sharing ⇒ String
Configuration for sharing idle compute resources across entities in the cluster.
-
#priority_classes ⇒ Array<Types::PriorityClass>
List of the priority classes, ‘PriorityClass`, of the cluster policy.
Instance Attribute Details
#fair_share ⇒ String
When enabled, entities borrow idle compute based on their assigned ‘FairShareWeight`.
When disabled, entities borrow idle compute based on a first-come first-serve basis.
Default is ‘Enabled`.
48878 48879 48880 48881 48882 48883 48884 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 48878 class SchedulerConfig < Struct.new( :priority_classes, :fair_share, :idle_resource_sharing) SENSITIVE = [] include Aws::Structure end |
#idle_resource_sharing ⇒ String
Configuration for sharing idle compute resources across entities in the cluster. When enabled, unallocated resources are automatically calculated and made available for entities to borrow.
48878 48879 48880 48881 48882 48883 48884 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 48878 class SchedulerConfig < Struct.new( :priority_classes, :fair_share, :idle_resource_sharing) SENSITIVE = [] include Aws::Structure end |
#priority_classes ⇒ Array<Types::PriorityClass>
List of the priority classes, ‘PriorityClass`, of the cluster policy. When specified, these class configurations define how tasks are queued.
48878 48879 48880 48881 48882 48883 48884 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 48878 class SchedulerConfig < Struct.new( :priority_classes, :fair_share, :idle_resource_sharing) SENSITIVE = [] include Aws::Structure end |