Class: Aws::SageMaker::Types::SearchRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::SearchRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cross_account_filter_option ⇒ String
A cross account filter option.
-
#max_results ⇒ Integer
The maximum number of results to return.
-
#next_token ⇒ String
If more than ‘MaxResults` resources match the specified `SearchExpression`, the response includes a `NextToken`.
-
#resource ⇒ String
The name of the SageMaker resource to search for.
-
#search_expression ⇒ Types::SearchExpression
A Boolean conditional statement.
-
#sort_by ⇒ String
The name of the resource property used to sort the ‘SearchResults`.
-
#sort_order ⇒ String
How ‘SearchResults` are ordered.
-
#visibility_conditions ⇒ Array<Types::VisibilityConditions>
Limits the results of your search request to the resources that you can access.
Instance Attribute Details
#cross_account_filter_option ⇒ String
A cross account filter option. When the value is ‘“CrossAccount”` the search results will only include resources made discoverable to you from other accounts. When the value is `“SameAccount”` or `null` the search results will only include resources from your account. Default is `null`. For more information on searching for resources made discoverable to your account, see [ Search discoverable resources] in the SageMaker Developer Guide. The maximum number of `ResourceCatalog`s viewable is 1000.
[1]: docs.aws.amazon.com/sagemaker/latest/dg/feature-store-cross-account-discoverability-use.html
49392 49393 49394 49395 49396 49397 49398 49399 49400 49401 49402 49403 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49392 class SearchRequest < Struct.new( :resource, :search_expression, :sort_by, :sort_order, :next_token, :max_results, :cross_account_filter_option, :visibility_conditions) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return.
49392 49393 49394 49395 49396 49397 49398 49399 49400 49401 49402 49403 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49392 class SearchRequest < Struct.new( :resource, :search_expression, :sort_by, :sort_order, :next_token, :max_results, :cross_account_filter_option, :visibility_conditions) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If more than ‘MaxResults` resources match the specified `SearchExpression`, the response includes a `NextToken`. The `NextToken` can be passed to the next `SearchRequest` to continue retrieving results.
49392 49393 49394 49395 49396 49397 49398 49399 49400 49401 49402 49403 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49392 class SearchRequest < Struct.new( :resource, :search_expression, :sort_by, :sort_order, :next_token, :max_results, :cross_account_filter_option, :visibility_conditions) SENSITIVE = [] include Aws::Structure end |
#resource ⇒ String
The name of the SageMaker resource to search for.
49392 49393 49394 49395 49396 49397 49398 49399 49400 49401 49402 49403 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49392 class SearchRequest < Struct.new( :resource, :search_expression, :sort_by, :sort_order, :next_token, :max_results, :cross_account_filter_option, :visibility_conditions) SENSITIVE = [] include Aws::Structure end |
#search_expression ⇒ Types::SearchExpression
A Boolean conditional statement. Resources must satisfy this condition to be included in search results. You must provide at least one subexpression, filter, or nested filter. The maximum number of recursive ‘SubExpressions`, `NestedFilters`, and `Filters` that can be included in a `SearchExpression` object is 50.
49392 49393 49394 49395 49396 49397 49398 49399 49400 49401 49402 49403 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49392 class SearchRequest < Struct.new( :resource, :search_expression, :sort_by, :sort_order, :next_token, :max_results, :cross_account_filter_option, :visibility_conditions) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
The name of the resource property used to sort the ‘SearchResults`. The default is `LastModifiedTime`.
49392 49393 49394 49395 49396 49397 49398 49399 49400 49401 49402 49403 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49392 class SearchRequest < Struct.new( :resource, :search_expression, :sort_by, :sort_order, :next_token, :max_results, :cross_account_filter_option, :visibility_conditions) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
How ‘SearchResults` are ordered. Valid values are `Ascending` or `Descending`. The default is `Descending`.
49392 49393 49394 49395 49396 49397 49398 49399 49400 49401 49402 49403 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49392 class SearchRequest < Struct.new( :resource, :search_expression, :sort_by, :sort_order, :next_token, :max_results, :cross_account_filter_option, :visibility_conditions) SENSITIVE = [] include Aws::Structure end |
#visibility_conditions ⇒ Array<Types::VisibilityConditions>
Limits the results of your search request to the resources that you can access.
49392 49393 49394 49395 49396 49397 49398 49399 49400 49401 49402 49403 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49392 class SearchRequest < Struct.new( :resource, :search_expression, :sort_by, :sort_order, :next_token, :max_results, :cross_account_filter_option, :visibility_conditions) SENSITIVE = [] include Aws::Structure end |