Class: Aws::SageMaker::Types::SearchRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cross_account_filter_optionString

A cross account filter option. When the value is ‘“CrossAccount”` the search results will only include resources made discoverable to you from other accounts. When the value is `“SameAccount”` or `null` the search results will only include resources from your account. Default is `null`. For more information on searching for resources made discoverable to your account, see [ Search discoverable resources] in the SageMaker Developer Guide. The maximum number of `ResourceCatalog`s viewable is 1000.

[1]: docs.aws.amazon.com/sagemaker/latest/dg/feature-store-cross-account-discoverability-use.html

Returns:

  • (String)


49279
49280
49281
49282
49283
49284
49285
49286
49287
49288
49289
49290
# File 'lib/aws-sdk-sagemaker/types.rb', line 49279

class SearchRequest < Struct.new(
  :resource,
  :search_expression,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results,
  :cross_account_filter_option,
  :visibility_conditions)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return.

Returns:

  • (Integer)


49279
49280
49281
49282
49283
49284
49285
49286
49287
49288
49289
49290
# File 'lib/aws-sdk-sagemaker/types.rb', line 49279

class SearchRequest < Struct.new(
  :resource,
  :search_expression,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results,
  :cross_account_filter_option,
  :visibility_conditions)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If more than ‘MaxResults` resources match the specified `SearchExpression`, the response includes a `NextToken`. The `NextToken` can be passed to the next `SearchRequest` to continue retrieving results.

Returns:

  • (String)


49279
49280
49281
49282
49283
49284
49285
49286
49287
49288
49289
49290
# File 'lib/aws-sdk-sagemaker/types.rb', line 49279

class SearchRequest < Struct.new(
  :resource,
  :search_expression,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results,
  :cross_account_filter_option,
  :visibility_conditions)
  SENSITIVE = []
  include Aws::Structure
end

#resourceString

The name of the SageMaker resource to search for.

Returns:

  • (String)


49279
49280
49281
49282
49283
49284
49285
49286
49287
49288
49289
49290
# File 'lib/aws-sdk-sagemaker/types.rb', line 49279

class SearchRequest < Struct.new(
  :resource,
  :search_expression,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results,
  :cross_account_filter_option,
  :visibility_conditions)
  SENSITIVE = []
  include Aws::Structure
end

#search_expressionTypes::SearchExpression

A Boolean conditional statement. Resources must satisfy this condition to be included in search results. You must provide at least one subexpression, filter, or nested filter. The maximum number of recursive ‘SubExpressions`, `NestedFilters`, and `Filters` that can be included in a `SearchExpression` object is 50.



49279
49280
49281
49282
49283
49284
49285
49286
49287
49288
49289
49290
# File 'lib/aws-sdk-sagemaker/types.rb', line 49279

class SearchRequest < Struct.new(
  :resource,
  :search_expression,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results,
  :cross_account_filter_option,
  :visibility_conditions)
  SENSITIVE = []
  include Aws::Structure
end

#sort_byString

The name of the resource property used to sort the ‘SearchResults`. The default is `LastModifiedTime`.

Returns:

  • (String)


49279
49280
49281
49282
49283
49284
49285
49286
49287
49288
49289
49290
# File 'lib/aws-sdk-sagemaker/types.rb', line 49279

class SearchRequest < Struct.new(
  :resource,
  :search_expression,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results,
  :cross_account_filter_option,
  :visibility_conditions)
  SENSITIVE = []
  include Aws::Structure
end

#sort_orderString

How ‘SearchResults` are ordered. Valid values are `Ascending` or `Descending`. The default is `Descending`.

Returns:

  • (String)


49279
49280
49281
49282
49283
49284
49285
49286
49287
49288
49289
49290
# File 'lib/aws-sdk-sagemaker/types.rb', line 49279

class SearchRequest < Struct.new(
  :resource,
  :search_expression,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results,
  :cross_account_filter_option,
  :visibility_conditions)
  SENSITIVE = []
  include Aws::Structure
end

#visibility_conditionsArray<Types::VisibilityConditions>

Limits the results of your search request to the resources that you can access.

Returns:



49279
49280
49281
49282
49283
49284
49285
49286
49287
49288
49289
49290
# File 'lib/aws-sdk-sagemaker/types.rb', line 49279

class SearchRequest < Struct.new(
  :resource,
  :search_expression,
  :sort_by,
  :sort_order,
  :next_token,
  :max_results,
  :cross_account_filter_option,
  :visibility_conditions)
  SENSITIVE = []
  include Aws::Structure
end