Class: Aws::SageMaker::Types::SearchTrainingPlanOfferingsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#duration_hoursInteger

The desired duration in hours for the training plan offerings.

Returns:

  • (Integer)


50423
50424
50425
50426
50427
50428
50429
50430
50431
50432
50433
50434
50435
# File 'lib/aws-sdk-sagemaker/types.rb', line 50423

class SearchTrainingPlanOfferingsRequest < Struct.new(
  :instance_type,
  :instance_count,
  :ultra_server_type,
  :ultra_server_count,
  :start_time_after,
  :end_time_before,
  :duration_hours,
  :target_resources,
  :training_plan_arn)
  SENSITIVE = []
  include Aws::Structure
end

#end_time_beforeTime

A filter to search for reserved capacity offerings with an end time before a specified date.

Returns:

  • (Time)


50423
50424
50425
50426
50427
50428
50429
50430
50431
50432
50433
50434
50435
# File 'lib/aws-sdk-sagemaker/types.rb', line 50423

class SearchTrainingPlanOfferingsRequest < Struct.new(
  :instance_type,
  :instance_count,
  :ultra_server_type,
  :ultra_server_count,
  :start_time_after,
  :end_time_before,
  :duration_hours,
  :target_resources,
  :training_plan_arn)
  SENSITIVE = []
  include Aws::Structure
end

#instance_countInteger

The number of instances you want to reserve in the training plan offerings. This allows you to specify the quantity of compute resources needed for your SageMaker training jobs or SageMaker HyperPod clusters, helping you find reserved capacity offerings that match your requirements.

Returns:

  • (Integer)


50423
50424
50425
50426
50427
50428
50429
50430
50431
50432
50433
50434
50435
# File 'lib/aws-sdk-sagemaker/types.rb', line 50423

class SearchTrainingPlanOfferingsRequest < Struct.new(
  :instance_type,
  :instance_count,
  :ultra_server_type,
  :ultra_server_count,
  :start_time_after,
  :end_time_before,
  :duration_hours,
  :target_resources,
  :training_plan_arn)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typeString

The type of instance you want to search for in the available training plan offerings. This field allows you to filter the search results based on the specific compute resources you require for your SageMaker training jobs or SageMaker HyperPod clusters. When searching for training plan offerings, specifying the instance type helps you find Reserved Instances that match your computational needs.

Returns:

  • (String)


50423
50424
50425
50426
50427
50428
50429
50430
50431
50432
50433
50434
50435
# File 'lib/aws-sdk-sagemaker/types.rb', line 50423

class SearchTrainingPlanOfferingsRequest < Struct.new(
  :instance_type,
  :instance_count,
  :ultra_server_type,
  :ultra_server_count,
  :start_time_after,
  :end_time_before,
  :duration_hours,
  :target_resources,
  :training_plan_arn)
  SENSITIVE = []
  include Aws::Structure
end

#start_time_afterTime

A filter to search for training plan offerings with a start time after a specified date.

Returns:

  • (Time)


50423
50424
50425
50426
50427
50428
50429
50430
50431
50432
50433
50434
50435
# File 'lib/aws-sdk-sagemaker/types.rb', line 50423

class SearchTrainingPlanOfferingsRequest < Struct.new(
  :instance_type,
  :instance_count,
  :ultra_server_type,
  :ultra_server_count,
  :start_time_after,
  :end_time_before,
  :duration_hours,
  :target_resources,
  :training_plan_arn)
  SENSITIVE = []
  include Aws::Structure
end

#target_resourcesArray<String>

The target resources (e.g., SageMaker Training Jobs, SageMaker HyperPod, SageMaker Endpoints, Studio apps) to search for in the offerings.

Training plans are specific to their target resource.

  • A training plan designed for SageMaker training jobs can only be used to schedule and run training jobs.

  • A training plan for HyperPod clusters can be used exclusively to provide compute resources to a cluster’s instance group.

  • A training plan for SageMaker endpoints can be used exclusively to provide compute resources to SageMaker endpoints for model deployment.

  • A training plan for Studio apps can be used to launch JupyterLab and Code Editor apps on reserved training plan capacity.

Returns:

  • (Array<String>)


50423
50424
50425
50426
50427
50428
50429
50430
50431
50432
50433
50434
50435
# File 'lib/aws-sdk-sagemaker/types.rb', line 50423

class SearchTrainingPlanOfferingsRequest < Struct.new(
  :instance_type,
  :instance_count,
  :ultra_server_type,
  :ultra_server_count,
  :start_time_after,
  :end_time_before,
  :duration_hours,
  :target_resources,
  :training_plan_arn)
  SENSITIVE = []
  include Aws::Structure
end

#training_plan_arnString

The Amazon Resource Name (ARN); of an existing training plan to search for extension offerings. When specified, the API returns extension offerings that can be used to extend the specified training plan.

Returns:

  • (String)


50423
50424
50425
50426
50427
50428
50429
50430
50431
50432
50433
50434
50435
# File 'lib/aws-sdk-sagemaker/types.rb', line 50423

class SearchTrainingPlanOfferingsRequest < Struct.new(
  :instance_type,
  :instance_count,
  :ultra_server_type,
  :ultra_server_count,
  :start_time_after,
  :end_time_before,
  :duration_hours,
  :target_resources,
  :training_plan_arn)
  SENSITIVE = []
  include Aws::Structure
end

#ultra_server_countInteger

The number of UltraServers to search for.

Returns:

  • (Integer)


50423
50424
50425
50426
50427
50428
50429
50430
50431
50432
50433
50434
50435
# File 'lib/aws-sdk-sagemaker/types.rb', line 50423

class SearchTrainingPlanOfferingsRequest < Struct.new(
  :instance_type,
  :instance_count,
  :ultra_server_type,
  :ultra_server_count,
  :start_time_after,
  :end_time_before,
  :duration_hours,
  :target_resources,
  :training_plan_arn)
  SENSITIVE = []
  include Aws::Structure
end

#ultra_server_typeString

The type of UltraServer to search for, such as ml.u-p6e-gb200x72.

Returns:

  • (String)


50423
50424
50425
50426
50427
50428
50429
50430
50431
50432
50433
50434
50435
# File 'lib/aws-sdk-sagemaker/types.rb', line 50423

class SearchTrainingPlanOfferingsRequest < Struct.new(
  :instance_type,
  :instance_count,
  :ultra_server_type,
  :ultra_server_count,
  :start_time_after,
  :end_time_before,
  :duration_hours,
  :target_resources,
  :training_plan_arn)
  SENSITIVE = []
  include Aws::Structure
end