Class: Aws::SageMaker::Types::SearchTrainingPlanOfferingsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::SearchTrainingPlanOfferingsResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#training_plan_extension_offerings ⇒ Array<Types::TrainingPlanExtensionOffering>
A list of extension offerings available for the specified training plan.
-
#training_plan_offerings ⇒ Array<Types::TrainingPlanOffering>
A list of training plan offerings that match the search criteria.
Instance Attribute Details
#training_plan_extension_offerings ⇒ Array<Types::TrainingPlanExtensionOffering>
A list of extension offerings available for the specified training
plan. These offerings can be used with the ExtendTrainingPlan
API to extend an existing training plan.
50787 50788 50789 50790 50791 50792 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 50787 class SearchTrainingPlanOfferingsResponse < Struct.new( :training_plan_offerings, :training_plan_extension_offerings) SENSITIVE = [] include Aws::Structure end |
#training_plan_offerings ⇒ Array<Types::TrainingPlanOffering>
A list of training plan offerings that match the search criteria.
50787 50788 50789 50790 50791 50792 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 50787 class SearchTrainingPlanOfferingsResponse < Struct.new( :training_plan_offerings, :training_plan_extension_offerings) SENSITIVE = [] include Aws::Structure end |