Class: Aws::SageMaker::Types::SearchTrainingPlanOfferingsResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#training_plan_extension_offeringsArray<Types::TrainingPlanExtensionOffering>

A list of extension offerings available for the specified training plan. These offerings can be used with the ‘ ExtendTrainingPlan ` API to extend an existing training plan.



47454
47455
47456
47457
47458
47459
# File 'lib/aws-sdk-sagemaker/types.rb', line 47454

class SearchTrainingPlanOfferingsResponse < Struct.new(
  :training_plan_offerings,
  :training_plan_extension_offerings)
  SENSITIVE = []
  include Aws::Structure
end

#training_plan_offeringsArray<Types::TrainingPlanOffering>

A list of training plan offerings that match the search criteria.

Returns:



47454
47455
47456
47457
47458
47459
# File 'lib/aws-sdk-sagemaker/types.rb', line 47454

class SearchTrainingPlanOfferingsResponse < Struct.new(
  :training_plan_offerings,
  :training_plan_extension_offerings)
  SENSITIVE = []
  include Aws::Structure
end