Class: Aws::SageMaker::Types::ServerlessJobConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The configuration for the serverless training job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#accept_eulaBoolean

Specifies agreement to the model end-user license agreement (EULA). The AcceptEula value must be explicitly defined as True in order to accept the EULA that this model requires. You are responsible for reviewing and complying with any applicable license terms and making sure they are acceptable for your use case before downloading or using a model. For more information, see End-user license agreements section for more details on accepting the EULA.

Returns:

  • (Boolean)


51137
51138
51139
51140
51141
51142
51143
51144
51145
51146
51147
51148
# File 'lib/aws-sdk-sagemaker/types.rb', line 51137

class ServerlessJobConfig < Struct.new(
  :base_model_arn,
  :accept_eula,
  :job_type,
  :customization_technique,
  :peft,
  :evaluation_type,
  :evaluator_arn,
  :sequence_length)
  SENSITIVE = []
  include Aws::Structure
end

#base_model_arnString

The base model Amazon Resource Name (ARN) in SageMaker Public Hub. SageMaker always selects the latest version of the provided model.

Returns:

  • (String)


51137
51138
51139
51140
51141
51142
51143
51144
51145
51146
51147
51148
# File 'lib/aws-sdk-sagemaker/types.rb', line 51137

class ServerlessJobConfig < Struct.new(
  :base_model_arn,
  :accept_eula,
  :job_type,
  :customization_technique,
  :peft,
  :evaluation_type,
  :evaluator_arn,
  :sequence_length)
  SENSITIVE = []
  include Aws::Structure
end

#customization_techniqueString

The model customization technique.

Returns:

  • (String)


51137
51138
51139
51140
51141
51142
51143
51144
51145
51146
51147
51148
# File 'lib/aws-sdk-sagemaker/types.rb', line 51137

class ServerlessJobConfig < Struct.new(
  :base_model_arn,
  :accept_eula,
  :job_type,
  :customization_technique,
  :peft,
  :evaluation_type,
  :evaluator_arn,
  :sequence_length)
  SENSITIVE = []
  include Aws::Structure
end

#evaluation_typeString

The evaluation job type. Required when serverless job type is Evaluation.

Returns:

  • (String)


51137
51138
51139
51140
51141
51142
51143
51144
51145
51146
51147
51148
# File 'lib/aws-sdk-sagemaker/types.rb', line 51137

class ServerlessJobConfig < Struct.new(
  :base_model_arn,
  :accept_eula,
  :job_type,
  :customization_technique,
  :peft,
  :evaluation_type,
  :evaluator_arn,
  :sequence_length)
  SENSITIVE = []
  include Aws::Structure
end

#evaluator_arnString

The evaluator Amazon Resource Name (ARN) used as reward function or reward prompt.

Returns:

  • (String)


51137
51138
51139
51140
51141
51142
51143
51144
51145
51146
51147
51148
# File 'lib/aws-sdk-sagemaker/types.rb', line 51137

class ServerlessJobConfig < Struct.new(
  :base_model_arn,
  :accept_eula,
  :job_type,
  :customization_technique,
  :peft,
  :evaluation_type,
  :evaluator_arn,
  :sequence_length)
  SENSITIVE = []
  include Aws::Structure
end

#job_typeString

The serverless training job type.

Returns:

  • (String)


51137
51138
51139
51140
51141
51142
51143
51144
51145
51146
51147
51148
# File 'lib/aws-sdk-sagemaker/types.rb', line 51137

class ServerlessJobConfig < Struct.new(
  :base_model_arn,
  :accept_eula,
  :job_type,
  :customization_technique,
  :peft,
  :evaluation_type,
  :evaluator_arn,
  :sequence_length)
  SENSITIVE = []
  include Aws::Structure
end

#peftString

The parameter-efficient fine-tuning configuration.

Returns:

  • (String)


51137
51138
51139
51140
51141
51142
51143
51144
51145
51146
51147
51148
# File 'lib/aws-sdk-sagemaker/types.rb', line 51137

class ServerlessJobConfig < Struct.new(
  :base_model_arn,
  :accept_eula,
  :job_type,
  :customization_technique,
  :peft,
  :evaluation_type,
  :evaluator_arn,
  :sequence_length)
  SENSITIVE = []
  include Aws::Structure
end

#sequence_lengthString

The maximum sequence length, in tokens, that the customization job supports. SageMaker uses this value to select a training configuration for the base model that you specify. The parameter supports the following values:

  • 1K

  • 2K

  • 4K

  • 8K

  • 16K

  • 32K

  • 64K

  • 128K

If you don't specify a value, SageMaker selects a training configuration based on the other values that you specify. The selection is not restricted to a particular sequence length.

Returns:

  • (String)


51137
51138
51139
51140
51141
51142
51143
51144
51145
51146
51147
51148
# File 'lib/aws-sdk-sagemaker/types.rb', line 51137

class ServerlessJobConfig < Struct.new(
  :base_model_arn,
  :accept_eula,
  :job_type,
  :customization_technique,
  :peft,
  :evaluation_type,
  :evaluator_arn,
  :sequence_length)
  SENSITIVE = []
  include Aws::Structure
end