Class: Aws::SageMaker::Types::ServerlessJobConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ServerlessJobConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The configuration for the serverless training job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#accept_eula ⇒ Boolean
Specifies agreement to the model end-user license agreement (EULA).
-
#base_model_arn ⇒ String
The base model Amazon Resource Name (ARN) in [SageMaker Public Hub][1].
-
#customization_technique ⇒ String
The model customization technique.
-
#evaluation_type ⇒ String
The evaluation job type.
-
#evaluator_arn ⇒ String
The evaluator Amazon Resource Name (ARN) used as reward function or reward prompt.
-
#job_type ⇒ String
The serverless training job type.
-
#peft ⇒ String
The parameter-efficient fine-tuning configuration.
-
#sequence_length ⇒ String
The maximum sequence length, in tokens, that the customization job supports.
Instance Attribute Details
#accept_eula ⇒ Boolean
Specifies agreement to the model end-user license agreement (EULA).
The AcceptEula value must be explicitly defined as True in order
to accept the EULA that this model requires. You are responsible for
reviewing and complying with any applicable license terms and making
sure they are acceptable for your use case before downloading or
using a model. For more information, see End-user license
agreements section for more details on accepting the EULA.
51137 51138 51139 51140 51141 51142 51143 51144 51145 51146 51147 51148 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 51137 class ServerlessJobConfig < Struct.new( :base_model_arn, :accept_eula, :job_type, :customization_technique, :peft, :evaluation_type, :evaluator_arn, :sequence_length) SENSITIVE = [] include Aws::Structure end |
#base_model_arn ⇒ String
The base model Amazon Resource Name (ARN) in SageMaker Public Hub. SageMaker always selects the latest version of the provided model.
51137 51138 51139 51140 51141 51142 51143 51144 51145 51146 51147 51148 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 51137 class ServerlessJobConfig < Struct.new( :base_model_arn, :accept_eula, :job_type, :customization_technique, :peft, :evaluation_type, :evaluator_arn, :sequence_length) SENSITIVE = [] include Aws::Structure end |
#customization_technique ⇒ String
The model customization technique.
51137 51138 51139 51140 51141 51142 51143 51144 51145 51146 51147 51148 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 51137 class ServerlessJobConfig < Struct.new( :base_model_arn, :accept_eula, :job_type, :customization_technique, :peft, :evaluation_type, :evaluator_arn, :sequence_length) SENSITIVE = [] include Aws::Structure end |
#evaluation_type ⇒ String
The evaluation job type. Required when serverless job type is
Evaluation.
51137 51138 51139 51140 51141 51142 51143 51144 51145 51146 51147 51148 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 51137 class ServerlessJobConfig < Struct.new( :base_model_arn, :accept_eula, :job_type, :customization_technique, :peft, :evaluation_type, :evaluator_arn, :sequence_length) SENSITIVE = [] include Aws::Structure end |
#evaluator_arn ⇒ String
The evaluator Amazon Resource Name (ARN) used as reward function or reward prompt.
51137 51138 51139 51140 51141 51142 51143 51144 51145 51146 51147 51148 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 51137 class ServerlessJobConfig < Struct.new( :base_model_arn, :accept_eula, :job_type, :customization_technique, :peft, :evaluation_type, :evaluator_arn, :sequence_length) SENSITIVE = [] include Aws::Structure end |
#job_type ⇒ String
The serverless training job type.
51137 51138 51139 51140 51141 51142 51143 51144 51145 51146 51147 51148 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 51137 class ServerlessJobConfig < Struct.new( :base_model_arn, :accept_eula, :job_type, :customization_technique, :peft, :evaluation_type, :evaluator_arn, :sequence_length) SENSITIVE = [] include Aws::Structure end |
#peft ⇒ String
The parameter-efficient fine-tuning configuration.
51137 51138 51139 51140 51141 51142 51143 51144 51145 51146 51147 51148 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 51137 class ServerlessJobConfig < Struct.new( :base_model_arn, :accept_eula, :job_type, :customization_technique, :peft, :evaluation_type, :evaluator_arn, :sequence_length) SENSITIVE = [] include Aws::Structure end |
#sequence_length ⇒ String
The maximum sequence length, in tokens, that the customization job supports. SageMaker uses this value to select a training configuration for the base model that you specify. The parameter supports the following values:
-
1K -
2K -
4K -
8K -
16K -
32K -
64K -
128K
If you don't specify a value, SageMaker selects a training configuration based on the other values that you specify. The selection is not restricted to a particular sequence length.
51137 51138 51139 51140 51141 51142 51143 51144 51145 51146 51147 51148 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 51137 class ServerlessJobConfig < Struct.new( :base_model_arn, :accept_eula, :job_type, :customization_technique, :peft, :evaluation_type, :evaluator_arn, :sequence_length) SENSITIVE = [] include Aws::Structure end |