Class: Aws::SageMaker::Types::ServerlessJobConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The configuration for the serverless training job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#accept_eulaBoolean

Specifies agreement to the model end-user license agreement (EULA). The ‘AcceptEula` value must be explicitly defined as `True` in order to accept the EULA that this model requires. You are responsible for reviewing and complying with any applicable license terms and making sure they are acceptable for your use case before downloading or using a model. For more information, see [End-user license agreements] section for more details on accepting the EULA.

[1]: docs.aws.amazon.com/sagemaker/latest/dg/jumpstart-foundation-models-choose.html#jumpstart-foundation-models-choose-eula

Returns:

  • (Boolean)


50655
50656
50657
50658
50659
50660
50661
50662
50663
50664
50665
# File 'lib/aws-sdk-sagemaker/types.rb', line 50655

class ServerlessJobConfig < Struct.new(
  :base_model_arn,
  :accept_eula,
  :job_type,
  :customization_technique,
  :peft,
  :evaluation_type,
  :evaluator_arn)
  SENSITIVE = []
  include Aws::Structure
end

#base_model_arnString

The base model Amazon Resource Name (ARN) in [SageMaker Public Hub]. SageMaker always selects the latest version of the provided model.

[1]: docs.aws.amazon.com/sagemaker/latest/dg/jumpstart-foundation-models-use.html

Returns:

  • (String)


50655
50656
50657
50658
50659
50660
50661
50662
50663
50664
50665
# File 'lib/aws-sdk-sagemaker/types.rb', line 50655

class ServerlessJobConfig < Struct.new(
  :base_model_arn,
  :accept_eula,
  :job_type,
  :customization_technique,
  :peft,
  :evaluation_type,
  :evaluator_arn)
  SENSITIVE = []
  include Aws::Structure
end

#customization_techniqueString

The model customization technique.

Returns:

  • (String)


50655
50656
50657
50658
50659
50660
50661
50662
50663
50664
50665
# File 'lib/aws-sdk-sagemaker/types.rb', line 50655

class ServerlessJobConfig < Struct.new(
  :base_model_arn,
  :accept_eula,
  :job_type,
  :customization_technique,
  :peft,
  :evaluation_type,
  :evaluator_arn)
  SENSITIVE = []
  include Aws::Structure
end

#evaluation_typeString

The evaluation job type. Required when serverless job type is ‘Evaluation`.

Returns:

  • (String)


50655
50656
50657
50658
50659
50660
50661
50662
50663
50664
50665
# File 'lib/aws-sdk-sagemaker/types.rb', line 50655

class ServerlessJobConfig < Struct.new(
  :base_model_arn,
  :accept_eula,
  :job_type,
  :customization_technique,
  :peft,
  :evaluation_type,
  :evaluator_arn)
  SENSITIVE = []
  include Aws::Structure
end

#evaluator_arnString

The evaluator Amazon Resource Name (ARN) used as reward function or reward prompt.

Returns:

  • (String)


50655
50656
50657
50658
50659
50660
50661
50662
50663
50664
50665
# File 'lib/aws-sdk-sagemaker/types.rb', line 50655

class ServerlessJobConfig < Struct.new(
  :base_model_arn,
  :accept_eula,
  :job_type,
  :customization_technique,
  :peft,
  :evaluation_type,
  :evaluator_arn)
  SENSITIVE = []
  include Aws::Structure
end

#job_typeString

The serverless training job type.

Returns:

  • (String)


50655
50656
50657
50658
50659
50660
50661
50662
50663
50664
50665
# File 'lib/aws-sdk-sagemaker/types.rb', line 50655

class ServerlessJobConfig < Struct.new(
  :base_model_arn,
  :accept_eula,
  :job_type,
  :customization_technique,
  :peft,
  :evaluation_type,
  :evaluator_arn)
  SENSITIVE = []
  include Aws::Structure
end

#peftString

The parameter-efficient fine-tuning configuration.

Returns:

  • (String)


50655
50656
50657
50658
50659
50660
50661
50662
50663
50664
50665
# File 'lib/aws-sdk-sagemaker/types.rb', line 50655

class ServerlessJobConfig < Struct.new(
  :base_model_arn,
  :accept_eula,
  :job_type,
  :customization_technique,
  :peft,
  :evaluation_type,
  :evaluator_arn)
  SENSITIVE = []
  include Aws::Structure
end