Class: Aws::SageMaker::Types::ServerlessJobConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::ServerlessJobConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The configuration for the serverless training job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#accept_eula ⇒ Boolean
Specifies agreement to the model end-user license agreement (EULA).
-
#base_model_arn ⇒ String
The base model Amazon Resource Name (ARN) in [SageMaker Public Hub].
-
#customization_technique ⇒ String
The model customization technique.
-
#evaluation_type ⇒ String
The evaluation job type.
-
#evaluator_arn ⇒ String
The evaluator Amazon Resource Name (ARN) used as reward function or reward prompt.
-
#job_type ⇒ String
The serverless training job type.
-
#peft ⇒ String
The parameter-efficient fine-tuning configuration.
Instance Attribute Details
#accept_eula ⇒ Boolean
Specifies agreement to the model end-user license agreement (EULA). The ‘AcceptEula` value must be explicitly defined as `True` in order to accept the EULA that this model requires. You are responsible for reviewing and complying with any applicable license terms and making sure they are acceptable for your use case before downloading or using a model. For more information, see [End-user license agreements] section for more details on accepting the EULA.
50423 50424 50425 50426 50427 50428 50429 50430 50431 50432 50433 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 50423 class ServerlessJobConfig < Struct.new( :base_model_arn, :accept_eula, :job_type, :customization_technique, :peft, :evaluation_type, :evaluator_arn) SENSITIVE = [] include Aws::Structure end |
#base_model_arn ⇒ String
The base model Amazon Resource Name (ARN) in [SageMaker Public Hub]. SageMaker always selects the latest version of the provided model.
[1]: docs.aws.amazon.com/sagemaker/latest/dg/jumpstart-foundation-models-use.html
50423 50424 50425 50426 50427 50428 50429 50430 50431 50432 50433 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 50423 class ServerlessJobConfig < Struct.new( :base_model_arn, :accept_eula, :job_type, :customization_technique, :peft, :evaluation_type, :evaluator_arn) SENSITIVE = [] include Aws::Structure end |
#customization_technique ⇒ String
The model customization technique.
50423 50424 50425 50426 50427 50428 50429 50430 50431 50432 50433 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 50423 class ServerlessJobConfig < Struct.new( :base_model_arn, :accept_eula, :job_type, :customization_technique, :peft, :evaluation_type, :evaluator_arn) SENSITIVE = [] include Aws::Structure end |
#evaluation_type ⇒ String
The evaluation job type. Required when serverless job type is ‘Evaluation`.
50423 50424 50425 50426 50427 50428 50429 50430 50431 50432 50433 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 50423 class ServerlessJobConfig < Struct.new( :base_model_arn, :accept_eula, :job_type, :customization_technique, :peft, :evaluation_type, :evaluator_arn) SENSITIVE = [] include Aws::Structure end |
#evaluator_arn ⇒ String
The evaluator Amazon Resource Name (ARN) used as reward function or reward prompt.
50423 50424 50425 50426 50427 50428 50429 50430 50431 50432 50433 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 50423 class ServerlessJobConfig < Struct.new( :base_model_arn, :accept_eula, :job_type, :customization_technique, :peft, :evaluation_type, :evaluator_arn) SENSITIVE = [] include Aws::Structure end |
#job_type ⇒ String
The serverless training job type.
50423 50424 50425 50426 50427 50428 50429 50430 50431 50432 50433 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 50423 class ServerlessJobConfig < Struct.new( :base_model_arn, :accept_eula, :job_type, :customization_technique, :peft, :evaluation_type, :evaluator_arn) SENSITIVE = [] include Aws::Structure end |
#peft ⇒ String
The parameter-efficient fine-tuning configuration.
50423 50424 50425 50426 50427 50428 50429 50430 50431 50432 50433 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 50423 class ServerlessJobConfig < Struct.new( :base_model_arn, :accept_eula, :job_type, :customization_technique, :peft, :evaluation_type, :evaluator_arn) SENSITIVE = [] include Aws::Structure end |