Class: Aws::SageMaker::Types::SharingSettings

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Specifies options for sharing Amazon SageMaker AI Studio notebooks. These settings are specified as part of DefaultUserSettings when the CreateDomain API is called, and as part of UserSettings when the CreateUserProfile API is called. When SharingSettings is not specified, notebook sharing isn't allowed.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#notebook_output_optionString

Whether to include the notebook cell output when sharing the notebook. The default is Disabled.

Returns:

  • (String)


51164
51165
51166
51167
51168
51169
51170
# File 'lib/aws-sdk-sagemaker/types.rb', line 51164

class SharingSettings < Struct.new(
  :notebook_output_option,
  :s3_output_path,
  :s3_kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#s3_kms_key_idString

When NotebookOutputOption is Allowed, the Amazon Web Services Key Management Service (KMS) encryption key ID used to encrypt the notebook cell output in the Amazon S3 bucket.

Returns:

  • (String)


51164
51165
51166
51167
51168
51169
51170
# File 'lib/aws-sdk-sagemaker/types.rb', line 51164

class SharingSettings < Struct.new(
  :notebook_output_option,
  :s3_output_path,
  :s3_kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#s3_output_pathString

When NotebookOutputOption is Allowed, the Amazon S3 bucket used to store the shared notebook snapshots.

Returns:

  • (String)


51164
51165
51166
51167
51168
51169
51170
# File 'lib/aws-sdk-sagemaker/types.rb', line 51164

class SharingSettings < Struct.new(
  :notebook_output_option,
  :s3_output_path,
  :s3_kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end