Class: Aws::SageMaker::Types::SourceAlgorithm

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Specifies an algorithm that was used to create the model package. The algorithm must be either an algorithm resource in your SageMaker account or an algorithm in Amazon Web Services Marketplace that you are subscribed to.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#algorithm_nameString

The name of an algorithm that was used to create the model package. The algorithm must be either an algorithm resource in your SageMaker account or an algorithm in Amazon Web Services Marketplace that you are subscribed to.

Returns:

  • (String)


51399
51400
51401
51402
51403
51404
51405
51406
# File 'lib/aws-sdk-sagemaker/types.rb', line 51399

class SourceAlgorithm < Struct.new(
  :model_data_url,
  :model_data_source,
  :model_data_etag,
  :algorithm_name)
  SENSITIVE = []
  include Aws::Structure
end

#model_data_etagString

The ETag associated with Model Data URL.

Returns:

  • (String)


51399
51400
51401
51402
51403
51404
51405
51406
# File 'lib/aws-sdk-sagemaker/types.rb', line 51399

class SourceAlgorithm < Struct.new(
  :model_data_url,
  :model_data_source,
  :model_data_etag,
  :algorithm_name)
  SENSITIVE = []
  include Aws::Structure
end

#model_data_sourceTypes::ModelDataSource

Specifies the location of ML model data to deploy during endpoint creation.



51399
51400
51401
51402
51403
51404
51405
51406
# File 'lib/aws-sdk-sagemaker/types.rb', line 51399

class SourceAlgorithm < Struct.new(
  :model_data_url,
  :model_data_source,
  :model_data_etag,
  :algorithm_name)
  SENSITIVE = []
  include Aws::Structure
end

#model_data_urlString

The Amazon S3 path where the model artifacts, which result from model training, are stored. This path must point to a single gzip compressed tar archive (.tar.gz suffix).

The model artifacts must be in an S3 bucket that is in the same Amazon Web Services region as the algorithm.

Returns:

  • (String)


51399
51400
51401
51402
51403
51404
51405
51406
# File 'lib/aws-sdk-sagemaker/types.rb', line 51399

class SourceAlgorithm < Struct.new(
  :model_data_url,
  :model_data_source,
  :model_data_etag,
  :algorithm_name)
  SENSITIVE = []
  include Aws::Structure
end