Class: Aws::SageMaker::Types::SourceAlgorithm
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::SourceAlgorithm
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Specifies an algorithm that was used to create the model package. The algorithm must be either an algorithm resource in your SageMaker account or an algorithm in Amazon Web Services Marketplace that you are subscribed to.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#algorithm_name ⇒ String
The name of an algorithm that was used to create the model package.
-
#model_data_etag ⇒ String
The ETag associated with Model Data URL.
-
#model_data_source ⇒ Types::ModelDataSource
Specifies the location of ML model data to deploy during endpoint creation.
-
#model_data_url ⇒ String
The Amazon S3 path where the model artifacts, which result from model training, are stored.
Instance Attribute Details
#algorithm_name ⇒ String
The name of an algorithm that was used to create the model package. The algorithm must be either an algorithm resource in your SageMaker account or an algorithm in Amazon Web Services Marketplace that you are subscribed to.
48355 48356 48357 48358 48359 48360 48361 48362 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 48355 class SourceAlgorithm < Struct.new( :model_data_url, :model_data_source, :model_data_etag, :algorithm_name) SENSITIVE = [] include Aws::Structure end |
#model_data_etag ⇒ String
The ETag associated with Model Data URL.
48355 48356 48357 48358 48359 48360 48361 48362 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 48355 class SourceAlgorithm < Struct.new( :model_data_url, :model_data_source, :model_data_etag, :algorithm_name) SENSITIVE = [] include Aws::Structure end |
#model_data_source ⇒ Types::ModelDataSource
Specifies the location of ML model data to deploy during endpoint creation.
48355 48356 48357 48358 48359 48360 48361 48362 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 48355 class SourceAlgorithm < Struct.new( :model_data_url, :model_data_source, :model_data_etag, :algorithm_name) SENSITIVE = [] include Aws::Structure end |
#model_data_url ⇒ String
The Amazon S3 path where the model artifacts, which result from
model training, are stored. This path must point to a single gzip
compressed tar archive (.tar.gz suffix).
48355 48356 48357 48358 48359 48360 48361 48362 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 48355 class SourceAlgorithm < Struct.new( :model_data_url, :model_data_source, :model_data_etag, :algorithm_name) SENSITIVE = [] include Aws::Structure end |