Class: Aws::SageMaker::Types::SpaceCodeEditorAppSettings

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The application settings for a Code Editor space.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#app_lifecycle_managementTypes::SpaceAppLifecycleManagement

Settings that are used to configure and manage the lifecycle of CodeEditor applications in a space.



51494
51495
51496
51497
51498
51499
# File 'lib/aws-sdk-sagemaker/types.rb', line 51494

class SpaceCodeEditorAppSettings < Struct.new(
  :default_resource_spec,
  :app_lifecycle_management)
  SENSITIVE = []
  include Aws::Structure
end

#default_resource_specTypes::ResourceSpec

Specifies the ARN's of a SageMaker AI image and SageMaker AI image version, and the instance type that the version runs on.

When both SageMakerImageVersionArn and SageMakerImageArn are passed, SageMakerImageVersionArn is used. Any updates to SageMakerImageArn will not take effect if SageMakerImageVersionArn already exists in the ResourceSpec because SageMakerImageVersionArn always takes precedence. To clear the value set for SageMakerImageVersionArn, pass None as the value.

Returns:



51494
51495
51496
51497
51498
51499
# File 'lib/aws-sdk-sagemaker/types.rb', line 51494

class SpaceCodeEditorAppSettings < Struct.new(
  :default_resource_spec,
  :app_lifecycle_management)
  SENSITIVE = []
  include Aws::Structure
end