Class: Aws::SageMaker::Types::SpaceCodeEditorAppSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::SpaceCodeEditorAppSettings
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The application settings for a Code Editor space.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#app_lifecycle_management ⇒ Types::SpaceAppLifecycleManagement
Settings that are used to configure and manage the lifecycle of CodeEditor applications in a space.
-
#default_resource_spec ⇒ Types::ResourceSpec
Specifies the ARN’s of a SageMaker AI image and SageMaker AI image version, and the instance type that the version runs on.
Instance Attribute Details
#app_lifecycle_management ⇒ Types::SpaceAppLifecycleManagement
Settings that are used to configure and manage the lifecycle of CodeEditor applications in a space.
48034 48035 48036 48037 48038 48039 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 48034 class SpaceCodeEditorAppSettings < Struct.new( :default_resource_spec, :app_lifecycle_management) SENSITIVE = [] include Aws::Structure end |
#default_resource_spec ⇒ Types::ResourceSpec
Specifies the ARN’s of a SageMaker AI image and SageMaker AI image version, and the instance type that the version runs on.
<note markdown=“1”> When both SageMakerImageVersionArn and SageMakerImageArn are passed, SageMakerImageVersionArn is used. Any updates to SageMakerImageArn will not take effect if SageMakerImageVersionArn already exists in the ResourceSpec because SageMakerImageVersionArn always takes precedence. To clear the value set for SageMakerImageVersionArn, pass None as the value.
</note>
48034 48035 48036 48037 48038 48039 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 48034 class SpaceCodeEditorAppSettings < Struct.new( :default_resource_spec, :app_lifecycle_management) SENSITIVE = [] include Aws::Structure end |