Class: Aws::SageMaker::Types::SpaceJupyterLabAppSettings

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The settings for the JupyterLab application within a space.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#app_lifecycle_managementTypes::SpaceAppLifecycleManagement

Settings that are used to configure and manage the lifecycle of JupyterLab applications in a space.



51625
51626
51627
51628
51629
51630
51631
# File 'lib/aws-sdk-sagemaker/types.rb', line 51625

class SpaceJupyterLabAppSettings < Struct.new(
  :default_resource_spec,
  :code_repositories,
  :app_lifecycle_management)
  SENSITIVE = []
  include Aws::Structure
end

#code_repositoriesArray<Types::CodeRepository>

A list of Git repositories that SageMaker automatically displays to users for cloning in the JupyterLab application.

Returns:



51625
51626
51627
51628
51629
51630
51631
# File 'lib/aws-sdk-sagemaker/types.rb', line 51625

class SpaceJupyterLabAppSettings < Struct.new(
  :default_resource_spec,
  :code_repositories,
  :app_lifecycle_management)
  SENSITIVE = []
  include Aws::Structure
end

#default_resource_specTypes::ResourceSpec

Specifies the ARN's of a SageMaker AI image and SageMaker AI image version, and the instance type that the version runs on.

When both SageMakerImageVersionArn and SageMakerImageArn are passed, SageMakerImageVersionArn is used. Any updates to SageMakerImageArn will not take effect if SageMakerImageVersionArn already exists in the ResourceSpec because SageMakerImageVersionArn always takes precedence. To clear the value set for SageMakerImageVersionArn, pass None as the value.

Returns:



51625
51626
51627
51628
51629
51630
51631
# File 'lib/aws-sdk-sagemaker/types.rb', line 51625

class SpaceJupyterLabAppSettings < Struct.new(
  :default_resource_spec,
  :code_repositories,
  :app_lifecycle_management)
  SENSITIVE = []
  include Aws::Structure
end