Class: Aws::SageMaker::Types::SpaceJupyterLabAppSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::SpaceJupyterLabAppSettings
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The settings for the JupyterLab application within a space.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#app_lifecycle_management ⇒ Types::SpaceAppLifecycleManagement
Settings that are used to configure and manage the lifecycle of JupyterLab applications in a space.
-
#code_repositories ⇒ Array<Types::CodeRepository>
A list of Git repositories that SageMaker automatically displays to users for cloning in the JupyterLab application.
-
#default_resource_spec ⇒ Types::ResourceSpec
Specifies the ARN’s of a SageMaker AI image and SageMaker AI image version, and the instance type that the version runs on.
Instance Attribute Details
#app_lifecycle_management ⇒ Types::SpaceAppLifecycleManagement
Settings that are used to configure and manage the lifecycle of JupyterLab applications in a space.
48266 48267 48268 48269 48270 48271 48272 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 48266 class SpaceJupyterLabAppSettings < Struct.new( :default_resource_spec, :code_repositories, :app_lifecycle_management) SENSITIVE = [] include Aws::Structure end |
#code_repositories ⇒ Array<Types::CodeRepository>
A list of Git repositories that SageMaker automatically displays to users for cloning in the JupyterLab application.
48266 48267 48268 48269 48270 48271 48272 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 48266 class SpaceJupyterLabAppSettings < Struct.new( :default_resource_spec, :code_repositories, :app_lifecycle_management) SENSITIVE = [] include Aws::Structure end |
#default_resource_spec ⇒ Types::ResourceSpec
Specifies the ARN’s of a SageMaker AI image and SageMaker AI image version, and the instance type that the version runs on.
<note markdown=“1”> When both SageMakerImageVersionArn and SageMakerImageArn are passed, SageMakerImageVersionArn is used. Any updates to SageMakerImageArn will not take effect if SageMakerImageVersionArn already exists in the ResourceSpec because SageMakerImageVersionArn always takes precedence. To clear the value set for SageMakerImageVersionArn, pass None as the value.
</note>
48266 48267 48268 48269 48270 48271 48272 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 48266 class SpaceJupyterLabAppSettings < Struct.new( :default_resource_spec, :code_repositories, :app_lifecycle_management) SENSITIVE = [] include Aws::Structure end |