Class: Aws::SageMaker::Types::SpaceSettings

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

A collection of space settings.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#app_typeString

The type of app created within the space.

If using the [ UpdateSpace][1] API, you can’t change the app type of your space by specifying a different value for this field.

[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_UpdateSpace.html



48330
48331
48332
48333
48334
48335
48336
48337
48338
48339
48340
48341
48342
# File 'lib/aws-sdk-sagemaker/types.rb', line 48330

class SpaceSettings < Struct.new(
  :jupyter_server_app_settings,
  :kernel_gateway_app_settings,
  :code_editor_app_settings,
  :jupyter_lab_app_settings,
  :app_type,
  :space_storage_settings,
  :space_managed_resources,
  :custom_file_systems,
  :remote_access)
  SENSITIVE = []
  include Aws::Structure
end

#code_editor_app_settingsTypes::SpaceCodeEditorAppSettings

The Code Editor application settings.



48330
48331
48332
48333
48334
48335
48336
48337
48338
48339
48340
48341
48342
# File 'lib/aws-sdk-sagemaker/types.rb', line 48330

class SpaceSettings < Struct.new(
  :jupyter_server_app_settings,
  :kernel_gateway_app_settings,
  :code_editor_app_settings,
  :jupyter_lab_app_settings,
  :app_type,
  :space_storage_settings,
  :space_managed_resources,
  :custom_file_systems,
  :remote_access)
  SENSITIVE = []
  include Aws::Structure
end

#custom_file_systemsArray<Types::CustomFileSystem>

A file system, created by you, that you assign to a space for an Amazon SageMaker AI Domain. Permitted users can access this file system in Amazon SageMaker AI Studio.



48330
48331
48332
48333
48334
48335
48336
48337
48338
48339
48340
48341
48342
# File 'lib/aws-sdk-sagemaker/types.rb', line 48330

class SpaceSettings < Struct.new(
  :jupyter_server_app_settings,
  :kernel_gateway_app_settings,
  :code_editor_app_settings,
  :jupyter_lab_app_settings,
  :app_type,
  :space_storage_settings,
  :space_managed_resources,
  :custom_file_systems,
  :remote_access)
  SENSITIVE = []
  include Aws::Structure
end

#jupyter_lab_app_settingsTypes::SpaceJupyterLabAppSettings

The settings for the JupyterLab application.



48330
48331
48332
48333
48334
48335
48336
48337
48338
48339
48340
48341
48342
# File 'lib/aws-sdk-sagemaker/types.rb', line 48330

class SpaceSettings < Struct.new(
  :jupyter_server_app_settings,
  :kernel_gateway_app_settings,
  :code_editor_app_settings,
  :jupyter_lab_app_settings,
  :app_type,
  :space_storage_settings,
  :space_managed_resources,
  :custom_file_systems,
  :remote_access)
  SENSITIVE = []
  include Aws::Structure
end

#jupyter_server_app_settingsTypes::JupyterServerAppSettings

The JupyterServer app settings.



48330
48331
48332
48333
48334
48335
48336
48337
48338
48339
48340
48341
48342
# File 'lib/aws-sdk-sagemaker/types.rb', line 48330

class SpaceSettings < Struct.new(
  :jupyter_server_app_settings,
  :kernel_gateway_app_settings,
  :code_editor_app_settings,
  :jupyter_lab_app_settings,
  :app_type,
  :space_storage_settings,
  :space_managed_resources,
  :custom_file_systems,
  :remote_access)
  SENSITIVE = []
  include Aws::Structure
end

#kernel_gateway_app_settingsTypes::KernelGatewayAppSettings

The KernelGateway app settings.



48330
48331
48332
48333
48334
48335
48336
48337
48338
48339
48340
48341
48342
# File 'lib/aws-sdk-sagemaker/types.rb', line 48330

class SpaceSettings < Struct.new(
  :jupyter_server_app_settings,
  :kernel_gateway_app_settings,
  :code_editor_app_settings,
  :jupyter_lab_app_settings,
  :app_type,
  :space_storage_settings,
  :space_managed_resources,
  :custom_file_systems,
  :remote_access)
  SENSITIVE = []
  include Aws::Structure
end

#remote_accessString

A setting that enables or disables remote access for a SageMaker space. When enabled, this allows you to connect to the remote space from your local IDE.



48330
48331
48332
48333
48334
48335
48336
48337
48338
48339
48340
48341
48342
# File 'lib/aws-sdk-sagemaker/types.rb', line 48330

class SpaceSettings < Struct.new(
  :jupyter_server_app_settings,
  :kernel_gateway_app_settings,
  :code_editor_app_settings,
  :jupyter_lab_app_settings,
  :app_type,
  :space_storage_settings,
  :space_managed_resources,
  :custom_file_systems,
  :remote_access)
  SENSITIVE = []
  include Aws::Structure
end

#space_managed_resourcesString

If you enable this option, SageMaker AI creates the following resources on your behalf when you create the space:

  • The user profile that possesses the space.

  • The app that the space contains.



48330
48331
48332
48333
48334
48335
48336
48337
48338
48339
48340
48341
48342
# File 'lib/aws-sdk-sagemaker/types.rb', line 48330

class SpaceSettings < Struct.new(
  :jupyter_server_app_settings,
  :kernel_gateway_app_settings,
  :code_editor_app_settings,
  :jupyter_lab_app_settings,
  :app_type,
  :space_storage_settings,
  :space_managed_resources,
  :custom_file_systems,
  :remote_access)
  SENSITIVE = []
  include Aws::Structure
end

#space_storage_settingsTypes::SpaceStorageSettings

The storage settings for a space.



48330
48331
48332
48333
48334
48335
48336
48337
48338
48339
48340
48341
48342
# File 'lib/aws-sdk-sagemaker/types.rb', line 48330

class SpaceSettings < Struct.new(
  :jupyter_server_app_settings,
  :kernel_gateway_app_settings,
  :code_editor_app_settings,
  :jupyter_lab_app_settings,
  :app_type,
  :space_storage_settings,
  :space_managed_resources,
  :custom_file_systems,
  :remote_access)
  SENSITIVE = []
  include Aws::Structure
end