Class: Aws::SageMaker::Types::Stairs
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::Stairs
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Defines the stairs traffic pattern for an Inference Recommender load test. This pattern type consists of multiple steps where the number of users increases at each step.
Specify either the stairs or phases traffic pattern.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#duration_in_seconds ⇒ Integer
Defines how long each traffic step should be.
-
#number_of_steps ⇒ Integer
Specifies how many steps to perform during traffic.
-
#users_per_step ⇒ Integer
Specifies how many new users to spawn in each step.
Instance Attribute Details
#duration_in_seconds ⇒ Integer
Defines how long each traffic step should be.
51841 51842 51843 51844 51845 51846 51847 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 51841 class Stairs < Struct.new( :duration_in_seconds, :number_of_steps, :users_per_step) SENSITIVE = [] include Aws::Structure end |