Class: Aws::SageMaker::Types::StartSessionRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#resource_identifierString

The Amazon Resource Name (ARN) of the resource to which the remote connection will be established. For example, this identifies the specific ARN space application you want to connect to from your local IDE.

Returns:

  • (String)


51809
51810
51811
51812
51813
# File 'lib/aws-sdk-sagemaker/types.rb', line 51809

class StartSessionRequest < Struct.new(
  :resource_identifier)
  SENSITIVE = []
  include Aws::Structure
end