Class: Aws::SageMaker::Types::StartSessionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::StartSessionRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resource_identifier ⇒ String
The Amazon Resource Name (ARN) of the resource to which the remote connection will be established.
Instance Attribute Details
#resource_identifier ⇒ String
The Amazon Resource Name (ARN) of the resource to which the remote connection will be established. For example, this identifies the specific ARN space application you want to connect to from your local IDE.
48996 48997 48998 48999 49000 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 48996 class StartSessionRequest < Struct.new( :resource_identifier) SENSITIVE = [] include Aws::Structure end |