Class: Aws::SageMaker::Types::StudioWebPortalSettings

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Studio settings. If these settings are applied on a user level, they take priority over the settings applied on a domain level.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#execution_role_session_name_modeString

The execution role session name mode. If this value is set to USER_IDENTITY, the session name of the execution role corresponds to the user's identity. For IAM domains, the session name is the IAM session name used to generate the presigned URL. For IAM Identity Center domains, the session name is the username of the associated IAM Identity Center user. If this value is set to STATIC or is not set, the session name defaults to SageMaker.

Returns:

  • (String)


52537
52538
52539
52540
52541
52542
52543
52544
52545
# File 'lib/aws-sdk-sagemaker/types.rb', line 52537

class StudioWebPortalSettings < Struct.new(
  :hidden_ml_tools,
  :hidden_app_types,
  :hidden_instance_types,
  :hidden_sage_maker_image_version_aliases,
  :execution_role_session_name_mode)
  SENSITIVE = []
  include Aws::Structure
end

#hidden_app_typesArray<String>

The Applications supported in Studio that are hidden from the Studio left navigation pane.

Returns:

  • (Array<String>)


52537
52538
52539
52540
52541
52542
52543
52544
52545
# File 'lib/aws-sdk-sagemaker/types.rb', line 52537

class StudioWebPortalSettings < Struct.new(
  :hidden_ml_tools,
  :hidden_app_types,
  :hidden_instance_types,
  :hidden_sage_maker_image_version_aliases,
  :execution_role_session_name_mode)
  SENSITIVE = []
  include Aws::Structure
end

#hidden_instance_typesArray<String>

The instance types you are hiding from the Studio user interface.

Returns:

  • (Array<String>)


52537
52538
52539
52540
52541
52542
52543
52544
52545
# File 'lib/aws-sdk-sagemaker/types.rb', line 52537

class StudioWebPortalSettings < Struct.new(
  :hidden_ml_tools,
  :hidden_app_types,
  :hidden_instance_types,
  :hidden_sage_maker_image_version_aliases,
  :execution_role_session_name_mode)
  SENSITIVE = []
  include Aws::Structure
end

#hidden_ml_toolsArray<String>

The machine learning tools that are hidden from the Studio left navigation pane.

Returns:

  • (Array<String>)


52537
52538
52539
52540
52541
52542
52543
52544
52545
# File 'lib/aws-sdk-sagemaker/types.rb', line 52537

class StudioWebPortalSettings < Struct.new(
  :hidden_ml_tools,
  :hidden_app_types,
  :hidden_instance_types,
  :hidden_sage_maker_image_version_aliases,
  :execution_role_session_name_mode)
  SENSITIVE = []
  include Aws::Structure
end

#hidden_sage_maker_image_version_aliasesArray<Types::HiddenSageMakerImage>

The version aliases you are hiding from the Studio user interface.

Returns:



52537
52538
52539
52540
52541
52542
52543
52544
52545
# File 'lib/aws-sdk-sagemaker/types.rb', line 52537

class StudioWebPortalSettings < Struct.new(
  :hidden_ml_tools,
  :hidden_app_types,
  :hidden_instance_types,
  :hidden_sage_maker_image_version_aliases,
  :execution_role_session_name_mode)
  SENSITIVE = []
  include Aws::Structure
end