Class: Aws::SageMaker::Types::StudioWebPortalSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::StudioWebPortalSettings
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Studio settings. If these settings are applied on a user level, they take priority over the settings applied on a domain level.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#execution_role_session_name_mode ⇒ String
The execution role session name mode.
-
#hidden_app_types ⇒ Array<String>
The [Applications supported in Studio] that are hidden from the Studio left navigation pane.
-
#hidden_instance_types ⇒ Array<String>
The instance types you are hiding from the Studio user interface.
-
#hidden_ml_tools ⇒ Array<String>
The machine learning tools that are hidden from the Studio left navigation pane.
-
#hidden_sage_maker_image_version_aliases ⇒ Array<Types::HiddenSageMakerImage>
The version aliases you are hiding from the Studio user interface.
Instance Attribute Details
#execution_role_session_name_mode ⇒ String
The execution role session name mode. If this value is set to ‘USER_IDENTITY`, the session name of the execution role corresponds to the user’s identity. For IAM domains, the session name is the IAM session name used to generate the presigned URL. For IAM Identity Center domains, the session name is the username of the associated IAM Identity Center user. If this value is set to ‘STATIC` or is not set, the session name defaults to `SageMaker`.
51215 51216 51217 51218 51219 51220 51221 51222 51223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 51215 class StudioWebPortalSettings < Struct.new( :hidden_ml_tools, :hidden_app_types, :hidden_instance_types, :hidden_sage_maker_image_version_aliases, :execution_role_session_name_mode) SENSITIVE = [] include Aws::Structure end |
#hidden_app_types ⇒ Array<String>
The [Applications supported in Studio] that are hidden from the Studio left navigation pane.
[1]: docs.aws.amazon.com/sagemaker/latest/dg/studio-updated-apps.html
51215 51216 51217 51218 51219 51220 51221 51222 51223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 51215 class StudioWebPortalSettings < Struct.new( :hidden_ml_tools, :hidden_app_types, :hidden_instance_types, :hidden_sage_maker_image_version_aliases, :execution_role_session_name_mode) SENSITIVE = [] include Aws::Structure end |
#hidden_instance_types ⇒ Array<String>
The instance types you are hiding from the Studio user interface.
51215 51216 51217 51218 51219 51220 51221 51222 51223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 51215 class StudioWebPortalSettings < Struct.new( :hidden_ml_tools, :hidden_app_types, :hidden_instance_types, :hidden_sage_maker_image_version_aliases, :execution_role_session_name_mode) SENSITIVE = [] include Aws::Structure end |
#hidden_ml_tools ⇒ Array<String>
The machine learning tools that are hidden from the Studio left navigation pane.
51215 51216 51217 51218 51219 51220 51221 51222 51223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 51215 class StudioWebPortalSettings < Struct.new( :hidden_ml_tools, :hidden_app_types, :hidden_instance_types, :hidden_sage_maker_image_version_aliases, :execution_role_session_name_mode) SENSITIVE = [] include Aws::Structure end |
#hidden_sage_maker_image_version_aliases ⇒ Array<Types::HiddenSageMakerImage>
The version aliases you are hiding from the Studio user interface.
51215 51216 51217 51218 51219 51220 51221 51222 51223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 51215 class StudioWebPortalSettings < Struct.new( :hidden_ml_tools, :hidden_app_types, :hidden_instance_types, :hidden_sage_maker_image_version_aliases, :execution_role_session_name_mode) SENSITIVE = [] include Aws::Structure end |