Class: Aws::SageMaker::Types::TabularResolvedAttributes

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The resolved attributes specific to the tabular problem type.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#problem_typeString

The type of supervised learning problem available for the model candidates of the AutoML job V2 (Binary Classification, Multiclass Classification, Regression). For more information, see SageMaker Autopilot problem types.

Returns:

  • (String)


52733
52734
52735
52736
52737
# File 'lib/aws-sdk-sagemaker/types.rb', line 52733

class TabularResolvedAttributes < Struct.new(
  :problem_type)
  SENSITIVE = []
  include Aws::Structure
end