Class: Aws::SageMaker::Types::TabularResolvedAttributes
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::TabularResolvedAttributes
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The resolved attributes specific to the tabular problem type.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#problem_type ⇒ String
The type of supervised learning problem available for the model candidates of the AutoML job V2 (Binary Classification, Multiclass Classification, Regression).
Instance Attribute Details
#problem_type ⇒ String
The type of supervised learning problem available for the model candidates of the AutoML job V2 (Binary Classification, Multiclass Classification, Regression). For more information, see SageMaker Autopilot problem types.
52569 52570 52571 52572 52573 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 52569 class TabularResolvedAttributes < Struct.new( :problem_type) SENSITIVE = [] include Aws::Structure end |