Class: Aws::SageMaker::Types::TextClassificationJobConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::TextClassificationJobConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The collection of settings used by an AutoML job V2 for the text classification problem type.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#completion_criteria ⇒ Types::AutoMLJobCompletionCriteria
How long a job is allowed to run, or how many candidates a job is allowed to generate.
-
#content_column ⇒ String
The name of the column used to provide the sentences to be classified.
-
#target_label_column ⇒ String
The name of the column used to provide the class labels.
Instance Attribute Details
#completion_criteria ⇒ Types::AutoMLJobCompletionCriteria
How long a job is allowed to run, or how many candidates a job is allowed to generate.
49365 49366 49367 49368 49369 49370 49371 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49365 class TextClassificationJobConfig < Struct.new( :completion_criteria, :content_column, :target_label_column) SENSITIVE = [] include Aws::Structure end |
#content_column ⇒ String
The name of the column used to provide the sentences to be classified. It should not be the same as the target column.
49365 49366 49367 49368 49369 49370 49371 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49365 class TextClassificationJobConfig < Struct.new( :completion_criteria, :content_column, :target_label_column) SENSITIVE = [] include Aws::Structure end |
#target_label_column ⇒ String
The name of the column used to provide the class labels. It should not be same as the content column.
49365 49366 49367 49368 49369 49370 49371 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 49365 class TextClassificationJobConfig < Struct.new( :completion_criteria, :content_column, :target_label_column) SENSITIVE = [] include Aws::Structure end |