Class: Aws::SageMaker::Types::TimeSeriesConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The collection of components that defines the time-series.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#grouping_attribute_namesArray<String>

A set of columns names that can be grouped with the item identifier column to create a composite key for which a target value is predicted.

Returns:

  • (Array<String>)


52029
52030
52031
52032
52033
52034
52035
52036
# File 'lib/aws-sdk-sagemaker/types.rb', line 52029

class TimeSeriesConfig < Struct.new(
  :target_attribute_name,
  :timestamp_attribute_name,
  :item_identifier_attribute_name,
  :grouping_attribute_names)
  SENSITIVE = []
  include Aws::Structure
end

#item_identifier_attribute_nameString

The name of the column that represents the set of item identifiers for which you want to predict the target value.

Returns:

  • (String)


52029
52030
52031
52032
52033
52034
52035
52036
# File 'lib/aws-sdk-sagemaker/types.rb', line 52029

class TimeSeriesConfig < Struct.new(
  :target_attribute_name,
  :timestamp_attribute_name,
  :item_identifier_attribute_name,
  :grouping_attribute_names)
  SENSITIVE = []
  include Aws::Structure
end

#target_attribute_nameString

The name of the column representing the target variable that you want to predict for each item in your dataset. The data type of the target variable must be numerical.

Returns:

  • (String)


52029
52030
52031
52032
52033
52034
52035
52036
# File 'lib/aws-sdk-sagemaker/types.rb', line 52029

class TimeSeriesConfig < Struct.new(
  :target_attribute_name,
  :timestamp_attribute_name,
  :item_identifier_attribute_name,
  :grouping_attribute_names)
  SENSITIVE = []
  include Aws::Structure
end

#timestamp_attribute_nameString

The name of the column indicating a point in time at which the target value of a given item is recorded.

Returns:

  • (String)


52029
52030
52031
52032
52033
52034
52035
52036
# File 'lib/aws-sdk-sagemaker/types.rb', line 52029

class TimeSeriesConfig < Struct.new(
  :target_attribute_name,
  :timestamp_attribute_name,
  :item_identifier_attribute_name,
  :grouping_attribute_names)
  SENSITIVE = []
  include Aws::Structure
end