Class: Aws::SageMaker::Types::TimeSeriesConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::TimeSeriesConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The collection of components that defines the time-series.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#grouping_attribute_names ⇒ Array<String>
A set of columns names that can be grouped with the item identifier column to create a composite key for which a target value is predicted.
-
#item_identifier_attribute_name ⇒ String
The name of the column that represents the set of item identifiers for which you want to predict the target value.
-
#target_attribute_name ⇒ String
The name of the column representing the target variable that you want to predict for each item in your dataset.
-
#timestamp_attribute_name ⇒ String
The name of the column indicating a point in time at which the target value of a given item is recorded.
Instance Attribute Details
#grouping_attribute_names ⇒ Array<String>
A set of columns names that can be grouped with the item identifier column to create a composite key for which a target value is predicted.
50150 50151 50152 50153 50154 50155 50156 50157 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 50150 class TimeSeriesConfig < Struct.new( :target_attribute_name, :timestamp_attribute_name, :item_identifier_attribute_name, :grouping_attribute_names) SENSITIVE = [] include Aws::Structure end |
#item_identifier_attribute_name ⇒ String
The name of the column that represents the set of item identifiers for which you want to predict the target value.
50150 50151 50152 50153 50154 50155 50156 50157 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 50150 class TimeSeriesConfig < Struct.new( :target_attribute_name, :timestamp_attribute_name, :item_identifier_attribute_name, :grouping_attribute_names) SENSITIVE = [] include Aws::Structure end |
#target_attribute_name ⇒ String
The name of the column representing the target variable that you want to predict for each item in your dataset. The data type of the target variable must be numerical.
50150 50151 50152 50153 50154 50155 50156 50157 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 50150 class TimeSeriesConfig < Struct.new( :target_attribute_name, :timestamp_attribute_name, :item_identifier_attribute_name, :grouping_attribute_names) SENSITIVE = [] include Aws::Structure end |
#timestamp_attribute_name ⇒ String
The name of the column indicating a point in time at which the target value of a given item is recorded.
50150 50151 50152 50153 50154 50155 50156 50157 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 50150 class TimeSeriesConfig < Struct.new( :target_attribute_name, :timestamp_attribute_name, :item_identifier_attribute_name, :grouping_attribute_names) SENSITIVE = [] include Aws::Structure end |