Class: Aws::SageMaker::Types::TrainingPlanExtension
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::TrainingPlanExtension
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Details about an extension to a training plan, including the offering ID, dates, status, and cost information.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zone ⇒ String
The Availability Zone of the extension.
-
#availability_zone_id ⇒ String
The Availability Zone ID of the extension.
-
#currency_code ⇒ String
The currency code for the upfront fee (e.g., USD).
-
#duration_hours ⇒ Integer
The duration of the extension in hours.
-
#end_date ⇒ Time
The end date of the extension period.
-
#extended_at ⇒ Time
The timestamp when the extension was created.
-
#payment_status ⇒ String
The payment processing status of the extension.
-
#start_date ⇒ Time
The start date of the extension period.
-
#status ⇒ String
The current status of the extension (e.g., Pending, Active, Scheduled, Failed, Expired).
-
#training_plan_extension_offering_id ⇒ String
The unique identifier of the extension offering that was used to create this extension.
-
#upfront_fee ⇒ String
The upfront fee for the extension.
Instance Attribute Details
#availability_zone ⇒ String
The Availability Zone of the extension.
52622 52623 52624 52625 52626 52627 52628 52629 52630 52631 52632 52633 52634 52635 52636 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 52622 class TrainingPlanExtension < Struct.new( :training_plan_extension_offering_id, :extended_at, :start_date, :end_date, :status, :payment_status, :availability_zone, :availability_zone_id, :duration_hours, :upfront_fee, :currency_code) SENSITIVE = [] include Aws::Structure end |
#availability_zone_id ⇒ String
The Availability Zone ID of the extension.
52622 52623 52624 52625 52626 52627 52628 52629 52630 52631 52632 52633 52634 52635 52636 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 52622 class TrainingPlanExtension < Struct.new( :training_plan_extension_offering_id, :extended_at, :start_date, :end_date, :status, :payment_status, :availability_zone, :availability_zone_id, :duration_hours, :upfront_fee, :currency_code) SENSITIVE = [] include Aws::Structure end |
#currency_code ⇒ String
The currency code for the upfront fee (e.g., USD).
52622 52623 52624 52625 52626 52627 52628 52629 52630 52631 52632 52633 52634 52635 52636 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 52622 class TrainingPlanExtension < Struct.new( :training_plan_extension_offering_id, :extended_at, :start_date, :end_date, :status, :payment_status, :availability_zone, :availability_zone_id, :duration_hours, :upfront_fee, :currency_code) SENSITIVE = [] include Aws::Structure end |
#duration_hours ⇒ Integer
The duration of the extension in hours.
52622 52623 52624 52625 52626 52627 52628 52629 52630 52631 52632 52633 52634 52635 52636 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 52622 class TrainingPlanExtension < Struct.new( :training_plan_extension_offering_id, :extended_at, :start_date, :end_date, :status, :payment_status, :availability_zone, :availability_zone_id, :duration_hours, :upfront_fee, :currency_code) SENSITIVE = [] include Aws::Structure end |
#end_date ⇒ Time
The end date of the extension period.
52622 52623 52624 52625 52626 52627 52628 52629 52630 52631 52632 52633 52634 52635 52636 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 52622 class TrainingPlanExtension < Struct.new( :training_plan_extension_offering_id, :extended_at, :start_date, :end_date, :status, :payment_status, :availability_zone, :availability_zone_id, :duration_hours, :upfront_fee, :currency_code) SENSITIVE = [] include Aws::Structure end |
#extended_at ⇒ Time
The timestamp when the extension was created.
52622 52623 52624 52625 52626 52627 52628 52629 52630 52631 52632 52633 52634 52635 52636 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 52622 class TrainingPlanExtension < Struct.new( :training_plan_extension_offering_id, :extended_at, :start_date, :end_date, :status, :payment_status, :availability_zone, :availability_zone_id, :duration_hours, :upfront_fee, :currency_code) SENSITIVE = [] include Aws::Structure end |
#payment_status ⇒ String
The payment processing status of the extension.
52622 52623 52624 52625 52626 52627 52628 52629 52630 52631 52632 52633 52634 52635 52636 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 52622 class TrainingPlanExtension < Struct.new( :training_plan_extension_offering_id, :extended_at, :start_date, :end_date, :status, :payment_status, :availability_zone, :availability_zone_id, :duration_hours, :upfront_fee, :currency_code) SENSITIVE = [] include Aws::Structure end |
#start_date ⇒ Time
The start date of the extension period.
52622 52623 52624 52625 52626 52627 52628 52629 52630 52631 52632 52633 52634 52635 52636 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 52622 class TrainingPlanExtension < Struct.new( :training_plan_extension_offering_id, :extended_at, :start_date, :end_date, :status, :payment_status, :availability_zone, :availability_zone_id, :duration_hours, :upfront_fee, :currency_code) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the extension (e.g., Pending, Active, Scheduled, Failed, Expired).
52622 52623 52624 52625 52626 52627 52628 52629 52630 52631 52632 52633 52634 52635 52636 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 52622 class TrainingPlanExtension < Struct.new( :training_plan_extension_offering_id, :extended_at, :start_date, :end_date, :status, :payment_status, :availability_zone, :availability_zone_id, :duration_hours, :upfront_fee, :currency_code) SENSITIVE = [] include Aws::Structure end |
#training_plan_extension_offering_id ⇒ String
The unique identifier of the extension offering that was used to create this extension.
52622 52623 52624 52625 52626 52627 52628 52629 52630 52631 52632 52633 52634 52635 52636 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 52622 class TrainingPlanExtension < Struct.new( :training_plan_extension_offering_id, :extended_at, :start_date, :end_date, :status, :payment_status, :availability_zone, :availability_zone_id, :duration_hours, :upfront_fee, :currency_code) SENSITIVE = [] include Aws::Structure end |
#upfront_fee ⇒ String
The upfront fee for the extension.
52622 52623 52624 52625 52626 52627 52628 52629 52630 52631 52632 52633 52634 52635 52636 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 52622 class TrainingPlanExtension < Struct.new( :training_plan_extension_offering_id, :extended_at, :start_date, :end_date, :status, :payment_status, :availability_zone, :availability_zone_id, :duration_hours, :upfront_fee, :currency_code) SENSITIVE = [] include Aws::Structure end |