Class: Aws::SageMaker::Types::TrainingPlanFilter
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::TrainingPlanFilter
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
A filter to apply when listing or searching for training plans.
For more information about how to reserve GPU capacity for your SageMaker HyperPod clusters using Amazon SageMaker Training Plan, see ‘ CreateTrainingPlan `.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the filter field (e.g., Status, InstanceType).
-
#value ⇒ String
The value to filter by for the specified field.
Instance Attribute Details
#name ⇒ String
The name of the filter field (e.g., Status, InstanceType).
50634 50635 50636 50637 50638 50639 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 50634 class TrainingPlanFilter < Struct.new( :name, :value) SENSITIVE = [] include Aws::Structure end |
#value ⇒ String
The value to filter by for the specified field.
50634 50635 50636 50637 50638 50639 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 50634 class TrainingPlanFilter < Struct.new( :name, :value) SENSITIVE = [] include Aws::Structure end |