Class: Aws::SageMaker::Types::TrainingPlanOffering
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::TrainingPlanOffering
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Details about a training plan offering.
For more information about how to reserve GPU capacity for your SageMaker HyperPod clusters using Amazon SageMaker Training Plan, see ‘ CreateTrainingPlan `.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#currency_code ⇒ String
The currency code for the upfront fee (e.g., USD).
-
#duration_hours ⇒ Integer
The number of whole hours in the total duration for this training plan offering.
-
#duration_minutes ⇒ Integer
The additional minutes beyond whole hours in the total duration for this training plan offering.
-
#requested_end_time_before ⇒ Time
The requested end time that the user specified when searching for the training plan offering.
-
#requested_start_time_after ⇒ Time
The requested start time that the user specified when searching for the training plan offering.
-
#reserved_capacity_offerings ⇒ Array<Types::ReservedCapacityOffering>
A list of reserved capacity offerings associated with this training plan offering.
-
#target_resources ⇒ Array<String>
The target resources (e.g., SageMaker Training Jobs, SageMaker HyperPod, SageMaker Endpoints, Studio apps) for this training plan offering.
-
#training_plan_offering_id ⇒ String
The unique identifier for this training plan offering.
-
#upfront_fee ⇒ String
The upfront fee for this training plan offering.
Instance Attribute Details
#currency_code ⇒ String
The currency code for the upfront fee (e.g., USD).
53857 53858 53859 53860 53861 53862 53863 53864 53865 53866 53867 53868 53869 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53857 class TrainingPlanOffering < Struct.new( :training_plan_offering_id, :target_resources, :requested_start_time_after, :requested_end_time_before, :duration_hours, :duration_minutes, :upfront_fee, :currency_code, :reserved_capacity_offerings) SENSITIVE = [] include Aws::Structure end |
#duration_hours ⇒ Integer
The number of whole hours in the total duration for this training plan offering.
53857 53858 53859 53860 53861 53862 53863 53864 53865 53866 53867 53868 53869 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53857 class TrainingPlanOffering < Struct.new( :training_plan_offering_id, :target_resources, :requested_start_time_after, :requested_end_time_before, :duration_hours, :duration_minutes, :upfront_fee, :currency_code, :reserved_capacity_offerings) SENSITIVE = [] include Aws::Structure end |
#duration_minutes ⇒ Integer
The additional minutes beyond whole hours in the total duration for this training plan offering.
53857 53858 53859 53860 53861 53862 53863 53864 53865 53866 53867 53868 53869 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53857 class TrainingPlanOffering < Struct.new( :training_plan_offering_id, :target_resources, :requested_start_time_after, :requested_end_time_before, :duration_hours, :duration_minutes, :upfront_fee, :currency_code, :reserved_capacity_offerings) SENSITIVE = [] include Aws::Structure end |
#requested_end_time_before ⇒ Time
The requested end time that the user specified when searching for the training plan offering.
53857 53858 53859 53860 53861 53862 53863 53864 53865 53866 53867 53868 53869 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53857 class TrainingPlanOffering < Struct.new( :training_plan_offering_id, :target_resources, :requested_start_time_after, :requested_end_time_before, :duration_hours, :duration_minutes, :upfront_fee, :currency_code, :reserved_capacity_offerings) SENSITIVE = [] include Aws::Structure end |
#requested_start_time_after ⇒ Time
The requested start time that the user specified when searching for the training plan offering.
53857 53858 53859 53860 53861 53862 53863 53864 53865 53866 53867 53868 53869 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53857 class TrainingPlanOffering < Struct.new( :training_plan_offering_id, :target_resources, :requested_start_time_after, :requested_end_time_before, :duration_hours, :duration_minutes, :upfront_fee, :currency_code, :reserved_capacity_offerings) SENSITIVE = [] include Aws::Structure end |
#reserved_capacity_offerings ⇒ Array<Types::ReservedCapacityOffering>
A list of reserved capacity offerings associated with this training plan offering.
53857 53858 53859 53860 53861 53862 53863 53864 53865 53866 53867 53868 53869 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53857 class TrainingPlanOffering < Struct.new( :training_plan_offering_id, :target_resources, :requested_start_time_after, :requested_end_time_before, :duration_hours, :duration_minutes, :upfront_fee, :currency_code, :reserved_capacity_offerings) SENSITIVE = [] include Aws::Structure end |
#target_resources ⇒ Array<String>
The target resources (e.g., SageMaker Training Jobs, SageMaker HyperPod, SageMaker Endpoints, Studio apps) for this training plan offering.
Training plans are specific to their target resource.
-
A training plan designed for SageMaker training jobs can only be used to schedule and run training jobs.
-
A training plan for HyperPod clusters can be used exclusively to provide compute resources to a cluster’s instance group.
-
A training plan for SageMaker endpoints can be used exclusively to provide compute resources to SageMaker endpoints for model deployment.
-
A training plan for Studio apps can be used to launch JupyterLab and Code Editor apps on reserved training plan capacity.
53857 53858 53859 53860 53861 53862 53863 53864 53865 53866 53867 53868 53869 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53857 class TrainingPlanOffering < Struct.new( :training_plan_offering_id, :target_resources, :requested_start_time_after, :requested_end_time_before, :duration_hours, :duration_minutes, :upfront_fee, :currency_code, :reserved_capacity_offerings) SENSITIVE = [] include Aws::Structure end |
#training_plan_offering_id ⇒ String
The unique identifier for this training plan offering.
53857 53858 53859 53860 53861 53862 53863 53864 53865 53866 53867 53868 53869 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53857 class TrainingPlanOffering < Struct.new( :training_plan_offering_id, :target_resources, :requested_start_time_after, :requested_end_time_before, :duration_hours, :duration_minutes, :upfront_fee, :currency_code, :reserved_capacity_offerings) SENSITIVE = [] include Aws::Structure end |
#upfront_fee ⇒ String
The upfront fee for this training plan offering.
53857 53858 53859 53860 53861 53862 53863 53864 53865 53866 53867 53868 53869 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53857 class TrainingPlanOffering < Struct.new( :training_plan_offering_id, :target_resources, :requested_start_time_after, :requested_end_time_before, :duration_hours, :duration_minutes, :upfront_fee, :currency_code, :reserved_capacity_offerings) SENSITIVE = [] include Aws::Structure end |