Class: Aws::SageMaker::Types::TrainingPlanSummary

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Details of the training plan.

For more information about how to reserve GPU capacity for your SageMaker HyperPod clusters using Amazon SageMaker Training Plan, see CreateTrainingPlan.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#available_instance_countInteger

The number of instances currently available for use in this training plan.

Returns:

  • (Integer)


54309
54310
54311
54312
54313
54314
54315
54316
54317
54318
54319
54320
54321
54322
54323
54324
54325
54326
54327
54328
# File 'lib/aws-sdk-sagemaker/types.rb', line 54309

class TrainingPlanSummary < Struct.new(
  :training_plan_arn,
  :training_plan_name,
  :status,
  :status_message,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :upfront_fee,
  :currency_code,
  :total_instance_count,
  :available_instance_count,
  :in_use_instance_count,
  :total_ultra_server_count,
  :target_resources,
  :reserved_capacity_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#currency_codeString

The currency code for the upfront fee (e.g., USD).

Returns:

  • (String)


54309
54310
54311
54312
54313
54314
54315
54316
54317
54318
54319
54320
54321
54322
54323
54324
54325
54326
54327
54328
# File 'lib/aws-sdk-sagemaker/types.rb', line 54309

class TrainingPlanSummary < Struct.new(
  :training_plan_arn,
  :training_plan_name,
  :status,
  :status_message,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :upfront_fee,
  :currency_code,
  :total_instance_count,
  :available_instance_count,
  :in_use_instance_count,
  :total_ultra_server_count,
  :target_resources,
  :reserved_capacity_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#duration_hoursInteger

The number of whole hours in the total duration for this training plan.

Returns:

  • (Integer)


54309
54310
54311
54312
54313
54314
54315
54316
54317
54318
54319
54320
54321
54322
54323
54324
54325
54326
54327
54328
# File 'lib/aws-sdk-sagemaker/types.rb', line 54309

class TrainingPlanSummary < Struct.new(
  :training_plan_arn,
  :training_plan_name,
  :status,
  :status_message,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :upfront_fee,
  :currency_code,
  :total_instance_count,
  :available_instance_count,
  :in_use_instance_count,
  :total_ultra_server_count,
  :target_resources,
  :reserved_capacity_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#duration_minutesInteger

The additional minutes beyond whole hours in the total duration for this training plan.

Returns:

  • (Integer)


54309
54310
54311
54312
54313
54314
54315
54316
54317
54318
54319
54320
54321
54322
54323
54324
54325
54326
54327
54328
# File 'lib/aws-sdk-sagemaker/types.rb', line 54309

class TrainingPlanSummary < Struct.new(
  :training_plan_arn,
  :training_plan_name,
  :status,
  :status_message,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :upfront_fee,
  :currency_code,
  :total_instance_count,
  :available_instance_count,
  :in_use_instance_count,
  :total_ultra_server_count,
  :target_resources,
  :reserved_capacity_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

The end time of the training plan.

Returns:

  • (Time)


54309
54310
54311
54312
54313
54314
54315
54316
54317
54318
54319
54320
54321
54322
54323
54324
54325
54326
54327
54328
# File 'lib/aws-sdk-sagemaker/types.rb', line 54309

class TrainingPlanSummary < Struct.new(
  :training_plan_arn,
  :training_plan_name,
  :status,
  :status_message,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :upfront_fee,
  :currency_code,
  :total_instance_count,
  :available_instance_count,
  :in_use_instance_count,
  :total_ultra_server_count,
  :target_resources,
  :reserved_capacity_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#in_use_instance_countInteger

The number of instances currently in use from this training plan.

Returns:

  • (Integer)


54309
54310
54311
54312
54313
54314
54315
54316
54317
54318
54319
54320
54321
54322
54323
54324
54325
54326
54327
54328
# File 'lib/aws-sdk-sagemaker/types.rb', line 54309

class TrainingPlanSummary < Struct.new(
  :training_plan_arn,
  :training_plan_name,
  :status,
  :status_message,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :upfront_fee,
  :currency_code,
  :total_instance_count,
  :available_instance_count,
  :in_use_instance_count,
  :total_ultra_server_count,
  :target_resources,
  :reserved_capacity_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#reserved_capacity_summariesArray<Types::ReservedCapacitySummary>

A list of reserved capacities associated with this training plan, including details such as instance types, counts, and availability zones.

Returns:



54309
54310
54311
54312
54313
54314
54315
54316
54317
54318
54319
54320
54321
54322
54323
54324
54325
54326
54327
54328
# File 'lib/aws-sdk-sagemaker/types.rb', line 54309

class TrainingPlanSummary < Struct.new(
  :training_plan_arn,
  :training_plan_name,
  :status,
  :status_message,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :upfront_fee,
  :currency_code,
  :total_instance_count,
  :available_instance_count,
  :in_use_instance_count,
  :total_ultra_server_count,
  :target_resources,
  :reserved_capacity_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The start time of the training plan.

Returns:

  • (Time)


54309
54310
54311
54312
54313
54314
54315
54316
54317
54318
54319
54320
54321
54322
54323
54324
54325
54326
54327
54328
# File 'lib/aws-sdk-sagemaker/types.rb', line 54309

class TrainingPlanSummary < Struct.new(
  :training_plan_arn,
  :training_plan_name,
  :status,
  :status_message,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :upfront_fee,
  :currency_code,
  :total_instance_count,
  :available_instance_count,
  :in_use_instance_count,
  :total_ultra_server_count,
  :target_resources,
  :reserved_capacity_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the training plan (e.g., Pending, Active, Expired). To see the complete list of status values available for a training plan, refer to the Status attribute within the TrainingPlanSummary object.

Returns:

  • (String)


54309
54310
54311
54312
54313
54314
54315
54316
54317
54318
54319
54320
54321
54322
54323
54324
54325
54326
54327
54328
# File 'lib/aws-sdk-sagemaker/types.rb', line 54309

class TrainingPlanSummary < Struct.new(
  :training_plan_arn,
  :training_plan_name,
  :status,
  :status_message,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :upfront_fee,
  :currency_code,
  :total_instance_count,
  :available_instance_count,
  :in_use_instance_count,
  :total_ultra_server_count,
  :target_resources,
  :reserved_capacity_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#status_messageString

A message providing additional information about the current status of the training plan.

Returns:

  • (String)


54309
54310
54311
54312
54313
54314
54315
54316
54317
54318
54319
54320
54321
54322
54323
54324
54325
54326
54327
54328
# File 'lib/aws-sdk-sagemaker/types.rb', line 54309

class TrainingPlanSummary < Struct.new(
  :training_plan_arn,
  :training_plan_name,
  :status,
  :status_message,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :upfront_fee,
  :currency_code,
  :total_instance_count,
  :available_instance_count,
  :in_use_instance_count,
  :total_ultra_server_count,
  :target_resources,
  :reserved_capacity_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#target_resourcesArray<String>

The target resources (e.g., training jobs, HyperPod clusters, Endpoints, Studio apps) that can use this training plan.

Training plans are specific to their target resource.

  • A training plan designed for SageMaker training jobs can only be used to schedule and run training jobs.

  • A training plan for HyperPod clusters can be used exclusively to provide compute resources to a cluster's instance group.

  • A training plan for SageMaker endpoints can be used exclusively to provide compute resources to SageMaker endpoints for model deployment.

  • A training plan for Studio apps can be used to launch JupyterLab and Code Editor apps on reserved training plan capacity.

Returns:

  • (Array<String>)


54309
54310
54311
54312
54313
54314
54315
54316
54317
54318
54319
54320
54321
54322
54323
54324
54325
54326
54327
54328
# File 'lib/aws-sdk-sagemaker/types.rb', line 54309

class TrainingPlanSummary < Struct.new(
  :training_plan_arn,
  :training_plan_name,
  :status,
  :status_message,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :upfront_fee,
  :currency_code,
  :total_instance_count,
  :available_instance_count,
  :in_use_instance_count,
  :total_ultra_server_count,
  :target_resources,
  :reserved_capacity_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#total_instance_countInteger

The total number of instances reserved in this training plan.

Returns:

  • (Integer)


54309
54310
54311
54312
54313
54314
54315
54316
54317
54318
54319
54320
54321
54322
54323
54324
54325
54326
54327
54328
# File 'lib/aws-sdk-sagemaker/types.rb', line 54309

class TrainingPlanSummary < Struct.new(
  :training_plan_arn,
  :training_plan_name,
  :status,
  :status_message,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :upfront_fee,
  :currency_code,
  :total_instance_count,
  :available_instance_count,
  :in_use_instance_count,
  :total_ultra_server_count,
  :target_resources,
  :reserved_capacity_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#total_ultra_server_countInteger

The total number of UltraServers allocated to this training plan.

Returns:

  • (Integer)


54309
54310
54311
54312
54313
54314
54315
54316
54317
54318
54319
54320
54321
54322
54323
54324
54325
54326
54327
54328
# File 'lib/aws-sdk-sagemaker/types.rb', line 54309

class TrainingPlanSummary < Struct.new(
  :training_plan_arn,
  :training_plan_name,
  :status,
  :status_message,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :upfront_fee,
  :currency_code,
  :total_instance_count,
  :available_instance_count,
  :in_use_instance_count,
  :total_ultra_server_count,
  :target_resources,
  :reserved_capacity_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#training_plan_arnString

The Amazon Resource Name (ARN); of the training plan.

Returns:

  • (String)


54309
54310
54311
54312
54313
54314
54315
54316
54317
54318
54319
54320
54321
54322
54323
54324
54325
54326
54327
54328
# File 'lib/aws-sdk-sagemaker/types.rb', line 54309

class TrainingPlanSummary < Struct.new(
  :training_plan_arn,
  :training_plan_name,
  :status,
  :status_message,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :upfront_fee,
  :currency_code,
  :total_instance_count,
  :available_instance_count,
  :in_use_instance_count,
  :total_ultra_server_count,
  :target_resources,
  :reserved_capacity_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#training_plan_nameString

The name of the training plan.

Returns:

  • (String)


54309
54310
54311
54312
54313
54314
54315
54316
54317
54318
54319
54320
54321
54322
54323
54324
54325
54326
54327
54328
# File 'lib/aws-sdk-sagemaker/types.rb', line 54309

class TrainingPlanSummary < Struct.new(
  :training_plan_arn,
  :training_plan_name,
  :status,
  :status_message,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :upfront_fee,
  :currency_code,
  :total_instance_count,
  :available_instance_count,
  :in_use_instance_count,
  :total_ultra_server_count,
  :target_resources,
  :reserved_capacity_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#upfront_feeString

The upfront fee for the training plan.

Returns:

  • (String)


54309
54310
54311
54312
54313
54314
54315
54316
54317
54318
54319
54320
54321
54322
54323
54324
54325
54326
54327
54328
# File 'lib/aws-sdk-sagemaker/types.rb', line 54309

class TrainingPlanSummary < Struct.new(
  :training_plan_arn,
  :training_plan_name,
  :status,
  :status_message,
  :duration_hours,
  :duration_minutes,
  :start_time,
  :end_time,
  :upfront_fee,
  :currency_code,
  :total_instance_count,
  :available_instance_count,
  :in_use_instance_count,
  :total_ultra_server_count,
  :target_resources,
  :reserved_capacity_summaries)
  SENSITIVE = []
  include Aws::Structure
end