Class: Aws::SageMaker::Types::TrainingPlanSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::TrainingPlanSummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Details of the training plan.
For more information about how to reserve GPU capacity for your SageMaker HyperPod clusters using Amazon SageMaker Training Plan, see ‘ CreateTrainingPlan `.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#available_instance_count ⇒ Integer
The number of instances currently available for use in this training plan.
-
#currency_code ⇒ String
The currency code for the upfront fee (e.g., USD).
-
#duration_hours ⇒ Integer
The number of whole hours in the total duration for this training plan.
-
#duration_minutes ⇒ Integer
The additional minutes beyond whole hours in the total duration for this training plan.
-
#end_time ⇒ Time
The end time of the training plan.
-
#in_use_instance_count ⇒ Integer
The number of instances currently in use from this training plan.
-
#reserved_capacity_summaries ⇒ Array<Types::ReservedCapacitySummary>
A list of reserved capacities associated with this training plan, including details such as instance types, counts, and availability zones.
-
#start_time ⇒ Time
The start time of the training plan.
-
#status ⇒ String
The current status of the training plan (e.g., Pending, Active, Expired).
-
#status_message ⇒ String
A message providing additional information about the current status of the training plan.
-
#target_resources ⇒ Array<String>
The target resources (e.g., training jobs, HyperPod clusters, Endpoints, Studio apps) that can use this training plan.
-
#total_instance_count ⇒ Integer
The total number of instances reserved in this training plan.
-
#total_ultra_server_count ⇒ Integer
The total number of UltraServers allocated to this training plan.
-
#training_plan_arn ⇒ String
The Amazon Resource Name (ARN); of the training plan.
-
#training_plan_name ⇒ String
The name of the training plan.
-
#upfront_fee ⇒ String
The upfront fee for the training plan.
Instance Attribute Details
#available_instance_count ⇒ Integer
The number of instances currently available for use in this training plan.
53784 53785 53786 53787 53788 53789 53790 53791 53792 53793 53794 53795 53796 53797 53798 53799 53800 53801 53802 53803 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53784 class TrainingPlanSummary < Struct.new( :training_plan_arn, :training_plan_name, :status, :status_message, :duration_hours, :duration_minutes, :start_time, :end_time, :upfront_fee, :currency_code, :total_instance_count, :available_instance_count, :in_use_instance_count, :total_ultra_server_count, :target_resources, :reserved_capacity_summaries) SENSITIVE = [] include Aws::Structure end |
#currency_code ⇒ String
The currency code for the upfront fee (e.g., USD).
53784 53785 53786 53787 53788 53789 53790 53791 53792 53793 53794 53795 53796 53797 53798 53799 53800 53801 53802 53803 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53784 class TrainingPlanSummary < Struct.new( :training_plan_arn, :training_plan_name, :status, :status_message, :duration_hours, :duration_minutes, :start_time, :end_time, :upfront_fee, :currency_code, :total_instance_count, :available_instance_count, :in_use_instance_count, :total_ultra_server_count, :target_resources, :reserved_capacity_summaries) SENSITIVE = [] include Aws::Structure end |
#duration_hours ⇒ Integer
The number of whole hours in the total duration for this training plan.
53784 53785 53786 53787 53788 53789 53790 53791 53792 53793 53794 53795 53796 53797 53798 53799 53800 53801 53802 53803 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53784 class TrainingPlanSummary < Struct.new( :training_plan_arn, :training_plan_name, :status, :status_message, :duration_hours, :duration_minutes, :start_time, :end_time, :upfront_fee, :currency_code, :total_instance_count, :available_instance_count, :in_use_instance_count, :total_ultra_server_count, :target_resources, :reserved_capacity_summaries) SENSITIVE = [] include Aws::Structure end |
#duration_minutes ⇒ Integer
The additional minutes beyond whole hours in the total duration for this training plan.
53784 53785 53786 53787 53788 53789 53790 53791 53792 53793 53794 53795 53796 53797 53798 53799 53800 53801 53802 53803 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53784 class TrainingPlanSummary < Struct.new( :training_plan_arn, :training_plan_name, :status, :status_message, :duration_hours, :duration_minutes, :start_time, :end_time, :upfront_fee, :currency_code, :total_instance_count, :available_instance_count, :in_use_instance_count, :total_ultra_server_count, :target_resources, :reserved_capacity_summaries) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
The end time of the training plan.
53784 53785 53786 53787 53788 53789 53790 53791 53792 53793 53794 53795 53796 53797 53798 53799 53800 53801 53802 53803 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53784 class TrainingPlanSummary < Struct.new( :training_plan_arn, :training_plan_name, :status, :status_message, :duration_hours, :duration_minutes, :start_time, :end_time, :upfront_fee, :currency_code, :total_instance_count, :available_instance_count, :in_use_instance_count, :total_ultra_server_count, :target_resources, :reserved_capacity_summaries) SENSITIVE = [] include Aws::Structure end |
#in_use_instance_count ⇒ Integer
The number of instances currently in use from this training plan.
53784 53785 53786 53787 53788 53789 53790 53791 53792 53793 53794 53795 53796 53797 53798 53799 53800 53801 53802 53803 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53784 class TrainingPlanSummary < Struct.new( :training_plan_arn, :training_plan_name, :status, :status_message, :duration_hours, :duration_minutes, :start_time, :end_time, :upfront_fee, :currency_code, :total_instance_count, :available_instance_count, :in_use_instance_count, :total_ultra_server_count, :target_resources, :reserved_capacity_summaries) SENSITIVE = [] include Aws::Structure end |
#reserved_capacity_summaries ⇒ Array<Types::ReservedCapacitySummary>
A list of reserved capacities associated with this training plan, including details such as instance types, counts, and availability zones.
53784 53785 53786 53787 53788 53789 53790 53791 53792 53793 53794 53795 53796 53797 53798 53799 53800 53801 53802 53803 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53784 class TrainingPlanSummary < Struct.new( :training_plan_arn, :training_plan_name, :status, :status_message, :duration_hours, :duration_minutes, :start_time, :end_time, :upfront_fee, :currency_code, :total_instance_count, :available_instance_count, :in_use_instance_count, :total_ultra_server_count, :target_resources, :reserved_capacity_summaries) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The start time of the training plan.
53784 53785 53786 53787 53788 53789 53790 53791 53792 53793 53794 53795 53796 53797 53798 53799 53800 53801 53802 53803 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53784 class TrainingPlanSummary < Struct.new( :training_plan_arn, :training_plan_name, :status, :status_message, :duration_hours, :duration_minutes, :start_time, :end_time, :upfront_fee, :currency_code, :total_instance_count, :available_instance_count, :in_use_instance_count, :total_ultra_server_count, :target_resources, :reserved_capacity_summaries) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the training plan (e.g., Pending, Active, Expired). To see the complete list of status values available for a training plan, refer to the ‘Status` attribute within the ` TrainingPlanSummary ` object.
53784 53785 53786 53787 53788 53789 53790 53791 53792 53793 53794 53795 53796 53797 53798 53799 53800 53801 53802 53803 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53784 class TrainingPlanSummary < Struct.new( :training_plan_arn, :training_plan_name, :status, :status_message, :duration_hours, :duration_minutes, :start_time, :end_time, :upfront_fee, :currency_code, :total_instance_count, :available_instance_count, :in_use_instance_count, :total_ultra_server_count, :target_resources, :reserved_capacity_summaries) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
A message providing additional information about the current status of the training plan.
53784 53785 53786 53787 53788 53789 53790 53791 53792 53793 53794 53795 53796 53797 53798 53799 53800 53801 53802 53803 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53784 class TrainingPlanSummary < Struct.new( :training_plan_arn, :training_plan_name, :status, :status_message, :duration_hours, :duration_minutes, :start_time, :end_time, :upfront_fee, :currency_code, :total_instance_count, :available_instance_count, :in_use_instance_count, :total_ultra_server_count, :target_resources, :reserved_capacity_summaries) SENSITIVE = [] include Aws::Structure end |
#target_resources ⇒ Array<String>
The target resources (e.g., training jobs, HyperPod clusters, Endpoints, Studio apps) that can use this training plan.
Training plans are specific to their target resource.
-
A training plan designed for SageMaker training jobs can only be used to schedule and run training jobs.
-
A training plan for HyperPod clusters can be used exclusively to provide compute resources to a cluster’s instance group.
-
A training plan for SageMaker endpoints can be used exclusively to provide compute resources to SageMaker endpoints for model deployment.
-
A training plan for Studio apps can be used to launch JupyterLab and Code Editor apps on reserved training plan capacity.
53784 53785 53786 53787 53788 53789 53790 53791 53792 53793 53794 53795 53796 53797 53798 53799 53800 53801 53802 53803 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53784 class TrainingPlanSummary < Struct.new( :training_plan_arn, :training_plan_name, :status, :status_message, :duration_hours, :duration_minutes, :start_time, :end_time, :upfront_fee, :currency_code, :total_instance_count, :available_instance_count, :in_use_instance_count, :total_ultra_server_count, :target_resources, :reserved_capacity_summaries) SENSITIVE = [] include Aws::Structure end |
#total_instance_count ⇒ Integer
The total number of instances reserved in this training plan.
53784 53785 53786 53787 53788 53789 53790 53791 53792 53793 53794 53795 53796 53797 53798 53799 53800 53801 53802 53803 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53784 class TrainingPlanSummary < Struct.new( :training_plan_arn, :training_plan_name, :status, :status_message, :duration_hours, :duration_minutes, :start_time, :end_time, :upfront_fee, :currency_code, :total_instance_count, :available_instance_count, :in_use_instance_count, :total_ultra_server_count, :target_resources, :reserved_capacity_summaries) SENSITIVE = [] include Aws::Structure end |
#total_ultra_server_count ⇒ Integer
The total number of UltraServers allocated to this training plan.
53784 53785 53786 53787 53788 53789 53790 53791 53792 53793 53794 53795 53796 53797 53798 53799 53800 53801 53802 53803 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53784 class TrainingPlanSummary < Struct.new( :training_plan_arn, :training_plan_name, :status, :status_message, :duration_hours, :duration_minutes, :start_time, :end_time, :upfront_fee, :currency_code, :total_instance_count, :available_instance_count, :in_use_instance_count, :total_ultra_server_count, :target_resources, :reserved_capacity_summaries) SENSITIVE = [] include Aws::Structure end |
#training_plan_arn ⇒ String
The Amazon Resource Name (ARN); of the training plan.
53784 53785 53786 53787 53788 53789 53790 53791 53792 53793 53794 53795 53796 53797 53798 53799 53800 53801 53802 53803 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53784 class TrainingPlanSummary < Struct.new( :training_plan_arn, :training_plan_name, :status, :status_message, :duration_hours, :duration_minutes, :start_time, :end_time, :upfront_fee, :currency_code, :total_instance_count, :available_instance_count, :in_use_instance_count, :total_ultra_server_count, :target_resources, :reserved_capacity_summaries) SENSITIVE = [] include Aws::Structure end |
#training_plan_name ⇒ String
The name of the training plan.
53784 53785 53786 53787 53788 53789 53790 53791 53792 53793 53794 53795 53796 53797 53798 53799 53800 53801 53802 53803 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53784 class TrainingPlanSummary < Struct.new( :training_plan_arn, :training_plan_name, :status, :status_message, :duration_hours, :duration_minutes, :start_time, :end_time, :upfront_fee, :currency_code, :total_instance_count, :available_instance_count, :in_use_instance_count, :total_ultra_server_count, :target_resources, :reserved_capacity_summaries) SENSITIVE = [] include Aws::Structure end |
#upfront_fee ⇒ String
The upfront fee for the training plan.
53784 53785 53786 53787 53788 53789 53790 53791 53792 53793 53794 53795 53796 53797 53798 53799 53800 53801 53802 53803 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53784 class TrainingPlanSummary < Struct.new( :training_plan_arn, :training_plan_name, :status, :status_message, :duration_hours, :duration_minutes, :start_time, :end_time, :upfront_fee, :currency_code, :total_instance_count, :available_instance_count, :in_use_instance_count, :total_ultra_server_count, :target_resources, :reserved_capacity_summaries) SENSITIVE = [] include Aws::Structure end |