Method: Aws::SageMaker::Types::TransformJob#batch_strategy
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
#batch_strategy ⇒ String
Specifies the number of records to include in a mini-batch for an HTTP inference request. A record is a single unit of input data that inference can be made on. For example, a single line in a CSV file is a record.
51162 51163 51164 51165 51166 51167 51168 51169 51170 51171 51172 51173 51174 51175 51176 51177 51178 51179 51180 51181 51182 51183 51184 51185 51186 51187 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 51162 class TransformJob < Struct.new( :transform_job_name, :transform_job_arn, :transform_job_status, :failure_reason, :model_name, :max_concurrent_transforms, :model_client_config, :max_payload_in_mb, :batch_strategy, :environment, :transform_input, :transform_output, :data_capture_config, :transform_resources, :creation_time, :transform_start_time, :transform_end_time, :labeling_job_arn, :auto_ml_job_arn, :data_processing, :experiment_config, :tags) SENSITIVE = [] include Aws::Structure end |