Class: Aws::SageMaker::Types::TransformJobDefinition
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::TransformJobDefinition
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Defines the input needed to run a transform job using the inference specification specified in the algorithm.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#batch_strategy ⇒ String
A string that determines the number of records included in a single mini-batch.
-
#environment ⇒ Hash<String,String>
The environment variables to set in the Docker container.
-
#max_concurrent_transforms ⇒ Integer
The maximum number of parallel requests that can be sent to each instance in a transform job.
-
#max_payload_in_mb ⇒ Integer
The maximum payload size allowed, in MB.
-
#transform_input ⇒ Types::TransformInput
A description of the input source and the way the transform job consumes it.
-
#transform_output ⇒ Types::TransformOutput
Identifies the Amazon S3 location where you want Amazon SageMaker to save the results from the transform job.
-
#transform_resources ⇒ Types::TransformResources
Identifies the ML compute instances for the transform job.
Instance Attribute Details
#batch_strategy ⇒ String
A string that determines the number of records included in a single mini-batch.
SingleRecord means only one record is used per mini-batch.
MultiRecord means a mini-batch is set to contain as many records
that can fit within the MaxPayloadInMB limit.
55087 55088 55089 55090 55091 55092 55093 55094 55095 55096 55097 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55087 class TransformJobDefinition < Struct.new( :max_concurrent_transforms, :max_payload_in_mb, :batch_strategy, :environment, :transform_input, :transform_output, :transform_resources) SENSITIVE = [] include Aws::Structure end |
#environment ⇒ Hash<String,String>
The environment variables to set in the Docker container. We support up to 16 key and values entries in the map.
55087 55088 55089 55090 55091 55092 55093 55094 55095 55096 55097 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55087 class TransformJobDefinition < Struct.new( :max_concurrent_transforms, :max_payload_in_mb, :batch_strategy, :environment, :transform_input, :transform_output, :transform_resources) SENSITIVE = [] include Aws::Structure end |
#max_concurrent_transforms ⇒ Integer
The maximum number of parallel requests that can be sent to each instance in a transform job. The default value is 1.
55087 55088 55089 55090 55091 55092 55093 55094 55095 55096 55097 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55087 class TransformJobDefinition < Struct.new( :max_concurrent_transforms, :max_payload_in_mb, :batch_strategy, :environment, :transform_input, :transform_output, :transform_resources) SENSITIVE = [] include Aws::Structure end |
#max_payload_in_mb ⇒ Integer
The maximum payload size allowed, in MB. A payload is the data portion of a record (without metadata).
55087 55088 55089 55090 55091 55092 55093 55094 55095 55096 55097 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55087 class TransformJobDefinition < Struct.new( :max_concurrent_transforms, :max_payload_in_mb, :batch_strategy, :environment, :transform_input, :transform_output, :transform_resources) SENSITIVE = [] include Aws::Structure end |
#transform_input ⇒ Types::TransformInput
A description of the input source and the way the transform job consumes it.
55087 55088 55089 55090 55091 55092 55093 55094 55095 55096 55097 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55087 class TransformJobDefinition < Struct.new( :max_concurrent_transforms, :max_payload_in_mb, :batch_strategy, :environment, :transform_input, :transform_output, :transform_resources) SENSITIVE = [] include Aws::Structure end |
#transform_output ⇒ Types::TransformOutput
Identifies the Amazon S3 location where you want Amazon SageMaker to save the results from the transform job.
55087 55088 55089 55090 55091 55092 55093 55094 55095 55096 55097 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55087 class TransformJobDefinition < Struct.new( :max_concurrent_transforms, :max_payload_in_mb, :batch_strategy, :environment, :transform_input, :transform_output, :transform_resources) SENSITIVE = [] include Aws::Structure end |
#transform_resources ⇒ Types::TransformResources
Identifies the ML compute instances for the transform job.
55087 55088 55089 55090 55091 55092 55093 55094 55095 55096 55097 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55087 class TransformJobDefinition < Struct.new( :max_concurrent_transforms, :max_payload_in_mb, :batch_strategy, :environment, :transform_input, :transform_output, :transform_resources) SENSITIVE = [] include Aws::Structure end |