Class: Aws::SageMaker::Types::TransformJobSummary

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Provides a summary of a transform job. Multiple TransformJobSummary objects are returned as a list after in response to a ListTransformJobs call.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timeTime

A timestamp that shows when the transform Job was created.

Returns:

  • (Time)


55155
55156
55157
55158
55159
55160
55161
55162
55163
55164
55165
# File 'lib/aws-sdk-sagemaker/types.rb', line 55155

class TransformJobSummary < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :creation_time,
  :transform_end_time,
  :last_modified_time,
  :transform_job_status,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

If the transform job failed, the reason it failed.

Returns:

  • (String)


55155
55156
55157
55158
55159
55160
55161
55162
55163
55164
55165
# File 'lib/aws-sdk-sagemaker/types.rb', line 55155

class TransformJobSummary < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :creation_time,
  :transform_end_time,
  :last_modified_time,
  :transform_job_status,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

Indicates when the transform job was last modified.

Returns:

  • (Time)


55155
55156
55157
55158
55159
55160
55161
55162
55163
55164
55165
# File 'lib/aws-sdk-sagemaker/types.rb', line 55155

class TransformJobSummary < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :creation_time,
  :transform_end_time,
  :last_modified_time,
  :transform_job_status,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#transform_end_timeTime

Indicates when the transform job ends on compute instances. For successful jobs and stopped jobs, this is the exact time recorded after the results are uploaded. For failed jobs, this is when Amazon SageMaker detected that the job failed.

Returns:

  • (Time)


55155
55156
55157
55158
55159
55160
55161
55162
55163
55164
55165
# File 'lib/aws-sdk-sagemaker/types.rb', line 55155

class TransformJobSummary < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :creation_time,
  :transform_end_time,
  :last_modified_time,
  :transform_job_status,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#transform_job_arnString

The Amazon Resource Name (ARN) of the transform job.

Returns:

  • (String)


55155
55156
55157
55158
55159
55160
55161
55162
55163
55164
55165
# File 'lib/aws-sdk-sagemaker/types.rb', line 55155

class TransformJobSummary < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :creation_time,
  :transform_end_time,
  :last_modified_time,
  :transform_job_status,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#transform_job_nameString

The name of the transform job.

Returns:

  • (String)


55155
55156
55157
55158
55159
55160
55161
55162
55163
55164
55165
# File 'lib/aws-sdk-sagemaker/types.rb', line 55155

class TransformJobSummary < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :creation_time,
  :transform_end_time,
  :last_modified_time,
  :transform_job_status,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#transform_job_statusString

The status of the transform job.

Returns:

  • (String)


55155
55156
55157
55158
55159
55160
55161
55162
55163
55164
55165
# File 'lib/aws-sdk-sagemaker/types.rb', line 55155

class TransformJobSummary < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :creation_time,
  :transform_end_time,
  :last_modified_time,
  :transform_job_status,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end