Class: Aws::SageMaker::Types::TransformJobSummary

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Provides a summary of a transform job. Multiple ‘TransformJobSummary` objects are returned as a list after in response to a

ListTransformJobs][1

call.

[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListTransformJobs.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timeTime

A timestamp that shows when the transform Job was created.

Returns:

  • (Time)


53819
53820
53821
53822
53823
53824
53825
53826
53827
53828
53829
# File 'lib/aws-sdk-sagemaker/types.rb', line 53819

class TransformJobSummary < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :creation_time,
  :transform_end_time,
  :last_modified_time,
  :transform_job_status,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

If the transform job failed, the reason it failed.

Returns:

  • (String)


53819
53820
53821
53822
53823
53824
53825
53826
53827
53828
53829
# File 'lib/aws-sdk-sagemaker/types.rb', line 53819

class TransformJobSummary < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :creation_time,
  :transform_end_time,
  :last_modified_time,
  :transform_job_status,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

Indicates when the transform job was last modified.

Returns:

  • (Time)


53819
53820
53821
53822
53823
53824
53825
53826
53827
53828
53829
# File 'lib/aws-sdk-sagemaker/types.rb', line 53819

class TransformJobSummary < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :creation_time,
  :transform_end_time,
  :last_modified_time,
  :transform_job_status,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#transform_end_timeTime

Indicates when the transform job ends on compute instances. For successful jobs and stopped jobs, this is the exact time recorded after the results are uploaded. For failed jobs, this is when Amazon SageMaker detected that the job failed.

Returns:

  • (Time)


53819
53820
53821
53822
53823
53824
53825
53826
53827
53828
53829
# File 'lib/aws-sdk-sagemaker/types.rb', line 53819

class TransformJobSummary < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :creation_time,
  :transform_end_time,
  :last_modified_time,
  :transform_job_status,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#transform_job_arnString

The Amazon Resource Name (ARN) of the transform job.

Returns:

  • (String)


53819
53820
53821
53822
53823
53824
53825
53826
53827
53828
53829
# File 'lib/aws-sdk-sagemaker/types.rb', line 53819

class TransformJobSummary < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :creation_time,
  :transform_end_time,
  :last_modified_time,
  :transform_job_status,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#transform_job_nameString

The name of the transform job.

Returns:

  • (String)


53819
53820
53821
53822
53823
53824
53825
53826
53827
53828
53829
# File 'lib/aws-sdk-sagemaker/types.rb', line 53819

class TransformJobSummary < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :creation_time,
  :transform_end_time,
  :last_modified_time,
  :transform_job_status,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#transform_job_statusString

The status of the transform job.

Returns:

  • (String)


53819
53820
53821
53822
53823
53824
53825
53826
53827
53828
53829
# File 'lib/aws-sdk-sagemaker/types.rb', line 53819

class TransformJobSummary < Struct.new(
  :transform_job_name,
  :transform_job_arn,
  :creation_time,
  :transform_end_time,
  :last_modified_time,
  :transform_job_status,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end