Class: Aws::SageMaker::Types::TransformJobSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::TransformJobSummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Provides a summary of a transform job. Multiple ‘TransformJobSummary` objects are returned as a list after in response to a
- ListTransformJobs][1
-
call.
[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListTransformJobs.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Time
A timestamp that shows when the transform Job was created.
-
#failure_reason ⇒ String
If the transform job failed, the reason it failed.
-
#last_modified_time ⇒ Time
Indicates when the transform job was last modified.
-
#transform_end_time ⇒ Time
Indicates when the transform job ends on compute instances.
-
#transform_job_arn ⇒ String
The Amazon Resource Name (ARN) of the transform job.
-
#transform_job_name ⇒ String
The name of the transform job.
-
#transform_job_status ⇒ String
The status of the transform job.
Instance Attribute Details
#creation_time ⇒ Time
A timestamp that shows when the transform Job was created.
53714 53715 53716 53717 53718 53719 53720 53721 53722 53723 53724 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53714 class TransformJobSummary < Struct.new( :transform_job_name, :transform_job_arn, :creation_time, :transform_end_time, :last_modified_time, :transform_job_status, :failure_reason) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
If the transform job failed, the reason it failed.
53714 53715 53716 53717 53718 53719 53720 53721 53722 53723 53724 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53714 class TransformJobSummary < Struct.new( :transform_job_name, :transform_job_arn, :creation_time, :transform_end_time, :last_modified_time, :transform_job_status, :failure_reason) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
Indicates when the transform job was last modified.
53714 53715 53716 53717 53718 53719 53720 53721 53722 53723 53724 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53714 class TransformJobSummary < Struct.new( :transform_job_name, :transform_job_arn, :creation_time, :transform_end_time, :last_modified_time, :transform_job_status, :failure_reason) SENSITIVE = [] include Aws::Structure end |
#transform_end_time ⇒ Time
Indicates when the transform job ends on compute instances. For successful jobs and stopped jobs, this is the exact time recorded after the results are uploaded. For failed jobs, this is when Amazon SageMaker detected that the job failed.
53714 53715 53716 53717 53718 53719 53720 53721 53722 53723 53724 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53714 class TransformJobSummary < Struct.new( :transform_job_name, :transform_job_arn, :creation_time, :transform_end_time, :last_modified_time, :transform_job_status, :failure_reason) SENSITIVE = [] include Aws::Structure end |
#transform_job_arn ⇒ String
The Amazon Resource Name (ARN) of the transform job.
53714 53715 53716 53717 53718 53719 53720 53721 53722 53723 53724 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53714 class TransformJobSummary < Struct.new( :transform_job_name, :transform_job_arn, :creation_time, :transform_end_time, :last_modified_time, :transform_job_status, :failure_reason) SENSITIVE = [] include Aws::Structure end |
#transform_job_name ⇒ String
The name of the transform job.
53714 53715 53716 53717 53718 53719 53720 53721 53722 53723 53724 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53714 class TransformJobSummary < Struct.new( :transform_job_name, :transform_job_arn, :creation_time, :transform_end_time, :last_modified_time, :transform_job_status, :failure_reason) SENSITIVE = [] include Aws::Structure end |
#transform_job_status ⇒ String
The status of the transform job.
53714 53715 53716 53717 53718 53719 53720 53721 53722 53723 53724 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53714 class TransformJobSummary < Struct.new( :transform_job_name, :transform_job_arn, :creation_time, :transform_end_time, :last_modified_time, :transform_job_status, :failure_reason) SENSITIVE = [] include Aws::Structure end |