Class: Aws::SageMaker::Types::Trial
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::Trial
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The properties of a trial as returned by the Search API.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_by ⇒ Types::UserContext
Who created the trial.
-
#creation_time ⇒ Time
When the trial was created.
-
#display_name ⇒ String
The name of the trial as displayed.
-
#experiment_name ⇒ String
The name of the experiment the trial is part of.
-
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
-
#last_modified_time ⇒ Time
Who last modified the trial.
-
#metadata_properties ⇒ Types::MetadataProperties
Metadata properties of the tracking entity, trial, or trial component.
-
#source ⇒ Types::TrialSource
The source of the trial.
-
#tags ⇒ Array<Types::Tag>
The list of tags that are associated with the trial.
-
#trial_arn ⇒ String
The Amazon Resource Name (ARN) of the trial.
-
#trial_component_summaries ⇒ Array<Types::TrialComponentSimpleSummary>
A list of the components associated with the trial.
-
#trial_name ⇒ String
The name of the trial.
Instance Attribute Details
#created_by ⇒ Types::UserContext
Who created the trial.
55300 55301 55302 55303 55304 55305 55306 55307 55308 55309 55310 55311 55312 55313 55314 55315 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55300 class Trial < Struct.new( :trial_name, :trial_arn, :display_name, :experiment_name, :source, :creation_time, :created_by, :last_modified_time, :last_modified_by, :metadata_properties, :tags, :trial_component_summaries) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
When the trial was created.
55300 55301 55302 55303 55304 55305 55306 55307 55308 55309 55310 55311 55312 55313 55314 55315 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55300 class Trial < Struct.new( :trial_name, :trial_arn, :display_name, :experiment_name, :source, :creation_time, :created_by, :last_modified_time, :last_modified_by, :metadata_properties, :tags, :trial_component_summaries) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The name of the trial as displayed. If DisplayName isn't
specified, TrialName is displayed.
55300 55301 55302 55303 55304 55305 55306 55307 55308 55309 55310 55311 55312 55313 55314 55315 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55300 class Trial < Struct.new( :trial_name, :trial_arn, :display_name, :experiment_name, :source, :creation_time, :created_by, :last_modified_time, :last_modified_by, :metadata_properties, :tags, :trial_component_summaries) SENSITIVE = [] include Aws::Structure end |
#experiment_name ⇒ String
The name of the experiment the trial is part of.
55300 55301 55302 55303 55304 55305 55306 55307 55308 55309 55310 55311 55312 55313 55314 55315 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55300 class Trial < Struct.new( :trial_name, :trial_arn, :display_name, :experiment_name, :source, :creation_time, :created_by, :last_modified_time, :last_modified_by, :metadata_properties, :tags, :trial_component_summaries) SENSITIVE = [] include Aws::Structure end |
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
55300 55301 55302 55303 55304 55305 55306 55307 55308 55309 55310 55311 55312 55313 55314 55315 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55300 class Trial < Struct.new( :trial_name, :trial_arn, :display_name, :experiment_name, :source, :creation_time, :created_by, :last_modified_time, :last_modified_by, :metadata_properties, :tags, :trial_component_summaries) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
Who last modified the trial.
55300 55301 55302 55303 55304 55305 55306 55307 55308 55309 55310 55311 55312 55313 55314 55315 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55300 class Trial < Struct.new( :trial_name, :trial_arn, :display_name, :experiment_name, :source, :creation_time, :created_by, :last_modified_time, :last_modified_by, :metadata_properties, :tags, :trial_component_summaries) SENSITIVE = [] include Aws::Structure end |
#metadata_properties ⇒ Types::MetadataProperties
Metadata properties of the tracking entity, trial, or trial component.
55300 55301 55302 55303 55304 55305 55306 55307 55308 55309 55310 55311 55312 55313 55314 55315 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55300 class Trial < Struct.new( :trial_name, :trial_arn, :display_name, :experiment_name, :source, :creation_time, :created_by, :last_modified_time, :last_modified_by, :metadata_properties, :tags, :trial_component_summaries) SENSITIVE = [] include Aws::Structure end |
#source ⇒ Types::TrialSource
The source of the trial.
55300 55301 55302 55303 55304 55305 55306 55307 55308 55309 55310 55311 55312 55313 55314 55315 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55300 class Trial < Struct.new( :trial_name, :trial_arn, :display_name, :experiment_name, :source, :creation_time, :created_by, :last_modified_time, :last_modified_by, :metadata_properties, :tags, :trial_component_summaries) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The list of tags that are associated with the trial. You can use Search API to search on the tags.
55300 55301 55302 55303 55304 55305 55306 55307 55308 55309 55310 55311 55312 55313 55314 55315 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55300 class Trial < Struct.new( :trial_name, :trial_arn, :display_name, :experiment_name, :source, :creation_time, :created_by, :last_modified_time, :last_modified_by, :metadata_properties, :tags, :trial_component_summaries) SENSITIVE = [] include Aws::Structure end |
#trial_arn ⇒ String
The Amazon Resource Name (ARN) of the trial.
55300 55301 55302 55303 55304 55305 55306 55307 55308 55309 55310 55311 55312 55313 55314 55315 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55300 class Trial < Struct.new( :trial_name, :trial_arn, :display_name, :experiment_name, :source, :creation_time, :created_by, :last_modified_time, :last_modified_by, :metadata_properties, :tags, :trial_component_summaries) SENSITIVE = [] include Aws::Structure end |
#trial_component_summaries ⇒ Array<Types::TrialComponentSimpleSummary>
A list of the components associated with the trial. For each component, a summary of the component's properties is included.
55300 55301 55302 55303 55304 55305 55306 55307 55308 55309 55310 55311 55312 55313 55314 55315 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55300 class Trial < Struct.new( :trial_name, :trial_arn, :display_name, :experiment_name, :source, :creation_time, :created_by, :last_modified_time, :last_modified_by, :metadata_properties, :tags, :trial_component_summaries) SENSITIVE = [] include Aws::Structure end |
#trial_name ⇒ String
The name of the trial.
55300 55301 55302 55303 55304 55305 55306 55307 55308 55309 55310 55311 55312 55313 55314 55315 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55300 class Trial < Struct.new( :trial_name, :trial_arn, :display_name, :experiment_name, :source, :creation_time, :created_by, :last_modified_time, :last_modified_by, :metadata_properties, :tags, :trial_component_summaries) SENSITIVE = [] include Aws::Structure end |