Class: Aws::SageMaker::Types::TrialComponent

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The properties of a trial component as returned by the [Search] API.

[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_Search.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_byTypes::UserContext

Who created the trial component.

Returns:



54125
54126
54127
54128
54129
54130
54131
54132
54133
54134
54135
54136
54137
54138
54139
54140
54141
54142
54143
54144
54145
54146
54147
54148
54149
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125

class TrialComponent < Struct.new(
  :trial_component_name,
  :display_name,
  :trial_component_arn,
  :source,
  :status,
  :start_time,
  :end_time,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :parameters,
  :input_artifacts,
  :output_artifacts,
  :metrics,
  :metadata_properties,
  :source_detail,
  :lineage_group_arn,
  :tags,
  :parents,
  :run_name)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

When the component was created.

Returns:

  • (Time)


54125
54126
54127
54128
54129
54130
54131
54132
54133
54134
54135
54136
54137
54138
54139
54140
54141
54142
54143
54144
54145
54146
54147
54148
54149
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125

class TrialComponent < Struct.new(
  :trial_component_name,
  :display_name,
  :trial_component_arn,
  :source,
  :status,
  :start_time,
  :end_time,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :parameters,
  :input_artifacts,
  :output_artifacts,
  :metrics,
  :metadata_properties,
  :source_detail,
  :lineage_group_arn,
  :tags,
  :parents,
  :run_name)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

The name of the component as displayed. If ‘DisplayName` isn’t specified, ‘TrialComponentName` is displayed.

Returns:

  • (String)


54125
54126
54127
54128
54129
54130
54131
54132
54133
54134
54135
54136
54137
54138
54139
54140
54141
54142
54143
54144
54145
54146
54147
54148
54149
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125

class TrialComponent < Struct.new(
  :trial_component_name,
  :display_name,
  :trial_component_arn,
  :source,
  :status,
  :start_time,
  :end_time,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :parameters,
  :input_artifacts,
  :output_artifacts,
  :metrics,
  :metadata_properties,
  :source_detail,
  :lineage_group_arn,
  :tags,
  :parents,
  :run_name)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

When the component ended.

Returns:

  • (Time)


54125
54126
54127
54128
54129
54130
54131
54132
54133
54134
54135
54136
54137
54138
54139
54140
54141
54142
54143
54144
54145
54146
54147
54148
54149
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125

class TrialComponent < Struct.new(
  :trial_component_name,
  :display_name,
  :trial_component_arn,
  :source,
  :status,
  :start_time,
  :end_time,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :parameters,
  :input_artifacts,
  :output_artifacts,
  :metrics,
  :metadata_properties,
  :source_detail,
  :lineage_group_arn,
  :tags,
  :parents,
  :run_name)
  SENSITIVE = []
  include Aws::Structure
end

#input_artifactsHash<String,Types::TrialComponentArtifact>

The input artifacts of the component.

Returns:



54125
54126
54127
54128
54129
54130
54131
54132
54133
54134
54135
54136
54137
54138
54139
54140
54141
54142
54143
54144
54145
54146
54147
54148
54149
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125

class TrialComponent < Struct.new(
  :trial_component_name,
  :display_name,
  :trial_component_arn,
  :source,
  :status,
  :start_time,
  :end_time,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :parameters,
  :input_artifacts,
  :output_artifacts,
  :metrics,
  :metadata_properties,
  :source_detail,
  :lineage_group_arn,
  :tags,
  :parents,
  :run_name)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_byTypes::UserContext

Information about the user who created or modified a SageMaker resource.

Returns:



54125
54126
54127
54128
54129
54130
54131
54132
54133
54134
54135
54136
54137
54138
54139
54140
54141
54142
54143
54144
54145
54146
54147
54148
54149
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125

class TrialComponent < Struct.new(
  :trial_component_name,
  :display_name,
  :trial_component_arn,
  :source,
  :status,
  :start_time,
  :end_time,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :parameters,
  :input_artifacts,
  :output_artifacts,
  :metrics,
  :metadata_properties,
  :source_detail,
  :lineage_group_arn,
  :tags,
  :parents,
  :run_name)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

When the component was last modified.

Returns:

  • (Time)


54125
54126
54127
54128
54129
54130
54131
54132
54133
54134
54135
54136
54137
54138
54139
54140
54141
54142
54143
54144
54145
54146
54147
54148
54149
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125

class TrialComponent < Struct.new(
  :trial_component_name,
  :display_name,
  :trial_component_arn,
  :source,
  :status,
  :start_time,
  :end_time,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :parameters,
  :input_artifacts,
  :output_artifacts,
  :metrics,
  :metadata_properties,
  :source_detail,
  :lineage_group_arn,
  :tags,
  :parents,
  :run_name)
  SENSITIVE = []
  include Aws::Structure
end

#lineage_group_arnString

The Amazon Resource Name (ARN) of the lineage group resource.

Returns:

  • (String)


54125
54126
54127
54128
54129
54130
54131
54132
54133
54134
54135
54136
54137
54138
54139
54140
54141
54142
54143
54144
54145
54146
54147
54148
54149
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125

class TrialComponent < Struct.new(
  :trial_component_name,
  :display_name,
  :trial_component_arn,
  :source,
  :status,
  :start_time,
  :end_time,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :parameters,
  :input_artifacts,
  :output_artifacts,
  :metrics,
  :metadata_properties,
  :source_detail,
  :lineage_group_arn,
  :tags,
  :parents,
  :run_name)
  SENSITIVE = []
  include Aws::Structure
end

#metadata_propertiesTypes::MetadataProperties

Metadata properties of the tracking entity, trial, or trial component.



54125
54126
54127
54128
54129
54130
54131
54132
54133
54134
54135
54136
54137
54138
54139
54140
54141
54142
54143
54144
54145
54146
54147
54148
54149
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125

class TrialComponent < Struct.new(
  :trial_component_name,
  :display_name,
  :trial_component_arn,
  :source,
  :status,
  :start_time,
  :end_time,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :parameters,
  :input_artifacts,
  :output_artifacts,
  :metrics,
  :metadata_properties,
  :source_detail,
  :lineage_group_arn,
  :tags,
  :parents,
  :run_name)
  SENSITIVE = []
  include Aws::Structure
end

#metricsArray<Types::TrialComponentMetricSummary>

The metrics for the component.



54125
54126
54127
54128
54129
54130
54131
54132
54133
54134
54135
54136
54137
54138
54139
54140
54141
54142
54143
54144
54145
54146
54147
54148
54149
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125

class TrialComponent < Struct.new(
  :trial_component_name,
  :display_name,
  :trial_component_arn,
  :source,
  :status,
  :start_time,
  :end_time,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :parameters,
  :input_artifacts,
  :output_artifacts,
  :metrics,
  :metadata_properties,
  :source_detail,
  :lineage_group_arn,
  :tags,
  :parents,
  :run_name)
  SENSITIVE = []
  include Aws::Structure
end

#output_artifactsHash<String,Types::TrialComponentArtifact>

The output artifacts of the component.

Returns:



54125
54126
54127
54128
54129
54130
54131
54132
54133
54134
54135
54136
54137
54138
54139
54140
54141
54142
54143
54144
54145
54146
54147
54148
54149
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125

class TrialComponent < Struct.new(
  :trial_component_name,
  :display_name,
  :trial_component_arn,
  :source,
  :status,
  :start_time,
  :end_time,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :parameters,
  :input_artifacts,
  :output_artifacts,
  :metrics,
  :metadata_properties,
  :source_detail,
  :lineage_group_arn,
  :tags,
  :parents,
  :run_name)
  SENSITIVE = []
  include Aws::Structure
end

#parametersHash<String,Types::TrialComponentParameterValue>

The hyperparameters of the component.

Returns:



54125
54126
54127
54128
54129
54130
54131
54132
54133
54134
54135
54136
54137
54138
54139
54140
54141
54142
54143
54144
54145
54146
54147
54148
54149
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125

class TrialComponent < Struct.new(
  :trial_component_name,
  :display_name,
  :trial_component_arn,
  :source,
  :status,
  :start_time,
  :end_time,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :parameters,
  :input_artifacts,
  :output_artifacts,
  :metrics,
  :metadata_properties,
  :source_detail,
  :lineage_group_arn,
  :tags,
  :parents,
  :run_name)
  SENSITIVE = []
  include Aws::Structure
end

#parentsArray<Types::Parent>

An array of the parents of the component. A parent is a trial the component is associated with and the experiment the trial is part of. A component might not have any parents.

Returns:



54125
54126
54127
54128
54129
54130
54131
54132
54133
54134
54135
54136
54137
54138
54139
54140
54141
54142
54143
54144
54145
54146
54147
54148
54149
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125

class TrialComponent < Struct.new(
  :trial_component_name,
  :display_name,
  :trial_component_arn,
  :source,
  :status,
  :start_time,
  :end_time,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :parameters,
  :input_artifacts,
  :output_artifacts,
  :metrics,
  :metadata_properties,
  :source_detail,
  :lineage_group_arn,
  :tags,
  :parents,
  :run_name)
  SENSITIVE = []
  include Aws::Structure
end

#run_nameString

The name of the experiment run.

Returns:

  • (String)


54125
54126
54127
54128
54129
54130
54131
54132
54133
54134
54135
54136
54137
54138
54139
54140
54141
54142
54143
54144
54145
54146
54147
54148
54149
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125

class TrialComponent < Struct.new(
  :trial_component_name,
  :display_name,
  :trial_component_arn,
  :source,
  :status,
  :start_time,
  :end_time,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :parameters,
  :input_artifacts,
  :output_artifacts,
  :metrics,
  :metadata_properties,
  :source_detail,
  :lineage_group_arn,
  :tags,
  :parents,
  :run_name)
  SENSITIVE = []
  include Aws::Structure
end

#sourceTypes::TrialComponentSource

The Amazon Resource Name (ARN) and job type of the source of the component.



54125
54126
54127
54128
54129
54130
54131
54132
54133
54134
54135
54136
54137
54138
54139
54140
54141
54142
54143
54144
54145
54146
54147
54148
54149
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125

class TrialComponent < Struct.new(
  :trial_component_name,
  :display_name,
  :trial_component_arn,
  :source,
  :status,
  :start_time,
  :end_time,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :parameters,
  :input_artifacts,
  :output_artifacts,
  :metrics,
  :metadata_properties,
  :source_detail,
  :lineage_group_arn,
  :tags,
  :parents,
  :run_name)
  SENSITIVE = []
  include Aws::Structure
end

#source_detailTypes::TrialComponentSourceDetail

Details of the source of the component.



54125
54126
54127
54128
54129
54130
54131
54132
54133
54134
54135
54136
54137
54138
54139
54140
54141
54142
54143
54144
54145
54146
54147
54148
54149
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125

class TrialComponent < Struct.new(
  :trial_component_name,
  :display_name,
  :trial_component_arn,
  :source,
  :status,
  :start_time,
  :end_time,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :parameters,
  :input_artifacts,
  :output_artifacts,
  :metrics,
  :metadata_properties,
  :source_detail,
  :lineage_group_arn,
  :tags,
  :parents,
  :run_name)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

When the component started.

Returns:

  • (Time)


54125
54126
54127
54128
54129
54130
54131
54132
54133
54134
54135
54136
54137
54138
54139
54140
54141
54142
54143
54144
54145
54146
54147
54148
54149
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125

class TrialComponent < Struct.new(
  :trial_component_name,
  :display_name,
  :trial_component_arn,
  :source,
  :status,
  :start_time,
  :end_time,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :parameters,
  :input_artifacts,
  :output_artifacts,
  :metrics,
  :metadata_properties,
  :source_detail,
  :lineage_group_arn,
  :tags,
  :parents,
  :run_name)
  SENSITIVE = []
  include Aws::Structure
end

#statusTypes::TrialComponentStatus

The status of the trial component.



54125
54126
54127
54128
54129
54130
54131
54132
54133
54134
54135
54136
54137
54138
54139
54140
54141
54142
54143
54144
54145
54146
54147
54148
54149
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125

class TrialComponent < Struct.new(
  :trial_component_name,
  :display_name,
  :trial_component_arn,
  :source,
  :status,
  :start_time,
  :end_time,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :parameters,
  :input_artifacts,
  :output_artifacts,
  :metrics,
  :metadata_properties,
  :source_detail,
  :lineage_group_arn,
  :tags,
  :parents,
  :run_name)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The list of tags that are associated with the component. You can use

Search][1

API to search on the tags.

[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_Search.html

Returns:



54125
54126
54127
54128
54129
54130
54131
54132
54133
54134
54135
54136
54137
54138
54139
54140
54141
54142
54143
54144
54145
54146
54147
54148
54149
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125

class TrialComponent < Struct.new(
  :trial_component_name,
  :display_name,
  :trial_component_arn,
  :source,
  :status,
  :start_time,
  :end_time,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :parameters,
  :input_artifacts,
  :output_artifacts,
  :metrics,
  :metadata_properties,
  :source_detail,
  :lineage_group_arn,
  :tags,
  :parents,
  :run_name)
  SENSITIVE = []
  include Aws::Structure
end

#trial_component_arnString

The Amazon Resource Name (ARN) of the trial component.

Returns:

  • (String)


54125
54126
54127
54128
54129
54130
54131
54132
54133
54134
54135
54136
54137
54138
54139
54140
54141
54142
54143
54144
54145
54146
54147
54148
54149
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125

class TrialComponent < Struct.new(
  :trial_component_name,
  :display_name,
  :trial_component_arn,
  :source,
  :status,
  :start_time,
  :end_time,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :parameters,
  :input_artifacts,
  :output_artifacts,
  :metrics,
  :metadata_properties,
  :source_detail,
  :lineage_group_arn,
  :tags,
  :parents,
  :run_name)
  SENSITIVE = []
  include Aws::Structure
end

#trial_component_nameString

The name of the trial component.

Returns:

  • (String)


54125
54126
54127
54128
54129
54130
54131
54132
54133
54134
54135
54136
54137
54138
54139
54140
54141
54142
54143
54144
54145
54146
54147
54148
54149
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125

class TrialComponent < Struct.new(
  :trial_component_name,
  :display_name,
  :trial_component_arn,
  :source,
  :status,
  :start_time,
  :end_time,
  :creation_time,
  :created_by,
  :last_modified_time,
  :last_modified_by,
  :parameters,
  :input_artifacts,
  :output_artifacts,
  :metrics,
  :metadata_properties,
  :source_detail,
  :lineage_group_arn,
  :tags,
  :parents,
  :run_name)
  SENSITIVE = []
  include Aws::Structure
end