Class: Aws::SageMaker::Types::TrialComponent
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::TrialComponent
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The properties of a trial component as returned by the [Search] API.
[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_Search.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_by ⇒ Types::UserContext
Who created the trial component.
-
#creation_time ⇒ Time
When the component was created.
-
#display_name ⇒ String
The name of the component as displayed.
-
#end_time ⇒ Time
When the component ended.
-
#input_artifacts ⇒ Hash<String,Types::TrialComponentArtifact>
The input artifacts of the component.
-
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
-
#last_modified_time ⇒ Time
When the component was last modified.
-
#lineage_group_arn ⇒ String
The Amazon Resource Name (ARN) of the lineage group resource.
-
#metadata_properties ⇒ Types::MetadataProperties
Metadata properties of the tracking entity, trial, or trial component.
-
#metrics ⇒ Array<Types::TrialComponentMetricSummary>
The metrics for the component.
-
#output_artifacts ⇒ Hash<String,Types::TrialComponentArtifact>
The output artifacts of the component.
-
#parameters ⇒ Hash<String,Types::TrialComponentParameterValue>
The hyperparameters of the component.
-
#parents ⇒ Array<Types::Parent>
An array of the parents of the component.
-
#run_name ⇒ String
The name of the experiment run.
-
#source ⇒ Types::TrialComponentSource
The Amazon Resource Name (ARN) and job type of the source of the component.
-
#source_detail ⇒ Types::TrialComponentSourceDetail
Details of the source of the component.
-
#start_time ⇒ Time
When the component started.
-
#status ⇒ Types::TrialComponentStatus
The status of the trial component.
-
#tags ⇒ Array<Types::Tag>
The list of tags that are associated with the component.
-
#trial_component_arn ⇒ String
The Amazon Resource Name (ARN) of the trial component.
-
#trial_component_name ⇒ String
The name of the trial component.
Instance Attribute Details
#created_by ⇒ Types::UserContext
Who created the trial component.
54125 54126 54127 54128 54129 54130 54131 54132 54133 54134 54135 54136 54137 54138 54139 54140 54141 54142 54143 54144 54145 54146 54147 54148 54149 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125 class TrialComponent < Struct.new( :trial_component_name, :display_name, :trial_component_arn, :source, :status, :start_time, :end_time, :creation_time, :created_by, :last_modified_time, :last_modified_by, :parameters, :input_artifacts, :output_artifacts, :metrics, :metadata_properties, :source_detail, :lineage_group_arn, :tags, :parents, :run_name) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
When the component was created.
54125 54126 54127 54128 54129 54130 54131 54132 54133 54134 54135 54136 54137 54138 54139 54140 54141 54142 54143 54144 54145 54146 54147 54148 54149 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125 class TrialComponent < Struct.new( :trial_component_name, :display_name, :trial_component_arn, :source, :status, :start_time, :end_time, :creation_time, :created_by, :last_modified_time, :last_modified_by, :parameters, :input_artifacts, :output_artifacts, :metrics, :metadata_properties, :source_detail, :lineage_group_arn, :tags, :parents, :run_name) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The name of the component as displayed. If ‘DisplayName` isn’t specified, ‘TrialComponentName` is displayed.
54125 54126 54127 54128 54129 54130 54131 54132 54133 54134 54135 54136 54137 54138 54139 54140 54141 54142 54143 54144 54145 54146 54147 54148 54149 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125 class TrialComponent < Struct.new( :trial_component_name, :display_name, :trial_component_arn, :source, :status, :start_time, :end_time, :creation_time, :created_by, :last_modified_time, :last_modified_by, :parameters, :input_artifacts, :output_artifacts, :metrics, :metadata_properties, :source_detail, :lineage_group_arn, :tags, :parents, :run_name) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
When the component ended.
54125 54126 54127 54128 54129 54130 54131 54132 54133 54134 54135 54136 54137 54138 54139 54140 54141 54142 54143 54144 54145 54146 54147 54148 54149 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125 class TrialComponent < Struct.new( :trial_component_name, :display_name, :trial_component_arn, :source, :status, :start_time, :end_time, :creation_time, :created_by, :last_modified_time, :last_modified_by, :parameters, :input_artifacts, :output_artifacts, :metrics, :metadata_properties, :source_detail, :lineage_group_arn, :tags, :parents, :run_name) SENSITIVE = [] include Aws::Structure end |
#input_artifacts ⇒ Hash<String,Types::TrialComponentArtifact>
The input artifacts of the component.
54125 54126 54127 54128 54129 54130 54131 54132 54133 54134 54135 54136 54137 54138 54139 54140 54141 54142 54143 54144 54145 54146 54147 54148 54149 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125 class TrialComponent < Struct.new( :trial_component_name, :display_name, :trial_component_arn, :source, :status, :start_time, :end_time, :creation_time, :created_by, :last_modified_time, :last_modified_by, :parameters, :input_artifacts, :output_artifacts, :metrics, :metadata_properties, :source_detail, :lineage_group_arn, :tags, :parents, :run_name) SENSITIVE = [] include Aws::Structure end |
#last_modified_by ⇒ Types::UserContext
Information about the user who created or modified a SageMaker resource.
54125 54126 54127 54128 54129 54130 54131 54132 54133 54134 54135 54136 54137 54138 54139 54140 54141 54142 54143 54144 54145 54146 54147 54148 54149 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125 class TrialComponent < Struct.new( :trial_component_name, :display_name, :trial_component_arn, :source, :status, :start_time, :end_time, :creation_time, :created_by, :last_modified_time, :last_modified_by, :parameters, :input_artifacts, :output_artifacts, :metrics, :metadata_properties, :source_detail, :lineage_group_arn, :tags, :parents, :run_name) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
When the component was last modified.
54125 54126 54127 54128 54129 54130 54131 54132 54133 54134 54135 54136 54137 54138 54139 54140 54141 54142 54143 54144 54145 54146 54147 54148 54149 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125 class TrialComponent < Struct.new( :trial_component_name, :display_name, :trial_component_arn, :source, :status, :start_time, :end_time, :creation_time, :created_by, :last_modified_time, :last_modified_by, :parameters, :input_artifacts, :output_artifacts, :metrics, :metadata_properties, :source_detail, :lineage_group_arn, :tags, :parents, :run_name) SENSITIVE = [] include Aws::Structure end |
#lineage_group_arn ⇒ String
The Amazon Resource Name (ARN) of the lineage group resource.
54125 54126 54127 54128 54129 54130 54131 54132 54133 54134 54135 54136 54137 54138 54139 54140 54141 54142 54143 54144 54145 54146 54147 54148 54149 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125 class TrialComponent < Struct.new( :trial_component_name, :display_name, :trial_component_arn, :source, :status, :start_time, :end_time, :creation_time, :created_by, :last_modified_time, :last_modified_by, :parameters, :input_artifacts, :output_artifacts, :metrics, :metadata_properties, :source_detail, :lineage_group_arn, :tags, :parents, :run_name) SENSITIVE = [] include Aws::Structure end |
#metadata_properties ⇒ Types::MetadataProperties
Metadata properties of the tracking entity, trial, or trial component.
54125 54126 54127 54128 54129 54130 54131 54132 54133 54134 54135 54136 54137 54138 54139 54140 54141 54142 54143 54144 54145 54146 54147 54148 54149 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125 class TrialComponent < Struct.new( :trial_component_name, :display_name, :trial_component_arn, :source, :status, :start_time, :end_time, :creation_time, :created_by, :last_modified_time, :last_modified_by, :parameters, :input_artifacts, :output_artifacts, :metrics, :metadata_properties, :source_detail, :lineage_group_arn, :tags, :parents, :run_name) SENSITIVE = [] include Aws::Structure end |
#metrics ⇒ Array<Types::TrialComponentMetricSummary>
The metrics for the component.
54125 54126 54127 54128 54129 54130 54131 54132 54133 54134 54135 54136 54137 54138 54139 54140 54141 54142 54143 54144 54145 54146 54147 54148 54149 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125 class TrialComponent < Struct.new( :trial_component_name, :display_name, :trial_component_arn, :source, :status, :start_time, :end_time, :creation_time, :created_by, :last_modified_time, :last_modified_by, :parameters, :input_artifacts, :output_artifacts, :metrics, :metadata_properties, :source_detail, :lineage_group_arn, :tags, :parents, :run_name) SENSITIVE = [] include Aws::Structure end |
#output_artifacts ⇒ Hash<String,Types::TrialComponentArtifact>
The output artifacts of the component.
54125 54126 54127 54128 54129 54130 54131 54132 54133 54134 54135 54136 54137 54138 54139 54140 54141 54142 54143 54144 54145 54146 54147 54148 54149 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125 class TrialComponent < Struct.new( :trial_component_name, :display_name, :trial_component_arn, :source, :status, :start_time, :end_time, :creation_time, :created_by, :last_modified_time, :last_modified_by, :parameters, :input_artifacts, :output_artifacts, :metrics, :metadata_properties, :source_detail, :lineage_group_arn, :tags, :parents, :run_name) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Hash<String,Types::TrialComponentParameterValue>
The hyperparameters of the component.
54125 54126 54127 54128 54129 54130 54131 54132 54133 54134 54135 54136 54137 54138 54139 54140 54141 54142 54143 54144 54145 54146 54147 54148 54149 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125 class TrialComponent < Struct.new( :trial_component_name, :display_name, :trial_component_arn, :source, :status, :start_time, :end_time, :creation_time, :created_by, :last_modified_time, :last_modified_by, :parameters, :input_artifacts, :output_artifacts, :metrics, :metadata_properties, :source_detail, :lineage_group_arn, :tags, :parents, :run_name) SENSITIVE = [] include Aws::Structure end |
#parents ⇒ Array<Types::Parent>
An array of the parents of the component. A parent is a trial the component is associated with and the experiment the trial is part of. A component might not have any parents.
54125 54126 54127 54128 54129 54130 54131 54132 54133 54134 54135 54136 54137 54138 54139 54140 54141 54142 54143 54144 54145 54146 54147 54148 54149 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125 class TrialComponent < Struct.new( :trial_component_name, :display_name, :trial_component_arn, :source, :status, :start_time, :end_time, :creation_time, :created_by, :last_modified_time, :last_modified_by, :parameters, :input_artifacts, :output_artifacts, :metrics, :metadata_properties, :source_detail, :lineage_group_arn, :tags, :parents, :run_name) SENSITIVE = [] include Aws::Structure end |
#run_name ⇒ String
The name of the experiment run.
54125 54126 54127 54128 54129 54130 54131 54132 54133 54134 54135 54136 54137 54138 54139 54140 54141 54142 54143 54144 54145 54146 54147 54148 54149 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125 class TrialComponent < Struct.new( :trial_component_name, :display_name, :trial_component_arn, :source, :status, :start_time, :end_time, :creation_time, :created_by, :last_modified_time, :last_modified_by, :parameters, :input_artifacts, :output_artifacts, :metrics, :metadata_properties, :source_detail, :lineage_group_arn, :tags, :parents, :run_name) SENSITIVE = [] include Aws::Structure end |
#source ⇒ Types::TrialComponentSource
The Amazon Resource Name (ARN) and job type of the source of the component.
54125 54126 54127 54128 54129 54130 54131 54132 54133 54134 54135 54136 54137 54138 54139 54140 54141 54142 54143 54144 54145 54146 54147 54148 54149 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125 class TrialComponent < Struct.new( :trial_component_name, :display_name, :trial_component_arn, :source, :status, :start_time, :end_time, :creation_time, :created_by, :last_modified_time, :last_modified_by, :parameters, :input_artifacts, :output_artifacts, :metrics, :metadata_properties, :source_detail, :lineage_group_arn, :tags, :parents, :run_name) SENSITIVE = [] include Aws::Structure end |
#source_detail ⇒ Types::TrialComponentSourceDetail
Details of the source of the component.
54125 54126 54127 54128 54129 54130 54131 54132 54133 54134 54135 54136 54137 54138 54139 54140 54141 54142 54143 54144 54145 54146 54147 54148 54149 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125 class TrialComponent < Struct.new( :trial_component_name, :display_name, :trial_component_arn, :source, :status, :start_time, :end_time, :creation_time, :created_by, :last_modified_time, :last_modified_by, :parameters, :input_artifacts, :output_artifacts, :metrics, :metadata_properties, :source_detail, :lineage_group_arn, :tags, :parents, :run_name) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
When the component started.
54125 54126 54127 54128 54129 54130 54131 54132 54133 54134 54135 54136 54137 54138 54139 54140 54141 54142 54143 54144 54145 54146 54147 54148 54149 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125 class TrialComponent < Struct.new( :trial_component_name, :display_name, :trial_component_arn, :source, :status, :start_time, :end_time, :creation_time, :created_by, :last_modified_time, :last_modified_by, :parameters, :input_artifacts, :output_artifacts, :metrics, :metadata_properties, :source_detail, :lineage_group_arn, :tags, :parents, :run_name) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::TrialComponentStatus
The status of the trial component.
54125 54126 54127 54128 54129 54130 54131 54132 54133 54134 54135 54136 54137 54138 54139 54140 54141 54142 54143 54144 54145 54146 54147 54148 54149 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125 class TrialComponent < Struct.new( :trial_component_name, :display_name, :trial_component_arn, :source, :status, :start_time, :end_time, :creation_time, :created_by, :last_modified_time, :last_modified_by, :parameters, :input_artifacts, :output_artifacts, :metrics, :metadata_properties, :source_detail, :lineage_group_arn, :tags, :parents, :run_name) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The list of tags that are associated with the component. You can use
- Search][1
-
API to search on the tags.
[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_Search.html
54125 54126 54127 54128 54129 54130 54131 54132 54133 54134 54135 54136 54137 54138 54139 54140 54141 54142 54143 54144 54145 54146 54147 54148 54149 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125 class TrialComponent < Struct.new( :trial_component_name, :display_name, :trial_component_arn, :source, :status, :start_time, :end_time, :creation_time, :created_by, :last_modified_time, :last_modified_by, :parameters, :input_artifacts, :output_artifacts, :metrics, :metadata_properties, :source_detail, :lineage_group_arn, :tags, :parents, :run_name) SENSITIVE = [] include Aws::Structure end |
#trial_component_arn ⇒ String
The Amazon Resource Name (ARN) of the trial component.
54125 54126 54127 54128 54129 54130 54131 54132 54133 54134 54135 54136 54137 54138 54139 54140 54141 54142 54143 54144 54145 54146 54147 54148 54149 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125 class TrialComponent < Struct.new( :trial_component_name, :display_name, :trial_component_arn, :source, :status, :start_time, :end_time, :creation_time, :created_by, :last_modified_time, :last_modified_by, :parameters, :input_artifacts, :output_artifacts, :metrics, :metadata_properties, :source_detail, :lineage_group_arn, :tags, :parents, :run_name) SENSITIVE = [] include Aws::Structure end |
#trial_component_name ⇒ String
The name of the trial component.
54125 54126 54127 54128 54129 54130 54131 54132 54133 54134 54135 54136 54137 54138 54139 54140 54141 54142 54143 54144 54145 54146 54147 54148 54149 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 54125 class TrialComponent < Struct.new( :trial_component_name, :display_name, :trial_component_arn, :source, :status, :start_time, :end_time, :creation_time, :created_by, :last_modified_time, :last_modified_by, :parameters, :input_artifacts, :output_artifacts, :metrics, :metadata_properties, :source_detail, :lineage_group_arn, :tags, :parents, :run_name) SENSITIVE = [] include Aws::Structure end |