Class: Aws::SageMaker::Types::TuningJobCompletionCriteria

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

The job completion criteria.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#best_objective_not_improvingTypes::BestObjectiveNotImproving

A flag to stop your hyperparameter tuning job if model performance fails to improve as evaluated against an objective function.



55888
55889
55890
55891
55892
55893
55894
# File 'lib/aws-sdk-sagemaker/types.rb', line 55888

class TuningJobCompletionCriteria < Struct.new(
  :target_objective_metric_value,
  :best_objective_not_improving,
  :convergence_detected)
  SENSITIVE = []
  include Aws::Structure
end

#convergence_detectedTypes::ConvergenceDetected

A flag to top your hyperparameter tuning job if automatic model tuning (AMT) has detected that your model has converged as evaluated against your objective function.



55888
55889
55890
55891
55892
55893
55894
# File 'lib/aws-sdk-sagemaker/types.rb', line 55888

class TuningJobCompletionCriteria < Struct.new(
  :target_objective_metric_value,
  :best_objective_not_improving,
  :convergence_detected)
  SENSITIVE = []
  include Aws::Structure
end

#target_objective_metric_valueFloat

The value of the objective metric.

Returns:

  • (Float)


55888
55889
55890
55891
55892
55893
55894
# File 'lib/aws-sdk-sagemaker/types.rb', line 55888

class TuningJobCompletionCriteria < Struct.new(
  :target_objective_metric_value,
  :best_objective_not_improving,
  :convergence_detected)
  SENSITIVE = []
  include Aws::Structure
end