Class: Aws::SageMaker::Types::TuningJobCompletionCriteria
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::TuningJobCompletionCriteria
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
The job completion criteria.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#best_objective_not_improving ⇒ Types::BestObjectiveNotImproving
A flag to stop your hyperparameter tuning job if model performance fails to improve as evaluated against an objective function.
-
#convergence_detected ⇒ Types::ConvergenceDetected
A flag to top your hyperparameter tuning job if automatic model tuning (AMT) has detected that your model has converged as evaluated against your objective function.
-
#target_objective_metric_value ⇒ Float
The value of the objective metric.
Instance Attribute Details
#best_objective_not_improving ⇒ Types::BestObjectiveNotImproving
A flag to stop your hyperparameter tuning job if model performance fails to improve as evaluated against an objective function.
55199 55200 55201 55202 55203 55204 55205 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55199 class TuningJobCompletionCriteria < Struct.new( :target_objective_metric_value, :best_objective_not_improving, :convergence_detected) SENSITIVE = [] include Aws::Structure end |
#convergence_detected ⇒ Types::ConvergenceDetected
A flag to top your hyperparameter tuning job if automatic model tuning (AMT) has detected that your model has converged as evaluated against your objective function.
55199 55200 55201 55202 55203 55204 55205 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55199 class TuningJobCompletionCriteria < Struct.new( :target_objective_metric_value, :best_objective_not_improving, :convergence_detected) SENSITIVE = [] include Aws::Structure end |
#target_objective_metric_value ⇒ Float
The value of the objective metric.
55199 55200 55201 55202 55203 55204 55205 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55199 class TuningJobCompletionCriteria < Struct.new( :target_objective_metric_value, :best_objective_not_improving, :convergence_detected) SENSITIVE = [] include Aws::Structure end |