Class: Aws::SageMaker::Types::UpdateClusterRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_scalingTypes::ClusterAutoScalingConfig

Updates the autoscaling configuration for the cluster. Use to enable or disable automatic node scaling.



55157
55158
55159
55160
55161
55162
55163
55164
55165
55166
55167
55168
55169
55170
# File 'lib/aws-sdk-sagemaker/types.rb', line 55157

class UpdateClusterRequest < Struct.new(
  :cluster_name,
  :instance_groups,
  :restricted_instance_groups,
  :tiered_storage_config,
  :node_recovery,
  :instance_groups_to_delete,
  :node_provisioning_mode,
  :cluster_role,
  :auto_scaling,
  :orchestrator)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_nameString

Specify the name of the SageMaker HyperPod cluster you want to update.

Returns:

  • (String)


55157
55158
55159
55160
55161
55162
55163
55164
55165
55166
55167
55168
55169
55170
# File 'lib/aws-sdk-sagemaker/types.rb', line 55157

class UpdateClusterRequest < Struct.new(
  :cluster_name,
  :instance_groups,
  :restricted_instance_groups,
  :tiered_storage_config,
  :node_recovery,
  :instance_groups_to_delete,
  :node_provisioning_mode,
  :cluster_role,
  :auto_scaling,
  :orchestrator)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_roleString

The Amazon Resource Name (ARN) of the IAM role that HyperPod assumes for cluster autoscaling operations. Cannot be updated while autoscaling is enabled.

Returns:

  • (String)


55157
55158
55159
55160
55161
55162
55163
55164
55165
55166
55167
55168
55169
55170
# File 'lib/aws-sdk-sagemaker/types.rb', line 55157

class UpdateClusterRequest < Struct.new(
  :cluster_name,
  :instance_groups,
  :restricted_instance_groups,
  :tiered_storage_config,
  :node_recovery,
  :instance_groups_to_delete,
  :node_provisioning_mode,
  :cluster_role,
  :auto_scaling,
  :orchestrator)
  SENSITIVE = []
  include Aws::Structure
end

#instance_groupsArray<Types::ClusterInstanceGroupSpecification>

Specify the instance groups to update.



55157
55158
55159
55160
55161
55162
55163
55164
55165
55166
55167
55168
55169
55170
# File 'lib/aws-sdk-sagemaker/types.rb', line 55157

class UpdateClusterRequest < Struct.new(
  :cluster_name,
  :instance_groups,
  :restricted_instance_groups,
  :tiered_storage_config,
  :node_recovery,
  :instance_groups_to_delete,
  :node_provisioning_mode,
  :cluster_role,
  :auto_scaling,
  :orchestrator)
  SENSITIVE = []
  include Aws::Structure
end

#instance_groups_to_deleteArray<String>

Specify the names of the instance groups to delete. Use a single ‘,` as the separator between multiple names.

Returns:

  • (Array<String>)


55157
55158
55159
55160
55161
55162
55163
55164
55165
55166
55167
55168
55169
55170
# File 'lib/aws-sdk-sagemaker/types.rb', line 55157

class UpdateClusterRequest < Struct.new(
  :cluster_name,
  :instance_groups,
  :restricted_instance_groups,
  :tiered_storage_config,
  :node_recovery,
  :instance_groups_to_delete,
  :node_provisioning_mode,
  :cluster_role,
  :auto_scaling,
  :orchestrator)
  SENSITIVE = []
  include Aws::Structure
end

#node_provisioning_modeString

Determines how instance provisioning is handled during cluster operations. In ‘Continuous` mode, the cluster provisions available instances incrementally and retries until the target count is reached. The cluster becomes operational once cluster-level resources are ready. Use `CurrentCount` and `TargetCount` in `DescribeCluster` to track provisioning progress.

Returns:

  • (String)


55157
55158
55159
55160
55161
55162
55163
55164
55165
55166
55167
55168
55169
55170
# File 'lib/aws-sdk-sagemaker/types.rb', line 55157

class UpdateClusterRequest < Struct.new(
  :cluster_name,
  :instance_groups,
  :restricted_instance_groups,
  :tiered_storage_config,
  :node_recovery,
  :instance_groups_to_delete,
  :node_provisioning_mode,
  :cluster_role,
  :auto_scaling,
  :orchestrator)
  SENSITIVE = []
  include Aws::Structure
end

#node_recoveryString

The node recovery mode to be applied to the SageMaker HyperPod cluster.

Returns:

  • (String)


55157
55158
55159
55160
55161
55162
55163
55164
55165
55166
55167
55168
55169
55170
# File 'lib/aws-sdk-sagemaker/types.rb', line 55157

class UpdateClusterRequest < Struct.new(
  :cluster_name,
  :instance_groups,
  :restricted_instance_groups,
  :tiered_storage_config,
  :node_recovery,
  :instance_groups_to_delete,
  :node_provisioning_mode,
  :cluster_role,
  :auto_scaling,
  :orchestrator)
  SENSITIVE = []
  include Aws::Structure
end

#orchestratorTypes::ClusterOrchestrator

The type of orchestrator used for the SageMaker HyperPod cluster.



55157
55158
55159
55160
55161
55162
55163
55164
55165
55166
55167
55168
55169
55170
# File 'lib/aws-sdk-sagemaker/types.rb', line 55157

class UpdateClusterRequest < Struct.new(
  :cluster_name,
  :instance_groups,
  :restricted_instance_groups,
  :tiered_storage_config,
  :node_recovery,
  :instance_groups_to_delete,
  :node_provisioning_mode,
  :cluster_role,
  :auto_scaling,
  :orchestrator)
  SENSITIVE = []
  include Aws::Structure
end

#restricted_instance_groupsArray<Types::ClusterRestrictedInstanceGroupSpecification>

The specialized instance groups for training models like Amazon Nova to be created in the SageMaker HyperPod cluster.



55157
55158
55159
55160
55161
55162
55163
55164
55165
55166
55167
55168
55169
55170
# File 'lib/aws-sdk-sagemaker/types.rb', line 55157

class UpdateClusterRequest < Struct.new(
  :cluster_name,
  :instance_groups,
  :restricted_instance_groups,
  :tiered_storage_config,
  :node_recovery,
  :instance_groups_to_delete,
  :node_provisioning_mode,
  :cluster_role,
  :auto_scaling,
  :orchestrator)
  SENSITIVE = []
  include Aws::Structure
end

#tiered_storage_configTypes::ClusterTieredStorageConfig

Updates the configuration for managed tier checkpointing on the HyperPod cluster. For example, you can enable or disable the feature and modify the percentage of cluster memory allocated for checkpoint storage.



55157
55158
55159
55160
55161
55162
55163
55164
55165
55166
55167
55168
55169
55170
# File 'lib/aws-sdk-sagemaker/types.rb', line 55157

class UpdateClusterRequest < Struct.new(
  :cluster_name,
  :instance_groups,
  :restricted_instance_groups,
  :tiered_storage_config,
  :node_recovery,
  :instance_groups_to_delete,
  :node_provisioning_mode,
  :cluster_role,
  :auto_scaling,
  :orchestrator)
  SENSITIVE = []
  include Aws::Structure
end