Class: Aws::SageMaker::Types::UpdateClusterRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::UpdateClusterRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_scaling ⇒ Types::ClusterAutoScalingConfig
Updates the autoscaling configuration for the cluster.
-
#cluster_name ⇒ String
Specify the name of the SageMaker HyperPod cluster you want to update.
-
#cluster_role ⇒ String
The Amazon Resource Name (ARN) of the IAM role that HyperPod assumes for cluster autoscaling operations.
-
#instance_groups ⇒ Array<Types::ClusterInstanceGroupSpecification>
Specify the instance groups to update.
-
#instance_groups_to_delete ⇒ Array<String>
Specify the names of the instance groups to delete.
-
#node_provisioning_mode ⇒ String
Determines how instance provisioning is handled during cluster operations.
-
#node_recovery ⇒ String
The node recovery mode to be applied to the SageMaker HyperPod cluster.
-
#orchestrator ⇒ Types::ClusterOrchestrator
The type of orchestrator used for the SageMaker HyperPod cluster.
-
#restricted_instance_groups ⇒ Array<Types::ClusterRestrictedInstanceGroupSpecification>
The specialized instance groups for training models like Amazon Nova to be created in the SageMaker HyperPod cluster.
-
#tiered_storage_config ⇒ Types::ClusterTieredStorageConfig
Updates the configuration for managed tier checkpointing on the HyperPod cluster.
Instance Attribute Details
#auto_scaling ⇒ Types::ClusterAutoScalingConfig
Updates the autoscaling configuration for the cluster. Use to enable or disable automatic node scaling.
52752 52753 52754 52755 52756 52757 52758 52759 52760 52761 52762 52763 52764 52765 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 52752 class UpdateClusterRequest < Struct.new( :cluster_name, :instance_groups, :restricted_instance_groups, :tiered_storage_config, :node_recovery, :instance_groups_to_delete, :node_provisioning_mode, :cluster_role, :auto_scaling, :orchestrator) SENSITIVE = [] include Aws::Structure end |
#cluster_name ⇒ String
Specify the name of the SageMaker HyperPod cluster you want to update.
52752 52753 52754 52755 52756 52757 52758 52759 52760 52761 52762 52763 52764 52765 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 52752 class UpdateClusterRequest < Struct.new( :cluster_name, :instance_groups, :restricted_instance_groups, :tiered_storage_config, :node_recovery, :instance_groups_to_delete, :node_provisioning_mode, :cluster_role, :auto_scaling, :orchestrator) SENSITIVE = [] include Aws::Structure end |
#cluster_role ⇒ String
The Amazon Resource Name (ARN) of the IAM role that HyperPod assumes for cluster autoscaling operations. Cannot be updated while autoscaling is enabled.
52752 52753 52754 52755 52756 52757 52758 52759 52760 52761 52762 52763 52764 52765 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 52752 class UpdateClusterRequest < Struct.new( :cluster_name, :instance_groups, :restricted_instance_groups, :tiered_storage_config, :node_recovery, :instance_groups_to_delete, :node_provisioning_mode, :cluster_role, :auto_scaling, :orchestrator) SENSITIVE = [] include Aws::Structure end |
#instance_groups ⇒ Array<Types::ClusterInstanceGroupSpecification>
Specify the instance groups to update.
52752 52753 52754 52755 52756 52757 52758 52759 52760 52761 52762 52763 52764 52765 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 52752 class UpdateClusterRequest < Struct.new( :cluster_name, :instance_groups, :restricted_instance_groups, :tiered_storage_config, :node_recovery, :instance_groups_to_delete, :node_provisioning_mode, :cluster_role, :auto_scaling, :orchestrator) SENSITIVE = [] include Aws::Structure end |
#instance_groups_to_delete ⇒ Array<String>
Specify the names of the instance groups to delete. Use a single ‘,` as the separator between multiple names.
52752 52753 52754 52755 52756 52757 52758 52759 52760 52761 52762 52763 52764 52765 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 52752 class UpdateClusterRequest < Struct.new( :cluster_name, :instance_groups, :restricted_instance_groups, :tiered_storage_config, :node_recovery, :instance_groups_to_delete, :node_provisioning_mode, :cluster_role, :auto_scaling, :orchestrator) SENSITIVE = [] include Aws::Structure end |
#node_provisioning_mode ⇒ String
Determines how instance provisioning is handled during cluster operations. In ‘Continuous` mode, the cluster provisions available instances incrementally and retries until the target count is reached. The cluster becomes operational once cluster-level resources are ready. Use `CurrentCount` and `TargetCount` in `DescribeCluster` to track provisioning progress.
52752 52753 52754 52755 52756 52757 52758 52759 52760 52761 52762 52763 52764 52765 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 52752 class UpdateClusterRequest < Struct.new( :cluster_name, :instance_groups, :restricted_instance_groups, :tiered_storage_config, :node_recovery, :instance_groups_to_delete, :node_provisioning_mode, :cluster_role, :auto_scaling, :orchestrator) SENSITIVE = [] include Aws::Structure end |
#node_recovery ⇒ String
The node recovery mode to be applied to the SageMaker HyperPod cluster.
52752 52753 52754 52755 52756 52757 52758 52759 52760 52761 52762 52763 52764 52765 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 52752 class UpdateClusterRequest < Struct.new( :cluster_name, :instance_groups, :restricted_instance_groups, :tiered_storage_config, :node_recovery, :instance_groups_to_delete, :node_provisioning_mode, :cluster_role, :auto_scaling, :orchestrator) SENSITIVE = [] include Aws::Structure end |
#orchestrator ⇒ Types::ClusterOrchestrator
The type of orchestrator used for the SageMaker HyperPod cluster.
52752 52753 52754 52755 52756 52757 52758 52759 52760 52761 52762 52763 52764 52765 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 52752 class UpdateClusterRequest < Struct.new( :cluster_name, :instance_groups, :restricted_instance_groups, :tiered_storage_config, :node_recovery, :instance_groups_to_delete, :node_provisioning_mode, :cluster_role, :auto_scaling, :orchestrator) SENSITIVE = [] include Aws::Structure end |
#restricted_instance_groups ⇒ Array<Types::ClusterRestrictedInstanceGroupSpecification>
The specialized instance groups for training models like Amazon Nova to be created in the SageMaker HyperPod cluster.
52752 52753 52754 52755 52756 52757 52758 52759 52760 52761 52762 52763 52764 52765 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 52752 class UpdateClusterRequest < Struct.new( :cluster_name, :instance_groups, :restricted_instance_groups, :tiered_storage_config, :node_recovery, :instance_groups_to_delete, :node_provisioning_mode, :cluster_role, :auto_scaling, :orchestrator) SENSITIVE = [] include Aws::Structure end |
#tiered_storage_config ⇒ Types::ClusterTieredStorageConfig
Updates the configuration for managed tier checkpointing on the HyperPod cluster. For example, you can enable or disable the feature and modify the percentage of cluster memory allocated for checkpoint storage.
52752 52753 52754 52755 52756 52757 52758 52759 52760 52761 52762 52763 52764 52765 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 52752 class UpdateClusterRequest < Struct.new( :cluster_name, :instance_groups, :restricted_instance_groups, :tiered_storage_config, :node_recovery, :instance_groups_to_delete, :node_provisioning_mode, :cluster_role, :auto_scaling, :orchestrator) SENSITIVE = [] include Aws::Structure end |