Class: Aws::SageMaker::Types::UpdateCodeRepositoryInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::UpdateCodeRepositoryInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code_repository_name ⇒ String
The name of the Git repository to update.
-
#git_config ⇒ Types::GitConfigForUpdate
The configuration of the git repository, including the URL and the Amazon Resource Name (ARN) of the Amazon Web Services Secrets Manager secret that contains the credentials used to access the repository.
Instance Attribute Details
#code_repository_name ⇒ String
The name of the Git repository to update.
56622 56623 56624 56625 56626 56627 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 56622 class UpdateCodeRepositoryInput < Struct.new( :code_repository_name, :git_config) SENSITIVE = [] include Aws::Structure end |
#git_config ⇒ Types::GitConfigForUpdate
The configuration of the git repository, including the URL and the
Amazon Resource Name (ARN) of the Amazon Web Services Secrets
Manager secret that contains the credentials used to access the
repository. The secret must have a staging label of AWSCURRENT and
must be in the following format:
{"username": UserName, "password": Password}
56622 56623 56624 56625 56626 56627 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 56622 class UpdateCodeRepositoryInput < Struct.new( :code_repository_name, :git_config) SENSITIVE = [] include Aws::Structure end |