Class: Aws::SageMaker::Types::UpdateCodeRepositoryInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#code_repository_nameString

The name of the Git repository to update.

Returns:

  • (String)


53540
53541
53542
53543
53544
53545
# File 'lib/aws-sdk-sagemaker/types.rb', line 53540

class UpdateCodeRepositoryInput < Struct.new(
  :code_repository_name,
  :git_config)
  SENSITIVE = []
  include Aws::Structure
end

#git_configTypes::GitConfigForUpdate

The configuration of the git repository, including the URL and the Amazon Resource Name (ARN) of the Amazon Web Services Secrets Manager secret that contains the credentials used to access the repository. The secret must have a staging label of ‘AWSCURRENT` and must be in the following format:

‘UserName, “password”: Password`



53540
53541
53542
53543
53544
53545
# File 'lib/aws-sdk-sagemaker/types.rb', line 53540

class UpdateCodeRepositoryInput < Struct.new(
  :code_repository_name,
  :git_config)
  SENSITIVE = []
  include Aws::Structure
end