Class: Aws::SageMaker::Types::UpdateDomainRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#app_network_access_typeString

Specifies the VPC used for non-EFS traffic.

  • ‘PublicInternetOnly` - Non-EFS traffic is through a VPC managed by Amazon SageMaker AI, which allows direct internet access.

  • ‘VpcOnly` - All Studio traffic is through the specified VPC and subnets.

This configuration can only be modified if there are no apps in the ‘InService`, `Pending`, or `Deleting` state. The configuration cannot be updated if `DomainSettings.RStudioServerProDomainSettings.DomainExecutionRoleArn` is already set or `DomainSettings.RStudioServerProDomainSettings.DomainExecutionRoleArn` is provided as part of the same request.

Returns:

  • (String)


55681
55682
55683
55684
55685
55686
55687
55688
55689
55690
55691
55692
55693
55694
# File 'lib/aws-sdk-sagemaker/types.rb', line 55681

class UpdateDomainRequest < Struct.new(
  :domain_id,
  :default_user_settings,
  :domain_settings_for_update,
  :app_security_group_management,
  :default_space_settings,
  :subnet_ids,
  :app_network_access_type,
  :tag_propagation,
  :home_efs_file_system_creation,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#app_security_group_managementString

The entity that creates and manages the required security groups for inter-app communication in ‘VPCOnly` mode. Required when `CreateDomain.AppNetworkAccessType` is `VPCOnly` and `DomainSettings.RStudioServerProDomainSettings.DomainExecutionRoleArn` is provided. If setting up the domain for use with RStudio, this value must be set to `Service`.

Returns:

  • (String)


55681
55682
55683
55684
55685
55686
55687
55688
55689
55690
55691
55692
55693
55694
# File 'lib/aws-sdk-sagemaker/types.rb', line 55681

class UpdateDomainRequest < Struct.new(
  :domain_id,
  :default_user_settings,
  :domain_settings_for_update,
  :app_security_group_management,
  :default_space_settings,
  :subnet_ids,
  :app_network_access_type,
  :tag_propagation,
  :home_efs_file_system_creation,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#default_space_settingsTypes::DefaultSpaceSettings

The default settings for shared spaces that users create in the domain.



55681
55682
55683
55684
55685
55686
55687
55688
55689
55690
55691
55692
55693
55694
# File 'lib/aws-sdk-sagemaker/types.rb', line 55681

class UpdateDomainRequest < Struct.new(
  :domain_id,
  :default_user_settings,
  :domain_settings_for_update,
  :app_security_group_management,
  :default_space_settings,
  :subnet_ids,
  :app_network_access_type,
  :tag_propagation,
  :home_efs_file_system_creation,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#default_user_settingsTypes::UserSettings

A collection of settings.

Returns:



55681
55682
55683
55684
55685
55686
55687
55688
55689
55690
55691
55692
55693
55694
# File 'lib/aws-sdk-sagemaker/types.rb', line 55681

class UpdateDomainRequest < Struct.new(
  :domain_id,
  :default_user_settings,
  :domain_settings_for_update,
  :app_security_group_management,
  :default_space_settings,
  :subnet_ids,
  :app_network_access_type,
  :tag_propagation,
  :home_efs_file_system_creation,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#domain_idString

The ID of the domain to be updated.

Returns:

  • (String)


55681
55682
55683
55684
55685
55686
55687
55688
55689
55690
55691
55692
55693
55694
# File 'lib/aws-sdk-sagemaker/types.rb', line 55681

class UpdateDomainRequest < Struct.new(
  :domain_id,
  :default_user_settings,
  :domain_settings_for_update,
  :app_security_group_management,
  :default_space_settings,
  :subnet_ids,
  :app_network_access_type,
  :tag_propagation,
  :home_efs_file_system_creation,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#domain_settings_for_updateTypes::DomainSettingsForUpdate

A collection of ‘DomainSettings` configuration values to update.



55681
55682
55683
55684
55685
55686
55687
55688
55689
55690
55691
55692
55693
55694
# File 'lib/aws-sdk-sagemaker/types.rb', line 55681

class UpdateDomainRequest < Struct.new(
  :domain_id,
  :default_user_settings,
  :domain_settings_for_update,
  :app_security_group_management,
  :default_space_settings,
  :subnet_ids,
  :app_network_access_type,
  :tag_propagation,
  :home_efs_file_system_creation,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#home_efs_file_system_creationString

Indicates whether to create a home EFS file system for the domain. You can change from ‘Disabled` to `Enabled` to provision EFS on demand, but you cannot change from `Enabled` to `Disabled`.

Returns:

  • (String)


55681
55682
55683
55684
55685
55686
55687
55688
55689
55690
55691
55692
55693
55694
# File 'lib/aws-sdk-sagemaker/types.rb', line 55681

class UpdateDomainRequest < Struct.new(
  :domain_id,
  :default_user_settings,
  :domain_settings_for_update,
  :app_security_group_management,
  :default_space_settings,
  :subnet_ids,
  :app_network_access_type,
  :tag_propagation,
  :home_efs_file_system_creation,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idsArray<String>

The VPC subnets that Studio uses for communication.

If removing subnets, ensure there are no apps in the ‘InService`, `Pending`, or `Deleting` state.

Returns:

  • (Array<String>)


55681
55682
55683
55684
55685
55686
55687
55688
55689
55690
55691
55692
55693
55694
# File 'lib/aws-sdk-sagemaker/types.rb', line 55681

class UpdateDomainRequest < Struct.new(
  :domain_id,
  :default_user_settings,
  :domain_settings_for_update,
  :app_security_group_management,
  :default_space_settings,
  :subnet_ids,
  :app_network_access_type,
  :tag_propagation,
  :home_efs_file_system_creation,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#tag_propagationString

Indicates whether custom tag propagation is supported for the domain. Defaults to ‘DISABLED`.

Returns:

  • (String)


55681
55682
55683
55684
55685
55686
55687
55688
55689
55690
55691
55692
55693
55694
# File 'lib/aws-sdk-sagemaker/types.rb', line 55681

class UpdateDomainRequest < Struct.new(
  :domain_id,
  :default_user_settings,
  :domain_settings_for_update,
  :app_security_group_management,
  :default_space_settings,
  :subnet_ids,
  :app_network_access_type,
  :tag_propagation,
  :home_efs_file_system_creation,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The identifier for the VPC used by the domain for network communication. Use this field only when adding VPC configuration to a SageMaker AI domain used in Amazon SageMaker Unified Studio that was created without VPC settings. SageMaker AI doesn’t automatically apply VPC updates to existing applications. Stop and restart your applications to apply the changes.

Returns:

  • (String)


55681
55682
55683
55684
55685
55686
55687
55688
55689
55690
55691
55692
55693
55694
# File 'lib/aws-sdk-sagemaker/types.rb', line 55681

class UpdateDomainRequest < Struct.new(
  :domain_id,
  :default_user_settings,
  :domain_settings_for_update,
  :app_security_group_management,
  :default_space_settings,
  :subnet_ids,
  :app_network_access_type,
  :tag_propagation,
  :home_efs_file_system_creation,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end