Class: Aws::SageMaker::Types::UpdateDomainRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#app_network_access_typeString

Specifies the VPC used for non-EFS traffic.

  • PublicInternetOnly - Non-EFS traffic is through a VPC managed by Amazon SageMaker AI, which allows direct internet access.

  • VpcOnly - All Studio traffic is through the specified VPC and subnets.

This configuration can only be modified if there are no apps in the InService, Pending, or Deleting state. The configuration cannot be updated if DomainSettings.RStudioServerProDomainSettings.DomainExecutionRoleArn is already set or DomainSettings.RStudioServerProDomainSettings.DomainExecutionRoleArn is provided as part of the same request.

Returns:

  • (String)


47554
47555
47556
47557
47558
47559
47560
47561
47562
47563
47564
47565
# File 'lib/aws-sdk-sagemaker/types.rb', line 47554

class UpdateDomainRequest < Struct.new(
  :domain_id,
  :default_user_settings,
  :domain_settings_for_update,
  :app_security_group_management,
  :default_space_settings,
  :subnet_ids,
  :app_network_access_type,
  :tag_propagation)
  SENSITIVE = []
  include Aws::Structure
end

#app_security_group_managementString

The entity that creates and manages the required security groups for inter-app communication in VPCOnly mode. Required when CreateDomain.AppNetworkAccessType is VPCOnly and DomainSettings.RStudioServerProDomainSettings.DomainExecutionRoleArn is provided. If setting up the domain for use with RStudio, this value must be set to Service.

Returns:

  • (String)


47554
47555
47556
47557
47558
47559
47560
47561
47562
47563
47564
47565
# File 'lib/aws-sdk-sagemaker/types.rb', line 47554

class UpdateDomainRequest < Struct.new(
  :domain_id,
  :default_user_settings,
  :domain_settings_for_update,
  :app_security_group_management,
  :default_space_settings,
  :subnet_ids,
  :app_network_access_type,
  :tag_propagation)
  SENSITIVE = []
  include Aws::Structure
end

#default_space_settingsTypes::DefaultSpaceSettings

The default settings for shared spaces that users create in the domain.



47554
47555
47556
47557
47558
47559
47560
47561
47562
47563
47564
47565
# File 'lib/aws-sdk-sagemaker/types.rb', line 47554

class UpdateDomainRequest < Struct.new(
  :domain_id,
  :default_user_settings,
  :domain_settings_for_update,
  :app_security_group_management,
  :default_space_settings,
  :subnet_ids,
  :app_network_access_type,
  :tag_propagation)
  SENSITIVE = []
  include Aws::Structure
end

#default_user_settingsTypes::UserSettings

A collection of settings.

Returns:



47554
47555
47556
47557
47558
47559
47560
47561
47562
47563
47564
47565
# File 'lib/aws-sdk-sagemaker/types.rb', line 47554

class UpdateDomainRequest < Struct.new(
  :domain_id,
  :default_user_settings,
  :domain_settings_for_update,
  :app_security_group_management,
  :default_space_settings,
  :subnet_ids,
  :app_network_access_type,
  :tag_propagation)
  SENSITIVE = []
  include Aws::Structure
end

#domain_idString

The ID of the domain to be updated.

Returns:

  • (String)


47554
47555
47556
47557
47558
47559
47560
47561
47562
47563
47564
47565
# File 'lib/aws-sdk-sagemaker/types.rb', line 47554

class UpdateDomainRequest < Struct.new(
  :domain_id,
  :default_user_settings,
  :domain_settings_for_update,
  :app_security_group_management,
  :default_space_settings,
  :subnet_ids,
  :app_network_access_type,
  :tag_propagation)
  SENSITIVE = []
  include Aws::Structure
end

#domain_settings_for_updateTypes::DomainSettingsForUpdate

A collection of DomainSettings configuration values to update.



47554
47555
47556
47557
47558
47559
47560
47561
47562
47563
47564
47565
# File 'lib/aws-sdk-sagemaker/types.rb', line 47554

class UpdateDomainRequest < Struct.new(
  :domain_id,
  :default_user_settings,
  :domain_settings_for_update,
  :app_security_group_management,
  :default_space_settings,
  :subnet_ids,
  :app_network_access_type,
  :tag_propagation)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idsArray<String>

The VPC subnets that Studio uses for communication.

If removing subnets, ensure there are no apps in the InService, Pending, or Deleting state.

Returns:

  • (Array<String>)


47554
47555
47556
47557
47558
47559
47560
47561
47562
47563
47564
47565
# File 'lib/aws-sdk-sagemaker/types.rb', line 47554

class UpdateDomainRequest < Struct.new(
  :domain_id,
  :default_user_settings,
  :domain_settings_for_update,
  :app_security_group_management,
  :default_space_settings,
  :subnet_ids,
  :app_network_access_type,
  :tag_propagation)
  SENSITIVE = []
  include Aws::Structure
end

#tag_propagationString

Indicates whether custom tag propagation is supported for the domain. Defaults to DISABLED.

Returns:

  • (String)


47554
47555
47556
47557
47558
47559
47560
47561
47562
47563
47564
47565
# File 'lib/aws-sdk-sagemaker/types.rb', line 47554

class UpdateDomainRequest < Struct.new(
  :domain_id,
  :default_user_settings,
  :domain_settings_for_update,
  :app_security_group_management,
  :default_space_settings,
  :subnet_ids,
  :app_network_access_type,
  :tag_propagation)
  SENSITIVE = []
  include Aws::Structure
end