Class: Aws::SageMaker::Types::UpdateDomainRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::UpdateDomainRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#app_network_access_type ⇒ String
Specifies the VPC used for non-EFS traffic.
-
#app_security_group_management ⇒ String
The entity that creates and manages the required security groups for inter-app communication in
VPCOnlymode. -
#default_space_settings ⇒ Types::DefaultSpaceSettings
The default settings used to create a space within the domain.
-
#default_user_settings ⇒ Types::UserSettings
A collection of settings.
-
#domain_id ⇒ String
The ID of the domain to be updated.
-
#domain_settings_for_update ⇒ Types::DomainSettingsForUpdate
A collection of
DomainSettingsconfiguration values to update. -
#subnet_ids ⇒ Array<String>
The VPC subnets that Studio uses for communication.
Instance Attribute Details
#app_network_access_type ⇒ String
Specifies the VPC used for non-EFS traffic.
-
PublicInternetOnly- Non-EFS traffic is through a VPC managed by Amazon SageMaker, which allows direct internet access. -
VpcOnly- All Studio traffic is through the specified VPC and subnets.
This configuration can only be modified if there are no apps in the InService, Pending, or Deleting state. The configuration cannot be updated if DomainSettings.RStudioServerProDomainSettings.DomainExecutionRoleArn is already set or DomainSettings.RStudioServerProDomainSettings.DomainExecutionRoleArn is provided as part of the same request.
43083 43084 43085 43086 43087 43088 43089 43090 43091 43092 43093 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43083 class UpdateDomainRequest < Struct.new( :domain_id, :default_user_settings, :domain_settings_for_update, :app_security_group_management, :default_space_settings, :subnet_ids, :app_network_access_type) SENSITIVE = [] include Aws::Structure end |
#app_security_group_management ⇒ String
The entity that creates and manages the required security groups for inter-app communication in VPCOnly mode. Required when CreateDomain.AppNetworkAccessType is VPCOnly and DomainSettings.RStudioServerProDomainSettings.DomainExecutionRoleArn is provided. If setting up the domain for use with RStudio, this value must be set to Service.
43083 43084 43085 43086 43087 43088 43089 43090 43091 43092 43093 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43083 class UpdateDomainRequest < Struct.new( :domain_id, :default_user_settings, :domain_settings_for_update, :app_security_group_management, :default_space_settings, :subnet_ids, :app_network_access_type) SENSITIVE = [] include Aws::Structure end |
#default_space_settings ⇒ Types::DefaultSpaceSettings
The default settings used to create a space within the domain.
43083 43084 43085 43086 43087 43088 43089 43090 43091 43092 43093 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43083 class UpdateDomainRequest < Struct.new( :domain_id, :default_user_settings, :domain_settings_for_update, :app_security_group_management, :default_space_settings, :subnet_ids, :app_network_access_type) SENSITIVE = [] include Aws::Structure end |
#default_user_settings ⇒ Types::UserSettings
A collection of settings.
43083 43084 43085 43086 43087 43088 43089 43090 43091 43092 43093 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43083 class UpdateDomainRequest < Struct.new( :domain_id, :default_user_settings, :domain_settings_for_update, :app_security_group_management, :default_space_settings, :subnet_ids, :app_network_access_type) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
The ID of the domain to be updated.
43083 43084 43085 43086 43087 43088 43089 43090 43091 43092 43093 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43083 class UpdateDomainRequest < Struct.new( :domain_id, :default_user_settings, :domain_settings_for_update, :app_security_group_management, :default_space_settings, :subnet_ids, :app_network_access_type) SENSITIVE = [] include Aws::Structure end |
#domain_settings_for_update ⇒ Types::DomainSettingsForUpdate
A collection of DomainSettings configuration values to update.
43083 43084 43085 43086 43087 43088 43089 43090 43091 43092 43093 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43083 class UpdateDomainRequest < Struct.new( :domain_id, :default_user_settings, :domain_settings_for_update, :app_security_group_management, :default_space_settings, :subnet_ids, :app_network_access_type) SENSITIVE = [] include Aws::Structure end |
#subnet_ids ⇒ Array<String>
The VPC subnets that Studio uses for communication.
If removing subnets, ensure there are no apps in the InService, Pending, or Deleting state.
43083 43084 43085 43086 43087 43088 43089 43090 43091 43092 43093 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 43083 class UpdateDomainRequest < Struct.new( :domain_id, :default_user_settings, :domain_settings_for_update, :app_security_group_management, :default_space_settings, :subnet_ids, :app_network_access_type) SENSITIVE = [] include Aws::Structure end |