Class: Aws::SageMaker::Types::UpdateDomainRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::UpdateDomainRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#app_security_group_management ⇒ String
The entity that creates and manages the required security groups for inter-app communication in
VPCOnlymode. -
#default_space_settings ⇒ Types::DefaultSpaceSettings
The default settings used to create a space within the Domain.
-
#default_user_settings ⇒ Types::UserSettings
A collection of settings.
-
#domain_id ⇒ String
The ID of the domain to be updated.
-
#domain_settings_for_update ⇒ Types::DomainSettingsForUpdate
A collection of
DomainSettingsconfiguration values to update.
Instance Attribute Details
#app_security_group_management ⇒ String
The entity that creates and manages the required security groups for inter-app communication in VPCOnly mode. Required when CreateDomain.AppNetworkAccessType is VPCOnly and DomainSettings.RStudioServerProDomainSettings.DomainExecutionRoleArn is provided.
37515 37516 37517 37518 37519 37520 37521 37522 37523 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37515 class UpdateDomainRequest < Struct.new( :domain_id, :default_user_settings, :domain_settings_for_update, :default_space_settings, :app_security_group_management) SENSITIVE = [] include Aws::Structure end |
#default_space_settings ⇒ Types::DefaultSpaceSettings
The default settings used to create a space within the Domain.
37515 37516 37517 37518 37519 37520 37521 37522 37523 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37515 class UpdateDomainRequest < Struct.new( :domain_id, :default_user_settings, :domain_settings_for_update, :default_space_settings, :app_security_group_management) SENSITIVE = [] include Aws::Structure end |
#default_user_settings ⇒ Types::UserSettings
A collection of settings.
37515 37516 37517 37518 37519 37520 37521 37522 37523 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37515 class UpdateDomainRequest < Struct.new( :domain_id, :default_user_settings, :domain_settings_for_update, :default_space_settings, :app_security_group_management) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
The ID of the domain to be updated.
37515 37516 37517 37518 37519 37520 37521 37522 37523 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37515 class UpdateDomainRequest < Struct.new( :domain_id, :default_user_settings, :domain_settings_for_update, :default_space_settings, :app_security_group_management) SENSITIVE = [] include Aws::Structure end |
#domain_settings_for_update ⇒ Types::DomainSettingsForUpdate
A collection of DomainSettings configuration values to update.
37515 37516 37517 37518 37519 37520 37521 37522 37523 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 37515 class UpdateDomainRequest < Struct.new( :domain_id, :default_user_settings, :domain_settings_for_update, :default_space_settings, :app_security_group_management) SENSITIVE = [] include Aws::Structure end |