Class: Aws::SageMaker::Types::UpdateDomainRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::UpdateDomainRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#app_network_access_type ⇒ String
Specifies the VPC used for non-EFS traffic.
-
#app_security_group_management ⇒ String
The entity that creates and manages the required security groups for inter-app communication in
VPCOnlymode. -
#default_space_settings ⇒ Types::DefaultSpaceSettings
The default settings for shared spaces that users create in the domain.
-
#default_user_settings ⇒ Types::UserSettings
A collection of settings.
-
#domain_id ⇒ String
The ID of the domain to be updated.
-
#domain_settings_for_update ⇒ Types::DomainSettingsForUpdate
A collection of
DomainSettingsconfiguration values to update. -
#subnet_ids ⇒ Array<String>
The VPC subnets that Studio uses for communication.
-
#tag_propagation ⇒ String
Indicates whether custom tag propagation is supported for the domain.
-
#vpc_id ⇒ String
The identifier for the VPC used by the domain for network communication.
Instance Attribute Details
#app_network_access_type ⇒ String
Specifies the VPC used for non-EFS traffic.
-
PublicInternetOnly- Non-EFS traffic is through a VPC managed by Amazon SageMaker AI, which allows direct internet access. -
VpcOnly- All Studio traffic is through the specified VPC and subnets.
This configuration can only be modified if there are no apps in the InService, Pending, or Deleting state. The configuration cannot be updated if DomainSettings.RStudioServerProDomainSettings.DomainExecutionRoleArn is already set or DomainSettings.RStudioServerProDomainSettings.DomainExecutionRoleArn is provided as part of the same request.
53159 53160 53161 53162 53163 53164 53165 53166 53167 53168 53169 53170 53171 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53159 class UpdateDomainRequest < Struct.new( :domain_id, :default_user_settings, :domain_settings_for_update, :app_security_group_management, :default_space_settings, :subnet_ids, :app_network_access_type, :tag_propagation, :vpc_id) SENSITIVE = [] include Aws::Structure end |
#app_security_group_management ⇒ String
The entity that creates and manages the required security groups for inter-app communication in VPCOnly mode. Required when CreateDomain.AppNetworkAccessType is VPCOnly and DomainSettings.RStudioServerProDomainSettings.DomainExecutionRoleArn is provided. If setting up the domain for use with RStudio, this value must be set to Service.
53159 53160 53161 53162 53163 53164 53165 53166 53167 53168 53169 53170 53171 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53159 class UpdateDomainRequest < Struct.new( :domain_id, :default_user_settings, :domain_settings_for_update, :app_security_group_management, :default_space_settings, :subnet_ids, :app_network_access_type, :tag_propagation, :vpc_id) SENSITIVE = [] include Aws::Structure end |
#default_space_settings ⇒ Types::DefaultSpaceSettings
The default settings for shared spaces that users create in the domain.
53159 53160 53161 53162 53163 53164 53165 53166 53167 53168 53169 53170 53171 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53159 class UpdateDomainRequest < Struct.new( :domain_id, :default_user_settings, :domain_settings_for_update, :app_security_group_management, :default_space_settings, :subnet_ids, :app_network_access_type, :tag_propagation, :vpc_id) SENSITIVE = [] include Aws::Structure end |
#default_user_settings ⇒ Types::UserSettings
A collection of settings.
53159 53160 53161 53162 53163 53164 53165 53166 53167 53168 53169 53170 53171 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53159 class UpdateDomainRequest < Struct.new( :domain_id, :default_user_settings, :domain_settings_for_update, :app_security_group_management, :default_space_settings, :subnet_ids, :app_network_access_type, :tag_propagation, :vpc_id) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
The ID of the domain to be updated.
53159 53160 53161 53162 53163 53164 53165 53166 53167 53168 53169 53170 53171 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53159 class UpdateDomainRequest < Struct.new( :domain_id, :default_user_settings, :domain_settings_for_update, :app_security_group_management, :default_space_settings, :subnet_ids, :app_network_access_type, :tag_propagation, :vpc_id) SENSITIVE = [] include Aws::Structure end |
#domain_settings_for_update ⇒ Types::DomainSettingsForUpdate
A collection of DomainSettings configuration values to update.
53159 53160 53161 53162 53163 53164 53165 53166 53167 53168 53169 53170 53171 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53159 class UpdateDomainRequest < Struct.new( :domain_id, :default_user_settings, :domain_settings_for_update, :app_security_group_management, :default_space_settings, :subnet_ids, :app_network_access_type, :tag_propagation, :vpc_id) SENSITIVE = [] include Aws::Structure end |
#subnet_ids ⇒ Array<String>
The VPC subnets that Studio uses for communication.
If removing subnets, ensure there are no apps in the InService, Pending, or Deleting state.
53159 53160 53161 53162 53163 53164 53165 53166 53167 53168 53169 53170 53171 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53159 class UpdateDomainRequest < Struct.new( :domain_id, :default_user_settings, :domain_settings_for_update, :app_security_group_management, :default_space_settings, :subnet_ids, :app_network_access_type, :tag_propagation, :vpc_id) SENSITIVE = [] include Aws::Structure end |
#tag_propagation ⇒ String
Indicates whether custom tag propagation is supported for the domain. Defaults to DISABLED.
53159 53160 53161 53162 53163 53164 53165 53166 53167 53168 53169 53170 53171 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53159 class UpdateDomainRequest < Struct.new( :domain_id, :default_user_settings, :domain_settings_for_update, :app_security_group_management, :default_space_settings, :subnet_ids, :app_network_access_type, :tag_propagation, :vpc_id) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The identifier for the VPC used by the domain for network communication. Use this field only when adding VPC configuration to a SageMaker AI domain used in Amazon SageMaker Unified Studio that was created without VPC settings. SageMaker AI doesn’t automatically apply VPC updates to existing applications. Stop and restart your applications to apply the changes.
53159 53160 53161 53162 53163 53164 53165 53166 53167 53168 53169 53170 53171 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 53159 class UpdateDomainRequest < Struct.new( :domain_id, :default_user_settings, :domain_settings_for_update, :app_security_group_management, :default_space_settings, :subnet_ids, :app_network_access_type, :tag_propagation, :vpc_id) SENSITIVE = [] include Aws::Structure end |