Class: Aws::SageMaker::Types::UpdateEndpointInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#deployment_configTypes::DeploymentConfig

The deployment configuration for an endpoint, which contains the desired deployment strategy and rollback configurations.



37581
37582
37583
37584
37585
37586
37587
37588
37589
37590
# File 'lib/aws-sdk-sagemaker/types.rb', line 37581

class UpdateEndpointInput < Struct.new(
  :endpoint_name,
  :endpoint_config_name,
  :retain_all_variant_properties,
  :exclude_retained_variant_properties,
  :deployment_config,
  :retain_deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_config_nameString

The name of the new endpoint configuration.

Returns:

  • (String)


37581
37582
37583
37584
37585
37586
37587
37588
37589
37590
# File 'lib/aws-sdk-sagemaker/types.rb', line 37581

class UpdateEndpointInput < Struct.new(
  :endpoint_name,
  :endpoint_config_name,
  :retain_all_variant_properties,
  :exclude_retained_variant_properties,
  :deployment_config,
  :retain_deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_nameString

The name of the endpoint whose configuration you want to update.

Returns:

  • (String)


37581
37582
37583
37584
37585
37586
37587
37588
37589
37590
# File 'lib/aws-sdk-sagemaker/types.rb', line 37581

class UpdateEndpointInput < Struct.new(
  :endpoint_name,
  :endpoint_config_name,
  :retain_all_variant_properties,
  :exclude_retained_variant_properties,
  :deployment_config,
  :retain_deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#exclude_retained_variant_propertiesArray<Types::VariantProperty>

When you are updating endpoint resources with UpdateEndpointInput$RetainAllVariantProperties, whose value is set to true, ExcludeRetainedVariantProperties specifies the list of type VariantProperty to override with the values provided by EndpointConfig. If you don’t specify a value for ExcludeRetainedVariantProperties, no variant properties are overridden.

Returns:



37581
37582
37583
37584
37585
37586
37587
37588
37589
37590
# File 'lib/aws-sdk-sagemaker/types.rb', line 37581

class UpdateEndpointInput < Struct.new(
  :endpoint_name,
  :endpoint_config_name,
  :retain_all_variant_properties,
  :exclude_retained_variant_properties,
  :deployment_config,
  :retain_deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#retain_all_variant_propertiesBoolean

When updating endpoint resources, enables or disables the retention of [variant properties], such as the instance count or the variant weight. To retain the variant properties of an endpoint when updating it, set RetainAllVariantProperties to true. To use the variant properties specified in a new EndpointConfig call when updating an endpoint, set RetainAllVariantProperties to false. The default is false.

[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_VariantProperty.html

Returns:

  • (Boolean)


37581
37582
37583
37584
37585
37586
37587
37588
37589
37590
# File 'lib/aws-sdk-sagemaker/types.rb', line 37581

class UpdateEndpointInput < Struct.new(
  :endpoint_name,
  :endpoint_config_name,
  :retain_all_variant_properties,
  :exclude_retained_variant_properties,
  :deployment_config,
  :retain_deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#retain_deployment_configBoolean

Specifies whether to reuse the last deployment configuration. The default value is false (the configuration is not reused).

Returns:

  • (Boolean)


37581
37582
37583
37584
37585
37586
37587
37588
37589
37590
# File 'lib/aws-sdk-sagemaker/types.rb', line 37581

class UpdateEndpointInput < Struct.new(
  :endpoint_name,
  :endpoint_config_name,
  :retain_all_variant_properties,
  :exclude_retained_variant_properties,
  :deployment_config,
  :retain_deployment_config)
  SENSITIVE = []
  include Aws::Structure
end