Class: Aws::SageMaker::Types::UpdateHubContentReferenceRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#hub_content_nameString

The name of the hub content resource that you want to update.

Returns:

  • (String)


53420
53421
53422
53423
53424
53425
53426
53427
# File 'lib/aws-sdk-sagemaker/types.rb', line 53420

class UpdateHubContentReferenceRequest < Struct.new(
  :hub_name,
  :hub_content_name,
  :hub_content_type,
  :min_version)
  SENSITIVE = []
  include Aws::Structure
end

#hub_content_typeString

The content type of the resource that you want to update. Only specify a ModelReference resource for this API. To update a Model or Notebook resource, use the UpdateHubContent API instead.

Returns:

  • (String)


53420
53421
53422
53423
53424
53425
53426
53427
# File 'lib/aws-sdk-sagemaker/types.rb', line 53420

class UpdateHubContentReferenceRequest < Struct.new(
  :hub_name,
  :hub_content_name,
  :hub_content_type,
  :min_version)
  SENSITIVE = []
  include Aws::Structure
end

#hub_nameString

The name of the SageMaker hub that contains the hub content you want to update. You can optionally use the hub ARN instead.

Returns:

  • (String)


53420
53421
53422
53423
53424
53425
53426
53427
# File 'lib/aws-sdk-sagemaker/types.rb', line 53420

class UpdateHubContentReferenceRequest < Struct.new(
  :hub_name,
  :hub_content_name,
  :hub_content_type,
  :min_version)
  SENSITIVE = []
  include Aws::Structure
end

#min_versionString

The minimum hub content version of the referenced model that you want to use. The minimum version must be older than the latest available version of the referenced model. To support all versions of a model, set the value to 1.0.0.

Returns:

  • (String)


53420
53421
53422
53423
53424
53425
53426
53427
# File 'lib/aws-sdk-sagemaker/types.rb', line 53420

class UpdateHubContentReferenceRequest < Struct.new(
  :hub_name,
  :hub_content_name,
  :hub_content_type,
  :min_version)
  SENSITIVE = []
  include Aws::Structure
end