Class: Aws::SageMaker::Types::UpdateHubContentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::UpdateHubContentRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#hub_content_description ⇒ String
The description of the hub content.
-
#hub_content_display_name ⇒ String
The display name of the hub content.
-
#hub_content_markdown ⇒ String
A string that provides a description of the hub content.
-
#hub_content_name ⇒ String
The name of the hub content resource that you want to update.
-
#hub_content_search_keywords ⇒ Array<String>
The searchable keywords of the hub content.
-
#hub_content_type ⇒ String
The content type of the resource that you want to update.
-
#hub_content_version ⇒ String
The hub content version that you want to update.
-
#hub_name ⇒ String
The name of the SageMaker hub that contains the hub content you want to update.
-
#support_status ⇒ String
Indicates the current status of the hub content resource.
Instance Attribute Details
#hub_content_description ⇒ String
The description of the hub content.
55592 55593 55594 55595 55596 55597 55598 55599 55600 55601 55602 55603 55604 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55592 class UpdateHubContentRequest < Struct.new( :hub_name, :hub_content_name, :hub_content_type, :hub_content_version, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_search_keywords, :support_status) SENSITIVE = [] include Aws::Structure end |
#hub_content_display_name ⇒ String
The display name of the hub content.
55592 55593 55594 55595 55596 55597 55598 55599 55600 55601 55602 55603 55604 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55592 class UpdateHubContentRequest < Struct.new( :hub_name, :hub_content_name, :hub_content_type, :hub_content_version, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_search_keywords, :support_status) SENSITIVE = [] include Aws::Structure end |
#hub_content_markdown ⇒ String
A string that provides a description of the hub content. This string can include links, tables, and standard markdown formatting.
55592 55593 55594 55595 55596 55597 55598 55599 55600 55601 55602 55603 55604 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55592 class UpdateHubContentRequest < Struct.new( :hub_name, :hub_content_name, :hub_content_type, :hub_content_version, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_search_keywords, :support_status) SENSITIVE = [] include Aws::Structure end |
#hub_content_name ⇒ String
The name of the hub content resource that you want to update.
55592 55593 55594 55595 55596 55597 55598 55599 55600 55601 55602 55603 55604 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55592 class UpdateHubContentRequest < Struct.new( :hub_name, :hub_content_name, :hub_content_type, :hub_content_version, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_search_keywords, :support_status) SENSITIVE = [] include Aws::Structure end |
#hub_content_search_keywords ⇒ Array<String>
The searchable keywords of the hub content.
55592 55593 55594 55595 55596 55597 55598 55599 55600 55601 55602 55603 55604 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55592 class UpdateHubContentRequest < Struct.new( :hub_name, :hub_content_name, :hub_content_type, :hub_content_version, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_search_keywords, :support_status) SENSITIVE = [] include Aws::Structure end |
#hub_content_type ⇒ String
The content type of the resource that you want to update. Only specify a ‘Model` or `Notebook` resource for this API. To update a `ModelReference`, use the `UpdateHubContentReference` API instead.
55592 55593 55594 55595 55596 55597 55598 55599 55600 55601 55602 55603 55604 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55592 class UpdateHubContentRequest < Struct.new( :hub_name, :hub_content_name, :hub_content_type, :hub_content_version, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_search_keywords, :support_status) SENSITIVE = [] include Aws::Structure end |
#hub_content_version ⇒ String
The hub content version that you want to update. For example, if you have two versions of a resource in your hub, you can update the second version.
55592 55593 55594 55595 55596 55597 55598 55599 55600 55601 55602 55603 55604 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55592 class UpdateHubContentRequest < Struct.new( :hub_name, :hub_content_name, :hub_content_type, :hub_content_version, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_search_keywords, :support_status) SENSITIVE = [] include Aws::Structure end |
#hub_name ⇒ String
The name of the SageMaker hub that contains the hub content you want to update. You can optionally use the hub ARN instead.
55592 55593 55594 55595 55596 55597 55598 55599 55600 55601 55602 55603 55604 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55592 class UpdateHubContentRequest < Struct.new( :hub_name, :hub_content_name, :hub_content_type, :hub_content_version, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_search_keywords, :support_status) SENSITIVE = [] include Aws::Structure end |
#support_status ⇒ String
Indicates the current status of the hub content resource.
55592 55593 55594 55595 55596 55597 55598 55599 55600 55601 55602 55603 55604 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55592 class UpdateHubContentRequest < Struct.new( :hub_name, :hub_content_name, :hub_content_type, :hub_content_version, :hub_content_display_name, :hub_content_description, :hub_content_markdown, :hub_content_search_keywords, :support_status) SENSITIVE = [] include Aws::Structure end |