Class: Aws::SageMaker::Types::UpdateImageVersionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::UpdateImageVersionRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias ⇒ String
The alias of the image version.
-
#aliases_to_add ⇒ Array<String>
A list of aliases to add.
-
#aliases_to_delete ⇒ Array<String>
A list of aliases to delete.
-
#horovod ⇒ Boolean
Indicates Horovod compatibility.
-
#image_name ⇒ String
The name of the image.
-
#job_type ⇒ String
Indicates SageMaker AI job type compatibility.
-
#ml_framework ⇒ String
The machine learning framework vended in the image version.
-
#processor ⇒ String
Indicates CPU or GPU compatibility.
-
#programming_lang ⇒ String
The supported programming language and its version.
-
#release_notes ⇒ String
The maintainer description of the image version.
-
#vendor_guidance ⇒ String
The availability of the image version specified by the maintainer.
-
#version ⇒ Integer
The version of the image.
Instance Attribute Details
#alias ⇒ String
The alias of the image version.
55957 55958 55959 55960 55961 55962 55963 55964 55965 55966 55967 55968 55969 55970 55971 55972 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55957 class UpdateImageVersionRequest < Struct.new( :image_name, :alias, :version, :aliases_to_add, :aliases_to_delete, :vendor_guidance, :job_type, :ml_framework, :programming_lang, :processor, :horovod, :release_notes) SENSITIVE = [] include Aws::Structure end |
#aliases_to_add ⇒ Array<String>
A list of aliases to add.
55957 55958 55959 55960 55961 55962 55963 55964 55965 55966 55967 55968 55969 55970 55971 55972 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55957 class UpdateImageVersionRequest < Struct.new( :image_name, :alias, :version, :aliases_to_add, :aliases_to_delete, :vendor_guidance, :job_type, :ml_framework, :programming_lang, :processor, :horovod, :release_notes) SENSITIVE = [] include Aws::Structure end |
#aliases_to_delete ⇒ Array<String>
A list of aliases to delete.
55957 55958 55959 55960 55961 55962 55963 55964 55965 55966 55967 55968 55969 55970 55971 55972 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55957 class UpdateImageVersionRequest < Struct.new( :image_name, :alias, :version, :aliases_to_add, :aliases_to_delete, :vendor_guidance, :job_type, :ml_framework, :programming_lang, :processor, :horovod, :release_notes) SENSITIVE = [] include Aws::Structure end |
#horovod ⇒ Boolean
Indicates Horovod compatibility.
55957 55958 55959 55960 55961 55962 55963 55964 55965 55966 55967 55968 55969 55970 55971 55972 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55957 class UpdateImageVersionRequest < Struct.new( :image_name, :alias, :version, :aliases_to_add, :aliases_to_delete, :vendor_guidance, :job_type, :ml_framework, :programming_lang, :processor, :horovod, :release_notes) SENSITIVE = [] include Aws::Structure end |
#image_name ⇒ String
The name of the image.
55957 55958 55959 55960 55961 55962 55963 55964 55965 55966 55967 55968 55969 55970 55971 55972 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55957 class UpdateImageVersionRequest < Struct.new( :image_name, :alias, :version, :aliases_to_add, :aliases_to_delete, :vendor_guidance, :job_type, :ml_framework, :programming_lang, :processor, :horovod, :release_notes) SENSITIVE = [] include Aws::Structure end |
#job_type ⇒ String
Indicates SageMaker AI job type compatibility.
-
‘TRAINING`: The image version is compatible with SageMaker AI training jobs.
-
‘INFERENCE`: The image version is compatible with SageMaker AI inference jobs.
-
‘NOTEBOOK_KERNEL`: The image version is compatible with SageMaker AI notebook kernels.
55957 55958 55959 55960 55961 55962 55963 55964 55965 55966 55967 55968 55969 55970 55971 55972 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55957 class UpdateImageVersionRequest < Struct.new( :image_name, :alias, :version, :aliases_to_add, :aliases_to_delete, :vendor_guidance, :job_type, :ml_framework, :programming_lang, :processor, :horovod, :release_notes) SENSITIVE = [] include Aws::Structure end |
#ml_framework ⇒ String
The machine learning framework vended in the image version.
55957 55958 55959 55960 55961 55962 55963 55964 55965 55966 55967 55968 55969 55970 55971 55972 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55957 class UpdateImageVersionRequest < Struct.new( :image_name, :alias, :version, :aliases_to_add, :aliases_to_delete, :vendor_guidance, :job_type, :ml_framework, :programming_lang, :processor, :horovod, :release_notes) SENSITIVE = [] include Aws::Structure end |
#processor ⇒ String
Indicates CPU or GPU compatibility.
-
‘CPU`: The image version is compatible with CPU.
-
‘GPU`: The image version is compatible with GPU.
55957 55958 55959 55960 55961 55962 55963 55964 55965 55966 55967 55968 55969 55970 55971 55972 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55957 class UpdateImageVersionRequest < Struct.new( :image_name, :alias, :version, :aliases_to_add, :aliases_to_delete, :vendor_guidance, :job_type, :ml_framework, :programming_lang, :processor, :horovod, :release_notes) SENSITIVE = [] include Aws::Structure end |
#programming_lang ⇒ String
The supported programming language and its version.
55957 55958 55959 55960 55961 55962 55963 55964 55965 55966 55967 55968 55969 55970 55971 55972 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55957 class UpdateImageVersionRequest < Struct.new( :image_name, :alias, :version, :aliases_to_add, :aliases_to_delete, :vendor_guidance, :job_type, :ml_framework, :programming_lang, :processor, :horovod, :release_notes) SENSITIVE = [] include Aws::Structure end |
#release_notes ⇒ String
The maintainer description of the image version.
55957 55958 55959 55960 55961 55962 55963 55964 55965 55966 55967 55968 55969 55970 55971 55972 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55957 class UpdateImageVersionRequest < Struct.new( :image_name, :alias, :version, :aliases_to_add, :aliases_to_delete, :vendor_guidance, :job_type, :ml_framework, :programming_lang, :processor, :horovod, :release_notes) SENSITIVE = [] include Aws::Structure end |
#vendor_guidance ⇒ String
The availability of the image version specified by the maintainer.
-
‘NOT_PROVIDED`: The maintainers did not provide a status for image version stability.
-
‘STABLE`: The image version is stable.
-
‘TO_BE_ARCHIVED`: The image version is set to be archived. Custom image versions that are set to be archived are automatically archived after three months.
-
‘ARCHIVED`: The image version is archived. Archived image versions are not searchable and are no longer actively supported.
55957 55958 55959 55960 55961 55962 55963 55964 55965 55966 55967 55968 55969 55970 55971 55972 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55957 class UpdateImageVersionRequest < Struct.new( :image_name, :alias, :version, :aliases_to_add, :aliases_to_delete, :vendor_guidance, :job_type, :ml_framework, :programming_lang, :processor, :horovod, :release_notes) SENSITIVE = [] include Aws::Structure end |
#version ⇒ Integer
The version of the image.
55957 55958 55959 55960 55961 55962 55963 55964 55965 55966 55967 55968 55969 55970 55971 55972 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55957 class UpdateImageVersionRequest < Struct.new( :image_name, :alias, :version, :aliases_to_add, :aliases_to_delete, :vendor_guidance, :job_type, :ml_framework, :programming_lang, :processor, :horovod, :release_notes) SENSITIVE = [] include Aws::Structure end |