Class: Aws::SageMaker::Types::UpdateInferenceComponentInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#deployment_configTypes::InferenceComponentDeploymentConfig

The deployment configuration for the inference component. The configuration contains the desired deployment strategy and rollback settings.



56763
56764
56765
56766
56767
56768
56769
56770
56771
# File 'lib/aws-sdk-sagemaker/types.rb', line 56763

class UpdateInferenceComponentInput < Struct.new(
  :inference_component_name,
  :specification,
  :specifications,
  :runtime_config,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#inference_component_nameString

The name of the inference component.

Returns:

  • (String)


56763
56764
56765
56766
56767
56768
56769
56770
56771
# File 'lib/aws-sdk-sagemaker/types.rb', line 56763

class UpdateInferenceComponentInput < Struct.new(
  :inference_component_name,
  :specification,
  :specifications,
  :runtime_config,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#runtime_configTypes::InferenceComponentRuntimeConfig

Runtime settings for a model that is deployed with an inference component.



56763
56764
56765
56766
56767
56768
56769
56770
56771
# File 'lib/aws-sdk-sagemaker/types.rb', line 56763

class UpdateInferenceComponentInput < Struct.new(
  :inference_component_name,
  :specification,
  :specifications,
  :runtime_config,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#specificationTypes::InferenceComponentSpecification

Details about the resources to deploy with this inference component, including the model, container, and compute resources.



56763
56764
56765
56766
56767
56768
56769
56770
56771
# File 'lib/aws-sdk-sagemaker/types.rb', line 56763

class UpdateInferenceComponentInput < Struct.new(
  :inference_component_name,
  :specification,
  :specifications,
  :runtime_config,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#specificationsArray<Types::InferenceComponentSpecification>

A list of specification objects for the inference component, one per instance type. Use this parameter when you want to specify different model or resource configurations for the inference component on each instance type. You can use either this parameter or the singular ‘Specification` parameter, but not both.



56763
56764
56765
56766
56767
56768
56769
56770
56771
# File 'lib/aws-sdk-sagemaker/types.rb', line 56763

class UpdateInferenceComponentInput < Struct.new(
  :inference_component_name,
  :specification,
  :specifications,
  :runtime_config,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end