Class: Aws::SageMaker::Types::UpdateInferenceComponentInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::UpdateInferenceComponentInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#deployment_config ⇒ Types::InferenceComponentDeploymentConfig
The deployment configuration for the inference component.
-
#inference_component_name ⇒ String
The name of the inference component.
-
#runtime_config ⇒ Types::InferenceComponentRuntimeConfig
Runtime settings for a model that is deployed with an inference component.
-
#specification ⇒ Types::InferenceComponentSpecification
Details about the resources to deploy with this inference component, including the model, container, and compute resources.
-
#specifications ⇒ Array<Types::InferenceComponentSpecification>
A list of specification objects for the inference component, one per instance type.
Instance Attribute Details
#deployment_config ⇒ Types::InferenceComponentDeploymentConfig
The deployment configuration for the inference component. The configuration contains the desired deployment strategy and rollback settings.
55999 56000 56001 56002 56003 56004 56005 56006 56007 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55999 class UpdateInferenceComponentInput < Struct.new( :inference_component_name, :specification, :specifications, :runtime_config, :deployment_config) SENSITIVE = [] include Aws::Structure end |
#inference_component_name ⇒ String
The name of the inference component.
55999 56000 56001 56002 56003 56004 56005 56006 56007 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55999 class UpdateInferenceComponentInput < Struct.new( :inference_component_name, :specification, :specifications, :runtime_config, :deployment_config) SENSITIVE = [] include Aws::Structure end |
#runtime_config ⇒ Types::InferenceComponentRuntimeConfig
Runtime settings for a model that is deployed with an inference component.
55999 56000 56001 56002 56003 56004 56005 56006 56007 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55999 class UpdateInferenceComponentInput < Struct.new( :inference_component_name, :specification, :specifications, :runtime_config, :deployment_config) SENSITIVE = [] include Aws::Structure end |
#specification ⇒ Types::InferenceComponentSpecification
Details about the resources to deploy with this inference component, including the model, container, and compute resources.
55999 56000 56001 56002 56003 56004 56005 56006 56007 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55999 class UpdateInferenceComponentInput < Struct.new( :inference_component_name, :specification, :specifications, :runtime_config, :deployment_config) SENSITIVE = [] include Aws::Structure end |
#specifications ⇒ Array<Types::InferenceComponentSpecification>
A list of specification objects for the inference component, one per instance type. Use this parameter when you want to specify different model or resource configurations for the inference component on each instance type. You can use either this parameter or the singular ‘Specification` parameter, but not both.
55999 56000 56001 56002 56003 56004 56005 56006 56007 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 55999 class UpdateInferenceComponentInput < Struct.new( :inference_component_name, :specification, :specifications, :runtime_config, :deployment_config) SENSITIVE = [] include Aws::Structure end |