Class: Aws::SageMaker::Types::UpdateMlflowAppRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::UpdateMlflowAppRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_default_status ⇒ String
Indicates whether this this MLflow App is the default for the account.
-
#arn ⇒ String
The ARN of the MLflow App to update.
-
#artifact_store_uri ⇒ String
The new S3 URI for the general purpose bucket to use as the artifact store for the MLflow App.
-
#default_domain_id_list ⇒ Array<String>
List of SageMaker Domain IDs for which this MLflow App is the default.
-
#model_registration_mode ⇒ String
Whether to enable or disable automatic registration of new MLflow models to the SageMaker Model Registry.
-
#name ⇒ String
The name of the MLflow App to update.
-
#weekly_maintenance_window_start ⇒ String
The new weekly maintenance window start day and time to update.
Instance Attribute Details
#account_default_status ⇒ String
Indicates whether this this MLflow App is the default for the account.
56151 56152 56153 56154 56155 56156 56157 56158 56159 56160 56161 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 56151 class UpdateMlflowAppRequest < Struct.new( :arn, :name, :artifact_store_uri, :model_registration_mode, :weekly_maintenance_window_start, :default_domain_id_list, :account_default_status) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The ARN of the MLflow App to update.
56151 56152 56153 56154 56155 56156 56157 56158 56159 56160 56161 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 56151 class UpdateMlflowAppRequest < Struct.new( :arn, :name, :artifact_store_uri, :model_registration_mode, :weekly_maintenance_window_start, :default_domain_id_list, :account_default_status) SENSITIVE = [] include Aws::Structure end |
#artifact_store_uri ⇒ String
The new S3 URI for the general purpose bucket to use as the artifact store for the MLflow App.
56151 56152 56153 56154 56155 56156 56157 56158 56159 56160 56161 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 56151 class UpdateMlflowAppRequest < Struct.new( :arn, :name, :artifact_store_uri, :model_registration_mode, :weekly_maintenance_window_start, :default_domain_id_list, :account_default_status) SENSITIVE = [] include Aws::Structure end |
#default_domain_id_list ⇒ Array<String>
List of SageMaker Domain IDs for which this MLflow App is the default.
56151 56152 56153 56154 56155 56156 56157 56158 56159 56160 56161 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 56151 class UpdateMlflowAppRequest < Struct.new( :arn, :name, :artifact_store_uri, :model_registration_mode, :weekly_maintenance_window_start, :default_domain_id_list, :account_default_status) SENSITIVE = [] include Aws::Structure end |
#model_registration_mode ⇒ String
Whether to enable or disable automatic registration of new MLflow models to the SageMaker Model Registry. To enable automatic model registration, set this value to ‘AutoModelRegistrationEnabled`. To disable automatic model registration, set this value to `AutoModelRegistrationDisabled`. If not specified, `AutomaticModelRegistration` defaults to `AutoModelRegistrationEnabled`
56151 56152 56153 56154 56155 56156 56157 56158 56159 56160 56161 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 56151 class UpdateMlflowAppRequest < Struct.new( :arn, :name, :artifact_store_uri, :model_registration_mode, :weekly_maintenance_window_start, :default_domain_id_list, :account_default_status) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the MLflow App to update.
56151 56152 56153 56154 56155 56156 56157 56158 56159 56160 56161 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 56151 class UpdateMlflowAppRequest < Struct.new( :arn, :name, :artifact_store_uri, :model_registration_mode, :weekly_maintenance_window_start, :default_domain_id_list, :account_default_status) SENSITIVE = [] include Aws::Structure end |
#weekly_maintenance_window_start ⇒ String
The new weekly maintenance window start day and time to update. The maintenance window day and time should be in Coordinated Universal Time (UTC) 24-hour standard time. For example: TUE:03:30.
56151 56152 56153 56154 56155 56156 56157 56158 56159 56160 56161 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 56151 class UpdateMlflowAppRequest < Struct.new( :arn, :name, :artifact_store_uri, :model_registration_mode, :weekly_maintenance_window_start, :default_domain_id_list, :account_default_status) SENSITIVE = [] include Aws::Structure end |