Class: Aws::SageMaker::Types::UpdateMlflowTrackingServerRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#artifact_store_uriString

The new S3 URI for the general purpose bucket to use as the artifact store for the MLflow Tracking Server.

Returns:



54188
54189
54190
54191
54192
54193
54194
54195
54196
54197
54198
# File 'lib/aws-sdk-sagemaker/types.rb', line 54188

class UpdateMlflowTrackingServerRequest < Struct.new(
  :tracking_server_name,
  :artifact_store_uri,
  :tracking_server_size,
  :automatic_model_registration,
  :weekly_maintenance_window_start,
  :s3_bucket_owner_account_id,
  :s3_bucket_owner_verification)
  SENSITIVE = []
  include Aws::Structure
end

#automatic_model_registrationBoolean

Whether to enable or disable automatic registration of new MLflow models to the SageMaker Model Registry. To enable automatic model registration, set this value to True. To disable automatic model registration, set this value to False. If not specified, AutomaticModelRegistration defaults to False

Returns:



54188
54189
54190
54191
54192
54193
54194
54195
54196
54197
54198
# File 'lib/aws-sdk-sagemaker/types.rb', line 54188

class UpdateMlflowTrackingServerRequest < Struct.new(
  :tracking_server_name,
  :artifact_store_uri,
  :tracking_server_size,
  :automatic_model_registration,
  :weekly_maintenance_window_start,
  :s3_bucket_owner_account_id,
  :s3_bucket_owner_verification)
  SENSITIVE = []
  include Aws::Structure
end

#s3_bucket_owner_account_idString

The new expected Amazon Web Services account ID that owns the Amazon S3 bucket for artifact storage.

Returns:



54188
54189
54190
54191
54192
54193
54194
54195
54196
54197
54198
# File 'lib/aws-sdk-sagemaker/types.rb', line 54188

class UpdateMlflowTrackingServerRequest < Struct.new(
  :tracking_server_name,
  :artifact_store_uri,
  :tracking_server_size,
  :automatic_model_registration,
  :weekly_maintenance_window_start,
  :s3_bucket_owner_account_id,
  :s3_bucket_owner_verification)
  SENSITIVE = []
  include Aws::Structure
end

#s3_bucket_owner_verificationBoolean

Whether to enable or disable Amazon S3 Bucket Owenrship Verifaction whenever the MLflow Tracking Server interacts with Amazon Amazon S3.

Returns:



54188
54189
54190
54191
54192
54193
54194
54195
54196
54197
54198
# File 'lib/aws-sdk-sagemaker/types.rb', line 54188

class UpdateMlflowTrackingServerRequest < Struct.new(
  :tracking_server_name,
  :artifact_store_uri,
  :tracking_server_size,
  :automatic_model_registration,
  :weekly_maintenance_window_start,
  :s3_bucket_owner_account_id,
  :s3_bucket_owner_verification)
  SENSITIVE = []
  include Aws::Structure
end

#tracking_server_nameString

The name of the MLflow Tracking Server to update.

Returns:



54188
54189
54190
54191
54192
54193
54194
54195
54196
54197
54198
# File 'lib/aws-sdk-sagemaker/types.rb', line 54188

class UpdateMlflowTrackingServerRequest < Struct.new(
  :tracking_server_name,
  :artifact_store_uri,
  :tracking_server_size,
  :automatic_model_registration,
  :weekly_maintenance_window_start,
  :s3_bucket_owner_account_id,
  :s3_bucket_owner_verification)
  SENSITIVE = []
  include Aws::Structure
end

#tracking_server_sizeString

The new size for the MLflow Tracking Server.

Returns:



54188
54189
54190
54191
54192
54193
54194
54195
54196
54197
54198
# File 'lib/aws-sdk-sagemaker/types.rb', line 54188

class UpdateMlflowTrackingServerRequest < Struct.new(
  :tracking_server_name,
  :artifact_store_uri,
  :tracking_server_size,
  :automatic_model_registration,
  :weekly_maintenance_window_start,
  :s3_bucket_owner_account_id,
  :s3_bucket_owner_verification)
  SENSITIVE = []
  include Aws::Structure
end

#weekly_maintenance_window_startString

The new weekly maintenance window start day and time to update. The maintenance window day and time should be in Coordinated Universal Time (UTC) 24-hour standard time. For example: TUE:03:30.

Returns:



54188
54189
54190
54191
54192
54193
54194
54195
54196
54197
54198
# File 'lib/aws-sdk-sagemaker/types.rb', line 54188

class UpdateMlflowTrackingServerRequest < Struct.new(
  :tracking_server_name,
  :artifact_store_uri,
  :tracking_server_size,
  :automatic_model_registration,
  :weekly_maintenance_window_start,
  :s3_bucket_owner_account_id,
  :s3_bucket_owner_verification)
  SENSITIVE = []
  include Aws::Structure
end