Class: Aws::SageMaker::Types::UpdateModelPackageInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::UpdateModelPackageInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_inference_specifications_to_add ⇒ Array<Types::AdditionalInferenceSpecificationDefinition>
An array of additional Inference Specification objects to be added to the existing array additional Inference Specification.
-
#approval_description ⇒ String
A description for the approval status of the model.
-
#client_token ⇒ String
A unique token that guarantees that the call to this API is idempotent.
-
#customer_metadata_properties ⇒ Hash<String,String>
The metadata properties associated with the model package versions.
-
#customer_metadata_properties_to_remove ⇒ Array<String>
The metadata properties associated with the model package versions to remove.
-
#inference_specification ⇒ Types::InferenceSpecification
Specifies details about inference jobs that you can run with models based on this model package, including the following information:.
-
#model_approval_status ⇒ String
The approval status of the model.
-
#model_card ⇒ Types::ModelPackageModelCard
The model card associated with the model package.
-
#model_life_cycle ⇒ Types::ModelLifeCycle
A structure describing the current state of the model in its life cycle.
-
#model_package_arn ⇒ String
The Amazon Resource Name (ARN) of the model package.
-
#model_package_registration_type ⇒ String
The package registration type of the model package input.
-
#source_uri ⇒ String
The URI of the source for the model package.
Instance Attribute Details
#additional_inference_specifications_to_add ⇒ Array<Types::AdditionalInferenceSpecificationDefinition>
An array of additional Inference Specification objects to be added to the existing array additional Inference Specification. Total number of additional Inference Specifications can not exceed 15. Each additional Inference Specification specifies artifacts based on this model package that can be used on inference endpoints. Generally used with SageMaker Neo to store the compiled artifacts.
57859 57860 57861 57862 57863 57864 57865 57866 57867 57868 57869 57870 57871 57872 57873 57874 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 57859 class UpdateModelPackageInput < Struct.new( :model_package_arn, :model_approval_status, :model_package_registration_type, :approval_description, :customer_metadata_properties, :customer_metadata_properties_to_remove, :additional_inference_specifications_to_add, :inference_specification, :source_uri, :model_card, :model_life_cycle, :client_token) SENSITIVE = [] include Aws::Structure end |
#approval_description ⇒ String
A description for the approval status of the model.
57859 57860 57861 57862 57863 57864 57865 57866 57867 57868 57869 57870 57871 57872 57873 57874 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 57859 class UpdateModelPackageInput < Struct.new( :model_package_arn, :model_approval_status, :model_package_registration_type, :approval_description, :customer_metadata_properties, :customer_metadata_properties_to_remove, :additional_inference_specifications_to_add, :inference_specification, :source_uri, :model_card, :model_life_cycle, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique token that guarantees that the call to this API is idempotent.
57859 57860 57861 57862 57863 57864 57865 57866 57867 57868 57869 57870 57871 57872 57873 57874 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 57859 class UpdateModelPackageInput < Struct.new( :model_package_arn, :model_approval_status, :model_package_registration_type, :approval_description, :customer_metadata_properties, :customer_metadata_properties_to_remove, :additional_inference_specifications_to_add, :inference_specification, :source_uri, :model_card, :model_life_cycle, :client_token) SENSITIVE = [] include Aws::Structure end |
#customer_metadata_properties ⇒ Hash<String,String>
The metadata properties associated with the model package versions.
57859 57860 57861 57862 57863 57864 57865 57866 57867 57868 57869 57870 57871 57872 57873 57874 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 57859 class UpdateModelPackageInput < Struct.new( :model_package_arn, :model_approval_status, :model_package_registration_type, :approval_description, :customer_metadata_properties, :customer_metadata_properties_to_remove, :additional_inference_specifications_to_add, :inference_specification, :source_uri, :model_card, :model_life_cycle, :client_token) SENSITIVE = [] include Aws::Structure end |
#customer_metadata_properties_to_remove ⇒ Array<String>
The metadata properties associated with the model package versions to remove.
57859 57860 57861 57862 57863 57864 57865 57866 57867 57868 57869 57870 57871 57872 57873 57874 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 57859 class UpdateModelPackageInput < Struct.new( :model_package_arn, :model_approval_status, :model_package_registration_type, :approval_description, :customer_metadata_properties, :customer_metadata_properties_to_remove, :additional_inference_specifications_to_add, :inference_specification, :source_uri, :model_card, :model_life_cycle, :client_token) SENSITIVE = [] include Aws::Structure end |
#inference_specification ⇒ Types::InferenceSpecification
Specifies details about inference jobs that you can run with models based on this model package, including the following information:
-
The Amazon ECR paths of containers that contain the inference code and model artifacts.
-
The instance types that the model package supports for transform jobs and real-time endpoints used for inference.
-
The input and output content formats that the model package supports for inference.
57859 57860 57861 57862 57863 57864 57865 57866 57867 57868 57869 57870 57871 57872 57873 57874 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 57859 class UpdateModelPackageInput < Struct.new( :model_package_arn, :model_approval_status, :model_package_registration_type, :approval_description, :customer_metadata_properties, :customer_metadata_properties_to_remove, :additional_inference_specifications_to_add, :inference_specification, :source_uri, :model_card, :model_life_cycle, :client_token) SENSITIVE = [] include Aws::Structure end |
#model_approval_status ⇒ String
The approval status of the model.
57859 57860 57861 57862 57863 57864 57865 57866 57867 57868 57869 57870 57871 57872 57873 57874 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 57859 class UpdateModelPackageInput < Struct.new( :model_package_arn, :model_approval_status, :model_package_registration_type, :approval_description, :customer_metadata_properties, :customer_metadata_properties_to_remove, :additional_inference_specifications_to_add, :inference_specification, :source_uri, :model_card, :model_life_cycle, :client_token) SENSITIVE = [] include Aws::Structure end |
#model_card ⇒ Types::ModelPackageModelCard
The model card associated with the model package. Since
ModelPackageModelCard is tied to a model package, it is a specific
usage of a model card and its schema is simplified compared to the
schema of ModelCard. The ModelPackageModelCard schema does not
include model_package_details, and model_overview is composed of
the model_creator and model_artifact properties. For more
information about the model package model card schema, see Model
package model card schema. For more information about the model
card associated with the model package, see View the Details of a
Model Version.
57859 57860 57861 57862 57863 57864 57865 57866 57867 57868 57869 57870 57871 57872 57873 57874 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 57859 class UpdateModelPackageInput < Struct.new( :model_package_arn, :model_approval_status, :model_package_registration_type, :approval_description, :customer_metadata_properties, :customer_metadata_properties_to_remove, :additional_inference_specifications_to_add, :inference_specification, :source_uri, :model_card, :model_life_cycle, :client_token) SENSITIVE = [] include Aws::Structure end |
#model_life_cycle ⇒ Types::ModelLifeCycle
A structure describing the current state of the model in its life cycle.
57859 57860 57861 57862 57863 57864 57865 57866 57867 57868 57869 57870 57871 57872 57873 57874 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 57859 class UpdateModelPackageInput < Struct.new( :model_package_arn, :model_approval_status, :model_package_registration_type, :approval_description, :customer_metadata_properties, :customer_metadata_properties_to_remove, :additional_inference_specifications_to_add, :inference_specification, :source_uri, :model_card, :model_life_cycle, :client_token) SENSITIVE = [] include Aws::Structure end |
#model_package_arn ⇒ String
The Amazon Resource Name (ARN) of the model package.
57859 57860 57861 57862 57863 57864 57865 57866 57867 57868 57869 57870 57871 57872 57873 57874 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 57859 class UpdateModelPackageInput < Struct.new( :model_package_arn, :model_approval_status, :model_package_registration_type, :approval_description, :customer_metadata_properties, :customer_metadata_properties_to_remove, :additional_inference_specifications_to_add, :inference_specification, :source_uri, :model_card, :model_life_cycle, :client_token) SENSITIVE = [] include Aws::Structure end |
#model_package_registration_type ⇒ String
The package registration type of the model package input.
57859 57860 57861 57862 57863 57864 57865 57866 57867 57868 57869 57870 57871 57872 57873 57874 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 57859 class UpdateModelPackageInput < Struct.new( :model_package_arn, :model_approval_status, :model_package_registration_type, :approval_description, :customer_metadata_properties, :customer_metadata_properties_to_remove, :additional_inference_specifications_to_add, :inference_specification, :source_uri, :model_card, :model_life_cycle, :client_token) SENSITIVE = [] include Aws::Structure end |
#source_uri ⇒ String
The URI of the source for the model package.
57859 57860 57861 57862 57863 57864 57865 57866 57867 57868 57869 57870 57871 57872 57873 57874 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 57859 class UpdateModelPackageInput < Struct.new( :model_package_arn, :model_approval_status, :model_package_registration_type, :approval_description, :customer_metadata_properties, :customer_metadata_properties_to_remove, :additional_inference_specifications_to_add, :inference_specification, :source_uri, :model_card, :model_life_cycle, :client_token) SENSITIVE = [] include Aws::Structure end |