Class: Aws::SageMaker::Types::UpdateModelPackageInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_inference_specifications_to_addArray<Types::AdditionalInferenceSpecificationDefinition>

An array of additional Inference Specification objects to be added to the existing array additional Inference Specification. Total number of additional Inference Specifications can not exceed 15. Each additional Inference Specification specifies artifacts based on this model package that can be used on inference endpoints. Generally used with SageMaker Neo to store the compiled artifacts.



56208
56209
56210
56211
56212
56213
56214
56215
56216
56217
56218
56219
56220
56221
56222
56223
# File 'lib/aws-sdk-sagemaker/types.rb', line 56208

class UpdateModelPackageInput < Struct.new(
  :model_package_arn,
  :model_approval_status,
  :model_package_registration_type,
  :approval_description,
  :customer_metadata_properties,
  :customer_metadata_properties_to_remove,
  :additional_inference_specifications_to_add,
  :inference_specification,
  :source_uri,
  :model_card,
  :model_life_cycle,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#approval_descriptionString

A description for the approval status of the model.

Returns:

  • (String)


56208
56209
56210
56211
56212
56213
56214
56215
56216
56217
56218
56219
56220
56221
56222
56223
# File 'lib/aws-sdk-sagemaker/types.rb', line 56208

class UpdateModelPackageInput < Struct.new(
  :model_package_arn,
  :model_approval_status,
  :model_package_registration_type,
  :approval_description,
  :customer_metadata_properties,
  :customer_metadata_properties_to_remove,
  :additional_inference_specifications_to_add,
  :inference_specification,
  :source_uri,
  :model_card,
  :model_life_cycle,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique token that guarantees that the call to this API is idempotent.

Returns:

  • (String)


56208
56209
56210
56211
56212
56213
56214
56215
56216
56217
56218
56219
56220
56221
56222
56223
# File 'lib/aws-sdk-sagemaker/types.rb', line 56208

class UpdateModelPackageInput < Struct.new(
  :model_package_arn,
  :model_approval_status,
  :model_package_registration_type,
  :approval_description,
  :customer_metadata_properties,
  :customer_metadata_properties_to_remove,
  :additional_inference_specifications_to_add,
  :inference_specification,
  :source_uri,
  :model_card,
  :model_life_cycle,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#customer_metadata_propertiesHash<String,String>

The metadata properties associated with the model package versions.

Returns:

  • (Hash<String,String>)


56208
56209
56210
56211
56212
56213
56214
56215
56216
56217
56218
56219
56220
56221
56222
56223
# File 'lib/aws-sdk-sagemaker/types.rb', line 56208

class UpdateModelPackageInput < Struct.new(
  :model_package_arn,
  :model_approval_status,
  :model_package_registration_type,
  :approval_description,
  :customer_metadata_properties,
  :customer_metadata_properties_to_remove,
  :additional_inference_specifications_to_add,
  :inference_specification,
  :source_uri,
  :model_card,
  :model_life_cycle,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#customer_metadata_properties_to_removeArray<String>

The metadata properties associated with the model package versions to remove.

Returns:

  • (Array<String>)


56208
56209
56210
56211
56212
56213
56214
56215
56216
56217
56218
56219
56220
56221
56222
56223
# File 'lib/aws-sdk-sagemaker/types.rb', line 56208

class UpdateModelPackageInput < Struct.new(
  :model_package_arn,
  :model_approval_status,
  :model_package_registration_type,
  :approval_description,
  :customer_metadata_properties,
  :customer_metadata_properties_to_remove,
  :additional_inference_specifications_to_add,
  :inference_specification,
  :source_uri,
  :model_card,
  :model_life_cycle,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#inference_specificationTypes::InferenceSpecification

Specifies details about inference jobs that you can run with models based on this model package, including the following information:

  • The Amazon ECR paths of containers that contain the inference code and model artifacts.

  • The instance types that the model package supports for transform jobs and real-time endpoints used for inference.

  • The input and output content formats that the model package supports for inference.



56208
56209
56210
56211
56212
56213
56214
56215
56216
56217
56218
56219
56220
56221
56222
56223
# File 'lib/aws-sdk-sagemaker/types.rb', line 56208

class UpdateModelPackageInput < Struct.new(
  :model_package_arn,
  :model_approval_status,
  :model_package_registration_type,
  :approval_description,
  :customer_metadata_properties,
  :customer_metadata_properties_to_remove,
  :additional_inference_specifications_to_add,
  :inference_specification,
  :source_uri,
  :model_card,
  :model_life_cycle,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#model_approval_statusString

The approval status of the model.

Returns:

  • (String)


56208
56209
56210
56211
56212
56213
56214
56215
56216
56217
56218
56219
56220
56221
56222
56223
# File 'lib/aws-sdk-sagemaker/types.rb', line 56208

class UpdateModelPackageInput < Struct.new(
  :model_package_arn,
  :model_approval_status,
  :model_package_registration_type,
  :approval_description,
  :customer_metadata_properties,
  :customer_metadata_properties_to_remove,
  :additional_inference_specifications_to_add,
  :inference_specification,
  :source_uri,
  :model_card,
  :model_life_cycle,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#model_cardTypes::ModelPackageModelCard

The model card associated with the model package. Since ‘ModelPackageModelCard` is tied to a model package, it is a specific usage of a model card and its schema is simplified compared to the schema of `ModelCard`. The `ModelPackageModelCard` schema does not include `model_package_details`, and `model_overview` is composed of the `model_creator` and `model_artifact` properties. For more information about the model package model card schema, see [Model package model card schema]. For more information about the model card associated with the model package, see [View the Details of a Model Version].

[1]: docs.aws.amazon.com/sagemaker/latest/dg/model-registry-details.html#model-card-schema [2]: docs.aws.amazon.com/sagemaker/latest/dg/model-registry-details.html



56208
56209
56210
56211
56212
56213
56214
56215
56216
56217
56218
56219
56220
56221
56222
56223
# File 'lib/aws-sdk-sagemaker/types.rb', line 56208

class UpdateModelPackageInput < Struct.new(
  :model_package_arn,
  :model_approval_status,
  :model_package_registration_type,
  :approval_description,
  :customer_metadata_properties,
  :customer_metadata_properties_to_remove,
  :additional_inference_specifications_to_add,
  :inference_specification,
  :source_uri,
  :model_card,
  :model_life_cycle,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#model_life_cycleTypes::ModelLifeCycle

A structure describing the current state of the model in its life cycle.



56208
56209
56210
56211
56212
56213
56214
56215
56216
56217
56218
56219
56220
56221
56222
56223
# File 'lib/aws-sdk-sagemaker/types.rb', line 56208

class UpdateModelPackageInput < Struct.new(
  :model_package_arn,
  :model_approval_status,
  :model_package_registration_type,
  :approval_description,
  :customer_metadata_properties,
  :customer_metadata_properties_to_remove,
  :additional_inference_specifications_to_add,
  :inference_specification,
  :source_uri,
  :model_card,
  :model_life_cycle,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#model_package_arnString

The Amazon Resource Name (ARN) of the model package.

Returns:

  • (String)


56208
56209
56210
56211
56212
56213
56214
56215
56216
56217
56218
56219
56220
56221
56222
56223
# File 'lib/aws-sdk-sagemaker/types.rb', line 56208

class UpdateModelPackageInput < Struct.new(
  :model_package_arn,
  :model_approval_status,
  :model_package_registration_type,
  :approval_description,
  :customer_metadata_properties,
  :customer_metadata_properties_to_remove,
  :additional_inference_specifications_to_add,
  :inference_specification,
  :source_uri,
  :model_card,
  :model_life_cycle,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#model_package_registration_typeString

The package registration type of the model package input.

Returns:

  • (String)


56208
56209
56210
56211
56212
56213
56214
56215
56216
56217
56218
56219
56220
56221
56222
56223
# File 'lib/aws-sdk-sagemaker/types.rb', line 56208

class UpdateModelPackageInput < Struct.new(
  :model_package_arn,
  :model_approval_status,
  :model_package_registration_type,
  :approval_description,
  :customer_metadata_properties,
  :customer_metadata_properties_to_remove,
  :additional_inference_specifications_to_add,
  :inference_specification,
  :source_uri,
  :model_card,
  :model_life_cycle,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#source_uriString

The URI of the source for the model package.

Returns:

  • (String)


56208
56209
56210
56211
56212
56213
56214
56215
56216
56217
56218
56219
56220
56221
56222
56223
# File 'lib/aws-sdk-sagemaker/types.rb', line 56208

class UpdateModelPackageInput < Struct.new(
  :model_package_arn,
  :model_approval_status,
  :model_package_registration_type,
  :approval_description,
  :customer_metadata_properties,
  :customer_metadata_properties_to_remove,
  :additional_inference_specifications_to_add,
  :inference_specification,
  :source_uri,
  :model_card,
  :model_life_cycle,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end