Class: Aws::SageMaker::Types::UpdateModelPackageInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_inference_specifications_to_addArray<Types::AdditionalInferenceSpecificationDefinition>

An array of additional Inference Specification objects to be added to the existing array additional Inference Specification. Total number of additional Inference Specifications can not exceed 15. Each additional Inference Specification specifies artifacts based on this model package that can be used on inference endpoints. Generally used with SageMaker Neo to store the compiled artifacts.

Returns:



48294
48295
48296
48297
48298
48299
48300
48301
48302
48303
48304
48305
48306
48307
48308
# File 'lib/aws-sdk-sagemaker/types.rb', line 48294

class UpdateModelPackageInput < Struct.new(
  :model_package_arn,
  :model_approval_status,
  :approval_description,
  :customer_metadata_properties,
  :customer_metadata_properties_to_remove,
  :additional_inference_specifications_to_add,
  :inference_specification,
  :source_uri,
  :model_card,
  :model_life_cycle,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#approval_descriptionString

A description for the approval status of the model.

Returns:



48294
48295
48296
48297
48298
48299
48300
48301
48302
48303
48304
48305
48306
48307
48308
# File 'lib/aws-sdk-sagemaker/types.rb', line 48294

class UpdateModelPackageInput < Struct.new(
  :model_package_arn,
  :model_approval_status,
  :approval_description,
  :customer_metadata_properties,
  :customer_metadata_properties_to_remove,
  :additional_inference_specifications_to_add,
  :inference_specification,
  :source_uri,
  :model_card,
  :model_life_cycle,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique token that guarantees that the call to this API is idempotent.

Returns:



48294
48295
48296
48297
48298
48299
48300
48301
48302
48303
48304
48305
48306
48307
48308
# File 'lib/aws-sdk-sagemaker/types.rb', line 48294

class UpdateModelPackageInput < Struct.new(
  :model_package_arn,
  :model_approval_status,
  :approval_description,
  :customer_metadata_properties,
  :customer_metadata_properties_to_remove,
  :additional_inference_specifications_to_add,
  :inference_specification,
  :source_uri,
  :model_card,
  :model_life_cycle,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#customer_metadata_propertiesHash<String,String>

The metadata properties associated with the model package versions.

Returns:



48294
48295
48296
48297
48298
48299
48300
48301
48302
48303
48304
48305
48306
48307
48308
# File 'lib/aws-sdk-sagemaker/types.rb', line 48294

class UpdateModelPackageInput < Struct.new(
  :model_package_arn,
  :model_approval_status,
  :approval_description,
  :customer_metadata_properties,
  :customer_metadata_properties_to_remove,
  :additional_inference_specifications_to_add,
  :inference_specification,
  :source_uri,
  :model_card,
  :model_life_cycle,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#customer_metadata_properties_to_removeArray<String>

The metadata properties associated with the model package versions to remove.

Returns:



48294
48295
48296
48297
48298
48299
48300
48301
48302
48303
48304
48305
48306
48307
48308
# File 'lib/aws-sdk-sagemaker/types.rb', line 48294

class UpdateModelPackageInput < Struct.new(
  :model_package_arn,
  :model_approval_status,
  :approval_description,
  :customer_metadata_properties,
  :customer_metadata_properties_to_remove,
  :additional_inference_specifications_to_add,
  :inference_specification,
  :source_uri,
  :model_card,
  :model_life_cycle,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#inference_specificationTypes::InferenceSpecification

Specifies details about inference jobs that you can run with models based on this model package, including the following information:

  • The Amazon ECR paths of containers that contain the inference code and model artifacts.

  • The instance types that the model package supports for transform jobs and real-time endpoints used for inference.

  • The input and output content formats that the model package supports for inference.

Returns:



48294
48295
48296
48297
48298
48299
48300
48301
48302
48303
48304
48305
48306
48307
48308
# File 'lib/aws-sdk-sagemaker/types.rb', line 48294

class UpdateModelPackageInput < Struct.new(
  :model_package_arn,
  :model_approval_status,
  :approval_description,
  :customer_metadata_properties,
  :customer_metadata_properties_to_remove,
  :additional_inference_specifications_to_add,
  :inference_specification,
  :source_uri,
  :model_card,
  :model_life_cycle,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#model_approval_statusString

The approval status of the model.

Returns:



48294
48295
48296
48297
48298
48299
48300
48301
48302
48303
48304
48305
48306
48307
48308
# File 'lib/aws-sdk-sagemaker/types.rb', line 48294

class UpdateModelPackageInput < Struct.new(
  :model_package_arn,
  :model_approval_status,
  :approval_description,
  :customer_metadata_properties,
  :customer_metadata_properties_to_remove,
  :additional_inference_specifications_to_add,
  :inference_specification,
  :source_uri,
  :model_card,
  :model_life_cycle,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#model_cardTypes::ModelPackageModelCard

The model card associated with the model package. Since ModelPackageModelCard is tied to a model package, it is a specific usage of a model card and its schema is simplified compared to the schema of ModelCard. The ModelPackageModelCard schema does not include model_package_details, and model_overview is composed of the model_creator and model_artifact properties. For more information about the model package model card schema, see [Model package model card schema]. For more information about the model card associated with the model package, see [View the Details of a Model Version].

[1]: docs.aws.amazon.com/sagemaker/latest/dg/model-registry-details.html#model-card-schema [2]: docs.aws.amazon.com/sagemaker/latest/dg/model-registry-details.html

Returns:



48294
48295
48296
48297
48298
48299
48300
48301
48302
48303
48304
48305
48306
48307
48308
# File 'lib/aws-sdk-sagemaker/types.rb', line 48294

class UpdateModelPackageInput < Struct.new(
  :model_package_arn,
  :model_approval_status,
  :approval_description,
  :customer_metadata_properties,
  :customer_metadata_properties_to_remove,
  :additional_inference_specifications_to_add,
  :inference_specification,
  :source_uri,
  :model_card,
  :model_life_cycle,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#model_life_cycleTypes::ModelLifeCycle

A structure describing the current state of the model in its life cycle.

Returns:



48294
48295
48296
48297
48298
48299
48300
48301
48302
48303
48304
48305
48306
48307
48308
# File 'lib/aws-sdk-sagemaker/types.rb', line 48294

class UpdateModelPackageInput < Struct.new(
  :model_package_arn,
  :model_approval_status,
  :approval_description,
  :customer_metadata_properties,
  :customer_metadata_properties_to_remove,
  :additional_inference_specifications_to_add,
  :inference_specification,
  :source_uri,
  :model_card,
  :model_life_cycle,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#model_package_arnString

The Amazon Resource Name (ARN) of the model package.

Returns:



48294
48295
48296
48297
48298
48299
48300
48301
48302
48303
48304
48305
48306
48307
48308
# File 'lib/aws-sdk-sagemaker/types.rb', line 48294

class UpdateModelPackageInput < Struct.new(
  :model_package_arn,
  :model_approval_status,
  :approval_description,
  :customer_metadata_properties,
  :customer_metadata_properties_to_remove,
  :additional_inference_specifications_to_add,
  :inference_specification,
  :source_uri,
  :model_card,
  :model_life_cycle,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#source_uriString

The URI of the source for the model package.

Returns:



48294
48295
48296
48297
48298
48299
48300
48301
48302
48303
48304
48305
48306
48307
48308
# File 'lib/aws-sdk-sagemaker/types.rb', line 48294

class UpdateModelPackageInput < Struct.new(
  :model_package_arn,
  :model_approval_status,
  :approval_description,
  :customer_metadata_properties,
  :customer_metadata_properties_to_remove,
  :additional_inference_specifications_to_add,
  :inference_specification,
  :source_uri,
  :model_card,
  :model_life_cycle,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end