Class: Aws::SageMaker::Types::UpdateModelPackageInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::UpdateModelPackageInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_inference_specifications_to_add ⇒ Array<Types::AdditionalInferenceSpecificationDefinition>
An array of additional Inference Specification objects to be added to the existing array additional Inference Specification.
-
#approval_description ⇒ String
A description for the approval status of the model.
-
#customer_metadata_properties ⇒ Hash<String,String>
The metadata properties associated with the model package versions.
-
#customer_metadata_properties_to_remove ⇒ Array<String>
The metadata properties associated with the model package versions to remove.
-
#model_approval_status ⇒ String
The approval status of the model.
-
#model_package_arn ⇒ String
The Amazon Resource Name (ARN) of the model package.
Instance Attribute Details
#additional_inference_specifications_to_add ⇒ Array<Types::AdditionalInferenceSpecificationDefinition>
An array of additional Inference Specification objects to be added to the existing array additional Inference Specification. Total number of additional Inference Specifications can not exceed 15. Each additional Inference Specification specifies artifacts based on this model package that can be used on inference endpoints. Generally used with SageMaker Neo to store the compiled artifacts.
38071 38072 38073 38074 38075 38076 38077 38078 38079 38080 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 38071 class UpdateModelPackageInput < Struct.new( :model_package_arn, :model_approval_status, :approval_description, :customer_metadata_properties, :customer_metadata_properties_to_remove, :additional_inference_specifications_to_add) SENSITIVE = [] include Aws::Structure end |
#approval_description ⇒ String
A description for the approval status of the model.
38071 38072 38073 38074 38075 38076 38077 38078 38079 38080 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 38071 class UpdateModelPackageInput < Struct.new( :model_package_arn, :model_approval_status, :approval_description, :customer_metadata_properties, :customer_metadata_properties_to_remove, :additional_inference_specifications_to_add) SENSITIVE = [] include Aws::Structure end |
#customer_metadata_properties ⇒ Hash<String,String>
The metadata properties associated with the model package versions.
38071 38072 38073 38074 38075 38076 38077 38078 38079 38080 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 38071 class UpdateModelPackageInput < Struct.new( :model_package_arn, :model_approval_status, :approval_description, :customer_metadata_properties, :customer_metadata_properties_to_remove, :additional_inference_specifications_to_add) SENSITIVE = [] include Aws::Structure end |
#customer_metadata_properties_to_remove ⇒ Array<String>
The metadata properties associated with the model package versions to remove.
38071 38072 38073 38074 38075 38076 38077 38078 38079 38080 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 38071 class UpdateModelPackageInput < Struct.new( :model_package_arn, :model_approval_status, :approval_description, :customer_metadata_properties, :customer_metadata_properties_to_remove, :additional_inference_specifications_to_add) SENSITIVE = [] include Aws::Structure end |
#model_approval_status ⇒ String
The approval status of the model.
38071 38072 38073 38074 38075 38076 38077 38078 38079 38080 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 38071 class UpdateModelPackageInput < Struct.new( :model_package_arn, :model_approval_status, :approval_description, :customer_metadata_properties, :customer_metadata_properties_to_remove, :additional_inference_specifications_to_add) SENSITIVE = [] include Aws::Structure end |
#model_package_arn ⇒ String
The Amazon Resource Name (ARN) of the model package.
38071 38072 38073 38074 38075 38076 38077 38078 38079 38080 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 38071 class UpdateModelPackageInput < Struct.new( :model_package_arn, :model_approval_status, :approval_description, :customer_metadata_properties, :customer_metadata_properties_to_remove, :additional_inference_specifications_to_add) SENSITIVE = [] include Aws::Structure end |