Class: Aws::SageMaker::Types::UpdatePartnerAppRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#app_versionString

The semantic version to upgrade the SageMaker Partner AI App to. Must be the same semantic version returned in the AvailableUpgrade field from DescribePartnerApp. Version skipping and downgrades are not supported.

Returns:

  • (String)


58367
58368
58369
58370
58371
58372
58373
58374
58375
58376
58377
58378
58379
58380
58381
# File 'lib/aws-sdk-sagemaker/types.rb', line 58367

class UpdatePartnerAppRequest < Struct.new(
  :arn,
  :maintenance_config,
  :tier,
  :application_config,
  :idc_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :enable_auto_minor_version_upgrade,
  :app_version,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#application_configTypes::PartnerAppConfig

Configuration settings for the SageMaker Partner AI App.



58367
58368
58369
58370
58371
58372
58373
58374
58375
58376
58377
58378
58379
58380
58381
# File 'lib/aws-sdk-sagemaker/types.rb', line 58367

class UpdatePartnerAppRequest < Struct.new(
  :arn,
  :maintenance_config,
  :tier,
  :application_config,
  :idc_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :enable_auto_minor_version_upgrade,
  :app_version,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The ARN of the SageMaker Partner AI App to update.

Returns:

  • (String)


58367
58368
58369
58370
58371
58372
58373
58374
58375
58376
58377
58378
58379
58380
58381
# File 'lib/aws-sdk-sagemaker/types.rb', line 58367

class UpdatePartnerAppRequest < Struct.new(
  :arn,
  :maintenance_config,
  :tier,
  :application_config,
  :idc_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :enable_auto_minor_version_upgrade,
  :app_version,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#auth_typeString

The authorization type that users use to access the SageMaker Partner AI App. Use this parameter to migrate an existing SageMaker Partner AI App from IAM authorization to IDC authorization. Valid values:

  • IAM: Users access the SageMaker Partner AI App with their Amazon Web Services IAM identity.

  • IDC: Users access the SageMaker Partner AI App with their Amazon Web Services IAM Identity Center identity. Specify the Identity Center instance to use in IdcConfig.

Returns:

  • (String)


58367
58368
58369
58370
58371
58372
58373
58374
58375
58376
58377
58378
58379
58380
58381
# File 'lib/aws-sdk-sagemaker/types.rb', line 58367

class UpdatePartnerAppRequest < Struct.new(
  :arn,
  :maintenance_config,
  :tier,
  :application_config,
  :idc_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :enable_auto_minor_version_upgrade,
  :app_version,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique token that guarantees that the call to this API is idempotent.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


58367
58368
58369
58370
58371
58372
58373
58374
58375
58376
58377
58378
58379
58380
58381
# File 'lib/aws-sdk-sagemaker/types.rb', line 58367

class UpdatePartnerAppRequest < Struct.new(
  :arn,
  :maintenance_config,
  :tier,
  :application_config,
  :idc_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :enable_auto_minor_version_upgrade,
  :app_version,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#enable_auto_minor_version_upgradeBoolean

When set to TRUE, the SageMaker Partner AI App is automatically upgraded to the latest minor version during the next scheduled maintenance window, if one is available.

Returns:

  • (Boolean)


58367
58368
58369
58370
58371
58372
58373
58374
58375
58376
58377
58378
58379
58380
58381
# File 'lib/aws-sdk-sagemaker/types.rb', line 58367

class UpdatePartnerAppRequest < Struct.new(
  :arn,
  :maintenance_config,
  :tier,
  :application_config,
  :idc_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :enable_auto_minor_version_upgrade,
  :app_version,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#enable_iam_session_based_identityBoolean

When set to TRUE, the SageMaker Partner AI App sets the Amazon Web Services IAM session name or the authenticated IAM user as the identity of the SageMaker Partner AI App user.

Returns:

  • (Boolean)


58367
58368
58369
58370
58371
58372
58373
58374
58375
58376
58377
58378
58379
58380
58381
# File 'lib/aws-sdk-sagemaker/types.rb', line 58367

class UpdatePartnerAppRequest < Struct.new(
  :arn,
  :maintenance_config,
  :tier,
  :application_config,
  :idc_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :enable_auto_minor_version_upgrade,
  :app_version,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#idc_configTypes::IdcConfigInput

Specifies the Amazon Web Services IAM Identity Center configuration for the SageMaker Partner AI App. Specify this parameter when AuthType is IDC. Apps that use IAM authorization don't use this parameter.



58367
58368
58369
58370
58371
58372
58373
58374
58375
58376
58377
58378
58379
58380
58381
# File 'lib/aws-sdk-sagemaker/types.rb', line 58367

class UpdatePartnerAppRequest < Struct.new(
  :arn,
  :maintenance_config,
  :tier,
  :application_config,
  :idc_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :enable_auto_minor_version_upgrade,
  :app_version,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#maintenance_configTypes::PartnerAppMaintenanceConfig

Maintenance configuration settings for the SageMaker Partner AI App.



58367
58368
58369
58370
58371
58372
58373
58374
58375
58376
58377
58378
58379
58380
58381
# File 'lib/aws-sdk-sagemaker/types.rb', line 58367

class UpdatePartnerAppRequest < Struct.new(
  :arn,
  :maintenance_config,
  :tier,
  :application_config,
  :idc_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :enable_auto_minor_version_upgrade,
  :app_version,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Each tag consists of a key and an optional value. Tag keys must be unique per resource.

Returns:



58367
58368
58369
58370
58371
58372
58373
58374
58375
58376
58377
58378
58379
58380
58381
# File 'lib/aws-sdk-sagemaker/types.rb', line 58367

class UpdatePartnerAppRequest < Struct.new(
  :arn,
  :maintenance_config,
  :tier,
  :application_config,
  :idc_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :enable_auto_minor_version_upgrade,
  :app_version,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tierString

Indicates the instance type and size of the cluster attached to the SageMaker Partner AI App.

Returns:

  • (String)


58367
58368
58369
58370
58371
58372
58373
58374
58375
58376
58377
58378
58379
58380
58381
# File 'lib/aws-sdk-sagemaker/types.rb', line 58367

class UpdatePartnerAppRequest < Struct.new(
  :arn,
  :maintenance_config,
  :tier,
  :application_config,
  :idc_config,
  :auth_type,
  :enable_iam_session_based_identity,
  :enable_auto_minor_version_upgrade,
  :app_version,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end