Class: Aws::SageMaker::Types::UpdatePartnerAppRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::UpdatePartnerAppRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#app_version ⇒ String
The semantic version to upgrade the SageMaker Partner AI App to.
-
#application_config ⇒ Types::PartnerAppConfig
Configuration settings for the SageMaker Partner AI App.
-
#arn ⇒ String
The ARN of the SageMaker Partner AI App to update.
-
#client_token ⇒ String
A unique token that guarantees that the call to this API is idempotent.
-
#enable_auto_minor_version_upgrade ⇒ Boolean
When set to ‘TRUE`, the SageMaker Partner AI App is automatically upgraded to the latest minor version during the next scheduled maintenance window, if one is available.
-
#enable_iam_session_based_identity ⇒ Boolean
When set to ‘TRUE`, the SageMaker Partner AI App sets the Amazon Web Services IAM session name or the authenticated IAM user as the identity of the SageMaker Partner AI App user.
-
#maintenance_config ⇒ Types::PartnerAppMaintenanceConfig
Maintenance configuration settings for the SageMaker Partner AI App.
-
#tags ⇒ Array<Types::Tag>
Each tag consists of a key and an optional value.
-
#tier ⇒ String
Indicates the instance type and size of the cluster attached to the SageMaker Partner AI App.
Instance Attribute Details
#app_version ⇒ String
The semantic version to upgrade the SageMaker Partner AI App to. Must be the same semantic version returned in the ‘AvailableUpgrade` field from `DescribePartnerApp`. Version skipping and downgrades are not supported.
57724 57725 57726 57727 57728 57729 57730 57731 57732 57733 57734 57735 57736 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 57724 class UpdatePartnerAppRequest < Struct.new( :arn, :maintenance_config, :tier, :application_config, :enable_iam_session_based_identity, :enable_auto_minor_version_upgrade, :app_version, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#application_config ⇒ Types::PartnerAppConfig
Configuration settings for the SageMaker Partner AI App.
57724 57725 57726 57727 57728 57729 57730 57731 57732 57733 57734 57735 57736 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 57724 class UpdatePartnerAppRequest < Struct.new( :arn, :maintenance_config, :tier, :application_config, :enable_iam_session_based_identity, :enable_auto_minor_version_upgrade, :app_version, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The ARN of the SageMaker Partner AI App to update.
57724 57725 57726 57727 57728 57729 57730 57731 57732 57733 57734 57735 57736 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 57724 class UpdatePartnerAppRequest < Struct.new( :arn, :maintenance_config, :tier, :application_config, :enable_iam_session_based_identity, :enable_auto_minor_version_upgrade, :app_version, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique token that guarantees that the call to this API is idempotent.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
57724 57725 57726 57727 57728 57729 57730 57731 57732 57733 57734 57735 57736 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 57724 class UpdatePartnerAppRequest < Struct.new( :arn, :maintenance_config, :tier, :application_config, :enable_iam_session_based_identity, :enable_auto_minor_version_upgrade, :app_version, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#enable_auto_minor_version_upgrade ⇒ Boolean
When set to ‘TRUE`, the SageMaker Partner AI App is automatically upgraded to the latest minor version during the next scheduled maintenance window, if one is available.
57724 57725 57726 57727 57728 57729 57730 57731 57732 57733 57734 57735 57736 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 57724 class UpdatePartnerAppRequest < Struct.new( :arn, :maintenance_config, :tier, :application_config, :enable_iam_session_based_identity, :enable_auto_minor_version_upgrade, :app_version, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#enable_iam_session_based_identity ⇒ Boolean
When set to ‘TRUE`, the SageMaker Partner AI App sets the Amazon Web Services IAM session name or the authenticated IAM user as the identity of the SageMaker Partner AI App user.
57724 57725 57726 57727 57728 57729 57730 57731 57732 57733 57734 57735 57736 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 57724 class UpdatePartnerAppRequest < Struct.new( :arn, :maintenance_config, :tier, :application_config, :enable_iam_session_based_identity, :enable_auto_minor_version_upgrade, :app_version, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#maintenance_config ⇒ Types::PartnerAppMaintenanceConfig
Maintenance configuration settings for the SageMaker Partner AI App.
57724 57725 57726 57727 57728 57729 57730 57731 57732 57733 57734 57735 57736 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 57724 class UpdatePartnerAppRequest < Struct.new( :arn, :maintenance_config, :tier, :application_config, :enable_iam_session_based_identity, :enable_auto_minor_version_upgrade, :app_version, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Each tag consists of a key and an optional value. Tag keys must be unique per resource.
57724 57725 57726 57727 57728 57729 57730 57731 57732 57733 57734 57735 57736 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 57724 class UpdatePartnerAppRequest < Struct.new( :arn, :maintenance_config, :tier, :application_config, :enable_iam_session_based_identity, :enable_auto_minor_version_upgrade, :app_version, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#tier ⇒ String
Indicates the instance type and size of the cluster attached to the SageMaker Partner AI App.
57724 57725 57726 57727 57728 57729 57730 57731 57732 57733 57734 57735 57736 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 57724 class UpdatePartnerAppRequest < Struct.new( :arn, :maintenance_config, :tier, :application_config, :enable_iam_session_based_identity, :enable_auto_minor_version_upgrade, :app_version, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |