Class: Aws::SageMaker::Types::UpdatePartnerAppRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_configTypes::PartnerAppConfig

Configuration settings for the SageMaker Partner AI App.



48620
48621
48622
48623
48624
48625
48626
48627
48628
48629
48630
# File 'lib/aws-sdk-sagemaker/types.rb', line 48620

class UpdatePartnerAppRequest < Struct.new(
  :arn,
  :maintenance_config,
  :tier,
  :application_config,
  :enable_iam_session_based_identity,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The ARN of the SageMaker Partner AI App to update.

Returns:

  • (String)


48620
48621
48622
48623
48624
48625
48626
48627
48628
48629
48630
# File 'lib/aws-sdk-sagemaker/types.rb', line 48620

class UpdatePartnerAppRequest < Struct.new(
  :arn,
  :maintenance_config,
  :tier,
  :application_config,
  :enable_iam_session_based_identity,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique token that guarantees that the call to this API is idempotent.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


48620
48621
48622
48623
48624
48625
48626
48627
48628
48629
48630
# File 'lib/aws-sdk-sagemaker/types.rb', line 48620

class UpdatePartnerAppRequest < Struct.new(
  :arn,
  :maintenance_config,
  :tier,
  :application_config,
  :enable_iam_session_based_identity,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#enable_iam_session_based_identityBoolean

When set to TRUE, the SageMaker Partner AI App sets the Amazon Web Services IAM session name or the authenticated IAM user as the identity of the SageMaker Partner AI App user.

Returns:

  • (Boolean)


48620
48621
48622
48623
48624
48625
48626
48627
48628
48629
48630
# File 'lib/aws-sdk-sagemaker/types.rb', line 48620

class UpdatePartnerAppRequest < Struct.new(
  :arn,
  :maintenance_config,
  :tier,
  :application_config,
  :enable_iam_session_based_identity,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#maintenance_configTypes::PartnerAppMaintenanceConfig

Maintenance configuration settings for the SageMaker Partner AI App.



48620
48621
48622
48623
48624
48625
48626
48627
48628
48629
48630
# File 'lib/aws-sdk-sagemaker/types.rb', line 48620

class UpdatePartnerAppRequest < Struct.new(
  :arn,
  :maintenance_config,
  :tier,
  :application_config,
  :enable_iam_session_based_identity,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Each tag consists of a key and an optional value. Tag keys must be unique per resource.

Returns:



48620
48621
48622
48623
48624
48625
48626
48627
48628
48629
48630
# File 'lib/aws-sdk-sagemaker/types.rb', line 48620

class UpdatePartnerAppRequest < Struct.new(
  :arn,
  :maintenance_config,
  :tier,
  :application_config,
  :enable_iam_session_based_identity,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tierString

Indicates the instance type and size of the cluster attached to the SageMaker Partner AI App.

Returns:

  • (String)


48620
48621
48622
48623
48624
48625
48626
48627
48628
48629
48630
# File 'lib/aws-sdk-sagemaker/types.rb', line 48620

class UpdatePartnerAppRequest < Struct.new(
  :arn,
  :maintenance_config,
  :tier,
  :application_config,
  :enable_iam_session_based_identity,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end