Class: Aws::SageMaker::Types::UpdatePipelineRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#parallelism_configurationTypes::ParallelismConfiguration

If specified, it applies to all executions of this pipeline by default.



57823
57824
57825
57826
57827
57828
57829
57830
57831
57832
57833
# File 'lib/aws-sdk-sagemaker/types.rb', line 57823

class UpdatePipelineRequest < Struct.new(
  :pipeline_name,
  :pipeline_display_name,
  :pipeline_definition,
  :pipeline_definition_s3_location,
  :pipeline_description,
  :role_arn,
  :parallelism_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#pipeline_definitionString

The JSON pipeline definition.

Returns:

  • (String)


57823
57824
57825
57826
57827
57828
57829
57830
57831
57832
57833
# File 'lib/aws-sdk-sagemaker/types.rb', line 57823

class UpdatePipelineRequest < Struct.new(
  :pipeline_name,
  :pipeline_display_name,
  :pipeline_definition,
  :pipeline_definition_s3_location,
  :pipeline_description,
  :role_arn,
  :parallelism_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#pipeline_definition_s3_locationTypes::PipelineDefinitionS3Location

The location of the pipeline definition stored in Amazon S3. If specified, SageMaker will retrieve the pipeline definition from this location.



57823
57824
57825
57826
57827
57828
57829
57830
57831
57832
57833
# File 'lib/aws-sdk-sagemaker/types.rb', line 57823

class UpdatePipelineRequest < Struct.new(
  :pipeline_name,
  :pipeline_display_name,
  :pipeline_definition,
  :pipeline_definition_s3_location,
  :pipeline_description,
  :role_arn,
  :parallelism_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#pipeline_descriptionString

The description of the pipeline.

Returns:

  • (String)


57823
57824
57825
57826
57827
57828
57829
57830
57831
57832
57833
# File 'lib/aws-sdk-sagemaker/types.rb', line 57823

class UpdatePipelineRequest < Struct.new(
  :pipeline_name,
  :pipeline_display_name,
  :pipeline_definition,
  :pipeline_definition_s3_location,
  :pipeline_description,
  :role_arn,
  :parallelism_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#pipeline_display_nameString

The display name of the pipeline.

Returns:

  • (String)


57823
57824
57825
57826
57827
57828
57829
57830
57831
57832
57833
# File 'lib/aws-sdk-sagemaker/types.rb', line 57823

class UpdatePipelineRequest < Struct.new(
  :pipeline_name,
  :pipeline_display_name,
  :pipeline_definition,
  :pipeline_definition_s3_location,
  :pipeline_description,
  :role_arn,
  :parallelism_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#pipeline_nameString

The name of the pipeline to update.

Returns:

  • (String)


57823
57824
57825
57826
57827
57828
57829
57830
57831
57832
57833
# File 'lib/aws-sdk-sagemaker/types.rb', line 57823

class UpdatePipelineRequest < Struct.new(
  :pipeline_name,
  :pipeline_display_name,
  :pipeline_definition,
  :pipeline_definition_s3_location,
  :pipeline_description,
  :role_arn,
  :parallelism_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) that the pipeline uses to execute.

Returns:

  • (String)


57823
57824
57825
57826
57827
57828
57829
57830
57831
57832
57833
# File 'lib/aws-sdk-sagemaker/types.rb', line 57823

class UpdatePipelineRequest < Struct.new(
  :pipeline_name,
  :pipeline_display_name,
  :pipeline_definition,
  :pipeline_definition_s3_location,
  :pipeline_description,
  :role_arn,
  :parallelism_configuration)
  SENSITIVE = []
  include Aws::Structure
end