Class: Aws::SageMaker::Types::UpdatePipelineRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::UpdatePipelineRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#parallelism_configuration ⇒ Types::ParallelismConfiguration
If specified, it applies to all executions of this pipeline by default.
-
#pipeline_definition ⇒ String
The JSON pipeline definition.
-
#pipeline_definition_s3_location ⇒ Types::PipelineDefinitionS3Location
The location of the pipeline definition stored in Amazon S3.
-
#pipeline_description ⇒ String
The description of the pipeline.
-
#pipeline_display_name ⇒ String
The display name of the pipeline.
-
#pipeline_name ⇒ String
The name of the pipeline to update.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) that the pipeline uses to execute.
Instance Attribute Details
#parallelism_configuration ⇒ Types::ParallelismConfiguration
If specified, it applies to all executions of this pipeline by default.
57102 57103 57104 57105 57106 57107 57108 57109 57110 57111 57112 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 57102 class UpdatePipelineRequest < Struct.new( :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_definition_s3_location, :pipeline_description, :role_arn, :parallelism_configuration) SENSITIVE = [] include Aws::Structure end |
#pipeline_definition ⇒ String
The JSON pipeline definition.
57102 57103 57104 57105 57106 57107 57108 57109 57110 57111 57112 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 57102 class UpdatePipelineRequest < Struct.new( :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_definition_s3_location, :pipeline_description, :role_arn, :parallelism_configuration) SENSITIVE = [] include Aws::Structure end |
#pipeline_definition_s3_location ⇒ Types::PipelineDefinitionS3Location
The location of the pipeline definition stored in Amazon S3. If specified, SageMaker will retrieve the pipeline definition from this location.
57102 57103 57104 57105 57106 57107 57108 57109 57110 57111 57112 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 57102 class UpdatePipelineRequest < Struct.new( :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_definition_s3_location, :pipeline_description, :role_arn, :parallelism_configuration) SENSITIVE = [] include Aws::Structure end |
#pipeline_description ⇒ String
The description of the pipeline.
57102 57103 57104 57105 57106 57107 57108 57109 57110 57111 57112 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 57102 class UpdatePipelineRequest < Struct.new( :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_definition_s3_location, :pipeline_description, :role_arn, :parallelism_configuration) SENSITIVE = [] include Aws::Structure end |
#pipeline_display_name ⇒ String
The display name of the pipeline.
57102 57103 57104 57105 57106 57107 57108 57109 57110 57111 57112 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 57102 class UpdatePipelineRequest < Struct.new( :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_definition_s3_location, :pipeline_description, :role_arn, :parallelism_configuration) SENSITIVE = [] include Aws::Structure end |
#pipeline_name ⇒ String
The name of the pipeline to update.
57102 57103 57104 57105 57106 57107 57108 57109 57110 57111 57112 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 57102 class UpdatePipelineRequest < Struct.new( :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_definition_s3_location, :pipeline_description, :role_arn, :parallelism_configuration) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) that the pipeline uses to execute.
57102 57103 57104 57105 57106 57107 57108 57109 57110 57111 57112 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 57102 class UpdatePipelineRequest < Struct.new( :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_definition_s3_location, :pipeline_description, :role_arn, :parallelism_configuration) SENSITIVE = [] include Aws::Structure end |