Class: Aws::SageMaker::Types::UpdatePipelineRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::UpdatePipelineRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#parallelism_configuration ⇒ Types::ParallelismConfiguration
If specified, it applies to all executions of this pipeline by default.
-
#pipeline_definition ⇒ String
The JSON pipeline definition.
-
#pipeline_definition_s3_location ⇒ Types::PipelineDefinitionS3Location
The location of the pipeline definition stored in Amazon S3.
-
#pipeline_description ⇒ String
The description of the pipeline.
-
#pipeline_display_name ⇒ String
The display name of the pipeline.
-
#pipeline_name ⇒ String
The name of the pipeline to update.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) that the pipeline uses to execute.
Instance Attribute Details
#parallelism_configuration ⇒ Types::ParallelismConfiguration
If specified, it applies to all executions of this pipeline by default.
56991 56992 56993 56994 56995 56996 56997 56998 56999 57000 57001 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 56991 class UpdatePipelineRequest < Struct.new( :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_definition_s3_location, :pipeline_description, :role_arn, :parallelism_configuration) SENSITIVE = [] include Aws::Structure end |
#pipeline_definition ⇒ String
The JSON pipeline definition.
56991 56992 56993 56994 56995 56996 56997 56998 56999 57000 57001 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 56991 class UpdatePipelineRequest < Struct.new( :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_definition_s3_location, :pipeline_description, :role_arn, :parallelism_configuration) SENSITIVE = [] include Aws::Structure end |
#pipeline_definition_s3_location ⇒ Types::PipelineDefinitionS3Location
The location of the pipeline definition stored in Amazon S3. If specified, SageMaker will retrieve the pipeline definition from this location.
56991 56992 56993 56994 56995 56996 56997 56998 56999 57000 57001 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 56991 class UpdatePipelineRequest < Struct.new( :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_definition_s3_location, :pipeline_description, :role_arn, :parallelism_configuration) SENSITIVE = [] include Aws::Structure end |
#pipeline_description ⇒ String
The description of the pipeline.
56991 56992 56993 56994 56995 56996 56997 56998 56999 57000 57001 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 56991 class UpdatePipelineRequest < Struct.new( :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_definition_s3_location, :pipeline_description, :role_arn, :parallelism_configuration) SENSITIVE = [] include Aws::Structure end |
#pipeline_display_name ⇒ String
The display name of the pipeline.
56991 56992 56993 56994 56995 56996 56997 56998 56999 57000 57001 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 56991 class UpdatePipelineRequest < Struct.new( :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_definition_s3_location, :pipeline_description, :role_arn, :parallelism_configuration) SENSITIVE = [] include Aws::Structure end |
#pipeline_name ⇒ String
The name of the pipeline to update.
56991 56992 56993 56994 56995 56996 56997 56998 56999 57000 57001 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 56991 class UpdatePipelineRequest < Struct.new( :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_definition_s3_location, :pipeline_description, :role_arn, :parallelism_configuration) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) that the pipeline uses to execute.
56991 56992 56993 56994 56995 56996 56997 56998 56999 57000 57001 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 56991 class UpdatePipelineRequest < Struct.new( :pipeline_name, :pipeline_display_name, :pipeline_definition, :pipeline_definition_s3_location, :pipeline_description, :role_arn, :parallelism_configuration) SENSITIVE = [] include Aws::Structure end |