Class: Aws::SageMaker::Types::UpdateTrainingJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::UpdateTrainingJobRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#profiler_config ⇒ Types::ProfilerConfigForUpdate
Configuration information for Amazon SageMaker Debugger system monitoring, framework profiling, and storage paths.
-
#profiler_rule_configurations ⇒ Array<Types::ProfilerRuleConfiguration>
Configuration information for Amazon SageMaker Debugger rules for profiling system and framework metrics.
-
#remote_debug_config ⇒ Types::RemoteDebugConfigForUpdate
Configuration for remote debugging while the training job is running.
-
#resource_config ⇒ Types::ResourceConfigForUpdate
The training job
ResourceConfigto update warm pool retention length. -
#training_job_name ⇒ String
The name of a training job to update the Debugger profiling configuration.
Instance Attribute Details
#profiler_config ⇒ Types::ProfilerConfigForUpdate
Configuration information for Amazon SageMaker Debugger system monitoring, framework profiling, and storage paths.
48905 48906 48907 48908 48909 48910 48911 48912 48913 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 48905 class UpdateTrainingJobRequest < Struct.new( :training_job_name, :profiler_config, :profiler_rule_configurations, :resource_config, :remote_debug_config) SENSITIVE = [] include Aws::Structure end |
#profiler_rule_configurations ⇒ Array<Types::ProfilerRuleConfiguration>
Configuration information for Amazon SageMaker Debugger rules for profiling system and framework metrics.
48905 48906 48907 48908 48909 48910 48911 48912 48913 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 48905 class UpdateTrainingJobRequest < Struct.new( :training_job_name, :profiler_config, :profiler_rule_configurations, :resource_config, :remote_debug_config) SENSITIVE = [] include Aws::Structure end |
#remote_debug_config ⇒ Types::RemoteDebugConfigForUpdate
Configuration for remote debugging while the training job is running. You can update the remote debugging configuration when the SecondaryStatus of the job is Downloading or Training.To learn more about the remote debugging functionality of SageMaker, see [Access a training container through Amazon Web Services Systems Manager (SSM) for remote debugging].
[1]: docs.aws.amazon.com/sagemaker/latest/dg/train-remote-debugging.html
48905 48906 48907 48908 48909 48910 48911 48912 48913 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 48905 class UpdateTrainingJobRequest < Struct.new( :training_job_name, :profiler_config, :profiler_rule_configurations, :resource_config, :remote_debug_config) SENSITIVE = [] include Aws::Structure end |
#resource_config ⇒ Types::ResourceConfigForUpdate
The training job ResourceConfig to update warm pool retention length.
48905 48906 48907 48908 48909 48910 48911 48912 48913 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 48905 class UpdateTrainingJobRequest < Struct.new( :training_job_name, :profiler_config, :profiler_rule_configurations, :resource_config, :remote_debug_config) SENSITIVE = [] include Aws::Structure end |
#training_job_name ⇒ String
The name of a training job to update the Debugger profiling configuration.
48905 48906 48907 48908 48909 48910 48911 48912 48913 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 48905 class UpdateTrainingJobRequest < Struct.new( :training_job_name, :profiler_config, :profiler_rule_configurations, :resource_config, :remote_debug_config) SENSITIVE = [] include Aws::Structure end |