Class: Aws::SageMaker::Types::UpdateTrainingJobRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#profiler_configTypes::ProfilerConfigForUpdate

Configuration information for Amazon SageMaker Debugger system monitoring, framework profiling, and storage paths.

Returns:



38566
38567
38568
38569
38570
38571
38572
38573
# File 'lib/aws-sdk-sagemaker/types.rb', line 38566

class UpdateTrainingJobRequest < Struct.new(
  :training_job_name,
  :profiler_config,
  :profiler_rule_configurations,
  :resource_config)
  SENSITIVE = []
  include Aws::Structure
end

#profiler_rule_configurationsArray<Types::ProfilerRuleConfiguration>

Configuration information for Amazon SageMaker Debugger rules for profiling system and framework metrics.

Returns:



38566
38567
38568
38569
38570
38571
38572
38573
# File 'lib/aws-sdk-sagemaker/types.rb', line 38566

class UpdateTrainingJobRequest < Struct.new(
  :training_job_name,
  :profiler_config,
  :profiler_rule_configurations,
  :resource_config)
  SENSITIVE = []
  include Aws::Structure
end

#resource_configTypes::ResourceConfigForUpdate

The training job ResourceConfig to update warm pool retention length.

Returns:



38566
38567
38568
38569
38570
38571
38572
38573
# File 'lib/aws-sdk-sagemaker/types.rb', line 38566

class UpdateTrainingJobRequest < Struct.new(
  :training_job_name,
  :profiler_config,
  :profiler_rule_configurations,
  :resource_config)
  SENSITIVE = []
  include Aws::Structure
end

#training_job_nameString

The name of a training job to update the Debugger profiling configuration.

Returns:



38566
38567
38568
38569
38570
38571
38572
38573
# File 'lib/aws-sdk-sagemaker/types.rb', line 38566

class UpdateTrainingJobRequest < Struct.new(
  :training_job_name,
  :profiler_config,
  :profiler_rule_configurations,
  :resource_config)
  SENSITIVE = []
  include Aws::Structure
end