Class: Aws::SageMaker::Types::UpdateTrainingJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::UpdateTrainingJobRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#profiler_config ⇒ Types::ProfilerConfigForUpdate
Configuration information for Amazon SageMaker Debugger system monitoring, framework profiling, and storage paths.
-
#profiler_rule_configurations ⇒ Array<Types::ProfilerRuleConfiguration>
Configuration information for Amazon SageMaker Debugger rules for profiling system and framework metrics.
-
#resource_config ⇒ Types::ResourceConfigForUpdate
The training job
ResourceConfigto update warm pool retention length. -
#training_job_name ⇒ String
The name of a training job to update the Debugger profiling configuration.
Instance Attribute Details
#profiler_config ⇒ Types::ProfilerConfigForUpdate
Configuration information for Amazon SageMaker Debugger system monitoring, framework profiling, and storage paths.
38566 38567 38568 38569 38570 38571 38572 38573 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 38566 class UpdateTrainingJobRequest < Struct.new( :training_job_name, :profiler_config, :profiler_rule_configurations, :resource_config) SENSITIVE = [] include Aws::Structure end |
#profiler_rule_configurations ⇒ Array<Types::ProfilerRuleConfiguration>
Configuration information for Amazon SageMaker Debugger rules for profiling system and framework metrics.
38566 38567 38568 38569 38570 38571 38572 38573 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 38566 class UpdateTrainingJobRequest < Struct.new( :training_job_name, :profiler_config, :profiler_rule_configurations, :resource_config) SENSITIVE = [] include Aws::Structure end |
#resource_config ⇒ Types::ResourceConfigForUpdate
The training job ResourceConfig to update warm pool retention length.
38566 38567 38568 38569 38570 38571 38572 38573 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 38566 class UpdateTrainingJobRequest < Struct.new( :training_job_name, :profiler_config, :profiler_rule_configurations, :resource_config) SENSITIVE = [] include Aws::Structure end |
#training_job_name ⇒ String
The name of a training job to update the Debugger profiling configuration.
38566 38567 38568 38569 38570 38571 38572 38573 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 38566 class UpdateTrainingJobRequest < Struct.new( :training_job_name, :profiler_config, :profiler_rule_configurations, :resource_config) SENSITIVE = [] include Aws::Structure end |