Class: Aws::SageMaker::Types::UpdateTrialComponentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::UpdateTrialComponentRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#display_name ⇒ String
The name of the component as displayed.
-
#end_time ⇒ Time
When the component ended.
-
#input_artifacts ⇒ Hash<String,Types::TrialComponentArtifact>
Replaces all of the component’s input artifacts with the specified artifacts or adds new input artifacts.
-
#input_artifacts_to_remove ⇒ Array<String>
The input artifacts to remove from the component.
-
#output_artifacts ⇒ Hash<String,Types::TrialComponentArtifact>
Replaces all of the component’s output artifacts with the specified artifacts or adds new output artifacts.
-
#output_artifacts_to_remove ⇒ Array<String>
The output artifacts to remove from the component.
-
#parameters ⇒ Hash<String,Types::TrialComponentParameterValue>
Replaces all of the component’s hyperparameters with the specified hyperparameters or add new hyperparameters.
-
#parameters_to_remove ⇒ Array<String>
The hyperparameters to remove from the component.
-
#start_time ⇒ Time
When the component started.
-
#status ⇒ Types::TrialComponentStatus
The new status of the component.
-
#trial_component_name ⇒ String
The name of the component to update.
Instance Attribute Details
#display_name ⇒ String
The name of the component as displayed. The name doesn’t need to be unique. If ‘DisplayName` isn’t specified, ‘TrialComponentName` is displayed.
58247 58248 58249 58250 58251 58252 58253 58254 58255 58256 58257 58258 58259 58260 58261 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 58247 class UpdateTrialComponentRequest < Struct.new( :trial_component_name, :display_name, :status, :start_time, :end_time, :parameters, :parameters_to_remove, :input_artifacts, :input_artifacts_to_remove, :output_artifacts, :output_artifacts_to_remove) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
When the component ended.
58247 58248 58249 58250 58251 58252 58253 58254 58255 58256 58257 58258 58259 58260 58261 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 58247 class UpdateTrialComponentRequest < Struct.new( :trial_component_name, :display_name, :status, :start_time, :end_time, :parameters, :parameters_to_remove, :input_artifacts, :input_artifacts_to_remove, :output_artifacts, :output_artifacts_to_remove) SENSITIVE = [] include Aws::Structure end |
#input_artifacts ⇒ Hash<String,Types::TrialComponentArtifact>
Replaces all of the component’s input artifacts with the specified artifacts or adds new input artifacts. Existing input artifacts are replaced if the trial component is updated with an identical input artifact key.
58247 58248 58249 58250 58251 58252 58253 58254 58255 58256 58257 58258 58259 58260 58261 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 58247 class UpdateTrialComponentRequest < Struct.new( :trial_component_name, :display_name, :status, :start_time, :end_time, :parameters, :parameters_to_remove, :input_artifacts, :input_artifacts_to_remove, :output_artifacts, :output_artifacts_to_remove) SENSITIVE = [] include Aws::Structure end |
#input_artifacts_to_remove ⇒ Array<String>
The input artifacts to remove from the component.
58247 58248 58249 58250 58251 58252 58253 58254 58255 58256 58257 58258 58259 58260 58261 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 58247 class UpdateTrialComponentRequest < Struct.new( :trial_component_name, :display_name, :status, :start_time, :end_time, :parameters, :parameters_to_remove, :input_artifacts, :input_artifacts_to_remove, :output_artifacts, :output_artifacts_to_remove) SENSITIVE = [] include Aws::Structure end |
#output_artifacts ⇒ Hash<String,Types::TrialComponentArtifact>
Replaces all of the component’s output artifacts with the specified artifacts or adds new output artifacts. Existing output artifacts are replaced if the trial component is updated with an identical output artifact key.
58247 58248 58249 58250 58251 58252 58253 58254 58255 58256 58257 58258 58259 58260 58261 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 58247 class UpdateTrialComponentRequest < Struct.new( :trial_component_name, :display_name, :status, :start_time, :end_time, :parameters, :parameters_to_remove, :input_artifacts, :input_artifacts_to_remove, :output_artifacts, :output_artifacts_to_remove) SENSITIVE = [] include Aws::Structure end |
#output_artifacts_to_remove ⇒ Array<String>
The output artifacts to remove from the component.
58247 58248 58249 58250 58251 58252 58253 58254 58255 58256 58257 58258 58259 58260 58261 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 58247 class UpdateTrialComponentRequest < Struct.new( :trial_component_name, :display_name, :status, :start_time, :end_time, :parameters, :parameters_to_remove, :input_artifacts, :input_artifacts_to_remove, :output_artifacts, :output_artifacts_to_remove) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Hash<String,Types::TrialComponentParameterValue>
Replaces all of the component’s hyperparameters with the specified hyperparameters or add new hyperparameters. Existing hyperparameters are replaced if the trial component is updated with an identical hyperparameter key.
58247 58248 58249 58250 58251 58252 58253 58254 58255 58256 58257 58258 58259 58260 58261 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 58247 class UpdateTrialComponentRequest < Struct.new( :trial_component_name, :display_name, :status, :start_time, :end_time, :parameters, :parameters_to_remove, :input_artifacts, :input_artifacts_to_remove, :output_artifacts, :output_artifacts_to_remove) SENSITIVE = [] include Aws::Structure end |
#parameters_to_remove ⇒ Array<String>
The hyperparameters to remove from the component.
58247 58248 58249 58250 58251 58252 58253 58254 58255 58256 58257 58258 58259 58260 58261 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 58247 class UpdateTrialComponentRequest < Struct.new( :trial_component_name, :display_name, :status, :start_time, :end_time, :parameters, :parameters_to_remove, :input_artifacts, :input_artifacts_to_remove, :output_artifacts, :output_artifacts_to_remove) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
When the component started.
58247 58248 58249 58250 58251 58252 58253 58254 58255 58256 58257 58258 58259 58260 58261 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 58247 class UpdateTrialComponentRequest < Struct.new( :trial_component_name, :display_name, :status, :start_time, :end_time, :parameters, :parameters_to_remove, :input_artifacts, :input_artifacts_to_remove, :output_artifacts, :output_artifacts_to_remove) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::TrialComponentStatus
The new status of the component.
58247 58248 58249 58250 58251 58252 58253 58254 58255 58256 58257 58258 58259 58260 58261 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 58247 class UpdateTrialComponentRequest < Struct.new( :trial_component_name, :display_name, :status, :start_time, :end_time, :parameters, :parameters_to_remove, :input_artifacts, :input_artifacts_to_remove, :output_artifacts, :output_artifacts_to_remove) SENSITIVE = [] include Aws::Structure end |
#trial_component_name ⇒ String
The name of the component to update.
58247 58248 58249 58250 58251 58252 58253 58254 58255 58256 58257 58258 58259 58260 58261 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 58247 class UpdateTrialComponentRequest < Struct.new( :trial_component_name, :display_name, :status, :start_time, :end_time, :parameters, :parameters_to_remove, :input_artifacts, :input_artifacts_to_remove, :output_artifacts, :output_artifacts_to_remove) SENSITIVE = [] include Aws::Structure end |