Class: Aws::SageMaker::Types::UpdateTrialComponentRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#display_nameString

The name of the component as displayed. The name doesn’t need to be unique. If DisplayName isn’t specified, TrialComponentName is displayed.

Returns:

  • (String)


54863
54864
54865
54866
54867
54868
54869
54870
54871
54872
54873
54874
54875
54876
54877
# File 'lib/aws-sdk-sagemaker/types.rb', line 54863

class UpdateTrialComponentRequest < Struct.new(
  :trial_component_name,
  :display_name,
  :status,
  :start_time,
  :end_time,
  :parameters,
  :parameters_to_remove,
  :input_artifacts,
  :input_artifacts_to_remove,
  :output_artifacts,
  :output_artifacts_to_remove)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

When the component ended.

Returns:

  • (Time)


54863
54864
54865
54866
54867
54868
54869
54870
54871
54872
54873
54874
54875
54876
54877
# File 'lib/aws-sdk-sagemaker/types.rb', line 54863

class UpdateTrialComponentRequest < Struct.new(
  :trial_component_name,
  :display_name,
  :status,
  :start_time,
  :end_time,
  :parameters,
  :parameters_to_remove,
  :input_artifacts,
  :input_artifacts_to_remove,
  :output_artifacts,
  :output_artifacts_to_remove)
  SENSITIVE = []
  include Aws::Structure
end

#input_artifactsHash<String,Types::TrialComponentArtifact>

Replaces all of the component’s input artifacts with the specified artifacts or adds new input artifacts. Existing input artifacts are replaced if the trial component is updated with an identical input artifact key.

Returns:



54863
54864
54865
54866
54867
54868
54869
54870
54871
54872
54873
54874
54875
54876
54877
# File 'lib/aws-sdk-sagemaker/types.rb', line 54863

class UpdateTrialComponentRequest < Struct.new(
  :trial_component_name,
  :display_name,
  :status,
  :start_time,
  :end_time,
  :parameters,
  :parameters_to_remove,
  :input_artifacts,
  :input_artifacts_to_remove,
  :output_artifacts,
  :output_artifacts_to_remove)
  SENSITIVE = []
  include Aws::Structure
end

#input_artifacts_to_removeArray<String>

The input artifacts to remove from the component.

Returns:

  • (Array<String>)


54863
54864
54865
54866
54867
54868
54869
54870
54871
54872
54873
54874
54875
54876
54877
# File 'lib/aws-sdk-sagemaker/types.rb', line 54863

class UpdateTrialComponentRequest < Struct.new(
  :trial_component_name,
  :display_name,
  :status,
  :start_time,
  :end_time,
  :parameters,
  :parameters_to_remove,
  :input_artifacts,
  :input_artifacts_to_remove,
  :output_artifacts,
  :output_artifacts_to_remove)
  SENSITIVE = []
  include Aws::Structure
end

#output_artifactsHash<String,Types::TrialComponentArtifact>

Replaces all of the component’s output artifacts with the specified artifacts or adds new output artifacts. Existing output artifacts are replaced if the trial component is updated with an identical output artifact key.

Returns:



54863
54864
54865
54866
54867
54868
54869
54870
54871
54872
54873
54874
54875
54876
54877
# File 'lib/aws-sdk-sagemaker/types.rb', line 54863

class UpdateTrialComponentRequest < Struct.new(
  :trial_component_name,
  :display_name,
  :status,
  :start_time,
  :end_time,
  :parameters,
  :parameters_to_remove,
  :input_artifacts,
  :input_artifacts_to_remove,
  :output_artifacts,
  :output_artifacts_to_remove)
  SENSITIVE = []
  include Aws::Structure
end

#output_artifacts_to_removeArray<String>

The output artifacts to remove from the component.

Returns:

  • (Array<String>)


54863
54864
54865
54866
54867
54868
54869
54870
54871
54872
54873
54874
54875
54876
54877
# File 'lib/aws-sdk-sagemaker/types.rb', line 54863

class UpdateTrialComponentRequest < Struct.new(
  :trial_component_name,
  :display_name,
  :status,
  :start_time,
  :end_time,
  :parameters,
  :parameters_to_remove,
  :input_artifacts,
  :input_artifacts_to_remove,
  :output_artifacts,
  :output_artifacts_to_remove)
  SENSITIVE = []
  include Aws::Structure
end

#parametersHash<String,Types::TrialComponentParameterValue>

Replaces all of the component’s hyperparameters with the specified hyperparameters or add new hyperparameters. Existing hyperparameters are replaced if the trial component is updated with an identical hyperparameter key.

Returns:



54863
54864
54865
54866
54867
54868
54869
54870
54871
54872
54873
54874
54875
54876
54877
# File 'lib/aws-sdk-sagemaker/types.rb', line 54863

class UpdateTrialComponentRequest < Struct.new(
  :trial_component_name,
  :display_name,
  :status,
  :start_time,
  :end_time,
  :parameters,
  :parameters_to_remove,
  :input_artifacts,
  :input_artifacts_to_remove,
  :output_artifacts,
  :output_artifacts_to_remove)
  SENSITIVE = []
  include Aws::Structure
end

#parameters_to_removeArray<String>

The hyperparameters to remove from the component.

Returns:

  • (Array<String>)


54863
54864
54865
54866
54867
54868
54869
54870
54871
54872
54873
54874
54875
54876
54877
# File 'lib/aws-sdk-sagemaker/types.rb', line 54863

class UpdateTrialComponentRequest < Struct.new(
  :trial_component_name,
  :display_name,
  :status,
  :start_time,
  :end_time,
  :parameters,
  :parameters_to_remove,
  :input_artifacts,
  :input_artifacts_to_remove,
  :output_artifacts,
  :output_artifacts_to_remove)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

When the component started.

Returns:

  • (Time)


54863
54864
54865
54866
54867
54868
54869
54870
54871
54872
54873
54874
54875
54876
54877
# File 'lib/aws-sdk-sagemaker/types.rb', line 54863

class UpdateTrialComponentRequest < Struct.new(
  :trial_component_name,
  :display_name,
  :status,
  :start_time,
  :end_time,
  :parameters,
  :parameters_to_remove,
  :input_artifacts,
  :input_artifacts_to_remove,
  :output_artifacts,
  :output_artifacts_to_remove)
  SENSITIVE = []
  include Aws::Structure
end

#statusTypes::TrialComponentStatus

The new status of the component.



54863
54864
54865
54866
54867
54868
54869
54870
54871
54872
54873
54874
54875
54876
54877
# File 'lib/aws-sdk-sagemaker/types.rb', line 54863

class UpdateTrialComponentRequest < Struct.new(
  :trial_component_name,
  :display_name,
  :status,
  :start_time,
  :end_time,
  :parameters,
  :parameters_to_remove,
  :input_artifacts,
  :input_artifacts_to_remove,
  :output_artifacts,
  :output_artifacts_to_remove)
  SENSITIVE = []
  include Aws::Structure
end

#trial_component_nameString

The name of the component to update.

Returns:

  • (String)


54863
54864
54865
54866
54867
54868
54869
54870
54871
54872
54873
54874
54875
54876
54877
# File 'lib/aws-sdk-sagemaker/types.rb', line 54863

class UpdateTrialComponentRequest < Struct.new(
  :trial_component_name,
  :display_name,
  :status,
  :start_time,
  :end_time,
  :parameters,
  :parameters_to_remove,
  :input_artifacts,
  :input_artifacts_to_remove,
  :output_artifacts,
  :output_artifacts_to_remove)
  SENSITIVE = []
  include Aws::Structure
end