Class: Aws::SageMaker::Types::UpdateWorkforceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::UpdateWorkforceRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ip_address_type ⇒ String
Use this parameter to specify whether you want
IPv4only ordualstack(IPv4andIPv6) to support your labeling workforce. -
#oidc_config ⇒ Types::OidcConfig
Use this parameter to update your OIDC Identity Provider (IdP) configuration for a workforce made using your own IdP.
-
#source_ip_config ⇒ Types::SourceIpConfig
A list of one to ten worker IP address ranges ([CIDRs][1]) that can be used to access tasks assigned to this workforce.
-
#workforce_name ⇒ String
The name of the private workforce that you want to update.
-
#workforce_vpc_config ⇒ Types::WorkforceVpcConfigRequest
Use this parameter to update your VPC configuration for a workforce.
Instance Attribute Details
#ip_address_type ⇒ String
Use this parameter to specify whether you want IPv4 only or
dualstack (IPv4 and IPv6) to support your labeling workforce.
59266 59267 59268 59269 59270 59271 59272 59273 59274 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 59266 class UpdateWorkforceRequest < Struct.new( :workforce_name, :source_ip_config, :oidc_config, :workforce_vpc_config, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#oidc_config ⇒ Types::OidcConfig
Use this parameter to update your OIDC Identity Provider (IdP) configuration for a workforce made using your own IdP.
59266 59267 59268 59269 59270 59271 59272 59273 59274 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 59266 class UpdateWorkforceRequest < Struct.new( :workforce_name, :source_ip_config, :oidc_config, :workforce_vpc_config, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#source_ip_config ⇒ Types::SourceIpConfig
A list of one to ten worker IP address ranges (CIDRs) that can be used to access tasks assigned to this workforce.
Maximum: Ten CIDR values
59266 59267 59268 59269 59270 59271 59272 59273 59274 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 59266 class UpdateWorkforceRequest < Struct.new( :workforce_name, :source_ip_config, :oidc_config, :workforce_vpc_config, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#workforce_name ⇒ String
The name of the private workforce that you want to update. You can find your workforce name by using the ListWorkforces operation.
59266 59267 59268 59269 59270 59271 59272 59273 59274 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 59266 class UpdateWorkforceRequest < Struct.new( :workforce_name, :source_ip_config, :oidc_config, :workforce_vpc_config, :ip_address_type) SENSITIVE = [] include Aws::Structure end |
#workforce_vpc_config ⇒ Types::WorkforceVpcConfigRequest
Use this parameter to update your VPC configuration for a workforce.
59266 59267 59268 59269 59270 59271 59272 59273 59274 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 59266 class UpdateWorkforceRequest < Struct.new( :workforce_name, :source_ip_config, :oidc_config, :workforce_vpc_config, :ip_address_type) SENSITIVE = [] include Aws::Structure end |