Class: Aws::SageMaker::Types::UpdateWorkforceResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::UpdateWorkforceResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#workforce ⇒ Types::Workforce
A single private workforce.
Instance Attribute Details
#workforce ⇒ Types::Workforce
A single private workforce. You can create one private work force in each Amazon Web Services Region. By default, any workforce-related API operation used in a specific region will apply to the workforce created in that region. To learn how to create a private workforce, see Create a Private Workforce.
59166 59167 59168 59169 59170 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 59166 class UpdateWorkforceResponse < Struct.new( :workforce) SENSITIVE = [] include Aws::Structure end |