Class: Aws::SageMaker::Types::UserContext

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Information about the user who created or modified a SageMaker resource.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#domain_idString

The domain associated with the user.

Returns:

  • (String)


59030
59031
59032
59033
59034
59035
59036
59037
# File 'lib/aws-sdk-sagemaker/types.rb', line 59030

class UserContext < Struct.new(
  :user_profile_arn,
  :user_profile_name,
  :domain_id,
  :iam_identity)
  SENSITIVE = []
  include Aws::Structure
end

#iam_identityTypes::IamIdentity

The IAM Identity details associated with the user. These details are associated with model package groups, model packages, and project entities only.

Returns:



59030
59031
59032
59033
59034
59035
59036
59037
# File 'lib/aws-sdk-sagemaker/types.rb', line 59030

class UserContext < Struct.new(
  :user_profile_arn,
  :user_profile_name,
  :domain_id,
  :iam_identity)
  SENSITIVE = []
  include Aws::Structure
end

#user_profile_arnString

The Amazon Resource Name (ARN) of the user's profile.

Returns:

  • (String)


59030
59031
59032
59033
59034
59035
59036
59037
# File 'lib/aws-sdk-sagemaker/types.rb', line 59030

class UserContext < Struct.new(
  :user_profile_arn,
  :user_profile_name,
  :domain_id,
  :iam_identity)
  SENSITIVE = []
  include Aws::Structure
end

#user_profile_nameString

The name of the user's profile.

Returns:

  • (String)


59030
59031
59032
59033
59034
59035
59036
59037
# File 'lib/aws-sdk-sagemaker/types.rb', line 59030

class UserContext < Struct.new(
  :user_profile_arn,
  :user_profile_name,
  :domain_id,
  :iam_identity)
  SENSITIVE = []
  include Aws::Structure
end