Class: Aws::SageMaker::Types::UserContext
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::UserContext
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Information about the user who created or modified a SageMaker resource.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_id ⇒ String
The domain associated with the user.
-
#iam_identity ⇒ Types::IamIdentity
The IAM Identity details associated with the user.
-
#user_profile_arn ⇒ String
The Amazon Resource Name (ARN) of the user's profile.
-
#user_profile_name ⇒ String
The name of the user's profile.
Instance Attribute Details
#domain_id ⇒ String
The domain associated with the user.
58875 58876 58877 58878 58879 58880 58881 58882 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 58875 class UserContext < Struct.new( :user_profile_arn, :user_profile_name, :domain_id, :iam_identity) SENSITIVE = [] include Aws::Structure end |
#iam_identity ⇒ Types::IamIdentity
The IAM Identity details associated with the user. These details are associated with model package groups, model packages, and project entities only.
58875 58876 58877 58878 58879 58880 58881 58882 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 58875 class UserContext < Struct.new( :user_profile_arn, :user_profile_name, :domain_id, :iam_identity) SENSITIVE = [] include Aws::Structure end |
#user_profile_arn ⇒ String
The Amazon Resource Name (ARN) of the user's profile.
58875 58876 58877 58878 58879 58880 58881 58882 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 58875 class UserContext < Struct.new( :user_profile_arn, :user_profile_name, :domain_id, :iam_identity) SENSITIVE = [] include Aws::Structure end |
#user_profile_name ⇒ String
The name of the user's profile.
58875 58876 58877 58878 58879 58880 58881 58882 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 58875 class UserContext < Struct.new( :user_profile_arn, :user_profile_name, :domain_id, :iam_identity) SENSITIVE = [] include Aws::Structure end |