Class: Aws::SageMaker::Types::UserContext

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Information about the user who created or modified a SageMaker resource.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#domain_idString

The domain associated with the user.

Returns:

  • (String)


58659
58660
58661
58662
58663
58664
58665
58666
# File 'lib/aws-sdk-sagemaker/types.rb', line 58659

class UserContext < Struct.new(
  :user_profile_arn,
  :user_profile_name,
  :domain_id,
  :iam_identity)
  SENSITIVE = []
  include Aws::Structure
end

#iam_identityTypes::IamIdentity

The IAM Identity details associated with the user. These details are associated with model package groups, model packages, and project entities only.

Returns:



58659
58660
58661
58662
58663
58664
58665
58666
# File 'lib/aws-sdk-sagemaker/types.rb', line 58659

class UserContext < Struct.new(
  :user_profile_arn,
  :user_profile_name,
  :domain_id,
  :iam_identity)
  SENSITIVE = []
  include Aws::Structure
end

#user_profile_arnString

The Amazon Resource Name (ARN) of the user’s profile.

Returns:

  • (String)


58659
58660
58661
58662
58663
58664
58665
58666
# File 'lib/aws-sdk-sagemaker/types.rb', line 58659

class UserContext < Struct.new(
  :user_profile_arn,
  :user_profile_name,
  :domain_id,
  :iam_identity)
  SENSITIVE = []
  include Aws::Structure
end

#user_profile_nameString

The name of the user’s profile.

Returns:

  • (String)


58659
58660
58661
58662
58663
58664
58665
58666
# File 'lib/aws-sdk-sagemaker/types.rb', line 58659

class UserContext < Struct.new(
  :user_profile_arn,
  :user_profile_name,
  :domain_id,
  :iam_identity)
  SENSITIVE = []
  include Aws::Structure
end