Class: Aws::SageMaker::Types::UserSettings

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

A collection of settings that apply to users in a domain. These settings are specified when the ‘CreateUserProfile` API is called, and as `DefaultUserSettings` when the `CreateDomain` API is called.

‘SecurityGroups` is aggregated when specified in both calls. For all other settings in `UserSettings`, the values specified in `CreateUserProfile` take precedence over those specified in `CreateDomain`.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_mount_home_efsString

Indicates whether auto-mounting of an EFS volume is supported for the user profile. The ‘DefaultAsDomain` value is only supported for user profiles. Do not use the `DefaultAsDomain` value when setting this parameter for a domain.

SageMaker applies this setting only to private spaces that the user creates in the domain. SageMaker doesn’t apply this setting to shared spaces.

Returns:

  • (String)


58849
58850
58851
58852
58853
58854
58855
58856
58857
58858
58859
58860
58861
58862
58863
58864
58865
58866
58867
58868
58869
58870
# File 'lib/aws-sdk-sagemaker/types.rb', line 58849

class UserSettings < Struct.new(
  :execution_role,
  :security_groups,
  :sharing_settings,
  :jupyter_server_app_settings,
  :kernel_gateway_app_settings,
  :tensor_board_app_settings,
  :r_studio_server_pro_app_settings,
  :r_session_app_settings,
  :canvas_app_settings,
  :code_editor_app_settings,
  :jupyter_lab_app_settings,
  :space_storage_settings,
  :default_landing_uri,
  :studio_web_portal,
  :custom_posix_user_config,
  :custom_file_system_configs,
  :studio_web_portal_settings,
  :auto_mount_home_efs)
  SENSITIVE = []
  include Aws::Structure
end

#canvas_app_settingsTypes::CanvasAppSettings

The Canvas app settings.

SageMaker applies these settings only to private spaces that SageMaker creates for the Canvas app.



58849
58850
58851
58852
58853
58854
58855
58856
58857
58858
58859
58860
58861
58862
58863
58864
58865
58866
58867
58868
58869
58870
# File 'lib/aws-sdk-sagemaker/types.rb', line 58849

class UserSettings < Struct.new(
  :execution_role,
  :security_groups,
  :sharing_settings,
  :jupyter_server_app_settings,
  :kernel_gateway_app_settings,
  :tensor_board_app_settings,
  :r_studio_server_pro_app_settings,
  :r_session_app_settings,
  :canvas_app_settings,
  :code_editor_app_settings,
  :jupyter_lab_app_settings,
  :space_storage_settings,
  :default_landing_uri,
  :studio_web_portal,
  :custom_posix_user_config,
  :custom_file_system_configs,
  :studio_web_portal_settings,
  :auto_mount_home_efs)
  SENSITIVE = []
  include Aws::Structure
end

#code_editor_app_settingsTypes::CodeEditorAppSettings

The Code Editor application settings.

SageMaker applies these settings only to private spaces that the user creates in the domain. SageMaker doesn’t apply these settings to shared spaces.



58849
58850
58851
58852
58853
58854
58855
58856
58857
58858
58859
58860
58861
58862
58863
58864
58865
58866
58867
58868
58869
58870
# File 'lib/aws-sdk-sagemaker/types.rb', line 58849

class UserSettings < Struct.new(
  :execution_role,
  :security_groups,
  :sharing_settings,
  :jupyter_server_app_settings,
  :kernel_gateway_app_settings,
  :tensor_board_app_settings,
  :r_studio_server_pro_app_settings,
  :r_session_app_settings,
  :canvas_app_settings,
  :code_editor_app_settings,
  :jupyter_lab_app_settings,
  :space_storage_settings,
  :default_landing_uri,
  :studio_web_portal,
  :custom_posix_user_config,
  :custom_file_system_configs,
  :studio_web_portal_settings,
  :auto_mount_home_efs)
  SENSITIVE = []
  include Aws::Structure
end

#custom_file_system_configsArray<Types::CustomFileSystemConfig>

The settings for assigning a custom file system to a user profile. Permitted users can access this file system in Amazon SageMaker AI Studio.

SageMaker applies these settings only to private spaces that the user creates in the domain. SageMaker doesn’t apply these settings to shared spaces.

Returns:



58849
58850
58851
58852
58853
58854
58855
58856
58857
58858
58859
58860
58861
58862
58863
58864
58865
58866
58867
58868
58869
58870
# File 'lib/aws-sdk-sagemaker/types.rb', line 58849

class UserSettings < Struct.new(
  :execution_role,
  :security_groups,
  :sharing_settings,
  :jupyter_server_app_settings,
  :kernel_gateway_app_settings,
  :tensor_board_app_settings,
  :r_studio_server_pro_app_settings,
  :r_session_app_settings,
  :canvas_app_settings,
  :code_editor_app_settings,
  :jupyter_lab_app_settings,
  :space_storage_settings,
  :default_landing_uri,
  :studio_web_portal,
  :custom_posix_user_config,
  :custom_file_system_configs,
  :studio_web_portal_settings,
  :auto_mount_home_efs)
  SENSITIVE = []
  include Aws::Structure
end

#custom_posix_user_configTypes::CustomPosixUserConfig

Details about the POSIX identity that is used for file system operations.

SageMaker applies these settings only to private spaces that the user creates in the domain. SageMaker doesn’t apply these settings to shared spaces.



58849
58850
58851
58852
58853
58854
58855
58856
58857
58858
58859
58860
58861
58862
58863
58864
58865
58866
58867
58868
58869
58870
# File 'lib/aws-sdk-sagemaker/types.rb', line 58849

class UserSettings < Struct.new(
  :execution_role,
  :security_groups,
  :sharing_settings,
  :jupyter_server_app_settings,
  :kernel_gateway_app_settings,
  :tensor_board_app_settings,
  :r_studio_server_pro_app_settings,
  :r_session_app_settings,
  :canvas_app_settings,
  :code_editor_app_settings,
  :jupyter_lab_app_settings,
  :space_storage_settings,
  :default_landing_uri,
  :studio_web_portal,
  :custom_posix_user_config,
  :custom_file_system_configs,
  :studio_web_portal_settings,
  :auto_mount_home_efs)
  SENSITIVE = []
  include Aws::Structure
end

#default_landing_uriString

The default experience that the user is directed to when accessing the domain. The supported values are:

  • ‘studio::`: Indicates that Studio is the default experience. This value can only be passed if `StudioWebPortal` is set to `ENABLED`.

  • ‘app:JupyterServer:`: Indicates that Studio Classic is the default experience.

Returns:

  • (String)


58849
58850
58851
58852
58853
58854
58855
58856
58857
58858
58859
58860
58861
58862
58863
58864
58865
58866
58867
58868
58869
58870
# File 'lib/aws-sdk-sagemaker/types.rb', line 58849

class UserSettings < Struct.new(
  :execution_role,
  :security_groups,
  :sharing_settings,
  :jupyter_server_app_settings,
  :kernel_gateway_app_settings,
  :tensor_board_app_settings,
  :r_studio_server_pro_app_settings,
  :r_session_app_settings,
  :canvas_app_settings,
  :code_editor_app_settings,
  :jupyter_lab_app_settings,
  :space_storage_settings,
  :default_landing_uri,
  :studio_web_portal,
  :custom_posix_user_config,
  :custom_file_system_configs,
  :studio_web_portal_settings,
  :auto_mount_home_efs)
  SENSITIVE = []
  include Aws::Structure
end

#execution_roleString

The execution role for the user.

SageMaker applies this setting only to private spaces that the user creates in the domain. SageMaker doesn’t apply this setting to shared spaces.

Returns:

  • (String)


58849
58850
58851
58852
58853
58854
58855
58856
58857
58858
58859
58860
58861
58862
58863
58864
58865
58866
58867
58868
58869
58870
# File 'lib/aws-sdk-sagemaker/types.rb', line 58849

class UserSettings < Struct.new(
  :execution_role,
  :security_groups,
  :sharing_settings,
  :jupyter_server_app_settings,
  :kernel_gateway_app_settings,
  :tensor_board_app_settings,
  :r_studio_server_pro_app_settings,
  :r_session_app_settings,
  :canvas_app_settings,
  :code_editor_app_settings,
  :jupyter_lab_app_settings,
  :space_storage_settings,
  :default_landing_uri,
  :studio_web_portal,
  :custom_posix_user_config,
  :custom_file_system_configs,
  :studio_web_portal_settings,
  :auto_mount_home_efs)
  SENSITIVE = []
  include Aws::Structure
end

#jupyter_lab_app_settingsTypes::JupyterLabAppSettings

The settings for the JupyterLab application.

SageMaker applies these settings only to private spaces that the user creates in the domain. SageMaker doesn’t apply these settings to shared spaces.



58849
58850
58851
58852
58853
58854
58855
58856
58857
58858
58859
58860
58861
58862
58863
58864
58865
58866
58867
58868
58869
58870
# File 'lib/aws-sdk-sagemaker/types.rb', line 58849

class UserSettings < Struct.new(
  :execution_role,
  :security_groups,
  :sharing_settings,
  :jupyter_server_app_settings,
  :kernel_gateway_app_settings,
  :tensor_board_app_settings,
  :r_studio_server_pro_app_settings,
  :r_session_app_settings,
  :canvas_app_settings,
  :code_editor_app_settings,
  :jupyter_lab_app_settings,
  :space_storage_settings,
  :default_landing_uri,
  :studio_web_portal,
  :custom_posix_user_config,
  :custom_file_system_configs,
  :studio_web_portal_settings,
  :auto_mount_home_efs)
  SENSITIVE = []
  include Aws::Structure
end

#jupyter_server_app_settingsTypes::JupyterServerAppSettings

The Jupyter server’s app settings.



58849
58850
58851
58852
58853
58854
58855
58856
58857
58858
58859
58860
58861
58862
58863
58864
58865
58866
58867
58868
58869
58870
# File 'lib/aws-sdk-sagemaker/types.rb', line 58849

class UserSettings < Struct.new(
  :execution_role,
  :security_groups,
  :sharing_settings,
  :jupyter_server_app_settings,
  :kernel_gateway_app_settings,
  :tensor_board_app_settings,
  :r_studio_server_pro_app_settings,
  :r_session_app_settings,
  :canvas_app_settings,
  :code_editor_app_settings,
  :jupyter_lab_app_settings,
  :space_storage_settings,
  :default_landing_uri,
  :studio_web_portal,
  :custom_posix_user_config,
  :custom_file_system_configs,
  :studio_web_portal_settings,
  :auto_mount_home_efs)
  SENSITIVE = []
  include Aws::Structure
end

#kernel_gateway_app_settingsTypes::KernelGatewayAppSettings

The kernel gateway app settings.



58849
58850
58851
58852
58853
58854
58855
58856
58857
58858
58859
58860
58861
58862
58863
58864
58865
58866
58867
58868
58869
58870
# File 'lib/aws-sdk-sagemaker/types.rb', line 58849

class UserSettings < Struct.new(
  :execution_role,
  :security_groups,
  :sharing_settings,
  :jupyter_server_app_settings,
  :kernel_gateway_app_settings,
  :tensor_board_app_settings,
  :r_studio_server_pro_app_settings,
  :r_session_app_settings,
  :canvas_app_settings,
  :code_editor_app_settings,
  :jupyter_lab_app_settings,
  :space_storage_settings,
  :default_landing_uri,
  :studio_web_portal,
  :custom_posix_user_config,
  :custom_file_system_configs,
  :studio_web_portal_settings,
  :auto_mount_home_efs)
  SENSITIVE = []
  include Aws::Structure
end

#r_session_app_settingsTypes::RSessionAppSettings

A collection of settings that configure the ‘RSessionGateway` app.



58849
58850
58851
58852
58853
58854
58855
58856
58857
58858
58859
58860
58861
58862
58863
58864
58865
58866
58867
58868
58869
58870
# File 'lib/aws-sdk-sagemaker/types.rb', line 58849

class UserSettings < Struct.new(
  :execution_role,
  :security_groups,
  :sharing_settings,
  :jupyter_server_app_settings,
  :kernel_gateway_app_settings,
  :tensor_board_app_settings,
  :r_studio_server_pro_app_settings,
  :r_session_app_settings,
  :canvas_app_settings,
  :code_editor_app_settings,
  :jupyter_lab_app_settings,
  :space_storage_settings,
  :default_landing_uri,
  :studio_web_portal,
  :custom_posix_user_config,
  :custom_file_system_configs,
  :studio_web_portal_settings,
  :auto_mount_home_efs)
  SENSITIVE = []
  include Aws::Structure
end

#r_studio_server_pro_app_settingsTypes::RStudioServerProAppSettings

A collection of settings that configure user interaction with the ‘RStudioServerPro` app.



58849
58850
58851
58852
58853
58854
58855
58856
58857
58858
58859
58860
58861
58862
58863
58864
58865
58866
58867
58868
58869
58870
# File 'lib/aws-sdk-sagemaker/types.rb', line 58849

class UserSettings < Struct.new(
  :execution_role,
  :security_groups,
  :sharing_settings,
  :jupyter_server_app_settings,
  :kernel_gateway_app_settings,
  :tensor_board_app_settings,
  :r_studio_server_pro_app_settings,
  :r_session_app_settings,
  :canvas_app_settings,
  :code_editor_app_settings,
  :jupyter_lab_app_settings,
  :space_storage_settings,
  :default_landing_uri,
  :studio_web_portal,
  :custom_posix_user_config,
  :custom_file_system_configs,
  :studio_web_portal_settings,
  :auto_mount_home_efs)
  SENSITIVE = []
  include Aws::Structure
end

#security_groupsArray<String>

The security groups for the Amazon Virtual Private Cloud (VPC) that the domain uses for communication.

Optional when the ‘CreateDomain.AppNetworkAccessType` parameter is set to `PublicInternetOnly`.

Required when the ‘CreateDomain.AppNetworkAccessType` parameter is set to `VpcOnly`, unless specified as part of the `DefaultUserSettings` for the domain.

Amazon SageMaker AI adds a security group to allow NFS traffic from Amazon SageMaker AI Studio. Therefore, the number of security groups that you can specify is one less than the maximum number shown.

SageMaker applies these settings only to private spaces that the user creates in the domain. SageMaker doesn’t apply these settings to shared spaces.

Returns:

  • (Array<String>)


58849
58850
58851
58852
58853
58854
58855
58856
58857
58858
58859
58860
58861
58862
58863
58864
58865
58866
58867
58868
58869
58870
# File 'lib/aws-sdk-sagemaker/types.rb', line 58849

class UserSettings < Struct.new(
  :execution_role,
  :security_groups,
  :sharing_settings,
  :jupyter_server_app_settings,
  :kernel_gateway_app_settings,
  :tensor_board_app_settings,
  :r_studio_server_pro_app_settings,
  :r_session_app_settings,
  :canvas_app_settings,
  :code_editor_app_settings,
  :jupyter_lab_app_settings,
  :space_storage_settings,
  :default_landing_uri,
  :studio_web_portal,
  :custom_posix_user_config,
  :custom_file_system_configs,
  :studio_web_portal_settings,
  :auto_mount_home_efs)
  SENSITIVE = []
  include Aws::Structure
end

#sharing_settingsTypes::SharingSettings

Specifies options for sharing Amazon SageMaker AI Studio notebooks.



58849
58850
58851
58852
58853
58854
58855
58856
58857
58858
58859
58860
58861
58862
58863
58864
58865
58866
58867
58868
58869
58870
# File 'lib/aws-sdk-sagemaker/types.rb', line 58849

class UserSettings < Struct.new(
  :execution_role,
  :security_groups,
  :sharing_settings,
  :jupyter_server_app_settings,
  :kernel_gateway_app_settings,
  :tensor_board_app_settings,
  :r_studio_server_pro_app_settings,
  :r_session_app_settings,
  :canvas_app_settings,
  :code_editor_app_settings,
  :jupyter_lab_app_settings,
  :space_storage_settings,
  :default_landing_uri,
  :studio_web_portal,
  :custom_posix_user_config,
  :custom_file_system_configs,
  :studio_web_portal_settings,
  :auto_mount_home_efs)
  SENSITIVE = []
  include Aws::Structure
end

#space_storage_settingsTypes::DefaultSpaceStorageSettings

The storage settings for a space.

SageMaker applies these settings only to private spaces that the user creates in the domain. SageMaker doesn’t apply these settings to shared spaces.



58849
58850
58851
58852
58853
58854
58855
58856
58857
58858
58859
58860
58861
58862
58863
58864
58865
58866
58867
58868
58869
58870
# File 'lib/aws-sdk-sagemaker/types.rb', line 58849

class UserSettings < Struct.new(
  :execution_role,
  :security_groups,
  :sharing_settings,
  :jupyter_server_app_settings,
  :kernel_gateway_app_settings,
  :tensor_board_app_settings,
  :r_studio_server_pro_app_settings,
  :r_session_app_settings,
  :canvas_app_settings,
  :code_editor_app_settings,
  :jupyter_lab_app_settings,
  :space_storage_settings,
  :default_landing_uri,
  :studio_web_portal,
  :custom_posix_user_config,
  :custom_file_system_configs,
  :studio_web_portal_settings,
  :auto_mount_home_efs)
  SENSITIVE = []
  include Aws::Structure
end

#studio_web_portalString

Whether the user can access Studio. If this value is set to ‘DISABLED`, the user cannot access Studio, even if that is the default experience for the domain.

Returns:

  • (String)


58849
58850
58851
58852
58853
58854
58855
58856
58857
58858
58859
58860
58861
58862
58863
58864
58865
58866
58867
58868
58869
58870
# File 'lib/aws-sdk-sagemaker/types.rb', line 58849

class UserSettings < Struct.new(
  :execution_role,
  :security_groups,
  :sharing_settings,
  :jupyter_server_app_settings,
  :kernel_gateway_app_settings,
  :tensor_board_app_settings,
  :r_studio_server_pro_app_settings,
  :r_session_app_settings,
  :canvas_app_settings,
  :code_editor_app_settings,
  :jupyter_lab_app_settings,
  :space_storage_settings,
  :default_landing_uri,
  :studio_web_portal,
  :custom_posix_user_config,
  :custom_file_system_configs,
  :studio_web_portal_settings,
  :auto_mount_home_efs)
  SENSITIVE = []
  include Aws::Structure
end

#studio_web_portal_settingsTypes::StudioWebPortalSettings

Studio settings. If these settings are applied on a user level, they take priority over the settings applied on a domain level.



58849
58850
58851
58852
58853
58854
58855
58856
58857
58858
58859
58860
58861
58862
58863
58864
58865
58866
58867
58868
58869
58870
# File 'lib/aws-sdk-sagemaker/types.rb', line 58849

class UserSettings < Struct.new(
  :execution_role,
  :security_groups,
  :sharing_settings,
  :jupyter_server_app_settings,
  :kernel_gateway_app_settings,
  :tensor_board_app_settings,
  :r_studio_server_pro_app_settings,
  :r_session_app_settings,
  :canvas_app_settings,
  :code_editor_app_settings,
  :jupyter_lab_app_settings,
  :space_storage_settings,
  :default_landing_uri,
  :studio_web_portal,
  :custom_posix_user_config,
  :custom_file_system_configs,
  :studio_web_portal_settings,
  :auto_mount_home_efs)
  SENSITIVE = []
  include Aws::Structure
end

#tensor_board_app_settingsTypes::TensorBoardAppSettings

The TensorBoard app settings.



58849
58850
58851
58852
58853
58854
58855
58856
58857
58858
58859
58860
58861
58862
58863
58864
58865
58866
58867
58868
58869
58870
# File 'lib/aws-sdk-sagemaker/types.rb', line 58849

class UserSettings < Struct.new(
  :execution_role,
  :security_groups,
  :sharing_settings,
  :jupyter_server_app_settings,
  :kernel_gateway_app_settings,
  :tensor_board_app_settings,
  :r_studio_server_pro_app_settings,
  :r_session_app_settings,
  :canvas_app_settings,
  :code_editor_app_settings,
  :jupyter_lab_app_settings,
  :space_storage_settings,
  :default_landing_uri,
  :studio_web_portal,
  :custom_posix_user_config,
  :custom_file_system_configs,
  :studio_web_portal_settings,
  :auto_mount_home_efs)
  SENSITIVE = []
  include Aws::Structure
end