Class: Aws::SageMaker::Types::VariantProperty
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::VariantProperty
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Specifies a production variant property type for an Endpoint.
If you are updating an endpoint with the UpdateEndpointInput$RetainAllVariantProperties option set to true, the VariantProperty objects listed in UpdateEndpointInput$ExcludeRetainedVariantProperties override the existing variant properties of the endpoint.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#variant_property_type ⇒ String
The type of variant property.
Instance Attribute Details
#variant_property_type ⇒ String
The type of variant property. The supported values are:
-
DesiredInstanceCount: Overrides the existing variant instance counts using the ProductionVariant$InitialInstanceCount values in the CreateEndpointConfigInput$ProductionVariants. -
DesiredWeight: Overrides the existing variant weights using the ProductionVariant$InitialVariantWeight values in the CreateEndpointConfigInput$ProductionVariants. -
DataCaptureConfig: (Not currently supported.)
39011 39012 39013 39014 39015 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 39011 class VariantProperty < Struct.new( :variant_property_type) SENSITIVE = [] include Aws::Structure end |