Class: Aws::SageMaker::Types::WorkerAccessConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Use this optional parameter to constrain access to an Amazon S3 resource based on the IP address using supported IAM global condition keys. The Amazon S3 resource is accessed in the worker portal using a Amazon S3 presigned URL.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#s3_presignTypes::S3Presign

Defines any Amazon S3 resource constraints.

Returns:



59070
59071
59072
59073
59074
# File 'lib/aws-sdk-sagemaker/types.rb', line 59070

class WorkerAccessConfiguration < Struct.new(
  :s3_presign)
  SENSITIVE = []
  include Aws::Structure
end