Class: Aws::SageMaker::Types::WorkerAccessConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::WorkerAccessConfiguration
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Use this optional parameter to constrain access to an Amazon S3 resource based on the IP address using supported IAM global condition keys. The Amazon S3 resource is accessed in the worker portal using a Amazon S3 presigned URL.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#s3_presign ⇒ Types::S3Presign
Defines any Amazon S3 resource constraints.
Instance Attribute Details
#s3_presign ⇒ Types::S3Presign
Defines any Amazon S3 resource constraints.
58913 58914 58915 58916 58917 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 58913 class WorkerAccessConfiguration < Struct.new( :s3_presign) SENSITIVE = [] include Aws::Structure end |