Class: Aws::SageMaker::Types::WorkloadSpec
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::WorkloadSpec
- Includes:
- Aws::Structure, Aws::Structure::Union
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Note:
WorkloadSpec is a union - when making an API calls you must set exactly one of the members.
Note:
WorkloadSpec is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of WorkloadSpec corresponding to the set member.
The workload specification for benchmark tool configuration. Provide an inline YAML or JSON string.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#inline ⇒ String
An inline YAML or JSON string that defines benchmark parameters.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#inline ⇒ String
An inline YAML or JSON string that defines benchmark parameters.
57973 57974 57975 57976 57977 57978 57979 57980 57981 57982 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 57973 class WorkloadSpec < Struct.new( :inline, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Inline < WorkloadSpec; end class Unknown < WorkloadSpec; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
57973 57974 57975 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 57973 def unknown @unknown end |