Class: Aws::SageMaker::Types::WorkloadSpec

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure, Aws::Structure::Union
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Note:

WorkloadSpec is a union - when making an API calls you must set exactly one of the members.

Note:

WorkloadSpec is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of WorkloadSpec corresponding to the set member.

The workload specification for benchmark tool configuration. Provide an inline YAML or JSON string.

Direct Known Subclasses

Inline, Unknown

Defined Under Namespace

Classes: Inline, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#inlineString

An inline YAML or JSON string that defines benchmark parameters.

Returns:

  • (String)


57813
57814
57815
57816
57817
57818
57819
57820
57821
57822
# File 'lib/aws-sdk-sagemaker/types.rb', line 57813

class WorkloadSpec < Struct.new(
  :inline,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Inline < WorkloadSpec; end
  class Unknown < WorkloadSpec; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



57813
57814
57815
# File 'lib/aws-sdk-sagemaker/types.rb', line 57813

def unknown
  @unknown
end