Class: Aws::SageMaker::Types::Workteam
- Inherits:
-
Struct
- Object
- Struct
- Aws::SageMaker::Types::Workteam
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sagemaker/types.rb
Overview
Provides details about a labeling work team.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#create_date ⇒ Time
The date and time that the work team was created (timestamp).
-
#description ⇒ String
A description of the work team.
-
#last_updated_date ⇒ Time
The date and time that the work team was last updated (timestamp).
-
#member_definitions ⇒ Array<Types::MemberDefinition>
A list of ‘MemberDefinition` objects that contains objects that identify the workers that make up the work team.
-
#notification_configuration ⇒ Types::NotificationConfiguration
Configures SNS notifications of available or expiring work items for work teams.
-
#product_listing_ids ⇒ Array<String>
The Amazon Marketplace identifier for a vendor’s work team.
-
#sub_domain ⇒ String
The URI of the labeling job’s user interface.
-
#worker_access_configuration ⇒ Types::WorkerAccessConfiguration
Describes any access constraints that have been defined for Amazon S3 resources.
-
#workforce_arn ⇒ String
The Amazon Resource Name (ARN) of the workforce.
-
#workteam_arn ⇒ String
The Amazon Resource Name (ARN) that identifies the work team.
-
#workteam_name ⇒ String
The name of the work team.
Instance Attribute Details
#create_date ⇒ Time
The date and time that the work team was created (timestamp).
58209 58210 58211 58212 58213 58214 58215 58216 58217 58218 58219 58220 58221 58222 58223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 58209 class Workteam < Struct.new( :workteam_name, :member_definitions, :workteam_arn, :workforce_arn, :product_listing_ids, :description, :sub_domain, :create_date, :last_updated_date, :notification_configuration, :worker_access_configuration) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the work team.
58209 58210 58211 58212 58213 58214 58215 58216 58217 58218 58219 58220 58221 58222 58223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 58209 class Workteam < Struct.new( :workteam_name, :member_definitions, :workteam_arn, :workforce_arn, :product_listing_ids, :description, :sub_domain, :create_date, :last_updated_date, :notification_configuration, :worker_access_configuration) SENSITIVE = [] include Aws::Structure end |
#last_updated_date ⇒ Time
The date and time that the work team was last updated (timestamp).
58209 58210 58211 58212 58213 58214 58215 58216 58217 58218 58219 58220 58221 58222 58223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 58209 class Workteam < Struct.new( :workteam_name, :member_definitions, :workteam_arn, :workforce_arn, :product_listing_ids, :description, :sub_domain, :create_date, :last_updated_date, :notification_configuration, :worker_access_configuration) SENSITIVE = [] include Aws::Structure end |
#member_definitions ⇒ Array<Types::MemberDefinition>
A list of ‘MemberDefinition` objects that contains objects that identify the workers that make up the work team.
Workforces can be created using Amazon Cognito or your own OIDC Identity Provider (IdP). For private workforces created using Amazon Cognito use ‘CognitoMemberDefinition`. For workforces created using your own OIDC identity provider (IdP) use `OidcMemberDefinition`.
58209 58210 58211 58212 58213 58214 58215 58216 58217 58218 58219 58220 58221 58222 58223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 58209 class Workteam < Struct.new( :workteam_name, :member_definitions, :workteam_arn, :workforce_arn, :product_listing_ids, :description, :sub_domain, :create_date, :last_updated_date, :notification_configuration, :worker_access_configuration) SENSITIVE = [] include Aws::Structure end |
#notification_configuration ⇒ Types::NotificationConfiguration
Configures SNS notifications of available or expiring work items for work teams.
58209 58210 58211 58212 58213 58214 58215 58216 58217 58218 58219 58220 58221 58222 58223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 58209 class Workteam < Struct.new( :workteam_name, :member_definitions, :workteam_arn, :workforce_arn, :product_listing_ids, :description, :sub_domain, :create_date, :last_updated_date, :notification_configuration, :worker_access_configuration) SENSITIVE = [] include Aws::Structure end |
#product_listing_ids ⇒ Array<String>
The Amazon Marketplace identifier for a vendor’s work team.
58209 58210 58211 58212 58213 58214 58215 58216 58217 58218 58219 58220 58221 58222 58223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 58209 class Workteam < Struct.new( :workteam_name, :member_definitions, :workteam_arn, :workforce_arn, :product_listing_ids, :description, :sub_domain, :create_date, :last_updated_date, :notification_configuration, :worker_access_configuration) SENSITIVE = [] include Aws::Structure end |
#sub_domain ⇒ String
The URI of the labeling job’s user interface. Workers open this URI to start labeling your data objects.
58209 58210 58211 58212 58213 58214 58215 58216 58217 58218 58219 58220 58221 58222 58223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 58209 class Workteam < Struct.new( :workteam_name, :member_definitions, :workteam_arn, :workforce_arn, :product_listing_ids, :description, :sub_domain, :create_date, :last_updated_date, :notification_configuration, :worker_access_configuration) SENSITIVE = [] include Aws::Structure end |
#worker_access_configuration ⇒ Types::WorkerAccessConfiguration
Describes any access constraints that have been defined for Amazon S3 resources.
58209 58210 58211 58212 58213 58214 58215 58216 58217 58218 58219 58220 58221 58222 58223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 58209 class Workteam < Struct.new( :workteam_name, :member_definitions, :workteam_arn, :workforce_arn, :product_listing_ids, :description, :sub_domain, :create_date, :last_updated_date, :notification_configuration, :worker_access_configuration) SENSITIVE = [] include Aws::Structure end |
#workforce_arn ⇒ String
The Amazon Resource Name (ARN) of the workforce.
58209 58210 58211 58212 58213 58214 58215 58216 58217 58218 58219 58220 58221 58222 58223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 58209 class Workteam < Struct.new( :workteam_name, :member_definitions, :workteam_arn, :workforce_arn, :product_listing_ids, :description, :sub_domain, :create_date, :last_updated_date, :notification_configuration, :worker_access_configuration) SENSITIVE = [] include Aws::Structure end |
#workteam_arn ⇒ String
The Amazon Resource Name (ARN) that identifies the work team.
58209 58210 58211 58212 58213 58214 58215 58216 58217 58218 58219 58220 58221 58222 58223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 58209 class Workteam < Struct.new( :workteam_name, :member_definitions, :workteam_arn, :workforce_arn, :product_listing_ids, :description, :sub_domain, :create_date, :last_updated_date, :notification_configuration, :worker_access_configuration) SENSITIVE = [] include Aws::Structure end |
#workteam_name ⇒ String
The name of the work team.
58209 58210 58211 58212 58213 58214 58215 58216 58217 58218 58219 58220 58221 58222 58223 |
# File 'lib/aws-sdk-sagemaker/types.rb', line 58209 class Workteam < Struct.new( :workteam_name, :member_definitions, :workteam_arn, :workforce_arn, :product_listing_ids, :description, :sub_domain, :create_date, :last_updated_date, :notification_configuration, :worker_access_configuration) SENSITIVE = [] include Aws::Structure end |