Class: Aws::SageMaker::Types::Workteam

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sagemaker/types.rb

Overview

Provides details about a labeling work team.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#create_dateTime

The date and time that the work team was created (timestamp).

Returns:

  • (Time)


55772
55773
55774
55775
55776
55777
55778
55779
55780
55781
55782
55783
55784
55785
55786
# File 'lib/aws-sdk-sagemaker/types.rb', line 55772

class Workteam < Struct.new(
  :workteam_name,
  :member_definitions,
  :workteam_arn,
  :workforce_arn,
  :product_listing_ids,
  :description,
  :sub_domain,
  :create_date,
  :last_updated_date,
  :notification_configuration,
  :worker_access_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the work team.

Returns:

  • (String)


55772
55773
55774
55775
55776
55777
55778
55779
55780
55781
55782
55783
55784
55785
55786
# File 'lib/aws-sdk-sagemaker/types.rb', line 55772

class Workteam < Struct.new(
  :workteam_name,
  :member_definitions,
  :workteam_arn,
  :workforce_arn,
  :product_listing_ids,
  :description,
  :sub_domain,
  :create_date,
  :last_updated_date,
  :notification_configuration,
  :worker_access_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_dateTime

The date and time that the work team was last updated (timestamp).

Returns:

  • (Time)


55772
55773
55774
55775
55776
55777
55778
55779
55780
55781
55782
55783
55784
55785
55786
# File 'lib/aws-sdk-sagemaker/types.rb', line 55772

class Workteam < Struct.new(
  :workteam_name,
  :member_definitions,
  :workteam_arn,
  :workforce_arn,
  :product_listing_ids,
  :description,
  :sub_domain,
  :create_date,
  :last_updated_date,
  :notification_configuration,
  :worker_access_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#member_definitionsArray<Types::MemberDefinition>

A list of ‘MemberDefinition` objects that contains objects that identify the workers that make up the work team.

Workforces can be created using Amazon Cognito or your own OIDC Identity Provider (IdP). For private workforces created using Amazon Cognito use ‘CognitoMemberDefinition`. For workforces created using your own OIDC identity provider (IdP) use `OidcMemberDefinition`.

Returns:



55772
55773
55774
55775
55776
55777
55778
55779
55780
55781
55782
55783
55784
55785
55786
# File 'lib/aws-sdk-sagemaker/types.rb', line 55772

class Workteam < Struct.new(
  :workteam_name,
  :member_definitions,
  :workteam_arn,
  :workforce_arn,
  :product_listing_ids,
  :description,
  :sub_domain,
  :create_date,
  :last_updated_date,
  :notification_configuration,
  :worker_access_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#notification_configurationTypes::NotificationConfiguration

Configures SNS notifications of available or expiring work items for work teams.



55772
55773
55774
55775
55776
55777
55778
55779
55780
55781
55782
55783
55784
55785
55786
# File 'lib/aws-sdk-sagemaker/types.rb', line 55772

class Workteam < Struct.new(
  :workteam_name,
  :member_definitions,
  :workteam_arn,
  :workforce_arn,
  :product_listing_ids,
  :description,
  :sub_domain,
  :create_date,
  :last_updated_date,
  :notification_configuration,
  :worker_access_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#product_listing_idsArray<String>

The Amazon Marketplace identifier for a vendor’s work team.

Returns:

  • (Array<String>)


55772
55773
55774
55775
55776
55777
55778
55779
55780
55781
55782
55783
55784
55785
55786
# File 'lib/aws-sdk-sagemaker/types.rb', line 55772

class Workteam < Struct.new(
  :workteam_name,
  :member_definitions,
  :workteam_arn,
  :workforce_arn,
  :product_listing_ids,
  :description,
  :sub_domain,
  :create_date,
  :last_updated_date,
  :notification_configuration,
  :worker_access_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#sub_domainString

The URI of the labeling job’s user interface. Workers open this URI to start labeling your data objects.

Returns:

  • (String)


55772
55773
55774
55775
55776
55777
55778
55779
55780
55781
55782
55783
55784
55785
55786
# File 'lib/aws-sdk-sagemaker/types.rb', line 55772

class Workteam < Struct.new(
  :workteam_name,
  :member_definitions,
  :workteam_arn,
  :workforce_arn,
  :product_listing_ids,
  :description,
  :sub_domain,
  :create_date,
  :last_updated_date,
  :notification_configuration,
  :worker_access_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#worker_access_configurationTypes::WorkerAccessConfiguration

Describes any access constraints that have been defined for Amazon S3 resources.



55772
55773
55774
55775
55776
55777
55778
55779
55780
55781
55782
55783
55784
55785
55786
# File 'lib/aws-sdk-sagemaker/types.rb', line 55772

class Workteam < Struct.new(
  :workteam_name,
  :member_definitions,
  :workteam_arn,
  :workforce_arn,
  :product_listing_ids,
  :description,
  :sub_domain,
  :create_date,
  :last_updated_date,
  :notification_configuration,
  :worker_access_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#workforce_arnString

The Amazon Resource Name (ARN) of the workforce.

Returns:

  • (String)


55772
55773
55774
55775
55776
55777
55778
55779
55780
55781
55782
55783
55784
55785
55786
# File 'lib/aws-sdk-sagemaker/types.rb', line 55772

class Workteam < Struct.new(
  :workteam_name,
  :member_definitions,
  :workteam_arn,
  :workforce_arn,
  :product_listing_ids,
  :description,
  :sub_domain,
  :create_date,
  :last_updated_date,
  :notification_configuration,
  :worker_access_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#workteam_arnString

The Amazon Resource Name (ARN) that identifies the work team.

Returns:

  • (String)


55772
55773
55774
55775
55776
55777
55778
55779
55780
55781
55782
55783
55784
55785
55786
# File 'lib/aws-sdk-sagemaker/types.rb', line 55772

class Workteam < Struct.new(
  :workteam_name,
  :member_definitions,
  :workteam_arn,
  :workforce_arn,
  :product_listing_ids,
  :description,
  :sub_domain,
  :create_date,
  :last_updated_date,
  :notification_configuration,
  :worker_access_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#workteam_nameString

The name of the work team.

Returns:

  • (String)


55772
55773
55774
55775
55776
55777
55778
55779
55780
55781
55782
55783
55784
55785
55786
# File 'lib/aws-sdk-sagemaker/types.rb', line 55772

class Workteam < Struct.new(
  :workteam_name,
  :member_definitions,
  :workteam_arn,
  :workforce_arn,
  :product_listing_ids,
  :description,
  :sub_domain,
  :create_date,
  :last_updated_date,
  :notification_configuration,
  :worker_access_configuration)
  SENSITIVE = []
  include Aws::Structure
end