Class: Aws::SageMaker::Waiters::NotebookInstanceStopped
- Inherits:
-
Object
- Object
- Aws::SageMaker::Waiters::NotebookInstanceStopped
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-sagemaker/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ NotebookInstanceStopped
constructor
A new instance of NotebookInstanceStopped.
-
#wait(params = {}) ⇒ Types::DescribeNotebookInstanceOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ NotebookInstanceStopped
Returns a new instance of NotebookInstanceStopped.
518 519 |
# File 'lib/aws-sdk-sagemaker/waiters.rb', line 518
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
550 551 552 |
# File 'lib/aws-sdk-sagemaker/waiters.rb', line 550 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeNotebookInstanceOutput
Returns a response object which responds to the following methods:
- #notebook_instance_arn => String
- #notebook_instance_name => String
- #notebook_instance_status => String
- #failure_reason => String
- #url => String
- #instance_type => String
- #ip_address_type => String
- #subnet_id => String
- #security_groups => Array<String>
- #role_arn => String
- #kms_key_id => String
- #network_interface_id => String
- #last_modified_time => Time
- #creation_time => Time
- #notebook_instance_lifecycle_config_name => String
- #direct_internet_access => String
- #volume_size_in_gb => Integer
- #accelerator_types => Array<String>
- #default_code_repository => String
- #additional_code_repositories => Array<String>
- #root_access => String
- #platform_identifier => String
- #instance_metadata_service_configuration => Types::InstanceMetadataServiceConfiguration
545 |
# File 'lib/aws-sdk-sagemaker/waiters.rb', line 545
def wait: (
|