Class: Aws::SageMaker::Waiters::ProcessingJobCompletedOrStopped
- Inherits:
-
Object
- Object
- Aws::SageMaker::Waiters::ProcessingJobCompletedOrStopped
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-sagemaker/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ProcessingJobCompletedOrStopped
constructor
A new instance of ProcessingJobCompletedOrStopped.
-
#wait(params = {}) ⇒ Types::DescribeProcessingJobResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ProcessingJobCompletedOrStopped
Returns a new instance of ProcessingJobCompletedOrStopped.
562 563 |
# File 'lib/aws-sdk-sagemaker/waiters.rb', line 562
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
605 606 607 |
# File 'lib/aws-sdk-sagemaker/waiters.rb', line 605 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeProcessingJobResponse
Returns a response object which responds to the following methods:
- #processing_inputs => Array<Types::ProcessingInput>
- #processing_output_config => Types::ProcessingOutputConfig
- #processing_job_name => String
- #processing_resources => Types::ProcessingResources
- #stopping_condition => Types::ProcessingStoppingCondition
- #app_specification => Types::AppSpecification
- #environment => Hash<String,String>
- #network_config => Types::NetworkConfig
- #role_arn => String
- #experiment_config => Types::ExperimentConfig
- #processing_job_arn => String
- #processing_job_status => String
- #exit_message => String
- #failure_reason => String
- #processing_end_time => Time
- #processing_start_time => Time
- #last_modified_time => Time
- #creation_time => Time
- #monitoring_schedule_arn => String
- #auto_ml_job_arn => String
- #training_job_arn => String
600 |
# File 'lib/aws-sdk-sagemaker/waiters.rb', line 600
def wait: (
|